// 页面加载后执行
document.addEventListener('DOMContentLoaded', function() {
    // 表单验证
    const forms = document.querySelectorAll('form');
    
    forms.forEach(form => {
        form.addEventListener('submit', function(event) {
            const requiredInputs = form.querySelectorAll('[required]');
            let isValid = true;
            
            requiredInputs.forEach(input => {
                if (!input.value.trim()) {
                    isValid = false;
                    input.classList.add('is-invalid');
                    
                    // 添加抖动动画
                    input.style.animation = 'shake 0.5s';
                    setTimeout(() => {
                        input.style.animation = '';
                    }, 500);
                } else {
                    input.classList.remove('is-invalid');
                }
            });
            
            if (!isValid) {
                event.preventDefault();
                alert('请填写所有必填字段！');
            } else {
                // 如果是安装步骤，禁用按钮并显示加载状态
                const submitBtn = form.querySelector('button[type="submit"]');
                if (submitBtn && form.closest('.card-body')) {
                    submitBtn.disabled = true;
                    submitBtn.innerHTML = '<span class="spinner"></span> 处理中...';
                }
            }
        });
        
        // 增强表单交互
        const inputs = form.querySelectorAll('input, select');
        inputs.forEach(input => {
            // 聚焦效果
            input.addEventListener('focus', function() {
                this.parentElement.classList.add('focused');
            });
            
            input.addEventListener('blur', function() {
                this.parentElement.classList.remove('focused');
            });
            
            // 验证反馈
            input.addEventListener('input', function() {
                if (this.hasAttribute('required') && this.value.trim()) {
                    this.classList.remove('is-invalid');
                }
            });
        });
    });
    
    // 数据库表前缀处理
    const dbPrefixInput = document.getElementById('db_prefix');
    if (dbPrefixInput) {
        dbPrefixInput.addEventListener('blur', function() {
            let value = this.value.trim();
            if (value && value.charAt(value.length - 1) !== '_') {
                this.value = value + '_';
            }
        });
    }
    
    // 增强卡片悬停效果
    const cards = document.querySelectorAll('.card');
    cards.forEach(card => {
        card.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-8px)';
            this.style.boxShadow = '0 12px 30px rgba(0,0,0,0.15)';
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = 'translateY(-5px)';
            this.style.boxShadow = '0 8px 24px rgba(0,0,0,0.12)';
        });
    });
    
    // 添加动画样式
    const style = document.createElement('style');
    style.textContent = `
        @keyframes shake {
            0%, 100% { transform: translateX(0); }
            10%, 30%, 50%, 70%, 90% { transform: translateX(-5px); }
            20%, 40%, 60%, 80% { transform: translateX(5px); }
        }
        
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        
        .spinner {
            display: inline-block;
            width: 18px;
            height: 18px;
            border: 2px solid #fff;
            border-radius: 50%;
            border-top-color: transparent;
            animation: spin 1s linear infinite;
            margin-right: 8px;
            vertical-align: middle;
        }
        
        .focused {
            transform: translateX(5px);
            transition: transform 0.3s ease;
        }
        
        .is-invalid {
            border-color: var(--danger-color) !important;
        }
    `;
    document.head.appendChild(style);
}); 