<?php
/**
 * 网站安装向导
 */
error_reporting(E_ALL & ~E_NOTICE);
@set_time_limit(0);
header('Content-Type: text/html; charset=UTF-8');

define('INSTALL_PATH', dirname(__FILE__));
define('ROOT_PATH', dirname(INSTALL_PATH));
define('DS', DIRECTORY_SEPARATOR);

// 包含辅助函数
require_once(INSTALL_PATH . DS . 'functions.php');

// 安装锁定文件改为key.txt
$keyFile = ROOT_PATH . DS . 'Install' . DS . 'key.txt';

// 检查key.txt文件是否存在且为空
$canInstall = file_exists($keyFile) && file_get_contents($keyFile) === '';

// 如果key.txt不为空（已安装），则停止安装
if (!$canInstall && !isset($_GET['force'])) {
    die('网站已经安装过了！如果需要重新安装，请清空 key文件。');
}

// 如果是自动安装模式
if (isset($_POST['auto_install']) && $_POST['auto_install'] == 1) {
    // 设置必要的变量供自动安装模板使用
    $CMSName = isset($_POST['cms_name']) ? $_POST['cms_name'] : '网站内容管理系统';
    $CompanyFullName = isset($_POST['company_name']) ? $_POST['company_name'] : '公司名称';
    $CompanyUrl = isset($_POST['company_url']) ? $_POST['company_url'] : 'http://www.example.com';
    $Css = 'Tpl/Public/css';
    $Images = 'Tpl/Public/images';
    
    // 处理自动安装请求
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // 收集数据库信息
        $db = array(
            'host'     => $_POST['dbhost'],
            'name'     => $_POST['dbname'],
            'user'     => $_POST['dbuser'],
            'password' => $_POST['dbpw'],
            'prefix'   => $_POST['dbprefix'],
            'port'     => $_POST['dbport']
        );
        
        // 收集网站配置信息
        $config = array(
            'site_name'     => $CMSName,
            'site_url'      => isset($_POST['site_url']) ? $_POST['site_url'] : 'http://'.$_SERVER['HTTP_HOST'],
            'admin_user'    => $_POST['AdminName'],
            'admin_password'=> $_POST['pwd1'],
            'admin_email'   => isset($_POST['admin_email']) ? $_POST['admin_email'] : 'admin@example.com'
        );
        
        // 验证数据
        $dbErrors = validateDatabase($db);
        $configErrors = validateConfig($config);
        $errors = array_merge($dbErrors, $configErrors);
        
        if (empty($errors)) {
            // 保存配置
            $_SESSION['database'] = $db;
            $_SESSION['config'] = $config;
            
            // 创建数据库
            $conn = @mysqli_connect($db['host'], $db['user'], $db['password'], '', $db['port']);
            if (!$conn) {
                $ErrMsg = '无法连接到数据库服务器: ' . mysqli_connect_error();
                include(INSTALL_PATH . DS . 'Tpl' . DS . 'error.html');
                exit;
            }
            
            // 检查数据库是否存在，不存在则创建
            $dbExists = mysqli_select_db($conn, $db['name']);
            if (!$dbExists) {
                $sql = "CREATE DATABASE IF NOT EXISTS `" . $db['name'] . "` DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci";
                if (!mysqli_query($conn, $sql)) {
                    $ErrMsg = '无法创建数据库: ' . mysqli_error($conn);
                    include(INSTALL_PATH . DS . 'Tpl' . DS . 'error.html');
                    exit;
                }
            }
            
            mysqli_close($conn);
            
            // 执行其他安装步骤
            $steps = array('tables', 'data', 'admin', 'config', 'lock');
            
            foreach ($steps as $step) {
                // 调用install.php中的相应功能
                $url = 'install.php?step=' . $step;
                $result = json_decode(file_get_contents($url), true);
                
                if ($result['status'] !== 'success') {
                    $ErrMsg = '安装步骤 ' . $step . ' 失败: ' . $result['message'];
                    include(INSTALL_PATH . DS . 'Tpl' . DS . 'error.html');
                    exit;
                }
            }
            
            // 安装成功后跳转
            header('Location: ?step=complete');
            exit;
        } else {
            // 显示错误信息
            $ErrMsg = implode('<br>', $errors);
            include(INSTALL_PATH . DS . 'Tpl' . DS . 'error.html');
            exit;
        }
    }
    
    // 显示自动安装表单
    include(INSTALL_PATH . DS . 'Tpl' . DS . 'auto_install.html');
    exit;
}

// 安装步骤
$steps = array(
    'welcome'   => '欢迎使用',
    'check'     => '环境检查',
    'database'  => '数据库配置',
    'config'    => '网站配置',
    'install'   => '安装进度',
    'complete'  => '安装完成'
);

// 当前步骤
$step = isset($_GET['step']) ? $_GET['step'] : 'welcome';
if (!isset($steps[$step])) {
    $step = 'welcome';
}

// 模板变量
$vars = array(
    'steps' => $steps,
    'current_step' => $step,
    'title' => '网站安装向导 - ' . $steps[$step]
);

// 处理不同步骤的逻辑
switch ($step) {
    case 'check':
        // 检查环境要求
        $vars['requirements'] = checkRequirements();
        $vars['directories'] = checkDirectories();
        $vars['functions'] = checkFunctions();
        $vars['can_install'] = canInstall($vars);
        break;
        
    case 'database':
        // 如果没有通过环境检查，不允许进入下一步
        if (!isset($_SESSION['env_checked']) || $_SESSION['env_checked'] !== true) {
            if (!canInstallFromCheck()) {
                redirect('?step=check');
                exit;
            }
            $_SESSION['env_checked'] = true;
        }
        
        // 表单提交处理
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $db = array(
                'host'     => $_POST['db_host'],
                'name'     => $_POST['db_name'],
                'user'     => $_POST['db_user'],
                'password' => $_POST['db_password'],
                'prefix'   => $_POST['db_prefix'],
                'port'     => $_POST['db_port']
            );
            
            // 验证数据库连接
            $errors = validateDatabase($db);
            
            if (empty($errors)) {
                $_SESSION['database'] = $db;
                redirect('?step=config');
                exit;
            }
            
            $vars['errors'] = $errors;
            $vars['db'] = $db;
        }
        break;
        
    case 'config':
        // 确保数据库配置已完成
        if (!isset($_SESSION['database'])) {
            redirect('?step=database');
            exit;
        }
        
        // 表单提交处理
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $config = array(
                'site_name'     => $_POST['site_name'],
                'site_url'      => $_POST['site_url'],
                'admin_user'    => $_POST['admin_user'],
                'admin_password'=> $_POST['admin_password'],
                'admin_email'   => $_POST['admin_email']
            );
            
            $errors = validateConfig($config);
            
            if (empty($errors)) {
                $_SESSION['config'] = $config;
                redirect('?step=install');
                exit;
            }
            
            $vars['errors'] = $errors;
            $vars['config'] = $config;
        }
        break;
        
    case 'install':
        // 确保配置已完成
        if (!isset($_SESSION['database']) || !isset($_SESSION['config'])) {
            redirect('?step=welcome');
            exit;
        }
        
        $vars['database'] = $_SESSION['database'];
        $vars['config'] = $_SESSION['config'];
        break;
        
    case 'complete':
        // 检查是否已完成安装
        if (!file_exists($keyFile)) {
            redirect('?step=welcome');
            exit;
        }
        break;
}

// 加载模板
require_once(INSTALL_PATH . DS . 'templates' . DS . 'header.php');
require_once(INSTALL_PATH . DS . 'templates' . DS . $step . '.php');
require_once(INSTALL_PATH . DS . 'templates' . DS . 'footer.php');
