<?php
/**
 * 执行安装过程
 */
error_reporting(E_ALL & ~E_NOTICE);
@set_time_limit(0);
header('Content-Type: application/json; charset=UTF-8');

// 开启会话
session_start();

define('INSTALL_PATH', dirname(__FILE__));
define('ROOT_PATH', dirname(INSTALL_PATH));
define('DS', DIRECTORY_SEPARATOR);

// 包含辅助函数
require_once(INSTALL_PATH . DS . 'functions.php');

// 检查必要的参数
if (!isset($_SESSION['database']) || !isset($_SESSION['config'])) {
    die(json_encode(array('status' => 'error', 'message' => '安装参数错误')));
}

$db = $_SESSION['database'];
$config = $_SESSION['config'];

$steps = array(
    'database' => '创建数据库',
    'tables' => '创建数据表',
    'data' => '导入初始数据',
    'admin' => '创建管理员账号',
    'config' => '写入配置文件',
    'lock' => '创建安装锁定文件'
);

$step = isset($_GET['step']) ? $_GET['step'] : '';

if (!isset($steps[$step])) {
    die(json_encode(array('status' => 'error', 'message' => '未知安装步骤')));
}

// 执行安装步骤
try {
    switch ($step) {
        case 'database':
            // 创建数据库连接
            $conn = @mysqli_connect($db['host'], $db['user'], $db['password'], '', $db['port']);
            if (!$conn) {
                throw new Exception('无法连接到数据库服务器: ' . mysqli_connect_error());
            }
            
            // 检查数据库是否存在，不存在则创建
            $dbExists = mysqli_select_db($conn, $db['name']);
            if (!$dbExists) {
                $sql = "CREATE DATABASE IF NOT EXISTS `" . $db['name'] . "` DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci";
                if (!mysqli_query($conn, $sql)) {
                    throw new Exception('无法创建数据库: ' . mysqli_error($conn));
                }
            }
            
            mysqli_close($conn);
            break;
            
        case 'tables':
            // 导入数据表结构 - 查找最新的SQL结构文件
            $sqlFiles = glob(ROOT_PATH . DS . 'Data' . DS . 'structure_*.sql');
            if (!empty($sqlFiles)) {
                // 按时间排序找到最新的
                usort($sqlFiles, function($a, $b) {
                    return filemtime($b) - filemtime($a);
                });
                $sqlFile = $sqlFiles[0]; // 使用最新的文件
            } else {
                $sqlFile = ROOT_PATH . DS . 'Data' . DS . 'tables.sql'; // 默认文件名
            }
            
            $result = executeSqlFile($sqlFile, $db);
            if ($result !== true) {
                throw new Exception($result[0]);
            }
            break;
            
        case 'data':
            // 导入初始数据 - 查找最新的SQL数据文件
            $sqlFiles = glob(ROOT_PATH . DS . 'Data' . DS . 'data_*.sql');
            if (!empty($sqlFiles)) {
                // 按时间排序找到最新的
                usort($sqlFiles, function($a, $b) {
                    return filemtime($b) - filemtime($a);
                });
                $sqlFile = $sqlFiles[0]; // 使用最新的文件
            } else {
                $sqlFile = ROOT_PATH . DS . 'Data' . DS . 'data.sql'; // 默认文件名
            }
            
            $result = executeSqlFile($sqlFile, $db);
            if ($result !== true) {
                throw new Exception($result[0]);
            }
            break;
            
        case 'admin':
            // 创建管理员账号
            $conn = @mysqli_connect($db['host'], $db['user'], $db['password'], $db['name'], $db['port']);
            if (!$conn) {
                throw new Exception('无法连接到数据库: ' . mysqli_connect_error());
            }
            
            // 设置编码
            mysqli_set_charset($conn, 'utf8mb4');
            
            // 检查管理员表是否存在
            $adminTable = $db['prefix'] . 'admin';
            $sql = "SHOW TABLES LIKE '{$adminTable}'";
            $result = mysqli_query($conn, $sql);
            
            if (!$result || mysqli_num_rows($result) == 0) {
                throw new Exception('管理员表不存在');
            }
            
            // 创建管理员账号
            $username = mysqli_real_escape_string($conn, $config['admin_user']);
            $password = password_hash($config['admin_password'], PASSWORD_DEFAULT);
            $email = mysqli_real_escape_string($conn, $config['admin_email']);
            
            // 检查是否已有管理员
            $sql = "SELECT COUNT(*) FROM `{$adminTable}`";
            $result = mysqli_query($conn, $sql);
            $row = mysqli_fetch_array($result);
            
            if ($row[0] > 0) {
                // 更新已有管理员
                $sql = "UPDATE `{$adminTable}` SET `username`='{$username}', `password`='{$password}', `email`='{$email}', `create_time`=NOW(), `update_time`=NOW() WHERE `id`=1";
            } else {
                // 创建新管理员
                $sql = "INSERT INTO `{$adminTable}` (`username`, `password`, `email`, `create_time`, `update_time`) VALUES ('{$username}', '{$password}', '{$email}', NOW(), NOW())";
            }
            
            if (!mysqli_query($conn, $sql)) {
                throw new Exception('创建管理员账号失败: ' . mysqli_error($conn));
            }
            
            mysqli_close($conn);
            break;
            
        case 'config':
            // 写入配置文件
            if (!writeConfig($db, $config)) {
                throw new Exception('写入配置文件失败');
            }
            break;
            
        case 'lock':
            // 创建安装锁定文件
            if (!createLockFile()) {
                throw new Exception('创建安装锁定文件失败');
            }
            break;
    }
    
    die(json_encode(array('status' => 'success', 'message' => $steps[$step] . '完成')));
} catch (Exception $e) {
    die(json_encode(array('status' => 'error', 'message' => $e->getMessage())));
} 
