<div class="card">
    <div class="card-header">
        <h2 class="card-title">正在安装</h2>
    </div>
    <div class="card-body">
        <div class="progress">
            <div class="progress-bar" id="progress-bar" style="width: 0%;">0%</div>
        </div>
        
        <div id="install-log" class="mt-3">
            <p>开始安装，请稍候...</p>
        </div>
        
        <div class="buttons" id="buttons" style="display: none;">
            <div>&nbsp;</div>
            <a href="?step=complete" class="btn btn-success">完成安装</a>
        </div>
    </div>
</div>

<script>
(function() {
    // 安装步骤
    const steps = [
        { id: 'database', name: '创建数据库' },
        { id: 'tables', name: '创建数据表' },
        { id: 'data', name: '导入初始数据' },
        { id: 'admin', name: '创建管理员账号' },
        { id: 'config', name: '写入配置文件' },
        { id: 'lock', name: '创建安装锁定文件' }
    ];
    
    const progressBar = document.getElementById('progress-bar');
    const installLog = document.getElementById('install-log');
    const buttons = document.getElementById('buttons');
    
    let currentStep = 0;
    const stepCount = steps.length;
    
    // 执行下一步安装
    function executeNextStep() {
        if (currentStep >= stepCount) {
            // 安装完成
            updateProgress(100);
            installLog.innerHTML += '<p class="text-success">✓ 安装完成！</p>';
            buttons.style.display = 'flex';
            return;
        }
        
        const step = steps[currentStep];
        const progress = Math.floor((currentStep / stepCount) * 100);
        
        updateProgress(progress);
        installLog.innerHTML += `<p>正在执行: ${step.name}...</p>`;
        
        // 发送AJAX请求
        fetch(`install.php?step=${step.id}`)
            .then(response => response.json())
            .then(data => {
                if (data.status === 'success') {
                    installLog.innerHTML += `<p class="text-success">✓ ${step.name}完成</p>`;
                    currentStep++;
                    executeNextStep();
                } else {
                    installLog.innerHTML += `<p class="text-danger">✗ ${step.name}失败: ${data.message}</p>`;
                    buttons.style.display = 'flex';
                }
            })
            .catch(error => {
                installLog.innerHTML += `<p class="text-danger">✗ 执行错误: ${error.message}</p>`;
                buttons.style.display = 'flex';
            });
    }
    
    // 更新进度条
    function updateProgress(progress) {
        progressBar.style.width = progress + '%';
        progressBar.textContent = progress + '%';
    }
    
    // 开始安装
    setTimeout(executeNextStep, 500);
})();
</script> 