<?php
/**
 * 合作伙伴页面
 * 展示所有合作伙伴分类和链接
 */

// 定义ROOT_PATH常量
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', __DIR__);
}

include ROOT_PATH . '/public/config.php';

// 引入数据库连接
require_once ROOT_PATH . '/config/database.php';

// 获取数据库连接
$db = getDbConnection();

// 获取所有启用的分类，按排序顺序
$stmt = $db->prepare("SELECT * FROM alliance_category WHERE status = 1 ORDER BY sort_order, id");
$stmt->execute();
$categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 为每个分类加载对应的链接
foreach ($categories as &$category) {
    $stmt = $db->prepare("SELECT * FROM alliance_link WHERE category_id = ? AND status = 1 ORDER BY sort_order, id");
    $stmt->execute([$category['id']]);
    $category['links'] = $stmt->fetchAll(PDO::FETCH_ASSOC);
}
unset($category); // 取消引用
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>合作伙伴 - 服务器行业精选伙伴推荐 | 互惠共赢合作平台</title>
    <meta name="keywords" content="服务器合作伙伴,云服务合作伙伴,高防服务器推荐,站群服务器联盟,服务器行业合作,云计算联盟,技术服务合作,服务器资源共享,服务器供应商推荐">
    <meta name="description" content="加入我们的服务器合作伙伴，连接全球优质服务器供应商与技术合作伙伴。我们精选推荐高防服务器、云服务器、站群服务器等资源提供商，提供真机测试和换退保障，打造互利共赢的服务器行业生态圈。">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="/public/css/style.css" rel="stylesheet">
    <link href="/public/css/breadcrumb.css" rel="stylesheet">
    <link href="/public/css/alliance.css" rel="stylesheet">
  </head>
  <body>
    <!-- 顶部导航 --> <?php include ROOT_PATH . '/public/header.php'; ?>
    <!-- Banner 区域 --> <?php include ROOT_PATH . '/public/banner.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <div class="alliance-wrapper">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/">首页</a>
            <i class="material-icons">chevron_right</i>
            <span>合作伙伴</span>
          </div>
        </div>
        <!-- 页面标题区域 -->
        <div class="promo-section">
          <div class="promo-title">
            <svg class="" viewBox="0 0 24 24" width="35" height="30">
              <path fill="#ff6600" d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27z" />
            </svg>
            <span class="promo-title-text with-underline">合作伙伴</span>
          </div>
          <div class="promo-desc"> 品质保证合作伙伴，共同为客户提供优质的服务器解决方案 </div>
        </div>
        <!-- 合作伙伴内容 -->
        <div class="alliance-content"> <?php foreach ($categories as $category): ?>
          <!-- <?php echo htmlspecialchars($category['name']); ?> -->
          <div class="alliance-section">
            <div class="alliance-header">
              <h2 class="section-title"><?php echo htmlspecialchars($category['name']); ?></h2>
              <div class="section-subtitle"><?php echo htmlspecialchars($category['subtitle']); ?></div>
            </div>
            <div class="alliance-grid"> <?php foreach ($category['links'] as $link): ?> <a href="<?php echo htmlspecialchars($link['url'] ?: '#'); ?>" class="alliance-item"
                 <?php if ($link['url'] && strpos($link['url'], 'http') === 0): ?>target="_blank" <?php endif; ?>
                 <?php if ($link['description']): ?>title="<?php echo htmlspecialchars($link['description']); ?>" <?php endif; ?>> <?php echo htmlspecialchars($link['name']); ?> </a> <?php endforeach; ?> </div>
          </div> <?php endforeach; ?>
          <!-- 加入联盟 -->
        </div>
      </div>
    </div>
    <!-- 页脚 --> <?php include ROOT_PATH . '/public/kf.php'; ?> <?php include ROOT_PATH . '/public/footer.php'; ?>
    <!-- 引入JavaScript文件 -->
    <script src="/public/js/js.js"></script>
  </body>
</html>
