<?php
/**
 * 获取脚本数据的API接口
 * 根据分类ID返回对应的脚本列表
 */

// 设置响应头
header('Content-Type: application/json; charset=utf-8');

// 引入数据库配置文件
require_once '../config/database.php';

// 获取分类ID参数
$categoryId = isset($_GET['category_id']) ? intval($_GET['category_id']) : 0;

// 验证分类ID
if ($categoryId <= 0) {
    echo json_encode([
        'success' => false,
        'message' => '无效的分类ID',
        'scripts' => []
    ]);
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 查询指定分类的脚本
    $scriptsQuery = "SELECT * FROM scripts WHERE category_id = ? AND status = 1 ORDER BY sort_order ASC";
    $scriptsStmt = $db->prepare($scriptsQuery);
    $scriptsStmt->execute([$categoryId]);
    $scripts = $scriptsStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 返回脚本数据
    echo json_encode([
        'success' => true,
        'scripts' => $scripts
    ]);
    
} catch (PDOException $e) {
    // 记录错误日志
    error_log("获取脚本数据出错: " . $e->getMessage());
    
    // 返回错误信息
    echo json_encode([
        'success' => false,
        'message' => '获取脚本数据失败',
        'scripts' => []
    ]);
}
?> 