<?php
/**
 * 视频观看次数统计API
 * 
 * 接收POST请求，增加视频的观看次数
 */

// 设置JSON响应头
header('Content-Type: application/json');

// 引入数据库配置
require_once __DIR__ . '/../config/database.php';

// 检查是否是POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode([
        'success' => false,
        'message' => '仅接受POST请求'
    ]);
    exit;
}

try {
    // 获取请求体数据
    $inputJSON = file_get_contents('php://input');
    $input = json_decode($inputJSON, true);
    
    // 验证参数
    if (!isset($input['videoId']) || !is_numeric($input['videoId'])) {
        echo json_encode([
            'success' => false,
            'message' => '缺少有效的视频ID参数'
        ]);
        exit;
    }
    
    $videoId = intval($input['videoId']);
    
    // 获取数据库连接
    $db = getDbConnection();
    
    // 检查视频是否存在
    $stmt = $db->prepare("SELECT id FROM videos WHERE id = ? LIMIT 1");
    $stmt->execute([$videoId]);
    
    if (!$stmt->fetch()) {
        echo json_encode([
            'success' => false,
            'message' => '视频不存在'
        ]);
        exit;
    }
    
    // 更新视频浏览量
    $stmt = $db->prepare("UPDATE videos SET views = views + 1 WHERE id = ?");
    $stmt->execute([$videoId]);
    
    // 返回成功响应
    echo json_encode([
        'success' => true,
        'message' => '视频浏览量已更新',
        'data' => [
            'videoId' => $videoId
        ]
    ]);
    
} catch (Exception $e) {
    // 记录错误
    error_log('视频播放量更新错误: ' . $e->getMessage());
    
    // 返回错误响应
    echo json_encode([
        'success' => false,
        'message' => '系统错误，请稍后再试'
    ]);
} 