<?php
/**
 * 合作伙伴分类表单页面
 * 用于添加和编辑合作伙伴分类
 */

// 引入认证检查文件
require_once 'code/auth_check.php';

// 引入数据库连接
require_once '../config/database.php';
$db = getDbConnection();

// 初始化变量
$message = '';
$messageType = '';
$category = [
    'id' => '',
    'name' => '',
    'code' => '',
    'subtitle' => '',
    'status' => 1,
    'sort_order' => 0
];
$isEdit = false;

// 检查是否是编辑模式
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $isEdit = true;
    $pageTitle = "编辑合作伙伴分类";
    
    // 获取分类数据
    try {
        $stmt = $db->prepare("SELECT * FROM alliance_category WHERE id = ?");
        $stmt->execute([$_GET['id']]);
        $category = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$category) {
            $message = "未找到指定的分类！";
            $messageType = 'danger';
        }
    } catch (PDOException $e) {
        $message = "获取分类数据失败: " . $e->getMessage();
        $messageType = 'danger';
    }
} else {
    $pageTitle = "添加合作伙伴分类";
}

// 处理表单提交
if (isset($_POST['action']) && $_POST['action'] == 'save_category') {
    try {
        if ($isEdit) {
            // 更新分类
            $stmt = $db->prepare("UPDATE alliance_category SET name = ?, code = ?, subtitle = ?, status = ?, sort_order = ? WHERE id = ?");
            $stmt->execute([
                $_POST['name'],
                $_POST['code'],
                $_POST['subtitle'],
                $_POST['status'],
                $_POST['sort_order'],
                $_GET['id']
            ]);
            $message = "分类更新成功！";
        } else {
            // 添加新分类
            $stmt = $db->prepare("INSERT INTO alliance_category (name, code, subtitle, status, sort_order) VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([
                $_POST['name'],
                $_POST['code'],
                $_POST['subtitle'],
                $_POST['status'],
                $_POST['sort_order']
            ]);
            $message = "新分类添加成功！";
        }
        $messageType = 'success';
    } catch (PDOException $e) {
        $message = "操作失败: " . $e->getMessage();
        $messageType = 'danger';
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@6.0.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/index.css">
    <link rel="stylesheet" href="public/css/alliance.css">
    <style>
        body {
            font-size: 14px;
            background-color: #f5f7fa;
        }
        .card {
            margin-bottom: 20px;
            border: none;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }
        .card-header {
            background-color: #fff;
            border-bottom: 1px solid #eee;
            padding: 1rem;
            font-weight: 500;
        }
        .card-body {
            padding: 1rem;
        }
        .form-text {
            font-size: 0.85rem;
            color: #6c757d;
        }
        .form-control,
        .form-select {
            font-size: 0.875rem;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        .form-control:focus,
        .form-select:focus {
            border-color: var(--primary-color);
            box-shadow: 0 0 0 2px rgba(24, 144, 255, 0.2);
        }
        .main-content {
            padding: 20px;
        }
    </style>
</head>
<body class="bg-light">
    <?php include 'public/header.php'; ?>
    <div class="container-fluid">
        <div class="row">
            <?php include 'public/letf.php'; ?>
            <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4 main-content">
                <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                    <h1 class="h2"><?php echo $pageTitle; ?></h1>
                    <div class="btn-toolbar mb-2 mb-md-0">
                        <div class="btn-group me-2">
                            <a href="alliance_management.php" class="btn btn-sm btn-outline-secondary">
                                <i class="fas fa-list"></i> 返回列表
                            </a>
                        </div>
                    </div>
                </div>

                <?php if ($message): ?>
                <div class="alert alert-<?php echo $messageType; ?> alert-dismissible fade show" role="alert">
                    <?php echo $message; ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
                <?php endif; ?>

                <div class="card">
                    <div class="card-header"><?php echo $isEdit ? '编辑分类' : '添加新分类'; ?></div>
                    <div class="card-body">
                        <form method="post" action="">
                            <input type="hidden" name="action" value="save_category">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="mb-3">
                                        <label for="name" class="form-label">分类名称</label>
                                        <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($category['name']); ?>" required>
                                    </div>
                                    <div class="mb-3">
                                        <label for="code" class="form-label">分类代码</label>
                                        <input type="text" class="form-control" id="code" name="code" value="<?php echo htmlspecialchars($category['code']); ?>" required>
                                        <div class="form-text">唯一标识符，建议使用英文</div>
                                    </div>
                                    <div class="mb-3">
                                        <label for="subtitle" class="form-label">副标题/描述</label>
                                        <input type="text" class="form-control" id="subtitle" name="subtitle" value="<?php echo htmlspecialchars($category['subtitle']); ?>">
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="mb-3">
                                        <label for="sort_order" class="form-label">排序顺序</label>
                                        <input type="number" class="form-control" id="sort_order" name="sort_order" value="<?php echo $category['sort_order']; ?>">
                                        <div class="form-text">数值越小排序越靠前</div>
                                    </div>
                                    <div class="mb-3">
                                        <label for="status" class="form-label">状态</label>
                                        <select class="form-select" id="status" name="status">
                                            <option value="1" <?php echo $category['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                            <option value="0" <?php echo $category['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                                        </select>
                                    </div>
                                </div>
                            </div>
                            <div class="d-flex justify-content-end gap-2">
                                <button type="submit" class="btn btn-primary"><?php echo $isEdit ? '保存修改' : '保存分类'; ?></button>
                                <a href="alliance_management.php" class="btn btn-outline-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                </div>
            </main>
        </div>
    </div>
</body>
</html> 