<?php
/**
 * 合作伙伴链接编辑页面
 */

// 引入认证检查文件
require_once 'code/auth_check.php';

// 引入数据库连接
require_once '../config/database.php';
$db = getDbConnection();

// 设置页面标题
$pageTitle = "编辑合作伙伴链接";

// 处理表单提交
$message = '';
$messageType = '';

// 处理链接操作
if (isset($_POST['action']) && $_POST['action'] == 'save_link') {
    try {
        // 检查是否为编辑操作
        if (!empty($_POST['link_id'])) {
            // 更新现有链接
            $stmt = $db->prepare("UPDATE alliance_link SET category_id = ?, name = ?, url = ?, logo = ?, description = ?, status = ?, sort_order = ? WHERE id = ?");
            $stmt->execute([
                $_POST['category_id'],
                $_POST['name'],
                $_POST['url'],
                $_POST['logo'],
                $_POST['description'],
                $_POST['status'],
                $_POST['sort_order'],
                $_POST['link_id']
            ]);
            $message = "链接更新成功！";
        } else {
            // 添加新链接
            $stmt = $db->prepare("INSERT INTO alliance_link (category_id, name, url, logo, description, status, sort_order) VALUES (?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([
                $_POST['category_id'],
                $_POST['name'],
                $_POST['url'],
                $_POST['logo'],
                $_POST['description'],
                $_POST['status'],
                $_POST['sort_order']
            ]);
            $message = "新链接添加成功！";
        }
        $messageType = 'success';
        // 添加成功后重定向到列表页
        header('Location: alliance_links.php?message=' . urlencode($message) . '&type=' . $messageType);
        exit;
    } catch (PDOException $e) {
        $message = "操作失败: " . $e->getMessage();
        $messageType = 'danger';
    }
}

// 获取分类数据
$categories = $db->query("SELECT * FROM alliance_category ORDER BY sort_order, id")->fetchAll(PDO::FETCH_ASSOC);

// 加载编辑的链接数据
$editLink = null;
if (isset($_GET['id'])) {
    $stmt = $db->prepare("SELECT * FROM alliance_link WHERE id = ?");
    $stmt->execute([$_GET['id']]);
    $editLink = $stmt->fetch(PDO::FETCH_ASSOC);
}

?>
<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@6.0.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/index.css">
    <link rel="stylesheet" href="public/css/alliance.css">
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            font-size: 14px;
            background-color: #f5f7fa;
            padding-top: 60px;
        }
        .card {
            margin-bottom: 20px;
            border: none;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }
        .card-header {
            background-color: #fff;
            border-bottom: 1px solid #eee;
            padding: 1rem;
            font-weight: 500;
        }
        .card-body {
            padding: 1rem;
        }
        .form-text {
            font-size: 0.85rem;
            color: #6c757d;
        }
        .main-content {
            padding: 20px;
            max-width: 800px;
            margin: 0 auto;
        }
    </style>
</head>
<body class="bg-light">
    <?php include 'public/header.php'; ?>
    <div class="container-fluid">
        <div class="row">
            <?php include 'public/letf.php'; ?>
            <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4 main-content">
                <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                    <h1 class="h2"><?php echo $editLink ? '编辑链接' : '添加新链接'; ?></h1>
                    <div class="btn-toolbar mb-2 mb-md-0">
                        <div class="btn-group me-2">
                            <a href="alliance_links.php" class="btn btn-sm btn-outline-secondary">
                                <i class="fas fa-arrow-left"></i> 返回列表
                            </a>
                        </div>
                    </div>
                </div>

                <?php if ($message): ?>
                <div class="alert alert-<?php echo $messageType; ?> alert-dismissible fade show" role="alert">
                    <?php echo $message; ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
                <?php endif; ?>

                <div class="card">
                    <div class="card-body">
                        <form method="post" action="">
                            <input type="hidden" name="action" value="save_link">
                            <?php if ($editLink): ?>
                            <input type="hidden" name="link_id" value="<?php echo $editLink['id']; ?>">
                            <?php endif; ?>

                            <div class="mb-3">
                                <label for="category_id" class="form-label">所属分类</label>
                                <select class="form-select" id="category_id" name="category_id" required>
                                    <option value="">请选择分类</option>
                                    <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category['id']; ?>" <?php echo $editLink && $editLink['category_id'] == $category['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($category['name']); ?>
                                    </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="mb-3">
                                <label for="name" class="form-label">链接名称</label>
                                <input type="text" class="form-control" id="name" name="name" value="<?php echo $editLink ? htmlspecialchars($editLink['name']) : ''; ?>" required>
                            </div>

                            <div class="mb-3">
                                <label for="url" class="form-label">链接URL</label>
                                <input type="text" class="form-control" id="url" name="url" value="<?php echo $editLink ? htmlspecialchars($editLink['url']) : ''; ?>">
                            </div>

                            <div class="mb-3">
                                <label for="logo" class="form-label">LOGO图片路径</label>
                                <input type="text" class="form-control" id="logo" name="logo" value="<?php echo $editLink ? htmlspecialchars($editLink['logo']) : ''; ?>">
                            </div>

                            <div class="mb-3">
                                <label for="description" class="form-label">链接描述</label>
                                <textarea class="form-control" id="description" name="description" rows="3"><?php echo $editLink ? htmlspecialchars($editLink['description']) : ''; ?></textarea>
                            </div>

                            <div class="mb-3">
                                <label for="sort_order" class="form-label">排序顺序</label>
                                <input type="number" class="form-control" id="sort_order" name="sort_order" value="<?php echo $editLink ? $editLink['sort_order'] : '0'; ?>">
                                <div class="form-text">数值越小排序越靠前</div>
                            </div>

                            <div class="mb-3">
                                <label for="status" class="form-label">状态</label>
                                <select class="form-select" id="status" name="status">
                                    <option value="1" <?php echo $editLink && $editLink['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                    <option value="0" <?php echo $editLink && $editLink['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                                </select>
                            </div>

                            <div class="d-grid gap-2">
                                <button type="submit" class="btn btn-primary">保存链接</button>
                                <a href="alliance_links.php" class="btn btn-outline-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                </div>
            </main>
        </div>
    </div>
</body>
</html> 