<?php
/**
 * 商业联盟分类管理页面
 * 用于管理商业联盟分类
 */

// 引入认证检查文件
require_once 'code/auth_check.php';

// 引入数据库连接
require_once '../config/database.php';
$db = getDbConnection();

// 设置页面标题
$pageTitle = "商业联盟分类管理";

// 处理删除分类操作
$message = '';
$messageType = '';

if (isset($_GET['action']) && $_GET['action'] == 'delete_category' && isset($_GET['id'])) {
    try {
        $stmt = $db->prepare("DELETE FROM alliance_category WHERE id = ?");
        $stmt->execute([$_GET['id']]);
        $message = "分类删除成功！";
        $messageType = 'success';
    } catch (PDOException $e) {
        $message = "删除失败: " . $e->getMessage();
        $messageType = 'danger';
    }
}

// 获取分类数据
$categories = $db->query("SELECT * FROM alliance_category ORDER BY sort_order, id")->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@6.0.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/index.css">
    <link rel="stylesheet" href="public/css/alliance.css">
    <style>
    .alliance-management {
      padding-top: 60px;
    }

    .alliance-management .table-responsive {
      min-height: 300px;
      background: #fff;
      border-radius: 4px;
      padding: 1rem;
    }

    .alliance-management .card {
      border: none;
      box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .alliance-management .card-header {
      background-color: #fff;
      border-bottom: 1px solid #eee;
      padding: 1rem;
      font-weight: 500;
    }

    .alliance-management .card-body {
      padding: 1rem;
    }

    .alliance-management .table th,
    .alliance-management .table td {
      padding: 0.75rem;
      vertical-align: middle;
      border-bottom: 1px solid #eee;
    }

    .alliance-management .table thead th {
      background: #fafafa;
      font-weight: 500;
      border-bottom: 1px solid #eee;
    }

    .alliance-management .badge {
      font-size: 0.85rem;
      padding: 0.35em 0.65em;
    }

    .alliance-management .main-content {
      padding: 20px;
    }

    .alliance-management-header {
      background: #fff;
      margin-bottom: 20px;
      padding: 15px;
      border-radius: 4px;
      box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    /* Basic body styles */
    body {
      font-size: 14px;
      background-color: #f5f7fa;
    }

    </style>
  </head>
  <body class="bg-light"> <?php include 'public/header.php'; ?> <div class="container-fluid alliance-management">
      <div class="row"> <?php include 'public/letf.php'; ?> <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4 main-content">
          <div class="alliance-management-header">
            <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center">
              <h1 class="h2 mb-0">商业联盟分类管理</h1>
              <div class="btn-toolbar mb-2 mb-md-0">
                <div class="btn-group me-2">
                  <a href="alliance_category_form.php" class="btn btn-sm btn-primary">
                    <i class="fas fa-plus"></i> 添加分类 </a>
                </div>
              </div>
            </div>
          </div> <?php if ($message): ?> <div class="alert alert-<?php echo $messageType; ?> alert-dismissible fade show" role="alert"> <?php echo $message; ?> <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
          </div> <?php endif; ?> <div class="card">
            <div class="card-header">分类列表</div>
            <div class="card-body">
              <div class="table-responsive">
                <table class="table">
                  <thead>
                    <tr>
                      <th>ID</th>
                      <th>名称</th>
                      <th>代码</th>
                      <th>副标题</th>
                      <th>排序</th>
                      <th>状态</th>
                      <th>操作</th>
                    </tr>
                  </thead>
                  <tbody> <?php foreach ($categories as $category): ?> <tr>
                      <td><?php echo $category['id']; ?></td>
                      <td><?php echo htmlspecialchars($category['name']); ?></td>
                      <td><?php echo htmlspecialchars($category['code']); ?></td>
                      <td><?php echo htmlspecialchars($category['subtitle']); ?></td>
                      <td><?php echo $category['sort_order']; ?></td>
                      <td>
                        <span class="badge bg-<?php echo $category['status'] ? 'success' : 'secondary'; ?>"> <?php echo $category['status'] ? '启用' : '禁用'; ?> </span>
                      </td>
                      <td>
                        <a href="alliance_category_form.php?action=edit&id=<?php echo $category['id']; ?>" class="btn btn-sm btn-outline-primary">编辑 </a>
                        <a href="?action=delete_category&id=<?php echo $category['id']; ?>" class="btn btn-sm btn-outline-danger" onclick="return confirm('确定要删除此分类吗？')">删除</a>
                      </td>
                    </tr> <?php endforeach; ?> </tbody>
                </table>
              </div>
            </div>
          </div>
        </main>
      </div>
    </div>
  </body>
</html>
