<?php
require_once '../../config/database.php';

// 获取POST数据
$data = json_decode(file_get_contents('php://input'), true);

if (!isset($data['product_ids']) || !isset($data['tags'])) {
    echo json_encode(['success' => false, 'message' => '参数错误']);
    exit;
}

try {
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 准备更新语句
    $tags = implode(',', $data['tags']);
    $stmt = $db->prepare("UPDATE products SET tags = :tags WHERE id = :id");
    
    // 批量更新每个产品的标签
    foreach ($data['product_ids'] as $productId) {
        $stmt->execute([
            ':tags' => $tags,
            ':id' => $productId
        ]);
    }
    
    // 提交事务
    $db->commit();
    
    echo json_encode(['success' => true]);
} catch (Exception $e) {
    // 发生错误时回滚事务
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    echo json_encode(['success' => false, 'message' => $e->getMessage()]);
} 