<?php
require_once 'code/auth_check.php';
define('INCLUDED_FROM_VIEW', true);
require_once 'code/area_code.php';
?>

<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>地区管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/area.css">
    <style>
    /* 筛选区域样式 */
    .filter {
      display: flex;
      align-items: center;
      gap: 10px;
    }

    .select-filter {
      padding: 8px;
      border-radius: 4px;
      border: 1px solid #ddd;
      min-width: 150px;
    }

    .btn-search {
      padding: 8px 16px;
      background-color: #4a90e2;
      color: white;
      border: none;
      border-radius: 4px;
      cursor: pointer;
    }

    .btn-search:hover {
      background-color: #3a80d2;
    }

    </style>
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>
      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-area-btn">+ 添加地区</button>
          <button class="btn btn-secondary" id="save-all-btn">保存所有修改</button>
        </div>
        <div class="filter">
          <select class="select-filter" id="parent-filter">
            <option value="0">父级地区</option>
            <option value="-1">不限</option>
            <?php
            foreach ($parentAreas as $parent) {
              echo "<option value=\"{$parent['id']}\">{$parent['name']}</option>";
            }
            ?>
          </select>
          <select class="select-filter" id="region-filter">
            <option value="0">大区域</option>
            <option value="-1">不限</option>
            <option value="1">亚太地区</option>
            <option value="2">欧洲地区</option>
            <option value="3">美洲地区</option>
            <option value="4">中东非洲</option>
            <option value="null">未设置</option>
          </select>
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>
      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>地区ID</th>
              <th>地区名称</th>
              <th>静态页面名称</th>
              <th>地区排序</th>
              <th>分类索引</th>
              <th>所属大区域</th>
              <th>父级地区</th>
              <th>数量</th>
              <th>状态</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php
            // 确保所有记录都被处理，即使没有明确的父子关系
            $processedIds = [];
            
            // 先处理有父子关系的记录
            foreach ($parentAreasForView as $parent) {
                $processedIds[] = $parent['id'];
                $statusBadge = $parent['status'] ? '启用' : '禁用';
                $hasChildren = isset($childAreasForView[$parent['id']]) && count($childAreasForView[$parent['id']]) > 0;
                
                echo "<tr class='parent-row' data-id=\"{$parent['id']}\">";
                echo "<td>{$parent['id']}</td>";
                echo "<td>";
                if ($hasChildren) {
                    echo "<span class=\"toggle-icon\" data-id=\"{$parent['id']}\">-</span> ";
                }
                echo "{$parent['name']}</td>";
                echo "<td>{$parent['slug']}</td>";
                echo "<td><input type='number' class='sort-input' data-id=\"{$parent['id']}\" value=\"{$parent['sort_order']}\" min='0'></td>";
                echo "<td>{$parent['category_index']}</td>";
                
                // 显示大区域名称
                $regionName = '';
                switch(isset($parent['region']) ? $parent['region'] : 0) {
                    case 1: $regionName = '亚太地区'; break;
                    case 2: $regionName = '欧洲地区'; break;
                    case 3: $regionName = '美洲地区'; break;
                    case 4: $regionName = '中东非洲'; break;
                    default: $regionName = ''; break;
                }
                echo "<td>{$regionName}</td>";
                
                echo "<td></td>";
                echo "<td>" . (isset($productCounts[$parent['id']]) && $productCounts[$parent['id']] > 0 ? $productCounts[$parent['id']] : '') . "</td>";
                echo "<td>{$statusBadge}</td>";
                echo "<td class=\"action-buttons\">";
                echo "<button class=\"btn btn-view\" data-id=\"{$parent['id']}\">预览</button>";
                echo "<button class=\"btn btn-edit\" data-id=\"{$parent['id']}\">修改</button>";
                echo "<button class=\"btn btn-delete\" data-id=\"{$parent['id']}\" data-name=\"{$parent['name']}\">删除</button>";
                echo "</td>";
                echo "</tr>";
                
                // 输出子地区
                if ($hasChildren) {
                    foreach ($childAreasForView[$parent['id']] as $child) {
                        $processedIds[] = $child['id'];
                        $childStatusBadge = $child['status'] ? '启用' : '禁用';
                        echo "<tr class='child-row' data-id=\"{$child['id']}\" data-parent=\"{$parent['id']}\">";
                        echo "<td>{$child['id']}</td>";
                        echo "<td><span class=\"indent\">{$child['name']}</span></td>";
                        echo "<td>{$child['slug']}</td>";
                        echo "<td><input type='number' class='sort-input' data-id=\"{$child['id']}\" value=\"{$child['sort_order']}\" min='0'></td>";
                        echo "<td>{$child['category_index']}</td>";
                        
                        // 显示大区域名称
                        $childRegionName = '';
                        switch(isset($child['region']) ? $child['region'] : 0) {
                            case 1: $childRegionName = '亚太地区'; break;
                            case 2: $childRegionName = '欧洲地区'; break;
                            case 3: $childRegionName = '美洲地区'; break;
                            case 4: $childRegionName = '中东非洲'; break;
                            default: $childRegionName = ''; break;
                        }
                        echo "<td>{$childRegionName}</td>";
                        
                        echo "<td>{$parent['name']}</td>";
                        echo "<td>" . (isset($productCounts[$child['id']]) && $productCounts[$child['id']] > 0 ? $productCounts[$child['id']] : '') . "</td>";
                        echo "<td>{$childStatusBadge}</td>";
                        echo "<td class=\"action-buttons\">";
                        echo "<button class=\"btn btn-view\" data-id=\"{$child['id']}\">预览</button>";
                        echo "<button class=\"btn btn-edit\" data-id=\"{$child['id']}\">修改</button>";
                        echo "<button class=\"btn btn-delete\" data-id=\"{$child['id']}\" data-name=\"{$child['name']}\">删除</button>";
                        echo "</td>";
                        echo "</tr>";
                    }
                }
            }
            
            // 处理剩余的记录（没有父子关系或父级不在数据库中的记录）
            foreach ($areas as $area) {
                if (!in_array($area['id'], $processedIds)) {
                    $statusBadge = $area['status'] ? '启用' : '禁用';
                    echo "<tr data-id=\"{$area['id']}\">";
                    echo "<td>{$area['id']}</td>";
                    echo "<td>{$area['name']}</td>";
                    echo "<td>{$area['slug']}</td>";
                    echo "<td><input type='number' class='sort-input' data-id=\"{$area['id']}\" value=\"{$area['sort_order']}\" min='0'></td>";
                    echo "<td>{$area['category_index']}</td>";
                    
                    // 显示大区域名称
                    $areaRegionName = '';
                    switch(isset($area['region']) ? $area['region'] : 0) {
                        case 1: $areaRegionName = '亚太地区'; break;
                        case 2: $areaRegionName = '欧洲地区'; break;
                        case 3: $areaRegionName = '美洲地区'; break;
                        case 4: $areaRegionName = '中东非洲'; break;
                        default: $areaRegionName = ''; break;
                    }
                    echo "<td>{$areaRegionName}</td>";
                    
                    echo "<td>" . ($area['parent_name'] ? $area['parent_name'] : '') . "</td>";
                    echo "<td>" . (isset($productCounts[$area['id']]) && $productCounts[$area['id']] > 0 ? $productCounts[$area['id']] : '') . "</td>";
                    echo "<td>{$statusBadge}</td>";
                    echo "<td class=\"action-buttons\">";
                    echo "<button class=\"btn btn-view\" data-id=\"{$area['id']}\">预览</button>";
                    echo "<button class=\"btn btn-edit\" data-id=\"{$area['id']}\">修改</button>";
                    echo "<button class=\"btn btn-delete\" data-id=\"{$area['id']}\" data-name=\"{$area['name']}\">删除</button>";
                    echo "</td>";
                    echo "</tr>";
                }
            }
            ?>
          </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除地区 "<span id="delete-area-name"></span>" 吗？</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 展开/折叠功能
      document.querySelectorAll('.toggle-icon').forEach(icon => {
        // 默认设置为展开状态
        icon.textContent = '-';
        // 显示所有子行
        const parentId = icon.getAttribute('data-id');
        document.querySelectorAll(`tr[data-parent="${parentId}"]`).forEach(row => {
          row.style.display = '';
        });
        icon.addEventListener('click', function() {
          const parentId = this.getAttribute('data-id');
          const isExpanded = this.textContent === '-';
          // 更新图标
          this.textContent = isExpanded ? '+' : '-';
          // 切换子行的显示状态
          document.querySelectorAll(`tr[data-parent="${parentId}"]`).forEach(row => {
            row.style.display = isExpanded ? 'none' : '';
          });
        });
      });
      // 添加地区按钮点击事件
      document.getElementById('add-area-btn').addEventListener('click', function() {
        window.location.href = 'area_add.php';
      });
      // 查询按钮点击事件
      document.getElementById('search-btn').addEventListener('click', function() {
        const parentId = document.getElementById('parent-filter').value;
        const regionId = document.getElementById('region-filter').value;
        // 如果都未选择，不执行查询
        if (parentId === '0' && regionId === '0') return;
        // 先重置显示所有行
        document.querySelectorAll('tbody tr').forEach(row => {
          row.style.display = '';
        });
        // 如果两个筛选条件都是"不限"，显示所有行并返回
        if (parentId === '-1' && regionId === '-1') {
          // 设置所有父行的展开/折叠图标为展开状态
          document.querySelectorAll('.toggle-icon').forEach(icon => {
            icon.textContent = '-';
          });
          return;
        }
        // 按父级地区筛选
        if (parentId !== '0' && parentId !== '-1') {
          // 只显示选中的父级地区及其子地区
          document.querySelectorAll('tbody tr').forEach(row => {
            if (row.dataset.id === parentId) {
              row.style.display = '';
              // 显示该父级下的所有子地区
              document.querySelectorAll(`tr[data-parent="${parentId}"]`).forEach(childRow => {
                childRow.style.display = '';
              });
              // 更新该父级的展开/折叠图标
              const icon = row.querySelector('.toggle-icon');
              if (icon) icon.textContent = '-';
            } else if (row.dataset.parent === parentId) {
              row.style.display = '';
            } else {
              row.style.display = 'none';
            }
          });
        }
        // 按大区域筛选
        if (regionId !== '0' && regionId !== '-1') {
          document.querySelectorAll('tbody tr').forEach(row => {
            // 获取行的region值
            const rowRegion = row.querySelector('td:nth-child(6)').textContent.trim();
            let shouldShow = false;
            if (regionId === 'null') {
              // "未设置"选项 - 仅显示没有设置大区域的一级栏目
              // 判断是否是一级栏目 (使用父行类或检查没有data-parent属性)
              const isParent = row.classList.contains('parent-row') || (!row.hasAttribute('data-parent') && !row.classList.contains('child-row'));
              shouldShow = isParent && rowRegion === '';
            } else {
              // 根据区域名称判断
              switch (regionId) {
                case '1':
                  shouldShow = rowRegion === '亚太地区';
                  break;
                case '2':
                  shouldShow = rowRegion === '欧洲地区';
                  break;
                case '3':
                  shouldShow = rowRegion === '美洲地区';
                  break;
                case '4':
                  shouldShow = rowRegion === '中东非洲';
                  break;
              }
            }
            // 如果不符合区域条件且不是已经通过父级筛选显示的，则隐藏
            if (!shouldShow && (parentId === '0' || parentId === '-1')) {
              row.style.display = 'none';
            }
          });
        }
        // 如果同时选择了父级地区和大区域，需要考虑交集
        if (parentId !== '0' && parentId !== '-1' && regionId !== '0' && regionId !== '-1') {
          document.querySelectorAll('tbody tr').forEach(row => {
            if (row.style.display !== 'none') { // 只检查当前显示的行
              const rowRegion = row.querySelector('td:nth-child(6)').textContent.trim();
              let matchesRegion = false;
              if (regionId === 'null') {
                // "未设置"选项 - 仅显示没有设置大区域的一级栏目
                const isParent = row.classList.contains('parent-row') || (!row.hasAttribute('data-parent') && !row.classList.contains('child-row'));
                matchesRegion = isParent && rowRegion === '';
              } else {
                switch (regionId) {
                  case '1':
                    matchesRegion = rowRegion === '亚太地区';
                    break;
                  case '2':
                    matchesRegion = rowRegion === '欧洲地区';
                    break;
                  case '3':
                    matchesRegion = rowRegion === '美洲地区';
                    break;
                  case '4':
                    matchesRegion = rowRegion === '中东非洲';
                    break;
                }
              }
              if (!matchesRegion) {
                row.style.display = 'none';
              }
            }
          });
        }
      });
      // 删除功能相关代码
      const modal = document.getElementById('delete-modal');
      const deleteAreaName = document.getElementById('delete-area-name');
      let deleteAreaId = null;
      // 删除按钮点击事件
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteAreaId = this.dataset.id;
          const areaName = this.dataset.name;
          deleteAreaName.textContent = areaName;
          modal.style.display = 'block';
        });
      });
      // 确认删除按钮点击事件
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteAreaId) {
          // 发送删除请求
          fetch('area_delete.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
              },
              body: 'id=' + deleteAreaId
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                // 删除成功，移除对应的行
                const row = document.querySelector(`tr[data-id="${deleteAreaId}"]`);
                if (row) {
                  // 如果是父级地区，同时删除其子地区
                  const children = document.querySelectorAll(`tr[data-parent="${deleteAreaId}"]`);
                  children.forEach(child => child.remove());
                  row.remove();
                }
                // 显示成功消息
                const successMessage = document.getElementById('success-message');
                successMessage.textContent = data.message;
                successMessage.style.display = 'block';
                setTimeout(() => {
                  successMessage.style.display = 'none';
                }, 3000);
              } else {
                alert(data.message);
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('删除失败，请重试');
            })
            .finally(() => {
              modal.style.display = 'none';
              deleteAreaId = null;
            });
        }
      });
      // 取消删除按钮点击事件
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteAreaId = null;
      });
      // 点击模态框外部关闭
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteAreaId = null;
        }
      });
      // 编辑按钮点击事件
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const areaId = this.dataset.id;
          window.location.href = `area_edit.php?id=${areaId}`;
        });
      });
      // 添加保存所有修改按钮点击事件
      document.getElementById('save-all-btn').addEventListener('click', function() {
        const sortInputs = document.querySelectorAll('.sort-input');
        const updates = [];
        sortInputs.forEach(input => {
          updates.push({
            id: input.dataset.id,
            sort_order: input.value
          });
        });
        if (updates.length > 0) {
          // 发送批量更新请求
          fetch('area_update_sort.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json',
              },
              body: JSON.stringify({
                updates: updates
              })
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                // 显示成功消息
                const successMessage = document.getElementById('success-message');
                successMessage.textContent = data.message || '排序更新成功！';
                successMessage.style.display = 'block';
                setTimeout(() => {
                  successMessage.style.display = 'none';
                }, 3000);
              } else {
                alert(data.message || '更新失败，请重试');
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('更新失败，请重试');
            });
        }
      });
      // 如果有成功消息参数，显示成功消息
      if (new URLSearchParams(window.location.search).has('success')) {
        const successMessage = document.getElementById('success-message');
        successMessage.textContent = '操作成功！';
        successMessage.style.display = 'block';
        setTimeout(() => {
          successMessage.style.display = 'none';
        }, 3000);
      }
    });
    </script>
  </body>
</html>
