<?php
/**
 * 添加地区页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
require_once 'code/auth_check.php';
// 获取数据库连接
$db = getDbConnection();
// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取并清理 slug
    $slug = isset($_POST['slug']) ? $_POST['slug'] : '';
    // 转换为小写
    $slug = strtolower($slug);
    // 替换空格为连字符
    $slug = preg_replace('/\s+/', '-', $slug);
    // 只保留小写字母、数字和连字符
    $slug = preg_replace('/[^a-z0-9-]/', '', $slug);
    // 替换多个连续的连字符为单个连字符
    $slug = preg_replace('/-+/', '-', $slug);
    // 移除开头和结尾的连字符
    $slug = trim($slug, '-');
    // 如果 slug 为空，可以从名称生成
    if (empty($slug) && !empty($_POST['name'])) {
        $name = $_POST['name'];
        $slug = strtolower($name);
        $slug = preg_replace('/\s+/', '-', $slug);
        $slug = preg_replace('/[^a-z0-9-]/', '', $slug);
        $slug = preg_replace('/-+/', '-', $slug);
        $slug = trim($slug, '-');
    }
    // 验证 slug 不为空
    if (empty($slug)) {
        $errors[] = 'Slug 不能为空';
    } else {
        // 继续处理表单...
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>添加地区</title>
        <link rel="stylesheet" href="public/css/style.css">
        <link rel="stylesheet" href="public/css/area_add.css">
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="sidebar">
            <?php include 'public/letf.php'; ?>
        </div>
        <div class="main-content">
            <div class="form-container">
                <form id="area-form" method="post" action="area_create.php">
                    <div class="form-group">
                        <label for="name">地区名称</label>
                        <input type="text" id="name" name="name" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="slug">静态页面名称</label>
                        <input type="text" id="slug" name="slug" class="form-control" required>
                        <small>只能包含小写字母、数字和连字符</small>
                    </div>
                    <div class="form-group">
                        <label for="region">所属大区域</label>
                        <select id="region" name="region" class="form-control">
                            <option value="">请选择大区域</option>
                            <option value="1">亚太地区</option>
                            <option value="2">欧洲地区</option>
                            <option value="3">美洲地区</option>
                            <option value="4">中东非洲</option>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="parent_id">父级地区</label>
                        <select id="parent_id" name="parent_id" class="form-control">
                            <option value="">无父级地区</option>
                            <?php
                        // 获取所有可能的父级地区
                        $parentQuery = "SELECT id, name FROM area WHERE parent_id IS NULL ORDER BY sort_order ASC";
                        $parentStmt = $db->query($parentQuery);
                        $parents = $parentStmt->fetchAll();
                        foreach ($parents as $parent) {
                            echo "<option value=\"{$parent['id']}\">{$parent['name']}</option>";
                        }
                        ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="sort_order">地区排序</label>
                        <input type="number" id="sort_order" name="sort_order" class="form-control" value="0">
                    </div>
                    <div class="form-group">
                        <label for="category_index">分类索引</label>
                        <input type="number" id="category_index" name="category_index" class="form-control" value="100">
                    </div>
                    <div class="form-group">
                        <label for="status">状态</label>
                        <select id="status" name="status" class="form-control">
                            <option value="1" selected>启用</option>
                            <option value="0">禁用</option>
                        </select>
                    </div>
                    <div class="btn-container">
                        <button type="submit" class="btn-save">保存</button>
                        <a href="area.php" class="btn-cancel">取消</a>
                    </div>
                </form>
            </div>
        </div>
        <script>
        document.addEventListener('DOMContentLoaded', function() {
            // 获取父级地区选择框和region选择框
            const parentIdSelect = document.getElementById('parent_id');
            const regionSelect = document.getElementById('region');
            const regionGroup = regionSelect.closest('.form-group');
            
            // 初始检查父级地区状态
            checkParentIdStatus();
            
            // 监听父级地区选择变化
            parentIdSelect.addEventListener('change', checkParentIdStatus);
            
            // 检查父级地区选择状态并控制region字段显示
            function checkParentIdStatus() {
                const hasParent = parentIdSelect.value !== '';
                if (hasParent) {
                    // 如果选择了父级地区，隐藏region选择
                    regionGroup.style.display = 'none';
                } else {
                    // 如果没有选择父级地区，显示region选择
                    regionGroup.style.display = 'block';
                }
            }
            
            // 为 slug 输入框添加自动格式化功能
            const slugInput = document.getElementById('slug');
            const nameInput = document.getElementById('name'); // 假设有一个名称输入框
            if (slugInput) {
                // 当用户输入时自动格式化 slug
                slugInput.addEventListener('input', function() {
                    formatSlug(this);
                });
                // 当表单提交时确保 slug 格式正确
                slugInput.closest('form').addEventListener('submit', function(e) {
                    const slug = slugInput.value.trim();
                    // 确保 slug 不以连字符开头或结尾
                    slugInput.value = slug.replace(/^-+|-+$/g, '');
                    
                    // 验证表单
                    if (!nameInput.value.trim()) {
                        e.preventDefault();
                        alert('请输入地区名称');
                        return false;
                    }
                    
                    if (!slug) {
                        e.preventDefault();
                        alert('请输入静态页面名称');
                        return false;
                    }
                    
                    // 检查一级地区是否选择了region
                    if (parentIdSelect.value === '' && regionSelect.value === '') {
                        e.preventDefault();
                        alert('一级地区必须选择所属大区域');
                        return false;
                    }
                });
            }
            // 从名称自动生成 slug
            if (nameInput && slugInput) {
                nameInput.addEventListener('blur', function() {
                    // 只有当 slug 为空时才自动生成
                    if (!slugInput.value) {
                        slugInput.value = generateSlug(this.value);
                    }
                });
            }
            // 格式化 slug 的函数
            function formatSlug(input) {
                // 转换为小写
                let value = input.value.toLowerCase();
                // 替换空格为连字符
                value = value.replace(/\s+/g, '-');
                // 移除除了小写字母、数字和连字符以外的所有字符
                value = value.replace(/[^a-z0-9-]/g, '');
                // 替换多个连续的连字符为单个连字符
                value = value.replace(/-+/g, '-');
                // 更新输入框的值
                input.value = value;
            }
            // 从文本生成 slug 的函数
            function generateSlug(text) {
                let slug = text.toLowerCase();
                // 替换空格为连字符
                slug = slug.replace(/\s+/g, '-');
                // 移除除了小写字母、数字和连字符以外的所有字符
                slug = slug.replace(/[^a-z0-9-]/g, '');
                // 替换多个连续的连字符为单个连字符
                slug = slug.replace(/-+/g, '-');
                // 移除开头和结尾的连字符
                slug = slug.replace(/^-+|-+$/g, '');
                return slug;
            }
        });
        </script>
    </body>
</html>
