<?php
/**
 * 地区添加处理
 */
// 引入数据库配置文件
require_once '../config/database.php';
require_once 'code/auth_check.php';
// 检查是否有POST请求
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取表单数据
    $name = isset($_POST['name']) ? trim($_POST['name']) : '';
    $slug = isset($_POST['slug']) ? trim($_POST['slug']) : '';
    $parentId = isset($_POST['parent_id']) && $_POST['parent_id'] !== '' ? intval($_POST['parent_id']) : null;
    $sortOrder = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
    $categoryIndex = isset($_POST['category_index']) ? intval($_POST['category_index']) : 100;
    $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
    $region = isset($_POST['region']) ? intval($_POST['region']) : null; // 获取region字段值
    
    // 验证数据
    if (empty($name) || empty($slug)) {
        echo "地区名称和静态页面名称不能为空";
        exit;
    }
    // 验证slug格式
    if (!preg_match('/^[a-z0-9-]+$/', $slug)) {
        echo "静态页面名称只能包含小写字母、数字和连字符";
        exit;
    }
    
    // 对于一级地区，验证region字段必须有值
    if ($parentId === null && empty($region)) {
        echo "一级地区必须选择所属大区域";
        exit;
    }
    
    try {
        // 获取数据库连接
        $db = getDbConnection();
        // 检查slug是否已存在
        $checkSlugQuery = "SELECT COUNT(*) as count FROM area WHERE slug = :slug";
        $checkStmt = $db->prepare($checkSlugQuery);
        $checkStmt->execute(['slug' => $slug]);
        $slugCount = $checkStmt->fetch()['count'];
        if ($slugCount > 0) {
            echo "静态页面名称已存在，请使用其他名称";
            exit;
        }
        // 插入地区数据
        $insertQuery = "INSERT INTO area (name, slug, parent_id, sort_order, category_index, status, region) 
                        VALUES (:name, :slug, :parent_id, :sort_order, :category_index, :status, :region)";
        $insertStmt = $db->prepare($insertQuery);
        $insertStmt->execute([
            'name' => $name,
            'slug' => $slug,
            'parent_id' => $parentId,
            'sort_order' => $sortOrder,
            'category_index' => $categoryIndex,
            'status' => $status,
            'region' => $region
        ]);
        // 重定向回地区列表页
        header('Location: area.php?success=1');
        exit;
    } catch (PDOException $e) {
        echo "数据库错误: " . $e->getMessage();
        exit;
    }
} else {
    echo "无效的请求方法";
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html>
