<?php
/**
 * 地区删除处理
 */
// 引入数据库配置文件
require_once '../config/database.php';
header('Content-Type: application/json');
// 检查是否有POST请求
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取要删除的地区ID
    $areaId = isset($_POST['id']) ? intval($_POST['id']) : 0;
    if ($areaId <= 0) {
        echo json_encode(['success' => false, 'message' => '无效的地区ID']);
        exit;
    }
    try {
        // 获取数据库连接
        $db = getDbConnection();
        // 开始事务
        $db->beginTransaction();
        // 检查是否有子地区
        $checkChildrenQuery = "SELECT COUNT(*) as count FROM area WHERE parent_id = :id";
        $checkStmt = $db->prepare($checkChildrenQuery);
        $checkStmt->execute(['id' => $areaId]);
        $childCount = $checkStmt->fetch()['count'];
        if ($childCount > 0) {
            // 如果有子地区，先删除所有子地区
            $deleteChildrenQuery = "DELETE FROM area WHERE parent_id = :id";
            $deleteChildrenStmt = $db->prepare($deleteChildrenQuery);
            $deleteChildrenStmt->execute(['id' => $areaId]);
        }
        // 删除当前地区
        $deleteQuery = "DELETE FROM area WHERE id = :id";
        $deleteStmt = $db->prepare($deleteQuery);
        $deleteStmt->execute(['id' => $areaId]);
        // 提交事务
        $db->commit();
        echo json_encode(['success' => true, 'message' => '地区删除成功']);
    } catch (PDOException $e) {
        // 回滚事务
        $db->rollBack();
        echo json_encode(['success' => false, 'message' => '删除失败: ' . $e->getMessage()]);
    }
} else {
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 