<?php
/**
 * 地区编辑页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
require_once 'code/auth_check.php';
// 获取要编辑的地区ID
$areaId = isset($_GET['id']) ? intval($_GET['id']) : 0;
// 初始化地区数据
$area = null;
if ($areaId > 0) {
    try {
        // 获取数据库连接
        $db = getDbConnection();
        // 获取地区数据
        $query = "SELECT * FROM area WHERE id = :id";
        $stmt = $db->prepare($query);
        $stmt->execute(['id' => $areaId]);
        $area = $stmt->fetch();
        if (!$area) {
            echo "地区不存在";
            exit;
        }
    } catch (PDOException $e) {
        echo "数据库错误: " . $e->getMessage();
        exit;
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑地区 - <?php echo $area ? $area['name'] : ''; ?></title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/area_edit.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <div class="form-container">
        <form id="area-form" method="post" action="area_update.php">
          <input type="hidden" name="id" value="<?php echo $area['id']; ?>">
          <div class="form-group">
            <label for="name">地区名称</label>
            <input type="text" id="name" name="name" class="form-control" value="<?php echo htmlspecialchars($area['name']); ?>" required>
          </div>
          <div class="form-group">
            <label for="slug">静态页面名称</label>
            <input type="text" id="slug" name="slug" class="form-control" value="<?php echo htmlspecialchars($area['slug']); ?>" required>
            <small>只能包含小写字母、数字和连字符</small>
          </div>

          <?php 
          // 只有当是一级地区时才显示region字段
          $isParent = empty($area['parent_id']);
          if ($isParent): 
          ?>
          <div class="form-group">
            <label for="region">所属大区域</label>
            <select id="region" name="region" class="form-control">
              <option value="">请选择大区域</option>
              <option value="1" <?php echo isset($area['region']) && $area['region'] == 1 ? 'selected' : ''; ?>>亚太地区</option>
              <option value="2" <?php echo isset($area['region']) && $area['region'] == 2 ? 'selected' : ''; ?>>欧洲地区</option>
              <option value="3" <?php echo isset($area['region']) && $area['region'] == 3 ? 'selected' : ''; ?>>美洲地区</option>
              <option value="4" <?php echo isset($area['region']) && $area['region'] == 4 ? 'selected' : ''; ?>>中东非洲</option>
            </select>
          </div>
          <?php else: ?>
          <!-- 对于子地区，添加一个隐藏字段保持现有值 -->
          <input type="hidden" name="region" value="<?php echo isset($area['region']) ? $area['region'] : ''; ?>">
          <?php endif; ?>

          <div class="form-group">
            <label for="parent_id">父级地区</label>
            <select id="parent_id" name="parent_id" class="form-control">
              <option value="">无父级地区</option>
              <?php
              // 获取所有一级栏目作为可能的父级
              try {
                  // 查询所有一级栏目（不限于parent_id为NULL的记录）
                  $parentQuery = "SELECT id, name FROM area 
                                  WHERE id != :id 
                                  AND (parent_id IS NULL OR parent_id = 0 OR parent_id = '')
                                  ORDER BY sort_order ASC";
                  $parentStmt = $db->prepare($parentQuery);
                  $parentStmt->execute(['id' => $areaId]);
                  $parents = $parentStmt->fetchAll();
                  foreach ($parents as $parent) {
                      $selected = ($area['parent_id'] == $parent['id']) ? 'selected' : '';
                      echo "<option value=\"{$parent['id']}\" {$selected}>{$parent['name']}</option>";
                  }
              } catch (PDOException $e) {
                  echo "<option value=''>获取地区列表失败</option>";
              }
              ?>
            </select>
          </div>
          <div class="form-group">
            <label for="sort_order">地区排序</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control"
                   value="<?php echo $area['sort_order']; ?>">
            <small class="form-text text-muted">建议使用负数（如-10、-9），数值越小排序越靠前</small>
          </div>
          <div class="form-group">
            <label for="category_index">分类索引</label>
            <input type="number" id="category_index" name="category_index" class="form-control"
                   value="<?php echo isset($area['category_index']) ? $area['category_index'] : 100; ?>">
            <small class="form-text text-muted">默认值为100</small>
          </div>
          <div class="form-group">
            <label for="status">状态</label>
            <select id="status" name="status" class="form-control">
              <option value="1" <?php echo $area['status'] == 1 ? 'selected' : ''; ?>>启用</option>
              <option value="0" <?php echo $area['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
            </select>
          </div>
          <div class="btn-container">
            <button type="submit" class="btn-save">保存</button>
            <a href="area.php" class="btn-cancel">取消</a>
          </div>
        </form>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 为 slug 输入框添加自动格式化功能
      const slugInput = document.getElementById('slug');
      const nameInput = document.getElementById('name');
      if (slugInput) {
        // 当用户输入时自动格式化 slug
        slugInput.addEventListener('input', function() {
          formatSlug(this);
        });
        // 当表单提交时确保 slug 格式正确
        slugInput.closest('form').addEventListener('submit', function(e) {
          const slug = slugInput.value.trim();
          // 确保 slug 不以连字符开头或结尾
          slugInput.value = slug.replace(/^-+|-+$/g, '');
          // 检查一级地区的region是否已选择
          <?php if ($isParent): ?>
          const regionSelect = document.getElementById('region');
          if (regionSelect && regionSelect.value === '') {
            e.preventDefault();
            alert('请选择所属大区域');
            return false;
          }
          <?php endif; ?>
        });
      }
      // 从名称自动生成 slug
      if (nameInput && slugInput) {
        nameInput.addEventListener('blur', function() {
          // 只有当 slug 为空时才自动生成
          if (!slugInput.value) {
            slugInput.value = generateSlug(this.value);
          }
        });
      }
      // 格式化 slug 的函数
      function formatSlug(input) {
        // 转换为小写
        let value = input.value.toLowerCase();
        // 替换空格为连字符
        value = value.replace(/\s+/g, '-');
        // 移除除了小写字母、数字和连字符以外的所有字符
        value = value.replace(/[^a-z0-9-]/g, '');
        // 替换多个连续的连字符为单个连字符
        value = value.replace(/-+/g, '-');
        // 更新输入框的值
        input.value = value;
      }
      // 从文本生成 slug 的函数
      function generateSlug(text) {
        let slug = text.toLowerCase();
        // 替换空格为连字符
        slug = slug.replace(/\s+/g, '-');
        // 移除除了小写字母、数字和连字符以外的所有字符
        slug = slug.replace(/[^a-z0-9-]/g, '');
        // 替换多个连续的连字符为单个连字符
        slug = slug.replace(/-+/g, '-');
        // 移除开头和结尾的连字符
        slug = slug.replace(/^-+|-+$/g, '');
        return slug;
      }
      // 表单提交前验证
      document.getElementById('area-form').addEventListener('submit', function(e) {
        const name = document.getElementById('name').value.trim();
        const slug = document.getElementById('slug').value.trim();
        if (!name) {
          e.preventDefault();
          alert('请输入地区名称');
          return false;
        }
        if (!slug) {
          e.preventDefault();
          alert('请输入静态页面名称');
          return false;
        }
        // 验证静态页面名称格式
        if (!/^[a-z0-9-]+$/.test(slug)) {
          e.preventDefault();
          alert('静态页面名称只能包含小写字母、数字和连字符');
          return false;
        }
        // 再次检查一级地区的region是否已选择
        <?php if ($isParent): ?>
        const regionSelect = document.getElementById('region');
        if (regionSelect && regionSelect.value === '') {
          e.preventDefault();
          alert('请选择所属大区域');
          return false;
        }
        <?php endif; ?>
      });
    });
    </script>
  </body>
</html>
