<?php
/**
 * 更新地区信息
 */
// 引入数据库配置文件
require_once '../config/database.php';
require_once 'code/auth_check.php';
// 检查请求方法
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: area.php');
    exit;
}
// 获取表单数据
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
$name = isset($_POST['name']) ? trim($_POST['name']) : '';
$slug = isset($_POST['slug']) ? trim($_POST['slug']) : '';
$parent_id = isset($_POST['parent_id']) && $_POST['parent_id'] !== '' ? intval($_POST['parent_id']) : null;
$sort_order = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
$category_index = isset($_POST['category_index']) ? intval($_POST['category_index']) : 100;
$status = isset($_POST['status']) ? intval($_POST['status']) : 1; // 默认启用
$region = isset($_POST['region']) ? intval($_POST['region']) : null; // 获取region字段值

// 验证数据
if (empty($name) || empty($slug)) {
    echo "地区名称和静态页面名称不能为空";
    exit;
}
// 验证slug格式
if (!preg_match('/^[a-z0-9-]+$/', $slug)) {
    echo "静态页面名称只能包含小写字母、数字和连字符";
    exit;
}

// 对于一级地区，验证region字段必须有值
if ($parent_id === null && empty($region)) {
    echo "一级地区必须选择所属大区域";
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查slug是否已存在（排除当前记录）
    $checkSlugQuery = "SELECT id FROM area WHERE slug = :slug AND id != :id";
    $checkSlugStmt = $db->prepare($checkSlugQuery);
    $checkSlugStmt->execute([
        'slug' => $slug,
        'id' => $id
    ]);
    if ($checkSlugStmt->rowCount() > 0) {
        echo "静态页面名称已存在，请使用其他名称";
        exit;
    }
    // 检查是否选择自己作为父级
    if ($parent_id == $id) {
        echo "不能选择自己作为父级地区";
        exit;
    }
    // 检查是否选择自己的子级作为父级（防止循环引用）
    if ($parent_id) {
        $checkChildQuery = "SELECT id FROM area WHERE parent_id = :id";
        $checkChildStmt = $db->prepare($checkChildQuery);
        $checkChildStmt->execute(['id' => $id]);
        $children = $checkChildStmt->fetchAll(PDO::FETCH_COLUMN);
        if (in_array($parent_id, $children)) {
            echo "不能选择自己的子级作为父级地区";
            exit;
        }
    }
    // 更新地区信息
    $updateQuery = "UPDATE area SET 
                    name = :name, 
                    slug = :slug, 
                    parent_id = :parent_id, 
                    sort_order = :sort_order, 
                    category_index = :category_index, 
                    status = :status,
                    region = :region
                    WHERE id = :id";
    $updateStmt = $db->prepare($updateQuery);
    $result = $updateStmt->execute([
        'name' => $name,
        'slug' => $slug,
        'parent_id' => $parent_id,
        'sort_order' => $sort_order,
        'category_index' => $category_index,
        'status' => $status,
        'region' => $region,
        'id' => $id
    ]);
    if ($result) {
        // 更新成功，重定向回地区列表页面
        header('Location: area.php?success=1');
        exit;
    } else {
        echo "更新失败，请重试";
    }
} catch (PDOException $e) {
    echo "数据库错误: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html>
