<?php
// 引入数据库配置文件
require_once '../config/database.php';
// 设置响应头为JSON
header('Content-Type: application/json');
// 获取POST数据
$input = json_decode(file_get_contents('php://input'), true);
if (!isset($input['updates']) || !is_array($input['updates'])) {
    echo json_encode(['success' => false, 'message' => '无效的请求数据']);
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    $db->beginTransaction();
    $updateCount = 0;
    foreach ($input['updates'] as $update) {
        if (!isset($update['id']) || !isset($update['sort_order'])) {
            continue;
        }
        $id = intval($update['id']);
        $sortOrder = intval($update['sort_order']);
        $stmt = $db->prepare("UPDATE area SET sort_order = :sort_order WHERE id = :id");
        $stmt->bindParam(':sort_order', $sortOrder, PDO::PARAM_INT);
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        $stmt->execute();
        $updateCount += $stmt->rowCount();
    }
    $db->commit();
    echo json_encode([
        'success' => true,
        'message' => "成功更新 {$updateCount} 个地区的排序",
        'count' => $updateCount
    ]);
} catch (PDOException $e) {
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    echo json_encode([
        'success' => false,
        'message' => '数据库错误: ' . $e->getMessage()
    ]);
}
?> 