<?php
/**
 * 后台管理系统登录验证
 */

// 启动会话
session_start();

// 引入数据库配置
require_once 'config/database.php';

// 设置内容类型
header('Content-Type: application/json; charset=utf-8');

// 响应数据
$response = [
    'success' => false,
    'message' => ''
];

// 验证请求方法
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    $response['message'] = '无效的请求方法';
    echo json_encode($response);
    exit;
}

// 获取登录信息
$username = isset($_POST['username']) ? trim($_POST['username']) : '';
$password = isset($_POST['password']) ? trim($_POST['password']) : '';

// 验证输入
if (empty($username) || empty($password)) {
    $response['message'] = '用户名和密码不能为空';
    echo json_encode($response);
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 查询管理员信息
    $query = "SELECT * FROM `admin` WHERE `username` = :username AND `status` = 1 LIMIT 1";
    $stmt = $db->prepare($query);
    $stmt->execute(['username' => $username]);
    
    if ($stmt->rowCount() === 0) {
        $response['message'] = '用户名不存在或账号已禁用';
        echo json_encode($response);
        exit;
    }
    
    $admin = $stmt->fetch(PDO::FETCH_ASSOC);
    
    // 验证密码
    if (!password_verify($password, $admin['password'])) {
        $response['message'] = '密码错误';
        echo json_encode($response);
        exit;
    }
    
    // 更新登录信息
    $updateQuery = "UPDATE `admin` SET 
                    `last_login` = NOW(),
                    `login_ip` = :ip,
                    `updated_at` = NOW()
                    WHERE `id` = :id";
                    
    $updateStmt = $db->prepare($updateQuery);
    $updateStmt->execute([
        'ip' => $_SERVER['REMOTE_ADDR'],
        'id' => $admin['id']
    ]);
    
    // 存储会话信息
    $_SESSION['admin_id'] = $admin['id'];
    $_SESSION['admin_username'] = $admin['username'];
    $_SESSION['admin_role'] = $admin['role'];
    $_SESSION['admin_login_time'] = time();
    
    // 返回成功
    $response['success'] = true;
    $response['message'] = '登录成功';
    $response['redirect'] = 'dashboard.php';
    
    echo json_encode($response);
    
} catch (PDOException $e) {
    $response['message'] = '系统错误：' . $e->getMessage();
    echo json_encode($response);
}
?> 