<?php
/**
 * 备份管理页面
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 确保Data目录存在
$backupDir = '../Data/';
if (!file_exists($backupDir)) {
    mkdir($backupDir, 0777, true);
}

// 获取备份列表
$backups = [];
if ($handle = opendir($backupDir)) {
    while (false !== ($entry = readdir($handle))) {
        if ($entry != "." && $entry != "..") {
            $filePath = $backupDir . $entry;
            $backups[] = [
                'name' => $entry,
                'size' => formatFileSize(filesize($filePath)),
                'date' => date("Y-m-d H:i:s", filemtime($filePath)),
                'type' => (pathinfo($entry, PATHINFO_EXTENSION) == 'sql') ? '数据库备份' : '网站完整备份'
            ];
        }
    }
    closedir($handle);
}

// 按时间倒序排序
usort($backups, function($a, $b) {
    return strtotime($b['date']) - strtotime($a['date']);
});

// 格式化文件大小
function formatFileSize($bytes) {
    $units = ['B', 'KB', 'MB', 'GB', 'TB'];
    $i = 0;
    while ($bytes >= 1024 && $i < count($units) - 1) {
        $bytes /= 1024;
        $i++;
    }
    return round($bytes, 2) . ' ' . $units[$i];
}

// 检查是否有提示消息
$successMessage = isset($_GET['success']) ? $_GET['success'] : '';
$errorMessage = isset($_GET['error']) ? $_GET['error'] : '';
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>备份管理</title>
        <link rel="stylesheet" href="public/css/style.css">
        <style>
        . .backup-container {
            margin: 20px 0;
        }

        .backup-options {
            display: flex;
            gap: 15px;
            margin-bottom: 20px;
        }

        .backup-list {
            width: 100%;
            border-collapse: collapse;
        }

        .backup-list th,
        .backup-list td {
            padding: 10px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }

        .backup-list th {
            background-color: #f2f2f2;
        }

        .btn-backup {
            background-color: #4CAF50;
            color: white;
            padding: 10px 15px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-restore {
            background-color: #2196F3;
            color: white;
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-delete {
            background-color: #f44336;
            color: white;
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-download {
            background-color: #2196F3;
            color: white;
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            margin-left: 10px;
        }

        .alert {
            padding: 10px 15px;
            border-radius: 4px;
            margin-bottom: 15px;
        }

        .alert-success {
            background-color: #dff0d8;
            color: #3c763d;
        }

        .alert-danger {
            background-color: #f2dede;
            color: #a94442;
        }

        .main-content h1 {
            font-size: 1.2rem;
        }

        </style>
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="sidebar">
            <?php include 'public/letf.php'; ?>
        </div>
        <div class="main-content">
            <h1>备份管理</h1>
            <?php if (!empty($successMessage)): ?>
            <div class="alert alert-success"><?php echo $successMessage; ?></div>
            <?php endif; ?>
            <?php if (!empty($errorMessage)): ?>
            <div class="alert alert-danger"><?php echo $errorMessage; ?></div>
            <?php endif; ?>
            <div class="backup-container">
                <div class="backup-options">
                    <form action="backup_create.php" method="post">
                        <input type="hidden" name="type" value="database">
                        <button type="submit" class="btn-backup">创建数据库备份</button>
                    </form>
                    <form action="backup_create.php" method="post">
                        <input type="hidden" name="type" value="full">
                        <button type="submit" class="btn-backup">创建完整网站备份</button>
                    </form>
                </div>
                <?php if (count($backups) > 0): ?>
                <table class="backup-list">
                    <thead>
                        <tr>
                            <th>备份名称</th>
                            <th>类型</th>
                            <th>大小</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($backups as $backup): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($backup['name']); ?></td>
                            <td><?php echo $backup['type']; ?></td>
                            <td><?php echo $backup['size']; ?></td>
                            <td><?php echo $backup['date']; ?></td>
                            <td>
                                <form action="backup_restore.php" method="post" style="display:inline;" onsubmit="return confirm('确定要恢复此备份吗？这将覆盖当前数据！');">
                                    <input type="hidden" name="file" value="<?php echo htmlspecialchars($backup['name']); ?>">
                                    <button type="submit" class="btn-restore">恢复</button>
                                </form>
                                <a href="backup_download.php?file=<?php echo urlencode($backup['name']); ?>" class="btn-download">下载</a>
                                <form action="backup_delete.php" method="post" style="display:inline;" onsubmit="return confirm('确定要删除此备份吗？此操作不可撤销！');">
                                    <input type="hidden" name="file" value="<?php echo htmlspecialchars($backup['name']); ?>">
                                    <button type="submit" class="btn-delete">删除</button>
                                </form>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
                <?php else: ?>
                <p>暂无备份记录。请使用上方按钮创建备份。</p>
                <?php endif; ?>
            </div>
        </div>
        <script>
        document.addEventListener('DOMContentLoaded', function() {
            // 自动隐藏提示信息
            setTimeout(function() {
                const alerts = document.querySelectorAll('.alert');
                alerts.forEach(function(alert) {
                    alert.style.display = 'none';
                });
            }, 5000);
        });
        </script>
    </body>
</html>
