<?php
class ScriptManager {
    private $db;
    
    public function __construct($db) {
        $this->db = $db;
    }
    
    public function toggleStatus($id) {
        try {
            $stmt = $this->db->prepare("UPDATE scripts SET status = NOT status WHERE id = ?");
            $result = $stmt->execute([intval($id)]);
            
            if ($result) {
                // Get new status
                $stmt = $this->db->prepare("SELECT status FROM scripts WHERE id = ?");
                $stmt->execute([intval($id)]);
                $newStatus = $stmt->fetchColumn();
                
                return [
                    'success' => true,
                    'message' => '状态更新成功',
                    'new_status' => $newStatus
                ];
            }
            
            return ['success' => false, 'message' => '状态更新失败'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => '状态更新失败：' . $e->getMessage()];
        }
    }
    
    public function delete($id) {
        try {
            $stmt = $this->db->prepare("DELETE FROM scripts WHERE id = ?");
            $result = $stmt->execute([intval($id)]);
            
            return [
                'success' => $result,
                'message' => $result ? '删除成功' : '删除失败'
            ];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => '删除失败：' . $e->getMessage()];
        }
    }
    
    public function batchDelete($ids) {
        try {
            $placeholders = str_repeat('?,', count($ids) - 1) . '?';
            $stmt = $this->db->prepare("DELETE FROM scripts WHERE id IN ($placeholders)");
            $result = $stmt->execute($ids);
            
            return [
                'success' => $result,
                'message' => $result ? '批量删除成功' : '批量删除失败'
            ];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => '批量删除失败：' . $e->getMessage()];
        }
    }
    
    public function batchToggleStatus($ids, $status) {
        try {
            $placeholders = str_repeat('?,', count($ids) - 1) . '?';
            $stmt = $this->db->prepare("UPDATE scripts SET status = ? WHERE id IN ($placeholders)");
            $params = array_merge([$status], $ids);
            $result = $stmt->execute($params);
            
            return [
                'success' => $result,
                'message' => $result ? '批量更新状态成功' : '批量更新状态失败'
            ];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => '批量更新状态失败：' . $e->getMessage()];
        }
    }
} 