<?php
class ScriptSearch {
    private $db;
    private $conditions = [];
    private $params = [];
    
    public function __construct($db) {
        $this->db = $db;
    }
    
    public function addCategoryFilter($categoryId) {
        if (!empty($categoryId)) {
            $this->conditions[] = "s.category_id = ?";
            $this->params[] = intval($categoryId);
        }
        return $this;
    }
    
    public function addKeywordFilter($keyword) {
        if (!empty($keyword)) {
            $this->conditions[] = "(s.name LIKE ? OR s.description LIKE ?)";
            $keyword = "%" . trim($keyword) . "%";
            $this->params[] = $keyword;
            $this->params[] = $keyword;
        }
        return $this;
    }
    
    public function getResults($page = 1, $limit = 10) {
        $offset = ($page - 1) * $limit;
        $where = !empty($this->conditions) ? "WHERE " . implode(" AND ", $this->conditions) : "";
        
        // Get total count
        $countSql = "SELECT COUNT(*) FROM scripts s " . $where;
        $countStmt = $this->db->prepare($countSql);
        $countStmt->execute($this->params);
        $total = $countStmt->fetchColumn();
        
        // Get results
        $sql = "SELECT s.*, c.name as category_name 
                FROM scripts s 
                LEFT JOIN script_categories c ON s.category_id = c.id 
                {$where} 
                ORDER BY s.sort_order ASC, s.id DESC 
                LIMIT ? OFFSET ?";
                
        $params = array_merge($this->params, [$limit, $offset]);
        $stmt = $this->db->prepare($sql);
        $stmt->execute($params);
        
        return [
            'total' => $total,
            'data' => $stmt->fetchAll(PDO::FETCH_ASSOC),
            'total_pages' => ceil($total / $limit)
        ];
    }
} 