<?php
/**
 * 合作伙伴链接管理逻辑
 * 用于管理合作伙伴链接的业务逻辑处理
 */

// 引入认证检查文件
require_once __DIR__ . '/auth_check.php';

// 引入数据库连接
require_once __DIR__ . '/../../config/database.php';
$db = getDbConnection();

// 设置页面标题
$pageTitle = "合作伙伴链接管理";

// 处理表单提交
$message = '';
$messageType = '';

// 处理链接操作
if (isset($_POST['action']) && $_POST['action'] == 'save_link') {
    try {
        // 检查是否为编辑操作
        if (!empty($_POST['link_id'])) {
            // 更新现有链接
            $stmt = $db->prepare("UPDATE alliance_link SET category_id = ?, name = ?, url = ?, logo = ?, description = ?, status = ?, sort_order = ? WHERE id = ?");
            $stmt->execute([
                $_POST['category_id'],
                $_POST['name'],
                $_POST['url'],
                $_POST['logo'],
                $_POST['description'],
                $_POST['status'],
                $_POST['sort_order'],
                $_POST['link_id']
            ]);
            $message = "链接更新成功！";
        } else {
            // 添加新链接
            $stmt = $db->prepare("INSERT INTO alliance_link (category_id, name, url, logo, description, status, sort_order) VALUES (?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([
                $_POST['category_id'],
                $_POST['name'],
                $_POST['url'],
                $_POST['logo'],
                $_POST['description'],
                $_POST['status'],
                $_POST['sort_order']
            ]);
            $message = "新链接添加成功！";
        }
        $messageType = 'success';
    } catch (PDOException $e) {
        $message = "操作失败: " . $e->getMessage();
        $messageType = 'danger';
    }
}

// 处理删除链接操作
if (isset($_GET['action']) && $_GET['action'] == 'delete_link' && isset($_GET['id'])) {
    try {
        $stmt = $db->prepare("DELETE FROM alliance_link WHERE id = ?");
        $stmt->execute([$_GET['id']]);
        $message = "链接删除成功！";
        $messageType = 'success';
    } catch (PDOException $e) {
        $message = "删除失败: " . $e->getMessage();
        $messageType = 'danger';
    }
}

// 获取分类数据
$categories = $db->query("SELECT * FROM alliance_category ORDER BY sort_order, id")->fetchAll(PDO::FETCH_ASSOC);

// 获取链接数据
$links = $db->query("
    SELECT l.*, c.name as category_name 
    FROM alliance_link l
    JOIN alliance_category c ON l.category_id = c.id
    ORDER BY l.category_id, l.sort_order, l.id
")->fetchAll(PDO::FETCH_ASSOC);

// 加载编辑的链接数据
$editLink = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit_link' && isset($_GET['id'])) {
    $stmt = $db->prepare("SELECT * FROM alliance_link WHERE id = ?");
    $stmt->execute([$_GET['id']]);
    $editLink = $stmt->fetch(PDO::FETCH_ASSOC);
}
