<?php
// 防止直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    die('Direct access not allowed');
}

// 引入数据库配置文件
require_once '../config/database.php';

/**
 * 获取所有父级地区
 */
function getParentAreas() {
    $db = getDbConnection();
    $parentQuery = "SELECT id, name FROM area WHERE parent_id IS NULL ORDER BY sort_order ASC";
    $parentStmt = $db->query($parentQuery);
    return $parentStmt->fetchAll();
}

/**
 * 获取所有地区数据
 */
function getAllAreas() {
    $db = getDbConnection();
    $query = "SELECT a.*, p.name as parent_name 
              FROM area a 
              LEFT JOIN area p ON a.parent_id = p.id 
              ORDER BY 
                CASE WHEN a.parent_id IS NULL THEN a.sort_order ELSE p.sort_order END ASC,
                a.parent_id ASC,
                a.sort_order ASC,
                a.id ASC";
    $stmt = $db->query($query);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

/**
 * 组织地区数据的父子关系
 */
function organizeAreaHierarchy($areas) {
    $parentAreas = [];
    $childAreas = [];
    
    foreach ($areas as $area) {
        if ($area['parent_id'] === null) {
            $parentAreas[] = $area;
        } else {
            if (!isset($childAreas[$area['parent_id']])) {
                $childAreas[$area['parent_id']] = [];
            }
            $childAreas[$area['parent_id']][] = $area;
        }
    }
    
    return [
        'parentAreas' => $parentAreas,
        'childAreas' => $childAreas
    ];
}

/**
 * 获取所有地区的产品数量
 */
function getAreaProductCounts() {
    $db = getDbConnection();
    $query = "SELECT region_id, COUNT(*) as count FROM products GROUP BY region_id";
    $stmt = $db->query($query);
    $counts = [];
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $counts[$row['region_id']] = $row['count'];
    }
    return $counts;
}

// 获取所有数据
$parentAreas = getParentAreas();
$areas = getAllAreas();
$areaHierarchy = organizeAreaHierarchy($areas);
$productCounts = getAreaProductCounts();

// 将数据赋值给变量供视图使用
$parentAreasForView = $areaHierarchy['parentAreas'];
$childAreasForView = $areaHierarchy['childAreas'];
?>
