<?php
// 开启错误显示，便于调试
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../config/database.php';
require_once 'auth_check.php';
require_once 'classes/ScriptManager.php';

// 检查CSRF文件是否存在
if (file_exists('code/csrf.php')) {
    require_once 'code/csrf.php';
} else {
    // 如果CSRF文件不存在，提供一个简单的实现
    function generateCsrfToken() {
        if (!isset($_SESSION)) {
            session_start();
        }
        if (empty($_SESSION['csrf_token'])) {
            $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
        }
        return $_SESSION['csrf_token'];
    }
    
    function verifyCsrfToken($token) {
        if (!isset($_SESSION)) {
            session_start();
        }
        return isset($_SESSION['csrf_token']) && hash_equals($_SESSION['csrf_token'], $token);
    }
}

// 获取数据库连接
try {
    $db = getDbConnection();
    if (!$db) {
        throw new Exception("数据库连接失败");
    }

    // 获取分类列表
    $categories = $db->query("SELECT id, name FROM script_categories WHERE status = 1 ORDER BY sort_order ASC, id DESC")->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    $error = "数据库错误: " . $e->getMessage();
    $categories = [];
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 验证CSRF令牌
    if (!verifyCsrfToken($_POST['csrf_token'] ?? '')) {
        $error = "安全验证失败，请重新提交表单";
    } else {
        // 验证表单数据
        $name = trim($_POST['name'] ?? '');
        $category_id = intval($_POST['category_id'] ?? 0);
        $description = trim($_POST['description'] ?? '');
        $source_type = isset($_POST['source_type']) ? $_POST['source_type'] : 'original';
        $sort_order = intval($_POST['sort_order'] ?? 0);
        
        // 基本验证
        if (empty($name)) {
            $error = "请输入脚本名称";
        } elseif ($category_id <= 0) {
            $error = "请选择有效的分类";
        } else {
            // 验证分类是否存在
            $stmt = $db->prepare("SELECT id FROM script_categories WHERE id = ? AND status = 1");
            $stmt->execute([$category_id]);
            if (!$stmt->fetch()) {
                $error = "选择的分类不存在或已禁用！";
            } else {
                try {
                    // 获取脚本URL
                    $url = '';
                    $script_url = trim($_POST['script_url'] ?? '');
                    
                    if (empty($script_url)) {
                        throw new Exception('请提供脚本URL！');
                    }
                    
                    // 验证URL
                    if (!filter_var($script_url, FILTER_VALIDATE_URL)) {
                        throw new Exception('无效的URL地址！');
                    }
                    
                    $url = $script_url;
                    
                    // 插入数据库
                    $stmt = $db->prepare("INSERT INTO scripts (category_id, name, url, description, source_type, sort_order, created_at) VALUES (?, ?, ?, ?, ?, ?, NOW())");
                    $stmt->execute([$category_id, $name, $url, $description, $source_type, $sort_order]);
                    
                    // 记录日志
                    $admin_id = $_SESSION['admin_id'] ?? 0;
                    $log_stmt = $db->prepare("INSERT INTO admin_logs (admin_id, action, module, content, created_at) VALUES (?, 'add', 'script', ?, NOW())");
                    $log_stmt->execute([$admin_id, "添加脚本: $name"]);
                    
                    header("Location: script.php?msg=add_success");
                    exit;
                    
                } catch (Exception $e) {
                    $error = $e->getMessage();
                }
            }
        }
    }
}

// 生成CSRF令牌
$csrf_token = generateCsrfToken();
?>
