<?php
require_once '../config/database.php';
$db = getDbConnection();
$statusFilter = isset($_GET['status']) ? $_GET['status'] : 'all';
$validStatuses = ['all', 'open', 'pending', 'closed'];
if (!in_array($statusFilter, $validStatuses)) {
    $statusFilter = 'all';
}

// 构建查询条件
$whereClause = '';
$params = [];
if ($statusFilter !== 'all') {
    $whereClause = ' WHERE c.status = :status';
    $params['status'] = $statusFilter;
}


$unreadQuery = "
    SELECT COUNT(*) as unread_count
    FROM message m
    JOIN conversation c ON m.conversation_id = c.id
    WHERE m.is_read = 0 AND m.user_id IS NOT NULL AND c.status <> 'closed'
";
$unreadStmt = $db->query($unreadQuery);
$unreadCount = $unreadStmt->fetch(PDO::FETCH_ASSOC)['unread_count'];

// 获取工单列表函数
function getTickets($db, $statusFilter, $whereClause, $params)
{
    $query = "
        SELECT c.*, u.username, 
        (SELECT COUNT(*) FROM message WHERE conversation_id = c.id AND user_id IS NOT NULL AND is_read = 0) as unread_count,
        (SELECT created_at FROM message WHERE conversation_id = c.id ORDER BY created_at DESC LIMIT 1) as last_reply
        FROM conversation c
        LEFT JOIN user u ON c.user_id = u.id
        $whereClause
        ORDER BY 
        CASE c.status 
            WHEN 'open' THEN 1
            WHEN 'pending' THEN 2
            WHEN 'closed' THEN 3
        END,
        c.updated_at DESC
    ";

    $stmt = $statusFilter !== 'all' ? $db->prepare($query) : $db->query($query);
    if ($statusFilter !== 'all') {
        $stmt->execute($params);
    }

    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// 获取工单状态对应的中文名称和样式
function getStatusBadge($status)
{
    switch ($status) {
        case 'open':
            return '<span class="badge badge-danger">待处理</span>';
        case 'pending':
            return '<span class="badge badge-warning">处理中</span>';
        case 'closed':
            return '<span class="badge badge-success">已关闭</span>';
        default:
            return '<span class="badge">未知</span>';
    }
}

// 获取工单列表
$tickets = getTickets($db, $statusFilter, $whereClause, $params);
