<?php
/**
 * 后台工单详情页面的业务逻辑处理
 * 包含数据库操作、工单状态管理等功能
 */

// 引入数据库配置文件
require_once '../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

// 设置附件目录路径
$uploadBaseDir = $_SERVER['DOCUMENT_ROOT'] . '/uploads/'; // 使用服务器根目录的绝对路径
$ticketUploadDir = $uploadBaseDir . 'tickets/'; // 工单附件目录

// 确保上传目录存在
if (!file_exists($ticketUploadDir)) {
    mkdir($ticketUploadDir, 0777, true);
}

// 设置显示用的URL路径
$ticketUploadPath = '/uploads/tickets/'; // 使用绝对路径

// 检查是否提供了工单ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: ticket.php');
    exit;
}

$ticketId = intval($_GET['id']);
$message = '';
$error = '';

// 状态映射
$statusMap = [
    'open' => '未处理',
    'pending' => '处理中',
    'answered' => '已回复',
    'closed' => '已关闭',
];

// 优先级映射
$priorityMap = [
    'low' => '低',
    'medium' => '中',
    'high' => '高',
];

// 处理工单回复提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 回复工单
    if (isset($_POST['reply_content']) && !empty($_POST['reply_content'])) {
        $replyContent = trim($_POST['reply_content']);
        $newStatus = isset($_POST['status']) ? $_POST['status'] : null;
        $newPriority = isset($_POST['priority']) ? $_POST['priority'] : null;
        
        try {
            $db = getDbConnection();
            $db->beginTransaction();
            
            // 获取工单信息
            $ticketQuery = "SELECT * FROM tickets WHERE id = :id";
            $stmt = $db->prepare($ticketQuery);
            $stmt->bindParam(':id', $ticketId, PDO::PARAM_INT);
            $stmt->execute();
            $ticket = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$ticket) {
                throw new Exception('找不到工单记录');
            }
            
            // 添加管理员回复，移除conversation_id字段
            $replyQuery = "INSERT INTO ticket_replies (ticket_id, admin_id, message, created_at)
                          VALUES (:ticket_id, :admin_id, :message, NOW())";
            
            $adminId = 1; // 假设管理员ID为1，实际应该从会话中获取
            
            $stmt = $db->prepare($replyQuery);
            $stmt->execute([
                'ticket_id' => $ticketId,
                'admin_id' => $adminId,
                'message' => $replyContent
            ]);
            
            // 获取插入的回复ID
            $replyId = $db->lastInsertId();
            
            // 处理上传的附件 - 修改为支持多附件上传
            if (!empty($_FILES['attachments']['name'][0])) {
                // 循环处理每个上传的文件
                for ($i = 0; $i < count($_FILES['attachments']['name']); $i++) {
                    // 获取文件信息
                    $fileName = $_FILES['attachments']['name'][$i];
                    $fileType = $_FILES['attachments']['type'][$i];
                    $fileSize = $_FILES['attachments']['size'][$i];
                    $fileTmpName = $_FILES['attachments']['tmp_name'][$i];
                    $fileError = $_FILES['attachments']['error'][$i];
                    
                    // 检查上传是否成功
                    if ($fileError === UPLOAD_ERR_OK) {
                        // 生成唯一文件名
                        $newFileName = uniqid() . '_' . $fileName;
                        $filePath = $ticketUploadDir . $newFileName;
                        
                        // 移动上传的文件
                        if (move_uploaded_file($fileTmpName, $filePath)) {
                            // 将附件信息保存到数据库 - 保存完整的URL路径
                            $attachmentQuery = "INSERT INTO ticket_attachments (ticket_id, reply_id, file_name, file_path, file_type, file_size, created_at)
                                             VALUES (:ticket_id, :reply_id, :file_name, :file_path, :file_type, :file_size, NOW())";
                            $stmt = $db->prepare($attachmentQuery);
                            $stmt->execute([
                                'ticket_id' => $ticketId,
                                'reply_id' => $replyId,
                                'file_name' => $fileName,
                                'file_path' => $ticketUploadPath . $newFileName,
                                'file_type' => $fileType,
                                'file_size' => $fileSize
                            ]);
                        }
                    }
                }
            }
            
            // 更新工单状态和最后回复时间
            $updateFields = ['last_reply = NOW()'];
            $updateParams = [];
            
            // 如果有状态变更
            if ($newStatus && in_array($newStatus, array_keys($statusMap))) {
                $updateFields[] = 'status = :status';
                $updateParams['status'] = $newStatus;
            } else {
                // 默认设置为已回复状态
                $updateFields[] = 'status = :status';
                $updateParams['status'] = 'answered';
            }
            
            // 如果有优先级变更
            if ($newPriority && in_array($newPriority, array_keys($priorityMap))) {
                $updateFields[] = 'priority = :priority';
                $updateParams['priority'] = $newPriority;
            }
            
            $updateQuery = "UPDATE tickets SET " . implode(', ', $updateFields) . " WHERE id = :ticket_id";
            $updateParams['ticket_id'] = $ticketId;
            
            $stmt = $db->prepare($updateQuery);
            $stmt->execute($updateParams);
            
            $db->commit();
            $message = '回复已成功提交';
            
        } catch (Exception $e) {
            if (isset($db)) {
                $db->rollBack();
            }
            $error = '提交回复时出错: ' . $e->getMessage();
        }
    } else {
        $error = '回复内容不能为空';
    }
}

// 处理工单操作：关闭或重开工单
if (isset($_GET['action'])) {
    try {
        $db = getDbConnection();
        $action = $_GET['action'];
        
        if ($action === 'close') {
            $updateQuery = "UPDATE tickets SET status = 'closed' WHERE id = :ticket_id";
            $stmt = $db->prepare($updateQuery);
            $stmt->execute(['ticket_id' => $ticketId]);
            $message = '工单已成功关闭';
        } elseif ($action === 'reopen') {
            $updateQuery = "UPDATE tickets SET status = 'open' WHERE id = :ticket_id";
            $stmt = $db->prepare($updateQuery);
            $stmt->execute(['ticket_id' => $ticketId]);
            $message = '工单已成功重新开启';
        }
    } catch (Exception $e) {
        $error = '操作工单时出错: ' . $e->getMessage();
    }
}

try {
    // 获取工单详情
    $db = getDbConnection();
    
    // 获取工单基本信息，不再连接users表
    $ticketQuery = "SELECT t.*, 
                   DATE_FORMAT(t.created_at, '%Y-%m-%d %H:%i:%s') as formatted_created_at,
                   DATE_FORMAT(t.last_reply, '%Y-%m-%d %H:%i:%s') as formatted_last_reply
                   FROM tickets t 
                   WHERE t.id = :id";
    $stmt = $db->prepare($ticketQuery);
    $stmt->bindParam(':id', $ticketId, PDO::PARAM_INT);
    $stmt->execute();
    $ticket = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$ticket) {
        header('Location: ticket.php');
        exit;
    }
    
    // 获取工单回复，不再连接users和admin表
    $repliesQuery = "SELECT r.*, 
                    DATE_FORMAT(r.created_at, '%Y-%m-%d %H:%i:%s') as formatted_created_at
                    FROM ticket_replies r 
                    WHERE r.ticket_id = :ticket_id 
                    ORDER BY r.created_at ASC";
    $stmt = $db->prepare($repliesQuery);
    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
    $stmt->execute();
    $replies = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 获取所有附件并按回复ID组织
    $attachmentsQuery = "SELECT * FROM ticket_attachments WHERE ticket_id = :ticket_id ORDER BY reply_id, created_at ASC";
    $stmt = $db->prepare($attachmentsQuery);
    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
    $stmt->execute();
    $attachmentsData = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 整理附件数据，按回复ID分组
    $attachments = [];
    foreach ($attachmentsData as $attachment) {
        $replyId = $attachment['reply_id'];
        if (!isset($attachments[$replyId])) {
            $attachments[$replyId] = [];
        }
        $attachments[$replyId][] = $attachment;
    }
    
} catch (PDOException $e) {
    $error = '获取工单数据时出错: ' . $e->getMessage();
    $ticket = null;
    $replies = [];
    $attachments = [];
}
?>
