<?php
require_once 'code/config_code.php';
$config = Config::getInstance();
$configs = $config->getAllConfigs();

// 处理AJAX更新请求
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    header('Content-Type: application/json');
    $result = $config->handleAjaxRequest();
    echo json_encode($result);
    exit;
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>系统配置管理</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
        <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11.3.0/dist/sweetalert2.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@6.0.0/css/all.min.css">
        <link rel="stylesheet" href="public/css/style.css">
        <link rel="stylesheet" href="public/css/config_list.css">
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="sidebar">
            <?php include 'public/letf.php'; ?>
        </div>
        <div class="main-content">
            <div class="page-header d-flex justify-content-between align-items-center">
                <h1 class="page-title">系统配置管理</h1>
                <div>
                    <a href="#" class="btn btn-info me-2">
                        <i class="fas fa-history me-2"></i>修改记录
                    </a>
                    <a href="config_add.php" class="btn btn-primary">
                        <i class="fas fa-plus me-2"></i>添加配置
                    </a>
                </div>
            </div>
            <?php if (isset($_GET['success'])): ?>
            <div class="alert alert-success alert-dismissible fade show" role="alert">
                <i class="fas fa-check-circle me-2"></i>配置更新成功！
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
            <?php endif; ?>
            <?php if (isset($error)): ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i><?php echo htmlspecialchars($error); ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
            <?php endif; ?>
            <div class="card">
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-hover config-table mb-0">
                            <thead>
                                <tr>
                                    <th class="px-4">配置名称</th>
                                    <th>配置值</th>
                                    <th class="text-center" style="width: 100px;">排序</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($configs as $name => $configData): ?>
                                <tr>
                                    <td class="px-4">
                                        <div class="config-name"><?php echo htmlspecialchars($configData['cn_name']); ?></div>
                                        <div class="config-key"><?php echo htmlspecialchars($name); ?></div>
                                    </td>
                                    <td>
                                        <textarea class="config-value"
                                                  data-name="<?php echo htmlspecialchars($name); ?>"
                                                  rows="1"><?php echo htmlspecialchars($configData['content']); ?></textarea>
                                    </td>
                                    <td class="text-center">
                                        <input type="number"
                                               class="sort-value"
                                               data-name="<?php echo htmlspecialchars($name); ?>"
                                               value="<?php echo htmlspecialchars($configData['sort_order']); ?>"
                                               min="0"
                                               step="1">
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
        <script src="public/js/config_list.js"></script>
    </body>
</html>
