<?php
/**
 * 数据表创建和迁移脚本
 * 
 * 使用方法:
 * 1. 确保config/database.php配置正确
 * 2. 运行脚本: php create_and_migrate.php
 */

// 引入数据库配置文件
require_once '../config/database.php';

// 设置错误报告
error_reporting(E_ALL);
ini_set('display_errors', 1);

// 设置最大执行时间（如果数据量大的话）
set_time_limit(0);

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

echo "<h1>创建并迁移数据 lk_info → news</h1>";

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    echo "<p>步骤1: 创建临时表 lk_info...</p>";
    
    // 创建临时的lk_info表用于转移
    $createLkInfoTable = "
    CREATE TABLE IF NOT EXISTS `lk_info` (
      `InfoID` int(11) NOT NULL AUTO_INCREMENT,
      `MemberID` int(11) NULL DEFAULT NULL,
      `ChannelID` int(11) NULL DEFAULT NULL,
      `InfoTitle` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `InfoContent` longtext CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
      `InfoSContent` text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
      `Keywords` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `Tag` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '',
      `IsCheck` tinyint(4) NOT NULL DEFAULT 0,
      `Description` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `InfoOrder` int(11) NOT NULL DEFAULT 1000,
      `Title` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `InfoHit` int(11) NULL DEFAULT 1000,
      `InfoTime` datetime NULL DEFAULT NULL,
      PRIMARY KEY (`InfoID`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Compact;
    ";
    
    $db->exec($createLkInfoTable);
    
    echo "<p>步骤2: 插入测试数据到lk_info表...</p>";
    
    // 插入一些测试数据到lk_info表
    $insertTestData = "
    INSERT INTO `lk_info` (`InfoID`, `ChannelID`, `InfoTitle`, `InfoContent`, `InfoSContent`, `Keywords`, `IsCheck`, `InfoOrder`, `InfoHit`, `InfoTime`) VALUES
    (1, 1, '公司新闻标题1', '<p>这是公司新闻的详细内容1</p>', '这是公司新闻的摘要1', '公司,新闻,1', 1, 100, 500, '2024-01-01 10:00:00'),
    (2, 1, '公司新闻标题2', '<p>这是公司新闻的详细内容2</p>', '这是公司新闻的摘要2', '公司,新闻,2', 1, 200, 300, '2024-01-02 10:00:00'),
    (3, 2, '行业动态标题1', '<p>这是行业动态的详细内容1</p>', '这是行业动态的摘要1', '行业,动态,1', 1, 300, 800, '2024-01-03 10:00:00'),
    (4, 2, '行业动态标题2', '<p>这是行业动态的详细内容2</p>', '这是行业动态的摘要2', '行业,动态,2', 0, 400, 200, '2024-01-04 10:00:00'),
    (5, 3, '技术资讯标题1', '<p>这是技术资讯的详细内容1</p>', '这是技术资讯的摘要1', '技术,资讯,1', 1, 500, 1000, '2024-01-05 10:00:00');
    ";
    
    $db->exec($insertTestData);
    
    echo "<p>步骤3: 创建news表...</p>";
    
    // 创建news表
    $createNewsTable = "
    CREATE TABLE IF NOT EXISTS `news` (
      `id` int(11) NOT NULL AUTO_INCREMENT,
      `category_id` int(11) NULL DEFAULT NULL,
      `title` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `summary` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `keywords` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
      `content` text CHARACTER SET utf8 COLLATE utf8_general_ci NULL,
      `status` tinyint(1) NOT NULL DEFAULT 0,
      `views` int(11) NULL DEFAULT 0,
      `sort_order` int(11) NOT NULL DEFAULT 1000,
      `created_at` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
      `updated_at` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
      PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Compact;
    ";
    
    $db->exec($createNewsTable);
    
    echo "<p>步骤4: 从lk_info表迁移数据到news表...</p>";
    
    // 从lk_info表迁移数据到news表
    $migrateData = "
    INSERT INTO news (id, category_id, title, summary, keywords, content, status, views, sort_order, created_at)
    SELECT 
        InfoID, 
        ChannelID, 
        COALESCE(InfoTitle, Title), 
        InfoSContent, 
        Keywords, 
        InfoContent, 
        IsCheck, 
        InfoHit, 
        InfoOrder, 
        InfoTime
    FROM lk_info;
    ";
    
    $db->exec($migrateData);
    
    echo "<p>步骤5: 删除临时的lk_info表...</p>";
    
    // 删除临时的lk_info表（可选，取消注释如果需要）
    // $db->exec("DROP TABLE IF EXISTS `lk_info`");
    
    // 提交事务
    $db->commit();
    
    // 检查迁移的记录数
    $countResult = $db->query("SELECT COUNT(*) as count FROM news");
    $count = $countResult->fetch(PDO::FETCH_ASSOC)['count'];
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "数据迁移完成！共迁移 $count 条记录。<br>";
    echo "<a href='../admin/news.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 进入新闻管理页面。";
    echo "</div>";
    
} catch (Exception $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "错误: " . $e->getMessage();
    echo "</div>";
    exit(1);
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>创建并迁移数据</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }
        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }
        p {
            margin: 10px 0;
        }
        .success {
            color: #3c763d;
        }
        .error {
            color: #a94442;
        }
    </style>
</head>
<body>
    <div class="container">
        <!-- PHP脚本输出的内容会显示在这里 -->
    </div>
</body>
</html> 