<?php
/**
 * 数据库连接测试文件
 * 用于诊断数据库连接问题
 */

// 显示所有错误
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// 引入配置文件
require_once '../config/database.php';

// 输出HTML头部
?>
<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>数据库连接测试</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            color: #333;
        }
        h1 {
            color: #2c3e50;
            border-bottom: 2px solid #eee;
            padding-bottom: 10px;
        }
        .container {
            max-width: 800px;
            margin: 0 auto;
        }
        .card {
            background: #fff;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            margin-bottom: 20px;
            padding: 20px;
        }
        .success {
            color: #27ae60;
            background-color: #dff0d8;
            border: 1px solid #d6e9c6;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
        }
        .error {
            color: #c0392b;
            background-color: #f2dede;
            border: 1px solid #ebccd1;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
        }
        .warning {
            color: #e67e22;
            background-color: #fcf8e3;
            border: 1px solid #faebcc;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
        }
        .info {
            background-color: #d9edf7;
            border: 1px solid #bce8f1;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            padding: 8px 12px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }
        th {
            background-color: #f5f5f5;
        }
        pre {
            background: #f4f4f4;
            border: 1px solid #ddd;
            border-radius: 2px;
            padding: 10px;
            overflow: auto;
        }
        .actions {
            margin-top: 20px;
        }
        .btn {
            display: inline-block;
            padding: 8px 16px;
            background: #3498db;
            color: white;
            text-decoration: none;
            border-radius: 4px;
            border: none;
            cursor: pointer;
        }
        .btn:hover {
            background: #2980b9;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>数据库连接测试</h1>
        
        <div class="card">
            <h2>数据库配置信息</h2>
            <table>
                <tr>
                    <th>主机名</th>
                    <td><?php echo htmlspecialchars($dbConfig['host']); ?></td>
                </tr>
                <tr>
                    <th>数据库名</th>
                    <td><?php echo htmlspecialchars($dbConfig['dbname']); ?></td>
                </tr>
                <tr>
                    <th>用户名</th>
                    <td><?php echo htmlspecialchars($dbConfig['username']); ?></td>
                </tr>
                <tr>
                    <th>端口</th>
                    <td><?php echo htmlspecialchars($dbConfig['port']); ?></td>
                </tr>
                <tr>
                    <th>字符集</th>
                    <td><?php echo htmlspecialchars($dbConfig['charset']); ?></td>
                </tr>
            </table>
        </div>
        
        <div class="card">
            <h2>连接测试结果</h2>
            <?php
            // 测试数据库连接
            $result = getDbConnection();
            if ($result) {
                echo '<div class="success">';
                echo '<strong>成功!</strong> 数据库连接正常。';
                echo '</div>';
                
                // 测试数据库表
                try {
                    $tables = $result->query("SHOW TABLES")->fetchAll(PDO::FETCH_COLUMN);
                    echo '<h3>数据库表列表</h3>';
                    if (count($tables) > 0) {
                        echo '<ul>';
                        foreach ($tables as $table) {
                            echo '<li>' . htmlspecialchars($table) . '</li>';
                        }
                        echo '</ul>';
                    } else {
                        echo '<div class="warning">数据库中没有表。</div>';
                    }
                    
                    // 检查视频分类表
                    $hasCategoriesTable = in_array('video_categories', $tables);
                    if ($hasCategoriesTable) {
                        echo '<h3>视频分类表结构</h3>';
                        $columns = $result->query("DESCRIBE video_categories")->fetchAll(PDO::FETCH_ASSOC);
                        echo '<table>';
                        echo '<tr><th>字段</th><th>类型</th><th>允许为空</th><th>键</th><th>默认值</th></tr>';
                        foreach ($columns as $column) {
                            echo '<tr>';
                            echo '<td>' . htmlspecialchars($column['Field']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Type']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Null']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Key']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Default'] ?? 'NULL') . '</td>';
                            echo '</tr>';
                        }
                        echo '</table>';
                        
                        // 检查是否有记录
                        $count = $result->query("SELECT COUNT(*) FROM video_categories")->fetchColumn();
                        echo '<p>视频分类表中有 ' . $count . ' 条记录。</p>';
                        if ($count == 0) {
                            echo '<div class="warning">视频分类表中没有数据，这可能导致新增视频时无法选择分类。</div>';
                        }
                    } else {
                        echo '<div class="error">未找到 video_categories 表!</div>';
                        echo '<p>建议SQL:</p>';
                        echo '<pre>';
                        echo 'CREATE TABLE `video_categories` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `description` text,
  `sort_order` int(11) NOT NULL DEFAULT 0,
  `status` tinyint(1) NOT NULL DEFAULT 1,
  `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

INSERT INTO `video_categories` (`name`, `description`, `sort_order`, `status`) VALUES
(\'默认分类\', \'默认视频分类\', 1, 1);';
                        echo '</pre>';
                    }
                    
                    // 检查视频表
                    $hasVideosTable = in_array('videos', $tables);
                    if ($hasVideosTable) {
                        echo '<h3>视频表结构</h3>';
                        $columns = $result->query("DESCRIBE videos")->fetchAll(PDO::FETCH_ASSOC);
                        echo '<table>';
                        echo '<tr><th>字段</th><th>类型</th><th>允许为空</th><th>键</th><th>默认值</th></tr>';
                        foreach ($columns as $column) {
                            echo '<tr>';
                            echo '<td>' . htmlspecialchars($column['Field']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Type']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Null']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Key']) . '</td>';
                            echo '<td>' . htmlspecialchars($column['Default'] ?? 'NULL') . '</td>';
                            echo '</tr>';
                        }
                        echo '</table>';
                    } else {
                        echo '<div class="error">未找到 videos 表!</div>';
                        echo '<p>建议SQL:</p>';
                        echo '<pre>';
                        echo 'CREATE TABLE `videos` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(255) NOT NULL,
  `description` text,
  `category_id` int(11) NOT NULL,
  `status` tinyint(1) NOT NULL DEFAULT 1,
  `thumbnail` varchar(255) DEFAULT NULL,
  `video_url` varchar(255) NOT NULL,
  `duration` varchar(20) DEFAULT NULL,
  `author` varchar(100) DEFAULT NULL,
  `source` varchar(255) DEFAULT NULL,
  `seo_title` varchar(255) DEFAULT NULL,
  `seo_keywords` varchar(255) DEFAULT NULL,
  `seo_description` text,
  `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `category_id` (`category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;';
                        echo '</pre>';
                    }
                    
                } catch (PDOException $e) {
                    echo '<div class="error">';
                    echo '<strong>错误!</strong> 数据库查询失败: ' . htmlspecialchars($e->getMessage());
                    echo '</div>';
                }
            } else {
                echo '<div class="error">';
                echo '<strong>失败!</strong> 无法连接到数据库。请检查连接参数是否正确。';
                echo '</div>';
                
                // 检查MySQL服务是否运行
                echo '<h3>问题诊断</h3>';
                echo '<ol>';
                echo '<li>确认MySQL服务是否正在运行</li>';
                echo '<li>验证用户名和密码是否正确</li>';
                echo '<li>检查数据库名称是否存在</li>';
                echo '<li>确认主机名和端口是否正确</li>';
                echo '<li>检查用户是否有足够的权限</li>';
                echo '</ol>';
                
                echo '<h3>建议</h3>';
                echo '<ul>';
                echo '<li>尝试使用 phpMyAdmin 或其他数据库管理工具测试连接</li>';
                echo '<li>检查 MySQL 错误日志获取更多信息</li>';
                echo '<li>修改 ../config/database.php 中的连接参数</li>';
                echo '</ul>';
            }
            ?>
        </div>
        
        <div class="card">
            <h2>PHP信息</h2>
            <table>
                <tr>
                    <th>PHP版本</th>
                    <td><?php echo phpversion(); ?></td>
                </tr>
                <tr>
                    <th>PDO扩展</th>
                    <td><?php echo extension_loaded('pdo') ? '已启用' : '未启用'; ?></td>
                </tr>
                <tr>
                    <th>PDO MySQL扩展</th>
                    <td><?php echo extension_loaded('pdo_mysql') ? '已启用' : '未启用'; ?></td>
                </tr>
                <tr>
                    <th>显示错误</th>
                    <td><?php echo ini_get('display_errors') ? '开启' : '关闭'; ?></td>
                </tr>
                <tr>
                    <th>错误记录</th>
                    <td><?php echo ini_get('log_errors') ? '开启' : '关闭'; ?></td>
                </tr>
                <tr>
                    <th>错误日志路径</th>
                    <td><?php echo htmlspecialchars(ini_get('error_log')); ?></td>
                </tr>
            </table>
        </div>
        
        <div class="actions">
            <a href="video_edit.php" class="btn">返回视频编辑页面</a>
        </div>
    </div>
</body>
</html> 