<?php
/**
 * 直接导入SQL文件脚本
 * 
 * 使用方法:
 * 1. 确保lk_info.sql文件存在于backend/setup/目录中
 * 2. 运行脚本: php direct_import.php 或通过浏览器访问
 */

// 设置错误报告
error_reporting(E_ALL);
ini_set('display_errors', 1);

// 设置最大执行时间（如果数据量大的话）
set_time_limit(0);

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

// 数据库连接信息 - 请修改为您的实际信息
$host = 'localhost';
$username = 'root';
$password = ''; // 请修改为您的数据库密码
$database = 'test'; // 请修改为您的数据库名称

// SQL文件路径
$sqlFile = __DIR__ . '/setup/lk_info.sql';

echo '<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>直接导入SQL文件</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }
        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }
        p {
            margin: 10px 0;
        }
        .success {
            color: #3c763d;
            background-color: #dff0d8;
            padding: 15px;
            border-radius: 4px;
            margin-top: 20px;
        }
        .error {
            color: #a94442;
            background-color: #f2dede;
            padding: 15px;
            border-radius: 4px;
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>直接导入SQL文件</h1>';

try {
    // 检查SQL文件是否存在
    if (!file_exists($sqlFile)) {
        throw new Exception("SQL文件不存在: $sqlFile");
    }
    
    echo "<p>开始从SQL文件导入数据...</p>";
    
    // 读取SQL文件内容
    $sql = file_get_contents($sqlFile);
    if (!$sql) {
        throw new Exception("无法读取SQL文件内容");
    }
    
    // 连接数据库
    $db = new PDO("mysql:host=$host;dbname=$database;charset=utf8mb4", $username, $password);
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    // 执行SQL语句
    $db->exec($sql);
    
    // 检查是否创建了news表
    $checkTable = $db->query("SHOW TABLES LIKE 'news'");
    if ($checkTable->rowCount() > 0) {
        // 获取news表中的记录数
        $countResult = $db->query("SELECT COUNT(*) as count FROM news");
        $count = $countResult->fetch(PDO::FETCH_ASSOC)['count'];
        
        echo '<div class="success">';
        echo "SQL文件导入成功！news表已创建，包含 {$count} 条记录。<br>";
        echo "<a href='../admin/news.php'>点击这里</a> 进入新闻管理页面。";
        echo '</div>';
    } else {
        echo '<div class="error">';
        echo "SQL文件似乎已执行，但未能找到news表。请检查SQL文件内容。";
        echo '</div>';
    }
    
} catch (Exception $e) {
    echo '<div class="error">';
    echo "错误: " . $e->getMessage();
    echo '</div>';
}

echo '    </div>
</body>
</html>';
?> 