<!DOCTYPE html>

<?php
// 引入登录检查文件
require_once 'code/auth_check.php';
?>

<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>财务管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/finance.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>

      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-finance-btn">+ 添加记录</button>
          <button class="btn btn-secondary" id="save-all-btn">保存所有修改</button>
        </div>
        <div class="filter">
          <select class="select-filter" id="type-filter">
            <option value="0">所有类型</option>
            <option value="1">会员充值</option>
            <option value="2">管理员操作</option>
            <option value="3">系统订单</option>
          </select>
          <input type="text" class="input-filter" id="member-id-filter" placeholder="会员ID">
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>

      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>ID</th>
              <th>类型</th>
              <th class="sortable" data-sort="amount">金额 <span class="sort-indicator"></span></th>
              <th>会员ID</th>
              <th>描述</th>
              <th>支付状态</th>
              <th class="sortable" data-sort="created_at">创建时间 <span class="sort-indicator"></span></th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php
            require_once '../config/database.php';
            $db = getDbConnection();
            
            // 基本查询
            $query = "SELECT * FROM finance ORDER BY created_at DESC";
            $stmt = $db->query($query);
            $finances = $stmt->fetchAll();
            
            foreach ($finances as $finance) {
              $typeClass = "type-" . $finance['type'];
              $typeText = "";
              switch ($finance['type']) {
                case 1:
                  $typeText = "会员充值";
                  break;
                case 2:
                  $typeText = "管理员操作";
                  break;
                case 3:
                  $typeText = "系统订单";
                  break;
                default:
                  $typeText = "未知类型";
              }
              
              $amountClass = $finance['amount'] >= 0 ? "amount-positive" : "amount-negative";
              $amountPrefix = $finance['amount'] >= 0 ? "+" : "";
              
              $paymentStatusClass = $finance['payment_status'] == 1 ? "status-paid" : "status-unpaid";
              $paymentStatusText = $finance['payment_status'] == 1 ? "已支付" : "未支付";
              
              echo "<tr data-id=\"{$finance['id']}\">";
              echo "<td>{$finance['id']}</td>";
              echo "<td><span class=\"type-badge {$typeClass}\">{$typeText}</span></td>";
              echo "<td class=\"{$amountClass}\">{$amountPrefix}{$finance['amount']}</td>";
              echo "<td>{$finance['member_id']}</td>";
              echo "<td><span class=\"editable-text\" data-id=\"{$finance['id']}\" data-field=\"description\">{$finance['description']}</span></td>";
              echo "<td><span class=\"{$paymentStatusClass}\">{$paymentStatusText}</span></td>";
              echo "<td>{$finance['created_at']}</td>";
              echo "<td class=\"action-buttons\">";
              echo "<button class='btn btn-edit' data-id='{$finance['id']}'>修改</button>";
              echo "<button class='btn btn-delete' data-id='{$finance['id']}'>删除</button>";
              echo "</td>";
              echo "</tr>";
            }
            ?>
          </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除此财务记录吗？此操作不可逆。</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 添加按钮
      document.getElementById('add-finance-btn').addEventListener('click', function() {
        window.location.href = 'finance_add.php';
      });
      // 筛选功能
      document.getElementById('search-btn').addEventListener('click', function() {
        const typeValue = document.getElementById('type-filter').value;
        const memberId = document.getElementById('member-id-filter').value.trim();
        document.querySelectorAll('tbody tr').forEach(row => {
          let showRow = true;
          // 类型筛选
          if (typeValue !== '0') {
            const rowType = row.querySelector('td:nth-child(2) .type-badge').className.includes(`type-${typeValue}`);
            if (!rowType) showRow = false;
          }
          // 会员ID筛选
          if (memberId !== '') {
            const rowMemberId = row.querySelector('td:nth-child(4)').textContent;
            if (rowMemberId !== memberId) showRow = false;
          }
          row.style.display = showRow ? '' : 'none';
        });
      });
      // 删除功能
      const modal = document.getElementById('delete-modal');
      let deleteFinanceId = null;
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteFinanceId = this.dataset.id;
          modal.style.display = 'block';
        });
      });
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteFinanceId) {
          window.location.href = `finance_delete.php?id=${deleteFinanceId}`;
        }
      });
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteFinanceId = null;
      });
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteFinanceId = null;
        }
      });
      // 编辑按钮
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const financeId = this.dataset.id;
          window.location.href = `finance_edit.php?id=${financeId}`;
        });
      });
      // 可编辑文本功能（仅描述字段）
      document.querySelectorAll('.editable-text').forEach(element => {
        element.addEventListener('click', function() {
          const id = this.dataset.id;
          const field = this.dataset.field;
          const currentValue = this.textContent;
          // 创建输入框
          const input = document.createElement('input');
          input.type = 'text';
          input.value = currentValue;
          input.className = 'inline-edit';
          // 替换文本为输入框
          this.textContent = '';
          this.appendChild(input);
          input.focus();
          // 处理输入完成
          input.addEventListener('blur', function() {
            const newValue = this.value.trim();
            if (newValue && newValue !== currentValue) {
              // 发送AJAX请求更新数据
              updateFinanceField(id, field, newValue);
            }
            element.textContent = newValue || currentValue;
          });
          // 处理回车键
          input.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
              this.blur();
            }
          });
        });
      });
      // 更新财务字段的函数
      function updateFinanceField(id, field, value) {
        fetch('finance_update_field.php', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: `id=${id}&field=${field}&value=${encodeURIComponent(value)}`
          })
          .then(response => response.json())
          .then(data => {
            if (data.success) {
              // 显示成功消息
              const successMessage = document.getElementById('success-message');
              successMessage.textContent = '更新成功';
              successMessage.style.display = 'block';
              setTimeout(() => {
                successMessage.style.display = 'none';
              }, 3000);
            } else {
              alert('更新失败: ' + data.message);
            }
          })
          .catch(error => {
            console.error('Error:', error);
            alert('更新请求失败');
          });
      }
      // 表格排序功能
      document.querySelectorAll('th.sortable').forEach(header => {
        header.addEventListener('click', function() {
          const sortField = this.dataset.sort;
          const sortDirection = this.getAttribute('data-direction') === 'asc' ? 'desc' : 'asc';
          this.setAttribute('data-direction', sortDirection);
          const indicator = this.querySelector('.sort-indicator');
          indicator.textContent = sortDirection === 'asc' ? '↑' : '↓';
          sortTable(sortField, sortDirection);
        });
      });

      function sortTable(field, direction) {
        const tbody = document.querySelector('tbody');
        const rows = Array.from(tbody.querySelectorAll('tr'));
        rows.sort((a, b) => {
          let aValue, bValue;
          if (field === 'amount') {
            aValue = parseFloat(a.querySelector('td:nth-child(3)').textContent.replace('+', ''));
            bValue = parseFloat(b.querySelector('td:nth-child(3)').textContent.replace('+', ''));
          } else if (field === 'created_at') {
            aValue = new Date(a.querySelector('td:nth-child(6)').textContent);
            bValue = new Date(b.querySelector('td:nth-child(6)').textContent);
          }
          if (direction === 'asc') {
            return aValue - bValue;
          } else {
            return bValue - aValue;
          }
        });
        // 清空表格并重新填充
        while (tbody.firstChild) {
          tbody.removeChild(tbody.firstChild);
        }
        rows.forEach(row => {
          tbody.appendChild(row);
        });
      }
    });
    </script>
  </body>
</html>
