<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑财务记录</title>
    <link rel="stylesheet" href="public/css/style.css">
    <style>
    .form-container {
      background-color: #fff;
      border-radius: 8px;
      box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
      padding: 25px;
      max-width: 800px;
      margin: 20px auto;
    }
    .form-group {
      margin-bottom: 20px;
    }
    .form-group label {
      display: block;
      margin-bottom: 8px;
      font-weight: 600;
      color: #333;
    }
    .form-group input,
    .form-group select,
    .form-group textarea {
      width: 100%;
      padding: 10px;
      border: 1px solid #ddd;
      border-radius: 4px;
      font-size: 14px;
      transition: border-color 0.3s;
    }
    .form-group input:focus,
    .form-group select:focus,
    .form-group textarea:focus {
      border-color: #4a90e2;
      outline: none;
      box-shadow: 0 0 0 2px rgba(74, 144, 226, 0.2);
    }
    .form-buttons {
      display: flex;
      gap: 15px;
      margin-top: 30px;
    }
    .btn {
      padding: 10px 20px;
      border: none;
      border-radius: 4px;
      cursor: pointer;
      font-weight: 500;
      transition: all 0.3s;
    }
    .btn-primary {
      background-color: #4a90e2;
      color: white;
    }
    .btn-primary:hover {
      background-color: #3a7bc8;
    }
    .btn:not(.btn-primary) {
      background-color: #f5f5f5;
      color: #333;
    }
    .btn:not(.btn-primary):hover {
      background-color: #e5e5e5;
    }
    .page-title {
      font-size: 24px;
      font-weight: 600;
      margin-bottom: 25px;
      color: #333;
      border-bottom: 2px solid #4a90e2;
      padding-bottom: 10px;
    }
    .radio-group {
      display: flex;
      gap: 15px;
      margin-top: 10px;
    }
    .radio-group label {
      display: flex;
      align-items: center;
      cursor: pointer;
      font-weight: normal;
    }
    .radio-group input[type="radio"] {
      width: auto;
      margin-right: 5px;
    }
    </style>
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    
    <?php
    require_once '../config/database.php';
    $id = isset($_GET['id']) ? intval($_GET['id']) : 0;
    if (!$id) {
        header('Location: finance.php');
        exit;
    }
    
    try {
        $db = getDbConnection();
        $stmt = $db->prepare("SELECT * FROM finance WHERE id = ?");
        $stmt->execute([$id]);
        $finance = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$finance) {
            header('Location: finance.php');
            exit;
        }
        
        // 确定金额方向
        $direction = $finance['amount'] >= 0 ? 'income' : 'expense';
        $amount = abs($finance['amount']); // 取绝对值用于显示
        
    } catch (PDOException $e) {
        die("Error: " . $e->getMessage());
    }
    ?>
    
    <div class="main-content">
      <div class="form-container">
        <h2 class="page-title">编辑财务记录</h2>
        <form action="finance_edit_process.php" method="POST">
          <input type="hidden" name="id" value="<?php echo $finance['id']; ?>">
          
          <div class="form-group">
            <label>交易类型</label>
            <select id="type" name="type" required>
              <option value="1" <?php echo $finance['type'] == 1 ? 'selected' : ''; ?>>会员充值</option>
              <option value="2" <?php echo $finance['type'] == 2 ? 'selected' : ''; ?>>管理员操作</option>
              <option value="3" <?php echo $finance['type'] == 3 ? 'selected' : ''; ?>>系统订单</option>
            </select>
          </div>
          
          <div class="form-group">
            <label>资金方向</label>
            <div class="radio-group">
              <label>
                <input type="radio" name="direction" value="income" <?php echo $direction == 'income' ? 'checked' : ''; ?>> 收入(+)
              </label>
              <label>
                <input type="radio" name="direction" value="expense" <?php echo $direction == 'expense' ? 'checked' : ''; ?>> 支出(-)
              </label>
            </div>
          </div>
          
          <div class="form-group">
            <label for="amount">金额</label>
            <input type="number" id="amount" name="amount" step="0.01" min="0.01" value="<?php echo $amount; ?>" required>
          </div>
          
          <div class="form-group">
            <label for="member_id">会员ID</label>
            <input type="number" id="member_id" name="member_id" min="1" value="<?php echo $finance['member_id']; ?>" required>
          </div>
          
          <div class="form-group">
            <label for="description">描述</label>
            <textarea id="description" name="description" rows="3"><?php echo htmlspecialchars($finance['description']); ?></textarea>
          </div>
          
          <div class="form-group">
            <label>支付状态</label>
            <div class="radio-group">
              <label>
                <input type="radio" name="payment_status" value="1" <?php echo $finance['payment_status'] == 1 ? 'checked' : ''; ?>> 已支付
              </label>
              <label>
                <input type="radio" name="payment_status" value="0" <?php echo $finance['payment_status'] == 0 ? 'checked' : ''; ?>> 未支付
              </label>
            </div>
          </div>
          
          <div class="form-buttons">
            <button type="submit" class="btn btn-primary">保存</button>
            <button type="button" class="btn" onclick="location.href='finance.php'">返回</button>
          </div>
        </form>
      </div>
    </div>
  </body>
</html> 