<?php
/**
 * 数据库修复工具 - 添加缺失字段
 */

// 显示所有错误
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// 引入配置文件
require_once '../config/database.php';

echo '<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>数据库修复工具</title>
    <style>
        body { font-family: Arial, sans-serif; line-height: 1.6; margin: 20px; }
        .container { max-width: 800px; margin: 0 auto; }
        .success { color: green; background-color: #dff0d8; padding: 10px; border-radius: 5px; }
        .error { color: red; background-color: #f2dede; padding: 10px; border-radius: 5px; }
    </style>
</head>
<body>
    <div class="container">
        <h1>数据库修复工具</h1>';

// 获取数据库连接
$db = getDbConnection();

if (!$db) {
    echo '<div class="error">无法连接到数据库，请检查数据库配置。</div>';
} else {
    try {
        // 检查videos表是否存在
        $tables = $db->query("SHOW TABLES LIKE 'videos'")->fetchAll(PDO::FETCH_COLUMN);
        
        if (empty($tables)) {
            echo '<div class="error">找不到videos表，请先创建该表。</div>';
            echo '<h2>创建videos表的SQL:</h2>';
            echo '<pre>
CREATE TABLE `videos` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(255) NOT NULL,
  `description` text,
  `category_id` int(11) NOT NULL,
  `status` tinyint(1) NOT NULL DEFAULT 1,
  `thumbnail` varchar(255) DEFAULT NULL,
  `video_url` varchar(255) NOT NULL,
  `duration` varchar(20) DEFAULT NULL,
  `author` varchar(100) DEFAULT NULL,
  `source` varchar(255) DEFAULT NULL,
  `seo_title` varchar(255) DEFAULT NULL,
  `seo_keywords` varchar(255) DEFAULT NULL,
  `seo_description` text,
  `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `category_id` (`category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
            </pre>';
        } else {
            // 检查author字段是否存在
            $columns = $db->query("SHOW COLUMNS FROM videos")->fetchAll(PDO::FETCH_COLUMN);
            $needAuthor = !in_array('author', $columns);
            
            if ($needAuthor) {
                // 添加author字段
                $db->exec("ALTER TABLE videos ADD COLUMN author varchar(100) DEFAULT NULL AFTER duration");
                echo '<div class="success">成功添加 author 字段到 videos 表!</div>';
            } else {
                echo '<div class="success">author 字段已存在于 videos 表中。</div>';
            }
            
            // 检查其他字段
            $expectedColumns = ['source', 'seo_title', 'seo_keywords', 'seo_description'];
            foreach ($expectedColumns as $column) {
                if (!in_array($column, $columns)) {
                    switch ($column) {
                        case 'source':
                            $db->exec("ALTER TABLE videos ADD COLUMN source varchar(255) DEFAULT NULL AFTER author");
                            echo '<div class="success">成功添加 source 字段到 videos 表!</div>';
                            break;
                        case 'seo_title':
                            $db->exec("ALTER TABLE videos ADD COLUMN seo_title varchar(255) DEFAULT NULL AFTER source");
                            echo '<div class="success">成功添加 seo_title 字段到 videos 表!</div>';
                            break;
                        case 'seo_keywords':
                            $db->exec("ALTER TABLE videos ADD COLUMN seo_keywords varchar(255) DEFAULT NULL AFTER seo_title");
                            echo '<div class="success">成功添加 seo_keywords 字段到 videos 表!</div>';
                            break;
                        case 'seo_description':
                            $db->exec("ALTER TABLE videos ADD COLUMN seo_description text AFTER seo_keywords");
                            echo '<div class="success">成功添加 seo_description 字段到 videos 表!</div>';
                            break;
                    }
                }
            }
            
            // 显示当前的表结构
            echo '<h2>当前 videos 表结构:</h2>';
            $columns = $db->query("DESCRIBE videos")->fetchAll(PDO::FETCH_ASSOC);
            echo '<table border="1" cellpadding="5" cellspacing="0">';
            echo '<tr><th>字段</th><th>类型</th><th>允许为空</th><th>默认值</th></tr>';
            foreach ($columns as $column) {
                echo '<tr>';
                echo '<td>' . htmlspecialchars($column['Field']) . '</td>';
                echo '<td>' . htmlspecialchars($column['Type']) . '</td>';
                echo '<td>' . htmlspecialchars($column['Null']) . '</td>';
                echo '<td>' . htmlspecialchars($column['Default'] ?? 'NULL') . '</td>';
                echo '</tr>';
            }
            echo '</table>';
        }
    } catch (PDOException $e) {
        echo '<div class="error">数据库操作失败: ' . htmlspecialchars($e->getMessage()) . '</div>';
    }
}

echo '<div style="margin-top: 20px;">
    <a href="video_edit.php" style="display: inline-block; padding: 10px 15px; background-color: #3498db; color: white; text-decoration: none; border-radius: 5px;">返回视频编辑页面</a>
</div>
</div>
</body>
</html>'; 