<?php
/**
 * SQL文件导入脚本
 * 
 * 使用方法:
 * 1. 确保config/database.php配置正确
 * 2. 确保lk_info.sql文件存在于backend/setup/目录中
 * 3. 运行脚本: php import_from_sql.php
 */

// 引入数据库配置文件
require_once '../config/database.php';

// 设置错误报告
error_reporting(E_ALL);
ini_set('display_errors', 1);

// 设置最大执行时间（如果数据量大的话）
set_time_limit(0);

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

echo "<h1>从SQL文件导入数据</h1>";

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // SQL文件路径
    $sqlFile = __DIR__ . '/setup/lk_info.sql';
    
    if (!file_exists($sqlFile)) {
        throw new Exception("SQL文件不存在: $sqlFile");
    }
    
    echo "<p>开始从SQL文件导入数据...</p>";
    
    // 读取SQL文件内容
    $sql = file_get_contents($sqlFile);
    if (!$sql) {
        throw new Exception("无法读取SQL文件内容");
    }
    
    // 开始事务
    $db->beginTransaction();
    
    // 执行SQL语句
    $result = $db->exec($sql);
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "SQL文件导入成功！数据表已创建。<br>";
    echo "<a href='../admin/news.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 进入新闻管理页面。";
    echo "</div>";
    
} catch (Exception $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "错误: " . $e->getMessage();
    echo "</div>";
    exit(1);
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>从SQL文件导入数据</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }
        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }
        p {
            margin: 10px 0;
        }
        .success {
            color: #3c763d;
        }
        .error {
            color: #a94442;
        }
    </style>
</head>
<body>
    <div class="container">
        <!-- PHP脚本输出的内容会显示在这里 -->
    </div>
</body>
</html> 