<?php
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
// 获取所有供应商
$supplierQuery = "SELECT * FROM suppliers WHERE status = 1 ORDER BY id ASC";
$supplierStmt = $db->query($supplierQuery);
$suppliers = $supplierStmt->fetchAll();
// 获取当前选中的供应商ID
$currentSupplierId = isset($_GET['supplier_id']) ? intval($_GET['supplier_id']) : (count($suppliers) > 0 ? $suppliers[0]['id'] : 0);
// 获取当前供应商的所有线路
$lineQuery = "SELECT l.*, s.name as supplier_name FROM line l 
              JOIN suppliers s ON l.supplier_id = s.id
              WHERE l.supplier_id = :supplier_id 
              ORDER BY l.sort_order ASC, l.id ASC";
$lineStmt = $db->prepare($lineQuery);
$lineStmt->execute(['supplier_id' => $currentSupplierId]);
$lines = $lineStmt->fetchAll();
// 获取当前供应商信息
$currentSupplier = null;
if ($currentSupplierId > 0) {
    foreach ($suppliers as $supplier) {
        if ($supplier['id'] == $currentSupplierId) {
            $currentSupplier = $supplier;
            break;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>线路管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <style>
    .supplier-tabs {
      display: flex;
      margin-bottom: 20px;
      border-bottom: 1px solid #ddd;
      flex-wrap: wrap;
      align-items: center;
    }

    .supplier-tab {
      padding: 8px 15px;
      cursor: pointer;
      border: 1px solid #ddd;
      border-bottom: none;
      margin-right: 5px;
      margin-bottom: 5px;
      border-radius: 5px 5px 0 0;
      background-color: #f5f5f5;
      font-size: 14px;
    }

    .supplier-tab.active {
      background-color: #fff;
      border-bottom: 1px solid #fff;
      margin-bottom: -1px;
      font-weight: bold;
      color: #007bff;
    }

    .supplier-tab:hover:not(.active) {
      background-color: #e9e9e9;
    }

    #manage-supplier-btn {
      margin-left: auto;
      background-color: #f8f9fa;
      border: 1px solid #ddd;
      padding: 6px 12px;
      border-radius: 4px;
      cursor: pointer;
      font-size: 14px;
    }

    #manage-supplier-btn:hover {
      background-color: #e9ecef;
    }

    .function-area {
      display: flex;
      justify-content: space-between;
      align-items: center;
      margin-bottom: 20px;
      flex-wrap: wrap;
    }

    .button-group {
      margin-bottom: 10px;
    }

    .filter {
      display: flex;
      align-items: center;
    }

    .select-filter {
      margin-right: 10px;
      padding: 6px 10px;
      border: 1px solid #ddd;
      border-radius: 4px;
      min-width: 150px;
    }

    .btn {
      padding: 6px 12px;
      border-radius: 4px;
      border: none;
      cursor: pointer;
      font-size: 14px;
    }

    .btn-primary {
      background-color: #007bff;
      color: white;
    }

    .btn-primary:hover {
      background-color: #0069d9;
    }

    .btn-search {
      background-color: #28a745;
      color: white;
    }

    .btn-search:hover {
      background-color: #218838;
    }

    .btn-edit {
      background-color: #ffc107;
      color: #212529;
      margin-right: 5px;
    }

    .btn-edit:hover {
      background-color: #e0a800;
    }

    .btn-delete {
      background-color: #dc3545;
      color: white;
    }

    .btn-delete:hover {
      background-color: #c82333;
    }

    .line-container {
      margin-top: 20px;
    }

    .table-container {
      overflow-x: auto;
    }

    table {
      width: 100%;
      border-collapse: collapse;
    }

    th,
    td {
      padding: 12px 15px;
      text-align: left;
      border-bottom: 1px solid #ddd;
    }

    th {
      background-color: #f8f9fa;
      font-weight: bold;
    }

    tr:hover {
      background-color: #f5f5f5;
    }

    .status-badge {
      display: inline-block;
      width: 10px;
      height: 10px;
      border-radius: 50%;
      margin-right: 5px;
    }



    .status-inactive {
      background-color: #f44336;
    }

    .success-message {
      background-color: #4CAF50;
      color: white;
      padding: 10px;
      margin-bottom: 15px;
      border-radius: 4px;
      display: none;
    }

    .modal {
      display: none;
      position: fixed;
      z-index: 1000;
      left: 0;
      top: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.4);
    }

    .modal-content {
      background-color: #fefefe;
      margin: 15% auto;
      padding: 20px;
      border: 1px solid #888;
      border-radius: 5px;
      width: 400px;
      max-width: 80%;
    }

    .modal-buttons {
      display: flex;
      justify-content: flex-end;
      margin-top: 20px;
    }

    .btn-confirm {
      background-color: #dc3545;
      color: white;
      border: none;
      padding: 8px 16px;
      margin-right: 10px;
      cursor: pointer;
      border-radius: 4px;
    }

    .btn-cancel {
      background-color: #6c757d;
      color: white;
      border: none;
      padding: 8px 16px;
      cursor: pointer;
      border-radius: 4px;
    }

    @media screen and (max-width: 768px) {
      .function-area {
        flex-direction: column;
        align-items: flex-start;
      }

      .filter {
        margin-top: 10px;
        width: 100%;
      }

      .select-filter {
        flex-grow: 1;
      }

      .supplier-tabs {
        overflow-x: auto;
        white-space: nowrap;
        flex-wrap: nowrap;
        padding-bottom: 5px;
      }

      .supplier-tab {
        flex-shrink: 0;
      }

      #manage-supplier-btn {
        margin-left: 0;
        margin-top: 10px;
      }
    }

    </style>
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>

      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-line-btn">+ 添加线路</button>
        </div>
        <div class="filter">
          <select class="select-filter" id="supplier-filter">
            <option value="0">选择供应商</option>
            <?php
            foreach ($suppliers as $supplier) {
              echo "<option value=\"{$supplier['id']}\" " . ($supplier['id'] == $currentSupplierId ? 'selected' : '') . ">{$supplier['name']}</option>";
            }
            ?>
          </select>
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>

      <!-- 供应商选项卡 -->
      <div class="supplier-tabs">
        <?php foreach ($suppliers as $supplier): ?>
        <div class="supplier-tab <?php echo ($supplier['id'] == $currentSupplierId) ? 'active' : ''; ?>"
             data-supplier-id="<?php echo $supplier['id']; ?>">
          <?php echo $supplier['name']; ?>
        </div>
        <?php endforeach; ?>
        <button id="manage-supplier-btn">管理供应商</button>
      </div>

      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>线路ID</th>
              <th>线路名称</th>
              <th>供应商</th>
              <th>排序</th>
              <th>状态</th>
              <th>创建时间</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php if (empty($lines)): ?>
            <tr>
              <td colspan="7" style="text-align: center;">暂无线路数据</td>
            </tr>
            <?php else: ?>
            <?php foreach ($lines as $line): ?>
            <tr data-id="<?php echo $line['id']; ?>">
              <td><?php echo $line['id']; ?></td>
              <td>

                <?php echo $line['name']; ?>
              </td>
              <td><?php echo $line['supplier_name']; ?></td>
              <td><?php echo $line['sort_order']; ?></td>
              <td><?php echo $line['status'] ? '启用' : '禁用'; ?></td>
              <td><?php echo $line['created_at']; ?></td>
              <td class="action-buttons">
                <button class="btn btn-edit" data-id="<?php echo $line['id']; ?>">修改</button>
                <button class="btn btn-delete" data-id="<?php echo $line['id']; ?>"
                        data-name="<?php echo $line['name']; ?>">删除</button>
              </td>
            </tr>
            <?php endforeach; ?>
            <?php endif; ?>
          </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除线路 "<span id="delete-line-name"></span>" 吗？</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 供应商选项卡切换
      document.querySelectorAll('.supplier-tab').forEach(tab => {
        tab.addEventListener('click', function() {
          const supplierId = this.dataset.supplierId;
          window.location.href = `line.php?supplier_id=${supplierId}`;
        });
      });
      // 添加线路按钮
      document.getElementById('add-line-btn').addEventListener('click', function() {
        const supplierId = <?php echo $currentSupplierId; ?>;
        window.location.href = `line_add.php?supplier_id=${supplierId}`;
      });
      // 管理供应商按钮
      document.getElementById('manage-supplier-btn').addEventListener('click', function() {
        window.location.href = 'supplier.php';
      });
      // 查询按钮点击事件
      document.getElementById('search-btn').addEventListener('click', function() {
        const supplierId = document.getElementById('supplier-filter').value;
        if (supplierId > 0) {
          window.location.href = `line.php?supplier_id=${supplierId}`;
        }
      });
      // 删除功能相关代码
      const modal = document.getElementById('delete-modal');
      const deleteLineName = document.getElementById('delete-line-name');
      let deleteLineId = null;
      // 删除按钮点击事件
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteLineId = this.dataset.id;
          const lineName = this.dataset.name;
          deleteLineName.textContent = lineName;
          modal.style.display = 'block';
        });
      });
      // 确认删除按钮点击事件
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteLineId) {
          // 发送删除请求
          fetch('line_delete.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
              },
              body: 'id=' + deleteLineId
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                // 删除成功，移除对应的行
                const row = document.querySelector(`tr[data-id="${deleteLineId}"]`);
                if (row) {
                  row.remove();
                }
                // 显示成功消息
                const successMessage = document.getElementById('success-message');
                successMessage.textContent = data.message;
                successMessage.style.display = 'block';
                setTimeout(() => {
                  successMessage.style.display = 'none';
                }, 3000);
              } else {
                alert(data.message);
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('删除失败，请重试');
            })
            .finally(() => {
              modal.style.display = 'none';
              deleteLineId = null;
            });
        }
      });
      // 取消删除按钮点击事件
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteLineId = null;
      });
      // 点击模态框外部关闭
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteLineId = null;
        }
      });
      // 编辑按钮点击事件
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const lineId = this.dataset.id;
          window.location.href = `line_edit.php?id=${lineId}`;
        });
      });
      // 如果有成功消息参数，显示成功消息
      if (new URLSearchParams(window.location.search).has('success')) {
        const successMessage = document.getElementById('success-message');
        successMessage.textContent = "操作成功！";
        successMessage.style.display = 'block';
        setTimeout(() => {
          successMessage.style.display = 'none';
        }, 3000);
      }
    });
    </script>
  </body>
</html>
