<?php
/**
 * 线路添加页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取供应商ID
$supplierId = isset($_GET['supplier_id']) ? intval($_GET['supplier_id']) : 0;
// 获取数据库连接
$db = getDbConnection();
// 获取供应商信息
$supplier = null;
if ($supplierId > 0) {
    $supplierQuery = "SELECT * FROM suppliers WHERE id = :id";
    $supplierStmt = $db->prepare($supplierQuery);
    $supplierStmt->execute(['id' => $supplierId]);
    $supplier = $supplierStmt->fetch();
    if (!$supplier) {
        echo "供应商不存在";
        exit;
    }
}
// 获取所有供应商（用于下拉选择）
$allSuppliersQuery = "SELECT * FROM suppliers WHERE status = 1 ORDER BY id ASC";
$allSuppliersStmt = $db->query($allSuppliersQuery);
$allSuppliers = $allSuppliersStmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>添加线路</title>
    <link rel="stylesheet" href="public/css/style.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <div class="form-container">
        <form id="line-form" method="post" action="line_save.php">
          <div class="form-group">
            <label for="supplier_id">供应商</label>
            <select id="supplier_id" name="supplier_id" class="form-control" required>
              <option value="">请选择供应商</option>
              <?php foreach ($allSuppliers as $s): ?>
                <option value="<?php echo $s['id']; ?>" <?php echo ($supplierId == $s['id']) ? 'selected' : ''; ?>>
                  <?php echo $s['name']; ?>
                </option>
              <?php endforeach; ?>
            </select>
          </div>
          <div class="form-group">
            <label for="name">线路名称</label>
            <input type="text" id="name" name="name" class="form-control" required>
          </div>
          <div class="form-group">
            <label for="code">线路代码</label>
            <input type="text" id="code" name="code" class="form-control" required>
            <small class="form-text text-muted">只能包含小写字母、数字和下划线</small>
          </div>
          <div class="form-group">
            <label for="description">线路描述</label>
            <textarea id="description" name="description" class="form-control" rows="4"></textarea>
          </div>
          <div class="form-group">
            <label for="sort_order">排序</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="-10">
            <small class="form-text text-muted">建议使用负数（如-10、-9），数值越小排序越靠前</small>
          </div>
          <div class="form-group">
            <label for="status">状态</label>
            <select id="status" name="status" class="form-control">
              <option value="1" selected>启用</option>
              <option value="0">禁用</option>
            </select>
          </div>
          <div class="btn-container">
            <button type="submit" class="btn-save">保存</button>
            <a href="line.php<?php echo $supplierId ? '?supplier_id='.$supplierId : ''; ?>" class="btn-cancel">取消</a>
          </div>
        </form>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 表单提交前验证
      document.getElementById('line-form').addEventListener('submit', function(e) {
        e.preventDefault(); // 阻止默认提交
        const supplierId = document.getElementById('supplier_id').value.trim();
        const name = document.getElementById('name').value.trim();
        const code = document.getElementById('code').value.trim();
        if (!supplierId) {
          alert('请选择供应商');
          return false;
        }
        if (!name) {
          alert('请输入线路名称');
          return false;
        }
        if (!code) {
          alert('请输入线路代码');
          return false;
        }
        // 验证线路代码格式
        if (!/^[a-z0-9_]+$/.test(code)) {
          alert('线路代码只能包含小写字母、数字和下划线');
          return false;
        }
        // 如果验证通过，提交表单
        this.submit();
      });
    });
    </script>
  </body>
</html> 