<?php
/**
 * 线路删除处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
    exit;
}
// 获取要删除的线路ID
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
if ($id <= 0) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的线路ID']);
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查线路是否存在
    $lineQuery = "SELECT id, name FROM line WHERE id = :id";
    $lineStmt = $db->prepare($lineQuery);
    $lineStmt->execute(['id' => $id]);
    $line = $lineStmt->fetch();
    if (!$line) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => '线路不存在']);
        exit;
    }
    // 删除线路
    $deleteQuery = "DELETE FROM line WHERE id = :id";
    $deleteStmt = $db->prepare($deleteQuery);
    $deleteStmt->execute(['id' => $id]);
    // 返回成功响应
    header('Content-Type: application/json');
    echo json_encode(['success' => true, 'message' => "线路 '{$line['name']}' 已成功删除"]);
    exit;
} catch (PDOException $e) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '删除失败: ' . $e->getMessage()]);
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 