<?php
/**
 * 线路编辑页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取要编辑的线路ID
$lineId = isset($_GET['id']) ? intval($_GET['id']) : 0;
if ($lineId <= 0) {
    echo "无效的线路ID";
    exit;
}
// 获取数据库连接
$db = getDbConnection();
// 获取线路数据
$lineQuery = "SELECT * FROM line WHERE id = :id";
$lineStmt = $db->prepare($lineQuery);
$lineStmt->execute(['id' => $lineId]);
$line = $lineStmt->fetch();
if (!$line) {
    echo "线路不存在";
    exit;
}
// 获取所有供应商
$supplierQuery = "SELECT * FROM suppliers WHERE status = 1 ORDER BY id ASC";
$supplierStmt = $db->query($supplierQuery);
$suppliers = $supplierStmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑线路 - <?php echo $line['name']; ?></title>
    <link rel="stylesheet" href="public/css/style.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <div class="form-container">
        <form id="line-form" method="post" action="line_update.php">
          <input type="hidden" name="id" value="<?php echo $line['id']; ?>">
          <div class="form-group">
            <label for="supplier_id">供应商</label>
            <select id="supplier_id" name="supplier_id" class="form-control" required>
              <option value="">请选择供应商</option>
              <?php foreach ($suppliers as $supplier): ?>
                <option value="<?php echo $supplier['id']; ?>" <?php echo ($line['supplier_id'] == $supplier['id']) ? 'selected' : ''; ?>>
                  <?php echo $supplier['name']; ?>
                </option>
              <?php endforeach; ?>
            </select>
          </div>
          <div class="form-group">
            <label for="name">线路名称</label>
            <input type="text" id="name" name="name" class="form-control" value="<?php echo $line['name']; ?>" required>
          </div>
          <div class="form-group">
            <label for="code">线路代码</label>
            <input type="text" id="code" name="code" class="form-control" value="<?php echo $line['code']; ?>" required>
            <small class="form-text text-muted">只能包含小写字母、数字和下划线</small>
          </div>
          <div class="form-group">
            <label for="description">线路描述</label>
            <textarea id="description" name="description" class="form-control" rows="4"><?php echo $line['description']; ?></textarea>
          </div>
          <div class="form-group">
            <label for="sort_order">排序</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="<?php echo $line['sort_order']; ?>">
            <small class="form-text text-muted">建议使用负数（如-10、-9），数值越小排序越靠前</small>
          </div>
          <div class="form-group">
            <label for="status">状态</label>
            <select id="status" name="status" class="form-control">
              <option value="1" <?php echo $line['status'] == 1 ? 'selected' : ''; ?>>启用</option>
              <option value="0" <?php echo $line['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
            </select>
          </div>
          <div class="btn-container">
            <button type="submit" class="btn-save">保存</button>
            <a href="line.php?supplier_id=<?php echo $line['supplier_id']; ?>" class="btn-cancel">取消</a>
          </div>
        </form>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 表单提交前验证
      document.getElementById('line-form').addEventListener('submit', function(e) {
        e.preventDefault(); // 阻止默认提交
        const supplierId = document.getElementById('supplier_id').value.trim();
        const name = document.getElementById('name').value.trim();
        const code = document.getElementById('code').value.trim();
        if (!supplierId) {
          alert('请选择供应商');
          return false;
        }
        if (!name) {
          alert('请输入线路名称');
          return false;
        }
        if (!code) {
          alert('请输入线路代码');
          return false;
        }
        // 验证线路代码格式
        if (!/^[a-z0-9_]+$/.test(code)) {
          alert('线路代码只能包含小写字母、数字和下划线');
          return false;
        }
        // 如果验证通过，提交表单
        this.submit();
      });
    });
    </script>
  </body>
</html> 