<?php
/**
 * 线路保存处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: line.php');
    exit;
}
// 获取表单数据
$supplierId = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
$name = isset($_POST['name']) ? trim($_POST['name']) : '';
$code = isset($_POST['code']) ? trim($_POST['code']) : '';
$description = isset($_POST['description']) ? trim($_POST['description']) : '';
$sortOrder = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
$status = isset($_POST['status']) ? intval($_POST['status']) : 1;
// 验证数据
if ($supplierId <= 0 || empty($name) || empty($code)) {
    echo "请填写所有必填字段";
    exit;
}
// 验证线路代码格式
if (!preg_match('/^[a-z0-9_]+$/', $code)) {
    echo "线路代码只能包含小写字母、数字和下划线";
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查供应商是否存在
    $supplierQuery = "SELECT id FROM suppliers WHERE id = :id";
    $supplierStmt = $db->prepare($supplierQuery);
    $supplierStmt->execute(['id' => $supplierId]);
    if (!$supplierStmt->fetch()) {
        echo "供应商不存在";
        exit;
    }
    // 检查线路代码是否已存在于同一供应商下
    $checkCodeQuery = "SELECT id FROM line WHERE supplier_id = :supplier_id AND code = :code";
    $checkCodeStmt = $db->prepare($checkCodeQuery);
    $checkCodeStmt->execute([
        'supplier_id' => $supplierId,
        'code' => $code
    ]);
    if ($checkCodeStmt->fetch()) {
        echo "该供应商下已存在相同代码的线路";
        exit;
    }
    // 插入线路数据
    $insertQuery = "INSERT INTO line (supplier_id, name, code, description, sort_order, status) 
                   VALUES (:supplier_id, :name, :code, :description, :sort_order, :status)";
    $insertStmt = $db->prepare($insertQuery);
    $insertStmt->execute([
        'supplier_id' => $supplierId,
        'name' => $name,
        'code' => $code,
        'description' => $description,
        'sort_order' => $sortOrder,
        'status' => $status
    ]);
    // 重定向回线路列表页面，并带上成功参数
    header("Location: line.php?supplier_id={$supplierId}&success=1");
    exit;
} catch (PDOException $e) {
    echo "数据库错误: " . $e->getMessage();
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 