<?php
// 引入登录逻辑处理文件
require_once 'code/login_logic.php';

// 如果已经登录，直接跳转到后台首页
if (isAdminLoggedIn()) {
    redirectTo('index.php');
}

// 定义错误信息变量
$error_message = '';

// 处理登录请求
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取登录信息
    $username = isset($_POST['username']) ? trim($_POST['username']) : '';
    $password = isset($_POST['password']) ? trim($_POST['password']) : '';
    
    // 处理登录
    $result = processLogin($username, $password);
    
    if ($result['status'] === 'success') {
        // 登录成功，跳转到后台首页
        redirectTo('index.php');
    } else {
        // 登录失败，显示错误信息
        $error_message = $result['message'];
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>后台管理系统 - 登录</title>
        <link rel="stylesheet" href="public/css/login.css">
        <link rel="shortcut icon" href="public/images/favicon.ico" type="image/x-icon">
    </head>
    <body>
        <div class="login-container">
            <div class="login-header">
                <h1>后台管理系统</h1>
                <p class="system-info">管理员登录入口</p>
            </div>
            <?php if (!empty($error_message)): ?>
            <div class="error-message"><?php echo htmlspecialchars($error_message); ?></div>
            <?php endif; ?>
            <form class="login-form" id="login-form" method="post">
                <div class="input-group">
                    <input type="text" name="username" id="username" placeholder="请输入用户名" required autocomplete="off">
                </div>
                <div class="input-group">
                    <input type="password" name="password" id="password" placeholder="请输入密码" required>
                </div>
                <div class="form-footer">
                    <button type="submit" class="login-btn">登 录</button>
                </div>
            </form>
        </div>

        <div class="login-footer">
            <p>© <?php echo date('Y'); ?> 管理系统 - 安全登录</p>
        </div>
    </body>
</html>
