<?php
// 引入数据库配置文件
require_once '../config/database.php';
require_once 'code/auth_check.php';
// 获取数据库连接
$db = getDbConnection();
// 获取所有新闻分类
$categoryQuery = "SELECT * FROM news_category WHERE status = 1 ORDER BY sort_order ASC, id ASC";
$categoryStmt = $db->query($categoryQuery);
$categories = $categoryStmt->fetchAll();
// 获取当前选中的分类ID
$currentCategoryId = isset($_GET['category_id']) ? intval($_GET['category_id']) : (count($categories) > 0 ? $categories[0]['id'] : 0);

// 分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$perPage = 10; // 每页显示10条记录
$offset = ($page - 1) * $perPage;

// 获取当前分类的新闻总数
$countQuery = "SELECT COUNT(*) as total FROM news WHERE category_id = :category_id";
$countStmt = $db->prepare($countQuery);
$countStmt->execute(['category_id' => $currentCategoryId]);
$totalCount = $countStmt->fetch()['total'];
$totalPages = ceil($totalCount / $perPage);

// 如果请求的页码超出范围，则重置为第一页
if ($page < 1) $page = 1;
if ($totalPages > 0 && $page > $totalPages) $page = $totalPages;

// 获取当前分类的分页新闻
$newsQuery = "SELECT * FROM news WHERE category_id = :category_id ORDER BY sort_order ASC, created_at DESC, id ASC LIMIT :limit OFFSET :offset";
$newsStmt = $db->prepare($newsQuery);
$newsStmt->bindValue(':category_id', $currentCategoryId, PDO::PARAM_INT);
$newsStmt->bindValue(':limit', $perPage, PDO::PARAM_INT);
$newsStmt->bindValue(':offset', $offset, PDO::PARAM_INT);
$newsStmt->execute();
$newsList = $newsStmt->fetchAll();

// 获取当前分类信息
$currentCategory = null;
if ($currentCategoryId > 0) {
    foreach ($categories as $category) {
        if ($category['id'] == $currentCategoryId) {
            $currentCategory = $category;
            break;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>新闻管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/news.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-news-btn">+ 添加新闻</button>
          <button class="btn btn-info" id="manage-category-btn">管理分类</button>
        </div>
        <div class="filter">
          <select class="select-filter" id="category-filter">
            <option value="0">选择分类</option>
            <?php foreach ($categories as $category): ?>
            <option value="<?php echo $category['id']; ?>" <?php echo $category['id'] == $currentCategoryId ? 'selected' : ''; ?>>
              <?php echo $category['name']; ?>
            </option>
            <?php endforeach; ?>
          </select>
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>
      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>ID</th>
              <th>标题</th>
              <th>简介</th>
              <th>浏览量</th>
              <th>排序</th>
              <th>状态</th>
              <th>发布时间</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php if (empty($newsList)): ?>
            <tr>
              <td colspan="8" style="text-align: center;">暂无新闻数据</td>
            </tr>
            <?php else: ?>
            <?php foreach ($newsList as $news): ?>
            <tr>
              <td><?php echo $news['id']; ?></td>
              <td><?php echo $news['title']; ?></td>
              <td><?php echo !empty($news['summary']) ? mb_substr($news['summary'], 0, 30, 'UTF-8') . '...' : ''; ?></td>
              <td><?php echo $news['views']; ?></td>
              <td><?php echo $news['sort_order']; ?></td>
              <td><?php echo $news['status'] ? '发布' : '草稿'; ?></td>
              <td><?php echo isset($news['publish_time']) && $news['publish_time'] ? date('Y-m-d H:i', strtotime($news['publish_time'])) : ''; ?></td>
              <td class="action-buttons">
                <button class="btn btn-edit" data-id="<?php echo $news['id']; ?>">修改</button>
                <button class="btn btn-delete" data-id="<?php echo $news['id']; ?>"
                        data-title="<?php echo htmlspecialchars($news['title']); ?>">删除</button>
              </td>
            </tr>
            <?php endforeach; ?>
            <?php endif; ?>
          </tbody>
        </table>
      </div>
      <!-- 分页控件 -->
      <?php if ($totalPages > 1): ?>
      <div class="pagination">
        <!-- 上一页 -->
        <a href="<?php echo $page > 1 ? "news.php?category_id={$currentCategoryId}&page=" . ($page - 1) : '#'; ?>"
           class="page-link <?php echo $page <= 1 ? 'disabled' : ''; ?>">上一页</a>

        <!-- 页码 -->
        <?php
        // 显示最多5个页码
        $startPage = max(1, $page - 2);
        $endPage = min($totalPages, $startPage + 4);
        if ($endPage - $startPage < 4) {
            $startPage = max(1, $endPage - 4);
        }
        
        for ($i = $startPage; $i <= $endPage; $i++):
        ?>
        <a href="news.php?category_id=<?php echo $currentCategoryId; ?>&page=<?php echo $i; ?>"
           class="page-link <?php echo ($i == $page) ? 'active' : ''; ?>">
          <?php echo $i; ?>
        </a>
        <?php endfor; ?>

        <!-- 下一页 -->
        <a href="<?php echo $page < $totalPages ? "news.php?category_id={$currentCategoryId}&page=" . ($page + 1) : '#'; ?>"
           class="page-link <?php echo $page >= $totalPages ? 'disabled' : ''; ?>">下一页</a>
      </div>
      <?php endif; ?>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除新闻 "<span id="delete-news-title"></span>" 吗？</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 变量声明
      const currentCategory = '<?php echo $currentCategoryId; ?>';
      const currentPage = <?php echo $page; ?>;
      const deleteModal = document.getElementById('delete-modal');
      // 分类筛选器变化事件
      document.getElementById('category-filter').addEventListener('change', function() {
        const categoryId = this.value;
        if (categoryId > 0) {
          window.location.href = `news.php?category_id=${categoryId}&page=1`;
        }
      });
      // 查询按钮点击事件
      document.getElementById('search-btn').addEventListener('click', function() {
        const categoryId = document.getElementById('category-filter').value;
        if (categoryId > 0) {
          window.location.href = `news.php?category_id=${categoryId}&page=1`;
        } else {
          alert('请选择一个分类');
        }
      });
      // 添加新闻按钮
      document.getElementById('add-news-btn').addEventListener('click', function() {
        window.location.href = 'news_add.php?category_id=' + currentCategory;
      });
      // 管理分类按钮
      document.getElementById('manage-category-btn').addEventListener('click', function() {
        window.location.href = 'news_category.php';
      });
      // 删除按钮点击事件
      document.addEventListener('click', function(e) {
        if (e.target.classList.contains('btn-delete')) {
          const newsId = e.target.dataset.id;
          const newsTitle = e.target.dataset.title;
          document.getElementById('delete-news-title').textContent = newsTitle;
          deleteModal.style.display = 'flex';
          // 存储要删除的ID
          document.getElementById('confirm-delete').dataset.id = newsId;
        }
      });
      // 确认删除
      document.getElementById('confirm-delete').addEventListener('click', function() {
        const newsId = this.dataset.id;
        // 发送删除请求
        fetch('news_delete.php', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: 'id=' + newsId
          })
          .then(response => response.json())
          .then(data => {
            if (data.success) {
              // 删除成功，刷新页面
              window.location.reload();
            } else {
              alert(data.message || '删除失败，请重试');
            }
          })
          .catch(error => {
            console.error('Error:', error);
            alert('删除失败，请重试');
          });
        // 关闭模态框
        deleteModal.style.display = 'none';
      });
      // 取消删除
      document.getElementById('cancel-delete').addEventListener('click', function() {
        deleteModal.style.display = 'none';
      });
      // 点击模态框外部关闭
      window.addEventListener('click', function(e) {
        if (e.target === deleteModal) {
          deleteModal.style.display = 'none';
        }
      });
      // 编辑按钮点击事件
      document.addEventListener('click', function(e) {
        if (e.target.classList.contains('btn-edit')) {
          const newsId = e.target.dataset.id;
          window.location.href = 'news_edit.php?id=' + newsId;
        }
      });
    });
    </script>
  </body>
</html>
