<?php
/**
 * 新闻添加页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取分类ID
$categoryId = isset($_GET['category_id']) ? intval($_GET['category_id']) : 0;
// 获取数据库连接
$db = getDbConnection();
// 获取分类信息
$category = null;
if ($categoryId > 0) {
    $categoryQuery = "SELECT * FROM news_category WHERE id = :id";
    $categoryStmt = $db->prepare($categoryQuery);
    $categoryStmt->execute(['id' => $categoryId]);
    $category = $categoryStmt->fetch();
    if (!$category) {
        echo "分类不存在";
        exit;
    }
}
// 获取所有分类（用于下拉选择）
$allCategoriesQuery = "SELECT * FROM news_category WHERE status = 1 ORDER BY sort_order ASC, id ASC";
$allCategoriesStmt = $db->query($allCategoriesQuery);
$allCategories = $allCategoriesStmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>添加新闻</title>
    <link rel="stylesheet" href="public/css/style.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <div class="form-container">
        <form id="news-form" method="post" action="news_save.php">
          <div class="form-group">
            <label for="category_id">所属分类</label>
            <select id="category_id" name="category_id" class="form-control" required>
              <option value="">请选择分类</option>
              <?php foreach ($allCategories as $cat): ?>
                <option value="<?php echo $cat['id']; ?>" <?php echo ($categoryId == $cat['id']) ? 'selected' : ''; ?>>
                  <?php echo $cat['name']; ?>
                </option>
              <?php endforeach; ?>
            </select>
          </div>
          <div class="form-group">
            <label for="title">新闻标题</label>
            <input type="text" id="title" name="title" class="form-control" required>
          </div>
          <div class="form-group">
            <label for="summary">新闻简介</label>
            <textarea id="summary" name="summary" class="form-control" rows="3"></textarea>
            <small class="form-text text-muted">简要描述新闻内容，不超过500字符</small>
          </div>
          <div class="form-group">
            <label for="keywords">关键词</label>
            <input type="text" id="keywords" name="keywords" class="form-control">
            <small class="form-text text-muted">多个关键词用逗号分隔</small>
          </div>
          <div class="form-group">
            <label for="content">详细内容</label>
            <textarea id="content" name="content" class="form-control" rows="15"></textarea>
          </div>
          <div class="form-group">
            <label for="sort_order">排序</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="0">
            <small class="form-text text-muted">数值越小排序越靠前</small>
          </div>
          <div class="form-group">
            <label for="status">状态</label>
            <select id="status" name="status" class="form-control">
              <option value="1" selected>发布</option>
              <option value="0">草稿</option>
            </select>
          </div>
          <div class="btn-container">
            <button type="submit" class="btn-save">保存</button>
            <a href="news.php<?php echo $categoryId ? '?category_id='.$categoryId : ''; ?>" class="btn-cancel">取消</a>
          </div>
        </form>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 表单提交前验证
      document.getElementById('news-form').addEventListener('submit', function(e) {
        e.preventDefault(); // 阻止默认提交
        const categoryId = document.getElementById('category_id').value.trim();
        const title = document.getElementById('title').value.trim();
        const content = document.getElementById('content').value.trim();
        
        if (!categoryId) {
          alert('请选择所属分类');
          return false;
        }
        if (!title) {
          alert('请输入新闻标题');
          return false;
        }
        if (!content) {
          alert('请输入新闻详细内容');
          return false;
        }
        
        // 如果验证通过，提交表单
        this.submit();
      });
    });
    </script>
  </body>
</html> 