<?php
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
// 获取所有新闻分类
$categoryQuery = "SELECT * FROM news_category ORDER BY sort_order ASC, id ASC";
$categoryStmt = $db->query($categoryQuery);
$categories = $categoryStmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>新闻分类管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
    /* 整体页面样式 */
    body {
      font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
      color: #333;
      margin: 0;
      padding: 0;
      min-height: 100vh;
    }

    /* 顶部导航栏样式 */
    .top-header {
      position: fixed;
      top: 0;
      left: 0;
      right: 0;
      height: 60px;
      background: #fff;
      box-shadow: 0 1px 4px rgba(0, 0, 0, 0.1);
      z-index: 1000;
      display: flex;
      align-items: center;
      padding: 0 20px;
    }

    .logo {
      font-size: 20px;
      font-weight: 600;
      color: #1a2236;
      text-decoration: none;
      margin-right: 40px;
    }

    .nav-menu {
      display: flex;
      gap: 20px;
      align-items: center;
    }

    .nav-item {
      color: #4b5563;
      text-decoration: none;
      font-size: 14px;
      font-weight: 500;
      padding: 8px 12px;
      border-radius: 6px;
      transition: all 0.3s ease;
    }

    .nav-item:hover {
      color: #2196F3;
      background: rgba(33, 150, 243, 0.1);
    }

    .nav-item.active {
      color: #2196F3;
      background: rgba(33, 150, 243, 0.1);
    }

    /* 修复左侧菜单和主内容区域的布局 */
    .sidebar {
      position: fixed;
      left: 0;
      top: 60px;
      bottom: 0;
      width: 220px;
      background: #1a2236;
      z-index: 100;
      padding-top: 20px;
    }

    .sidebar-menu {
      list-style: none;
      padding: 0;
      margin: 0;
    }

    .sidebar-item {
      padding: 12px 20px;
      color: #a0aec0;
      text-decoration: none;
      display: flex;
      align-items: center;
      gap: 12px;
      transition: all 0.3s ease;
      font-size: 14px;
    }

    .sidebar-item:hover {
      background: rgba(255, 255, 255, 0.1);
      color: #fff;
    }

    .sidebar-item.active {
      background: rgba(255, 255, 255, 0.1);
      color: #fff;
      border-left: 3px solid #2196F3;
    }

    .sidebar-item i {
      font-size: 18px;
      width: 20px;
      text-align: center;
    }

    .main-content {
      position: relative;
      margin-left: 220px;
      /* 左侧菜单宽度 */
      margin-top: 60px;
      /* 顶部导航栏高度 */
      padding: 20px;
      background-color: #fff;
      min-height: calc(100vh - 100px);
    }

    /* 头部样式增强 */
    .header {
      display: flex;
      justify-content: space-between;
      align-items: center;
      margin-bottom: 25px;
      padding: 15px 20px;
      background: #fff;
      border-radius: 8px;
      box-shadow: 0 2px 4px rgba(0, 0, 0, 0.04);
    }

    .button-group {
      display: flex;
      gap: 12px;
    }

    /* 按钮样式优化 */
    .btn {
      padding: 8px 20px;
      border: none;
      border-radius: 6px;
      cursor: pointer;
      font-weight: 500;
      transition: all 0.3s ease;
      text-decoration: none;
      display: inline-flex;
      align-items: center;
      justify-content: center;
      font-size: 14px;
      letter-spacing: 0.3px;
    }

    #add-category-btn {
      background-color: #4CAF50;
      color: white;
      box-shadow: 0 2px 4px rgba(76, 175, 80, 0.2);
    }

    #add-category-btn:hover {
      background-color: #43a047;
      transform: translateY(-1px);
    }

    a.btn {
      background-color: #2196F3;
      color: white;
      box-shadow: 0 2px 4px rgba(33, 150, 243, 0.2);
    }

    a.btn:hover {
      background-color: #1e88e5;
      transform: translateY(-1px);
    }

    /* 表格样式优化 */
    .table-container {
      overflow-x: auto;
      background: #fff;
      border-radius: 8px;
      box-shadow: 0 2px 8px rgba(0, 0, 0, 0.06);
      margin-top: 20px;
    }

    table {
      width: 100%;
      border-collapse: separate;
      border-spacing: 0;
      background-color: white;
    }

    th {
      background-color: #f8f9fa;
      color: #2c3e50;
      font-weight: 600;
      text-align: left;
      padding: 16px;
      border-bottom: 2px solid #e9ecef;
      font-size: 14px;
    }

    td {
      padding: 16px;
      border-bottom: 1px solid #edf2f7;
      vertical-align: middle;
      font-size: 14px;
      color: #4a5568;
    }

    tr:hover {
      background-color: #f8fafc;
    }

    /* 状态徽章样式优化 */
    .status-badge {
      display: inline-block;
      width: 8px;
      height: 8px;
      border-radius: 50%;
      margin-right: 8px;
      box-shadow: 0 0 0 2px rgba(0, 0, 0, 0.05);
    }

    .status-active {
      background-color: #10b981;
    }

    .status-inactive {
      background-color: #ef4444;
    }

    /* 操作按钮样式优化 */
    .btn-edit,
    .btn-delete {
      padding: 6px 12px;
      font-size: 13px;
      border-radius: 4px;
      min-width: 80px;
    }

    .btn-edit {
      background-color: #3b82f6;
      color: white;
      box-shadow: 0 2px 4px rgba(59, 130, 246, 0.2);
    }

    .btn-delete {
      background-color: #ef4444;
      color: white;
      box-shadow: 0 2px 4px rgba(239, 68, 68, 0.2);
    }

    .btn-edit:hover,
    .btn-delete:hover {
      transform: translateY(-1px);
      box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
    }

    /* 成功消息样式优化 */
    .success-message {
      background-color: #10b981;
      color: white;
      padding: 16px;
      margin-bottom: 20px;
      border-radius: 8px;
      display: none;
      box-shadow: 0 4px 6px rgba(16, 185, 129, 0.1);
      animation: slideDown 0.3s ease;
      font-size: 14px;
    }

    @keyframes slideDown {
      from {
        opacity: 0;
        transform: translateY(-20px);
      }

      to {
        opacity: 1;
        transform: translateY(0);
      }
    }

    /* 模态框样式优化 */
    .modal {
      display: none;
      position: fixed;
      z-index: 1000;
      left: 0;
      top: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.5);
      animation: fadeIn 0.3s ease;
      backdrop-filter: blur(4px);
    }

    .modal-content {
      background-color: #fff;
      margin: 8% auto;
      padding: 30px;
      border-radius: 12px;
      box-shadow: 0 8px 30px rgba(0, 0, 0, 0.12);
      width: 450px;
      max-width: 90%;
    }

    .modal-content h3 {
      margin: 0 0 20px 0;
      color: #1f2937;
      font-size: 20px;
      font-weight: 600;
    }

    .warning {
      color: #ef4444;
      font-weight: 500;
      background: #fee2e2;
      padding: 12px;
      border-radius: 6px;
      margin: 16px 0;
      font-size: 14px;
    }

    .modal-buttons {
      display: flex;
      justify-content: flex-end;
      gap: 12px;
      margin-top: 24px;
    }

    .btn-confirm,
    .btn-cancel {
      padding: 8px 20px;
      border-radius: 6px;
      font-weight: 500;
      font-size: 14px;
      transition: all 0.3s ease;
    }

    .btn-confirm {
      background-color: #ef4444;
      color: white;
    }

    .btn-cancel {
      background-color: #9ca3af;
      color: white;
    }

    .btn-confirm:hover,
    .btn-cancel:hover {
      transform: translateY(-1px);
      box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
    }

    /* 响应式布局优化 */
    @media (max-width: 1024px) {
      .main-content {
        margin-left: 200px;
      }

      .sidebar {
        width: 200px;
      }

      .nav-menu {
        gap: 10px;
      }

      .nav-item {
        padding: 6px 10px;
        font-size: 13px;
      }
    }

    @media (max-width: 768px) {
      .top-header {
        padding: 0 15px;
      }

      .logo {
        font-size: 18px;
        margin-right: 20px;
      }

      .nav-menu {
        display: none;
      }

      .mobile-menu-btn {
        display: block;
        font-size: 24px;
        color: #1a2236;
        background: none;
        border: none;
        padding: 0;
        margin-left: auto;
        cursor: pointer;
      }

      .main-content {
        margin-left: 0;
        padding: 15px;
      }

      .sidebar {
        transform: translateX(-100%);
        transition: transform 0.3s ease;
      }

      .sidebar.active {
        transform: translateX(0);
      }

      .header {
        flex-direction: column;
        align-items: stretch;
        gap: 10px;
        padding: 12px;
      }

      .button-group {
        flex-direction: column;
        width: 100%;
      }

      .btn {
        width: 100%;
      }

      th,
      td {
        padding: 12px;
        font-size: 13px;
      }

      .modal-content {
        margin: 20% auto;
        padding: 20px;
      }

      .sidebar-overlay {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        right: 0;
        bottom: 0;
        background: rgba(0, 0, 0, 0.5);
        z-index: 99;
      }

      .sidebar-overlay.active {
        display: block;
      }
    }

    </style>
  </head>
  <body> <?php include 'public/header.php'; ?> <div class="sidebar"> <?php include 'public/letf.php'; ?> </div>
    <div class="sidebar-overlay"></div>
    <!-- 左侧菜单 -->
    <div class="sidebar">
      <nav class="sidebar-menu">
        <a href="news.php" class="sidebar-item">
          <i class="fas fa-newspaper"></i> 新闻列表 </a>
        <a href="news_category.php" class="sidebar-item active">
          <i class="fas fa-folder"></i> 分类管理 </a>
        <a href="news_tag.php" class="sidebar-item">
          <i class="fas fa-tags"></i> 标签管理 </a>
      </nav>
    </div>
    <div class="main-content">
      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>
      <div class="header">
        <div class="button-group">
          <button class="btn" id="add-category-btn">+ 添加分类</button>
          <a href="news.php" class="btn">返回新闻管理</a>
        </div>
      </div>
      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>ID</th>
              <th>分类名称</th>
              <th>分类代码</th>
              <th>描述</th>
              <th>排序</th>
              <th>状态</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody> <?php if (empty($categories)): ?> <tr>
              <td colspan="7" style="text-align: center;">暂无分类数据</td>
            </tr> <?php else: ?> <?php foreach ($categories as $category): ?> <tr data-id="<?php echo $category['id']; ?>">
              <td><?php echo $category['id']; ?></td>
              <td>
                <span class="status-badge <?php echo $category['status'] ? 'status-active' : 'status-inactive'; ?>"></span> <?php echo $category['name']; ?>
              </td>
              <td><?php echo $category['code']; ?></td>
              <td><?php echo mb_substr($category['description'], 0, 30) . (mb_strlen($category['description']) > 30 ? '...' : ''); ?></td>
              <td><?php echo $category['sort_order']; ?></td>
              <td><?php echo $category['status'] ? '启用' : '禁用'; ?></td>
              <td class="action-buttons">
                <button class="btn btn-edit" data-id="<?php echo $category['id']; ?>">修改</button>
                <button class="btn btn-delete" data-id="<?php echo $category['id']; ?>"
                        data-name="<?php echo $category['name']; ?>">删除</button>
              </td>
            </tr> <?php endforeach; ?> <?php endif; ?> </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除分类 "<span id="delete-category-name"></span>" 吗？</p>
        <p class="warning">注意：删除分类将同时删除该分类下的所有新闻！</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 添加分类按钮
      document.getElementById('add-category-btn').addEventListener('click', function() {
        window.location.href = 'news_category_add.php';
      });
      // 删除功能相关代码
      const modal = document.getElementById('delete-modal');
      const deleteCategoryName = document.getElementById('delete-category-name');
      let deleteCategoryId = null;
      // 删除按钮点击事件
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteCategoryId = this.dataset.id;
          const categoryName = this.dataset.name;
          deleteCategoryName.textContent = categoryName;
          modal.style.display = 'block';
        });
      });
      // 确认删除按钮点击事件
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteCategoryId) {
          // 发送删除请求
          fetch('news_category_delete.php', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: 'id=' + deleteCategoryId
          }).then(response => response.json()).then(data => {
            if (data.success) {
              // 删除成功，移除对应的行
              const row = document.querySelector(`tr[data-id="${deleteCategoryId}"]`);
              if (row) {
                row.remove();
              }
              // 显示成功消息
              const successMessage = document.getElementById('success-message');
              successMessage.textContent = data.message;
              successMessage.style.display = 'block';
              setTimeout(() => {
                successMessage.style.display = 'none';
              }, 3000);
            } else {
              alert(data.message);
            }
          }).catch(error => {
            console.error('Error:', error);
            alert('删除失败，请重试');
          }).finally(() => {
            modal.style.display = 'none';
            deleteCategoryId = null;
          });
        }
      });
      // 取消删除按钮点击事件
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteCategoryId = null;
      });
      // 点击模态框外部关闭
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteCategoryId = null;
        }
      });
      // 编辑按钮点击事件
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const categoryId = this.dataset.id;
          window.location.href = `news_category_edit.php?id=${categoryId}`;
        });
      });
      // 如果有成功消息参数，显示成功消息
      if (new URLSearchParams(window.location.search).has('success')) {
        const successMessage = document.getElementById('success-message');
        successMessage.textContent = "操作成功！";
        successMessage.style.display = 'block';
        setTimeout(() => {
          successMessage.style.display = 'none';
        }, 3000);
      }
    });
    // 移动端菜单控制
    const mobileMenuBtn = document.querySelector('.mobile-menu-btn');
    const sidebar = document.querySelector('.sidebar');
    const overlay = document.querySelector('.sidebar-overlay');
    mobileMenuBtn.addEventListener('click', function() {
      sidebar.classList.toggle('active');
      overlay.classList.toggle('active');
    });
    overlay.addEventListener('click', function() {
      sidebar.classList.remove('active');
      overlay.classList.remove('active');
    });
    </script>
  </body>
</html>
