<?php
/**
 * 新闻分类删除处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
    exit;
}
// 获取要删除的分类ID
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
if ($id <= 0) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的分类ID']);
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查分类是否存在
    $categoryQuery = "SELECT id, name FROM news_category WHERE id = :id";
    $categoryStmt = $db->prepare($categoryQuery);
    $categoryStmt->execute(['id' => $id]);
    $category = $categoryStmt->fetch();
    if (!$category) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => '分类不存在']);
        exit;
    }
    
    // 开始事务
    $db->beginTransaction();
    
    // 删除该分类下的所有新闻
    $deleteNewsQuery = "DELETE FROM news WHERE category_id = :category_id";
    $deleteNewsStmt = $db->prepare($deleteNewsQuery);
    $deleteNewsStmt->execute(['category_id' => $id]);
    
    // 删除分类
    $deleteCategoryQuery = "DELETE FROM news_category WHERE id = :id";
    $deleteCategoryStmt = $db->prepare($deleteCategoryQuery);
    $deleteCategoryStmt->execute(['id' => $id]);
    
    // 提交事务
    $db->commit();
    
    // 返回成功响应
    header('Content-Type: application/json');
    echo json_encode(['success' => true, 'message' => "分类 '{$category['name']}' 及其所有新闻已成功删除"]);
    exit;
} catch (PDOException $e) {
    // 回滚事务
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '删除失败: ' . $e->getMessage()]);
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 