<?php
/**
 * 新闻分类编辑页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取要编辑的分类ID
$categoryId = isset($_GET['id']) ? intval($_GET['id']) : 0;
if ($categoryId <= 0) {
    echo "无效的分类ID";
    exit;
}
// 获取数据库连接
$db = getDbConnection();
// 获取分类数据
$categoryQuery = "SELECT * FROM news_category WHERE id = :id";
$categoryStmt = $db->prepare($categoryQuery);
$categoryStmt->execute(['id' => $categoryId]);
$category = $categoryStmt->fetch();
if (!$category) {
    echo "分类不存在";
    exit;
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑新闻分类 - <?php echo $category['name']; ?></title>
    <link rel="stylesheet" href="public/css/style.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <div class="form-container">
        <form id="category-form" method="post" action="news_category_update.php">
          <input type="hidden" name="id" value="<?php echo $category['id']; ?>">
          <div class="form-group">
            <label for="name">分类名称</label>
            <input type="text" id="name" name="name" class="form-control" value="<?php echo htmlspecialchars($category['name']); ?>" required>
          </div>
          <div class="form-group">
            <label for="code">分类代码</label>
            <input type="text" id="code" name="code" class="form-control" value="<?php echo htmlspecialchars($category['code']); ?>" required>
            <small class="form-text text-muted">只能包含小写字母、数字和下划线</small>
          </div>
          <div class="form-group">
            <label for="description">分类描述</label>
            <textarea id="description" name="description" class="form-control" rows="4"><?php echo htmlspecialchars($category['description']); ?></textarea>
          </div>
          <div class="form-group">
            <label for="sort_order">排序</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="<?php echo $category['sort_order']; ?>">
            <small class="form-text text-muted">数值越小排序越靠前</small>
          </div>
          <div class="form-group">
            <label for="status">状态</label>
            <select id="status" name="status" class="form-control">
              <option value="1" <?php echo $category['status'] == 1 ? 'selected' : ''; ?>>启用</option>
              <option value="0" <?php echo $category['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
            </select>
          </div>
          <div class="btn-container">
            <button type="submit" class="btn-save">保存</button>
            <a href="news_category.php" class="btn-cancel">取消</a>
          </div>
        </form>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 表单提交前验证
      document.getElementById('category-form').addEventListener('submit', function(e) {
        e.preventDefault(); // 阻止默认提交
        const name = document.getElementById('name').value.trim();
        const code = document.getElementById('code').value.trim();
        if (!name) {
          alert('请输入分类名称');
          return false;
        }
        if (!code) {
          alert('请输入分类代码');
          return false;
        }
        // 验证分类代码格式
        if (!/^[a-z0-9_]+$/.test(code)) {
          alert('分类代码只能包含小写字母、数字和下划线');
          return false;
        }
        // 如果验证通过，提交表单
        this.submit();
      });
    });
    </script>
  </body>
</html>
