<?php
/**
 * 新闻分类更新处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: news_category.php');
    exit;
}
// 获取表单数据
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
$name = isset($_POST['name']) ? trim($_POST['name']) : '';
$code = isset($_POST['code']) ? trim($_POST['code']) : '';
$description = isset($_POST['description']) ? trim($_POST['description']) : '';
$sortOrder = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
$status = isset($_POST['status']) ? intval($_POST['status']) : 1;
// 验证数据
if ($id <= 0 || empty($name) || empty($code)) {
    echo "请填写所有必填字段";
    exit;
}
// 验证分类代码格式
if (!preg_match('/^[a-z0-9_]+$/', $code)) {
    echo "分类代码只能包含小写字母、数字和下划线";
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查分类是否存在
    $categoryQuery = "SELECT id FROM news_category WHERE id = :id";
    $categoryStmt = $db->prepare($categoryQuery);
    $categoryStmt->execute(['id' => $id]);
    if (!$categoryStmt->fetch()) {
        echo "分类不存在";
        exit;
    }
    // 检查分类代码是否已存在（排除当前分类）
    $checkCodeQuery = "SELECT id FROM news_category WHERE code = :code AND id != :id";
    $checkCodeStmt = $db->prepare($checkCodeQuery);
    $checkCodeStmt->execute([
        'code' => $code,
        'id' => $id
    ]);
    if ($checkCodeStmt->fetch()) {
        echo "该分类代码已存在";
        exit;
    }
    // 更新分类数据
    $updateQuery = "UPDATE news_category SET 
                    name = :name,
                    code = :code,
                    description = :description,
                    sort_order = :sort_order,
                    status = :status
                    WHERE id = :id";
    $updateStmt = $db->prepare($updateQuery);
    $updateStmt->execute([
        'id' => $id,
        'name' => $name,
        'code' => $code,
        'description' => $description,
        'sort_order' => $sortOrder,
        'status' => $status
    ]);
    // 重定向回分类列表页面，并带上成功参数
    header("Location: news_category.php?success=1");
    exit;
} catch (PDOException $e) {
    echo "数据库错误: " . $e->getMessage();
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 