<?php
/**
 * 新闻删除处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
    exit;
}
// 获取要删除的新闻ID
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
if ($id <= 0) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的新闻ID']);
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查新闻是否存在
    $newsQuery = "SELECT id, title FROM news WHERE id = :id";
    $newsStmt = $db->prepare($newsQuery);
    $newsStmt->execute(['id' => $id]);
    $news = $newsStmt->fetch();
    if (!$news) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => '新闻不存在']);
        exit;
    }
    // 删除新闻
    $deleteQuery = "DELETE FROM news WHERE id = :id";
    $deleteStmt = $db->prepare($deleteQuery);
    $deleteStmt->execute(['id' => $id]);
    // 返回成功响应
    header('Content-Type: application/json');
    echo json_encode(['success' => true, 'message' => "新闻 '{$news['title']}' 已成功删除"]);
    exit;
} catch (PDOException $e) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '删除失败: ' . $e->getMessage()]);
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 