<?php
/**
 * 新闻保存处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: news.php');
    exit;
}
// 获取表单数据
$categoryId = isset($_POST['category_id']) ? intval($_POST['category_id']) : 0;
$title = isset($_POST['title']) ? trim($_POST['title']) : '';
$summary = isset($_POST['summary']) ? trim($_POST['summary']) : '';
$keywords = isset($_POST['keywords']) ? trim($_POST['keywords']) : '';
$content = isset($_POST['content']) ? $_POST['content'] : '';
$sortOrder = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
$status = isset($_POST['status']) ? intval($_POST['status']) : 1;
// 验证数据
if ($categoryId <= 0 || empty($title) || empty($content)) {
    echo "请填写所有必填字段";
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查分类是否存在
    $categoryQuery = "SELECT id FROM news_category WHERE id = :id";
    $categoryStmt = $db->prepare($categoryQuery);
    $categoryStmt->execute(['id' => $categoryId]);
    if (!$categoryStmt->fetch()) {
        echo "分类不存在";
        exit;
    }
    // 插入新闻数据
    $insertQuery = "INSERT INTO news (category_id, title, summary, keywords, content, sort_order, status) 
                   VALUES (:category_id, :title, :summary, :keywords, :content, :sort_order, :status)";
    $insertStmt = $db->prepare($insertQuery);
    $insertStmt->execute([
        'category_id' => $categoryId,
        'title' => $title,
        'summary' => $summary,
        'keywords' => $keywords,
        'content' => $content,
        'sort_order' => $sortOrder,
        'status' => $status
    ]);
    // 重定向回新闻列表页面，并带上成功参数
    header("Location: news.php?category_id={$categoryId}&success=1");
    exit;
} catch (PDOException $e) {
    echo "数据库错误: " . $e->getMessage();
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 