<!DOCTYPE html>
<html lang="zh-CN">
  <?php
require_once '../config/database.php';

// 设置详细错误报告
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 记录访问和会话信息
$log_prefix = "[OCS后台管理] - " . date('Y-m-d H:i:s') . ": ";
error_log($log_prefix . "页面访问开始");

// 获取数据库连接
try {
  $db = getDbConnection();
  $db_ok = true;
  error_log($log_prefix . "数据库连接成功");
} catch (Exception $e) {
  $db_ok = false;
  error_log($log_prefix . "数据库连接失败: " . $e->getMessage());
}

// 获取所有有聊天记录的用户列表
$users = [];
if ($db_ok) {
  try {
    $sql = "SELECT DISTINCT user_id, 
            (SELECT COUNT(*) FROM chat_messages WHERE user_id = cm.user_id AND admin_id IS NULL AND is_read = 0) as unread_count, 
            (SELECT message FROM chat_messages WHERE user_id = cm.user_id ORDER BY created_at DESC LIMIT 1) as last_message 
            FROM chat_messages cm 
            GROUP BY user_id 
            ORDER BY MAX(created_at) DESC";
    
    $result = $db->query($sql);
    if ($result) {
      $users = $result->fetchAll(PDO::FETCH_ASSOC);
      error_log($log_prefix . "加载用户数量: " . count($users));
    } else {
      error_log($log_prefix . "查询用户失败: " . print_r($db->errorInfo(), true));
    }
  } catch (Exception $e) {
    error_log($log_prefix . "获取用户列表失败: " . $e->getMessage());
  }
}

// 获取正在查看的用户ID
$current_user_id = isset($_GET['user_id']) ? intval($_GET['user_id']) : (isset($users[0]) ? $users[0]['user_id'] : 0);
error_log($log_prefix . "当前查看的用户ID: " . $current_user_id);

// 处理管理员回复
if (isset($_POST['admin_reply']) && !empty($_POST['reply_message']) && $current_user_id > 0) {
  $reply_message = trim($_POST['reply_message']);
  
  try {
    $stmt = $db->prepare("INSERT INTO chat_messages (user_id, admin_id, message, is_read, created_at) VALUES (?, 1, ?, 0, NOW())");
    $stmt->execute([$current_user_id, $reply_message]);
    
    error_log($log_prefix . "管理员回复成功：消息ID: " . $db->lastInsertId());
    
    // 重定向回当前页面
    header('Location: ' . $_SERVER['PHP_SELF'] . '?user_id=' . $current_user_id);
    exit;
  } catch (Exception $e) {
    error_log($log_prefix . "管理员回复失败: " . $e->getMessage());
  }
}

// 获取当前用户的历史消息
$messages = [];
if ($db_ok && $current_user_id > 0) {
  try {
    // 获取指定用户的聊天消息
    $sql = "SELECT * FROM chat_messages WHERE user_id = ? ORDER BY created_at ASC";
    $stmt = $db->prepare($sql);
    $stmt->execute([$current_user_id]);
    $messages = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 调试信息：记录消息数量
    error_log($log_prefix . "当前用户ID: " . $current_user_id . ", 加载消息数量: " . count($messages));
    
    // 将未读消息标记为已读
    $update_sql = "UPDATE chat_messages SET is_read = 1 WHERE user_id = ? AND admin_id IS NULL AND is_read = 0";
    $update_stmt = $db->prepare($update_sql);
    $update_stmt->execute([$current_user_id]);
  } catch (Exception $e) {
    error_log($log_prefix . "获取消息失败: " . $e->getMessage());
  }
}

// 直接使用用户ID作为显示名称
$current_user_name = "用户ID: " . $current_user_id;

// 计算对话开始时间
$chat_start_time = isset($messages[0]) ? date('H:i', strtotime($messages[0]['created_at'])) : date('H:i');
?>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>在线客服管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/ocs.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
    .unread-badge {
      display: inline-flex;
      align-items: center;
      justify-content: center;
      min-width: 18px;
      height: 18px;
      padding: 0 5px;
      font-size: 12px;
      font-weight: bold;
      color: white;
      background-color: #ff3b30;
      border-radius: 9px;
      margin-left: auto;
    }

    .no-messages {
      text-align: center;
      padding: 20px;
      color: #999;
      font-style: italic;
    }

    </style>
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <h1 class="page-title">在线客服管理</h1>
      <div class="content-wrapper">
        <div class="chat-layout">
          <!-- 客户列表 -->
          <div class="customers-list">
            <div class="customers-list-header">
              客户列表 (<?php echo count($users); ?>)
            </div>
            <?php if (!empty($users)): ?>
            <?php foreach ($users as $user): ?>
            <div class="customer-item <?php echo ($user['user_id'] == $current_user_id) ? 'active' : ''; ?>"
                 onclick="window.location.href='ocs.php?user_id=<?php echo $user['user_id']; ?>'">
              <div class="user-avatar">U<?php echo $user['user_id']; ?></div>
              <div class="customer-info">
                <div class="customer-name">用户ID: <?php echo $user['user_id']; ?></div>
                <div class="last-message"><?php echo mb_substr(htmlspecialchars($user['last_message']), 0, 15).(mb_strlen($user['last_message']) > 15 ? '...' : ''); ?></div>
              </div>
              <?php if ($user['unread_count'] > 0): ?>
              <div class="unread-badge"><?php echo $user['unread_count']; ?></div>
              <?php endif; ?>
            </div>
            <?php endforeach; ?>
            <?php else: ?>
            <div class="no-customers">暂无客户记录</div>
            <?php endif; ?>
          </div>
          <!-- 聊天主界面 -->
          <div class="chat-main">
            <!-- 聊天工具栏 -->
            <div class="chat-tools">
              <div class="chat-status">
                <span class="status-indicator"></span>
                当前对话中 - <?php echo $current_user_name; ?> (<?php echo $chat_start_time; ?>开始)
              </div>
              <div class="chat-actions">
                <button class="action-btn" onclick="window.location.reload()">刷新消息</button>
              </div>
            </div>
            <!-- 聊天容器 -->
            <div class="chat-container">
              <div class="chat-messages">
                <?php if (!empty($messages)): ?>
                <div class="system-message">
                  <p>系统消息: <?php echo $current_user_name; ?>的聊天记录，共<?php echo count($messages); ?>条消息</p>
                </div>
                <?php foreach ($messages as $message): ?>
                <?php 
                    $messageClass = '';
                    // 根据消息的发送者类型来判断样式类名
                    if ($message['admin_id'] === null) {
                      // 用户发送的消息
                      $messageClass = 'user-message';
                    } else {
                      // 管理员回复的消息
                      $messageClass = 'agent-message';
                    }
                    ?>

                <div class="<?php echo $messageClass; ?>">
                  <div class="message-content">
                    <p><?php echo htmlspecialchars($message['message']); ?></p>
                    <div class="message-time"><?php echo date('m-d H:i', strtotime($message['created_at'])); ?></div>
                  </div>
                </div>
                <?php endforeach; ?>
                <?php else: ?>
                <div class="no-messages">
                  <p>暂无聊天记录</p>
                </div>
                <?php endif; ?>
              </div>
              <!-- 聊天输入区域 -->
              <?php if ($current_user_id > 0): ?>
              <form method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>?user_id=<?php echo $current_user_id; ?>" class="chat-input-area">
                <input type="text" name="reply_message" class="chat-input" placeholder="请输入回复内容..." required>
                <input type="hidden" name="admin_reply" value="1">
                <button type="submit" class="send-btn">
                  <i class="fas fa-paper-plane"></i>
                  发送
                </button>
              </form>
              <?php else: ?>
              <div class="chat-input-area">
                <input type="text" class="chat-input" placeholder="请先选择客户..." disabled>
                <button class="send-btn" disabled>
                  <i class="fas fa-paper-plane"></i>
                  发送
                </button>
              </div>
              <?php endif; ?>
            </div>
          </div>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 滚动到最新消息
      const chatMessages = document.querySelector('.chat-messages');
      chatMessages.scrollTop = chatMessages.scrollHeight;
      // 发送消息表单
      const chatForm = document.querySelector('.chat-input-area');
      const chatInput = document.querySelector('.chat-input');
      // 如果有表单和输入框
      if (chatForm && chatInput) {
        // 表单提交处理
        chatForm.addEventListener('submit', function(e) {
          const message = chatInput.value.trim();
          if (message === '') {
            e.preventDefault(); // 阻止空消息提交
            alert('请输入消息!');
            return false;
          }
        });
        // 焦点放在输入框
        chatInput.focus();
      }
    });
    </script>
  </body>
</html>
