<?php
/**
 * 订单删除处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
    exit;
}
// 获取要删除的订单ID
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
if ($id <= 0) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '无效的订单ID']);
    exit;
}
try {
    // 获取数据库连接
    $db = getDbConnection();
    // 检查订单是否存在
    $orderQuery = "SELECT id, hostname FROM orders WHERE id = :id";
    $orderStmt = $db->prepare($orderQuery);
    $orderStmt->execute(['id' => $id]);
    $order = $orderStmt->fetch();
    if (!$order) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => '订单不存在']);
        exit;
    }
    // 删除订单
    $deleteQuery = "DELETE FROM orders WHERE id = :id";
    $deleteStmt = $db->prepare($deleteQuery);
    $deleteStmt->execute(['id' => $id]);
    // 返回成功响应
    header('Content-Type: application/json');
    echo json_encode(['success' => true, 'message' => "订单 '{$order['hostname']}' 已成功删除"]);
    exit;
} catch (PDOException $e) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '删除失败: ' . $e->getMessage()]);
    exit;
}
?> 