<?php
/**
 * 订单详情页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取订单ID
$orderId = isset($_GET['id']) ? intval($_GET['id']) : 0;
if ($orderId <= 0) {
    echo "无效的订单ID";
    exit;
}
// 获取数据库连接
$db = getDbConnection();
// 获取订单数据
$orderQuery = "SELECT * FROM orders WHERE id = :id";
$orderStmt = $db->prepare($orderQuery);
$orderStmt->execute(['id' => $orderId]);
$order = $orderStmt->fetch();
if (!$order) {
    echo "订单不存在";
    exit;
}

// 状态映射
$statusNames = [
    1 => '有效',
    2 => '审核中',
    3 => '已暂停',
    4 => '已终止',
    5 => '已取消'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单详情 - <?php echo htmlspecialchars($order['hostname']); ?></title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/order_detail.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <script src="public/js/order_detail.js"></script>
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <div class="header-action">
        <h2><i class="fas fa-server"></i> 订单详情 - <?php echo htmlspecialchars($order['hostname']); ?></h2>
        <div class="btn-container">
          <a href="order_edit.php?id=<?php echo $order['id']; ?>" class="btn btn-edit"><i class="fas fa-edit"></i> 编辑订单</a>
          <a href="orders.php" class="btn btn-info"><i class="fas fa-list"></i> 返回列表</a>
        </div>
      </div>
      <div class="form-container">
        <div class="detail-section">
          <div class="section-title"><i class="fas fa-info-circle"></i> 基本信息</div>
          <div class="detail-grid">
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-tag"></i> 产品/服务类型</span>
              <div class="detail-value"><?php echo htmlspecialchars($order['product_type']); ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-server"></i> 主机名称</span>
              <div class="detail-value">
                <?php echo htmlspecialchars($order['hostname']); ?>
                <button class="copy-btn" data-copy="<?php echo htmlspecialchars($order['hostname']); ?>">
                  <i class="fas fa-copy"></i>
                </button>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-network-wired"></i> IP地址</span>
              <div class="detail-value">
                <?php echo htmlspecialchars($order['ip_address']); ?>
                <button class="copy-btn" data-copy="<?php echo htmlspecialchars($order['ip_address']); ?>">
                  <i class="fas fa-copy"></i>
                </button>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-microchip"></i> 服务器配置</span>
              <div class="detail-value"><?php echo htmlspecialchars($order['server_specs'] ?: '-'); ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-dollar-sign"></i> 价格</span>
              <div class="detail-value"><?php echo "$" . number_format($order['price'], 2) . " " . $order['currency']; ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-calendar-alt"></i> 下次付款日期</span>
              <div class="detail-value"><?php echo $order['next_payment_date'] ? date('Y-m-d', strtotime($order['next_payment_date'])) : '-'; ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-flag"></i> 状态</span>
              <div class="detail-value">
                <span class="status-badge status-<?php echo $order['status']; ?>">
                  <?php echo $statusNames[$order['status']]; ?>
                </span>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-project-diagram"></i> VPC信息</span>
              <div class="detail-value"><?php echo htmlspecialchars($order['vpc'] ?: '-'); ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-sync-alt"></i> 自动续费</span>
              <div class="detail-value">
                <?php if($order['auto_renew']): ?>
                <span style="color: #27ae60;"><i class="fas fa-check"></i> 是</span>
                <?php else: ?>
                <span style="color: #e74c3c;"><i class="fas fa-times"></i> 否</span>
                <?php endif; ?>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-network-wired"></i> 多IP服务器</span>
              <div class="detail-value">
                <?php if($order['is_multiple_ip']): ?>
                <span style="color: #27ae60;"><i class="fas fa-check"></i> 是</span>
                <?php else: ?>
                <span style="color: #e74c3c;"><i class="fas fa-times"></i> 否</span>
                <?php endif; ?>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-list-ol"></i> IP数量</span>
              <div class="detail-value"><?php echo $order['ip_count']; ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-shopping-cart"></i> 订单类型</span>
              <div class="detail-value">
                <?php if($order['is_manual_order']): ?>
                <span><i class="fas fa-user-edit"></i> 人工订单</span>
                <?php else: ?>
                <span><i class="fas fa-robot"></i> 会员系统自动订单</span>
                <?php endif; ?>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-sticky-note"></i> 备注/额外信息</span>
              <div class="detail-value"><?php echo htmlspecialchars($order['notes'] ?: '-'); ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-clock"></i> 创建时间</span>
              <div class="detail-value"><?php echo date('Y-m-d H:i:s', strtotime($order['created_at'])); ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-edit"></i> 最后更新时间</span>
              <div class="detail-value"><?php echo isset($order['updated_at']) && $order['updated_at'] ? date('Y-m-d H:i:s', strtotime($order['updated_at'])) : '-'; ?></div>
            </div>
          </div>
        </div>
        <div class="detail-section">
          <div class="section-title"><i class="fas fa-key"></i> 登录信息</div>
          <div class="detail-grid">
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-desktop"></i> 操作系统</span>
              <div class="detail-value"><?php echo htmlspecialchars($order['os_type'] ?: '-'); ?></div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-user"></i> 用户名</span>
              <div class="detail-value">
                <span class="sensitive-data"><?php echo htmlspecialchars($order['username'] ?: '-'); ?></span>
                <?php if ($order['username']): ?>
                <button class="copy-btn" data-copy="<?php echo htmlspecialchars($order['username']); ?>">
                  <i class="fas fa-copy"></i>
                </button>
                <?php endif; ?>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-lock"></i> 密码</span>
              <div class="detail-value">
                <span class="sensitive-data"><?php echo htmlspecialchars($order['password'] ?: '-'); ?></span>
                <?php if ($order['password']): ?>
                <button class="copy-btn" data-copy="<?php echo htmlspecialchars($order['password']); ?>">
                  <i class="fas fa-copy"></i>
                </button>
                <?php endif; ?>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-plug"></i> 端口</span>
              <div class="detail-value">
                <?php echo $order['port'] ?: '-'; ?>
                <?php if ($order['port']): ?>
                <button class="copy-btn" data-copy="<?php echo $order['port']; ?>">
                  <i class="fas fa-copy"></i>
                </button>
                <?php endif; ?>
              </div>
            </div>
            <div class="detail-item">
              <span class="detail-label"><i class="fas fa-key"></i> 面板密码</span>
              <div class="detail-value">
                <span class="sensitive-data"><?php echo htmlspecialchars($order['panel_password'] ?: '-'); ?></span>
                <?php if ($order['panel_password']): ?>
                <button class="copy-btn" data-copy="<?php echo htmlspecialchars($order['panel_password']); ?>">
                  <i class="fas fa-copy"></i>
                </button>
                <?php endif; ?>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </body>
</html>
