<?php
/**
 * 订单保存处理脚本
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: orders.php');
    exit;
}

// 获取表单数据
$productType = isset($_POST['product_type']) ? trim($_POST['product_type']) : '';
$hostname = isset($_POST['hostname']) ? trim($_POST['hostname']) : '';
$ipAddress = isset($_POST['ip_address']) ? trim($_POST['ip_address']) : '';
$price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
$currency = isset($_POST['currency']) ? trim($_POST['currency']) : 'USD';
$nextPaymentDate = isset($_POST['next_payment_date']) && !empty($_POST['next_payment_date']) ? $_POST['next_payment_date'] : null;
$status = isset($_POST['status']) ? intval($_POST['status']) : 1;
$vpc = isset($_POST['vpc']) ? trim($_POST['vpc']) : null;
$autoRenew = isset($_POST['auto_renew']) ? 1 : 0;
$serverSpecs = isset($_POST['server_specs']) ? trim($_POST['server_specs']) : null;
$isMultipleIp = isset($_POST['is_multiple_ip']) ? 1 : 0;
$ipCount = isset($_POST['ip_count']) ? intval($_POST['ip_count']) : 1;
$notes = isset($_POST['notes']) ? trim($_POST['notes']) : null;
$osType = isset($_POST['os_type']) ? trim($_POST['os_type']) : null;
$username = isset($_POST['username']) ? trim($_POST['username']) : null;
$password = isset($_POST['password']) ? trim($_POST['password']) : null;
$port = isset($_POST['port']) ? intval($_POST['port']) : null;
$panelPassword = isset($_POST['panel_password']) ? trim($_POST['panel_password']) : null;
$isManualOrder = isset($_POST['is_manual_order']) ? 1 : 0;

// 验证数据
if (empty($productType) || empty($hostname) || empty($ipAddress) || $price <= 0) {
    echo "请填写所有必填字段";
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 插入订单数据
    $insertQuery = "INSERT INTO orders (product_type, hostname, ip_address, price, currency, next_payment_date, 
                   status, vpc, auto_renew, server_specs, is_multiple_ip, ip_count, notes, os_type, username, 
                   password, port, panel_password, is_manual_order) 
                   VALUES (:product_type, :hostname, :ip_address, :price, :currency, :next_payment_date, 
                   :status, :vpc, :auto_renew, :server_specs, :is_multiple_ip, :ip_count, :notes, :os_type, 
                   :username, :password, :port, :panel_password, :is_manual_order)";
                   
    $insertStmt = $db->prepare($insertQuery);
    $insertStmt->execute([
        'product_type' => $productType,
        'hostname' => $hostname,
        'ip_address' => $ipAddress,
        'price' => $price,
        'currency' => $currency,
        'next_payment_date' => $nextPaymentDate,
        'status' => $status,
        'vpc' => $vpc,
        'auto_renew' => $autoRenew,
        'server_specs' => $serverSpecs,
        'is_multiple_ip' => $isMultipleIp,
        'ip_count' => $ipCount,
        'notes' => $notes,
        'os_type' => $osType,
        'username' => $username,
        'password' => $password,
        'port' => $port,
        'panel_password' => $panelPassword,
        'is_manual_order' => $isManualOrder
    ]);
    
    // 重定向回订单列表页面，并带上成功参数
    header("Location: orders.php?success=1");
    exit;
} catch (PDOException $e) {
    echo "数据库错误: " . $e->getMessage();
    exit;
}
?> 