<?php
// 引入业务逻辑代码
require_once 'code/orders_code.php';

// 处理请求并获取数据
$data = processOrdersRequest();

// 解构返回的数据
extract($data);
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/orders.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.1/css/all.min.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
      <div class="page-header">
        <h2 class="page-title">订单管理</h2>
      </div>
      <?php if ($hasSuccessMessage): ?>
      <div id="success-message" class="success-message show">
        <i class="fas fa-check-circle"></i> 操作成功！
      </div>
      <?php else: ?>
      <div id="success-message" class="success-message"></div>
      <?php endif; ?>
      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-order-btn">
            <i class="fas fa-plus"></i> 添加订单
          </button>
        </div>
        <div class="filter">
          <form class="search-form" method="GET" action="orders.php">
            <input type="hidden" name="status" value="<?php echo $statusFilter; ?>">
            <input type="text" name="search" placeholder="搜索主机名/IP/产品类型..." value="<?php echo htmlspecialchars($searchTerm); ?>">
            <button type="submit" class="btn btn-search">
              <i class="fas fa-search"></i> 搜索
            </button>
          </form>
        </div>
      </div>
      <!-- 状态筛选标签 -->
      <div class="order-tabs">
        <?php foreach ($statusNames as $statusId => $statusName): ?>
        <a href="orders.php?status=<?php echo $statusId; ?><?php echo !empty($searchTerm) ? '&search=' . urlencode($searchTerm) : ''; ?>"
           class="order-tab <?php echo $statusFilter === $statusId ? 'active' : ''; ?>">
          <?php echo $statusName; ?>
        </a>
        <?php endforeach; ?>
      </div>
      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>ID</th>
              <th>产品/服务</th>
              <th>主机名称</th>
              <th>IP地址</th>
              <th>价格</th>
              <th>下次付款日期</th>
              <th>状态</th>
              <th>订单类型</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php if (empty($orders)): ?>
            <tr>
              <td colspan="9" class="empty-data-container">
                <i class="fas fa-inbox empty-data-icon"></i>
                暂无订单数据
              </td>
            </tr>
            <?php else: ?>
            <?php foreach ($orders as $order): ?>
            <tr>
              <td><?php echo $order['id']; ?></td>
              <td>
                <?php if ($order['is_multiple_ip']): ?>
                <span class="multiple-ip-badge">多IP</span>
                <?php endif; ?>
                <div><?php echo htmlspecialchars($order['product_type']); ?></div>
                <?php if (!empty($order['server_specs'])): ?>
                <div class="server-specs"><?php echo htmlspecialchars($order['server_specs']); ?></div>
                <?php endif; ?>
              </td>
              <td><?php echo htmlspecialchars($order['hostname']); ?></td>
              <td><?php echo htmlspecialchars($order['ip_address']); ?></td>
              <td>
                <strong>$<?php echo number_format($order['price'], 2); ?></strong>
                <span class="order-price-currency"><?php echo $order['currency']; ?></span>
              </td>
              <td>
                <?php if ($order['next_payment_date']): ?>
                <span><?php echo date('Y-m-d', strtotime($order['next_payment_date'])); ?></span>
                <?php else: ?>
                <span class="order-date-empty">-</span>
                <?php endif; ?>
              </td>
              <td>
                <span class="status-badge status-<?php echo $order['status']; ?>">
                  <?php 
                  // 使用原始的状态名称（不包含全部选项）
                  echo isset($originalStatusNames[$order['status']]) ? $originalStatusNames[$order['status']] : '未知'; 
                  ?>
                </span>
              </td>
              <td>
                <?php if ($order['is_manual_order']): ?>
                <span class="order-type-text"><i class="fas fa-user order-type-icon"></i> 人工</span>
                <?php else: ?>
                <span class="order-type-text"><i class="fas fa-robot order-type-icon"></i> 自动</span>
                <?php endif; ?>
              </td>
              <td class="action-buttons">
                <button class="btn btn-info view-btn" data-id="<?php echo $order['id']; ?>">
                  <i class="fas fa-eye"></i> 查看
                </button>
                <button class="btn btn-edit" data-id="<?php echo $order['id']; ?>">
                  <i class="fas fa-edit"></i> 修改
                </button>
                <button class="btn btn-delete" data-id="<?php echo $order['id']; ?>"
                        data-hostname="<?php echo htmlspecialchars($order['hostname']); ?>">
                  <i class="fas fa-trash-alt"></i> 删除
                </button>
              </td>
            </tr>
            <?php endforeach; ?>
            <?php endif; ?>
          </tbody>
        </table>
      </div>
      <!-- 分页控件 -->
      <?php echo $paginationHtml; ?>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3><i class="fas fa-exclamation-triangle modal-warning-icon"></i> 确认删除</h3>
        <p>您确定要删除主机 "<span id="delete-order-hostname"></span>" 的订单吗？</p>
        <p class="modal-warning-text">此操作无法撤销，请谨慎操作。</p>
        <div class="modal-buttons">
          <button class="btn-cancel" id="cancel-delete">取消</button>
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 添加订单按钮
      document.getElementById('add-order-btn').addEventListener('click', function() {
        window.location.href = 'order_add.php';
      });

      // 详情查看按钮
      document.querySelectorAll('.view-btn').forEach(button => {
        button.addEventListener('click', function() {
          const orderId = this.dataset.id;
          window.location.href = 'order_detail.php?id=' + orderId;
        });
      });

      // 编辑按钮
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const orderId = this.dataset.id;
          window.location.href = 'order_edit.php?id=' + orderId;
        });
      });

      // 删除功能
      let deleteOrderId = null;

      // 删除按钮点击事件
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteOrderId = this.dataset.id;
          const hostname = this.dataset.hostname;
          document.getElementById('delete-order-hostname').textContent = hostname;
          document.getElementById('delete-modal').style.display = 'block';
        });
      });

      // 确认删除按钮
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteOrderId) {
          // 添加按钮加载效果
          this.innerHTML = '<i class="fas fa-spinner fa-spin"></i> 处理中...';
          this.disabled = true;

          // 发送删除请求
          fetch('order_delete.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
              },
              body: 'id=' + deleteOrderId
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                // 删除成功，刷新页面
                window.location.reload();
              } else {
                alert(data.message || '删除失败，请重试');
                // 恢复按钮状态
                document.getElementById('confirm-delete').innerHTML = '确认删除';
                document.getElementById('confirm-delete').disabled = false;
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('删除失败，请重试');
              // 恢复按钮状态
              document.getElementById('confirm-delete').innerHTML = '确认删除';
              document.getElementById('confirm-delete').disabled = false;
            });

          // 关闭模态框
          document.getElementById('delete-modal').style.display = 'none';
        }
      });

      // 取消删除按钮
      document.getElementById('cancel-delete').addEventListener('click', function() {
        document.getElementById('delete-modal').style.display = 'none';
      });

      // 点击模态框外部关闭
      window.onclick = function(event) {
        const modal = document.getElementById('delete-modal');
        if (event.target == modal) {
          modal.style.display = 'none';
        }
      };

      // 如果有成功消息，3秒后自动隐藏
      const successMessage = document.getElementById('success-message');
      if (successMessage && successMessage.classList.contains('show')) {
        setTimeout(() => {
          successMessage.style.opacity = '0';
          setTimeout(() => {
            successMessage.classList.remove('show');
            successMessage.style.opacity = '1';
          }, 300);
        }, 3000);
      }
    });
    </script>
  </body>
</html>
