<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>批量添加产品</title>
    <link rel="stylesheet" href="public/css/style.css">
</head>

<body>
    <?php
    require_once '../config/database.php';
    $db = getDbConnection();
    // 获取地区、标签和线路数据
    $regions = $db->query("SELECT * FROM area ORDER BY sort_order ASC")->fetchAll();
    $tags = $db->query("SELECT * FROM tags")->fetchAll();
    $lines = $db->query("SELECT l.*, s.name as supplier_name FROM line l JOIN suppliers s ON l.supplier_id = s.id ORDER BY l.supplier_id ASC, l.sort_order ASC")->fetchAll();
    
    // 表单提交处理 - 此处理逻辑必须在任何HTML输出之前
    $formSubmitted = false;
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        try {
            // 添加调试信息
            error_log("POST数据: " . print_r($_POST, true));

            $stmt = $db->prepare("INSERT INTO products (cpu, memory, disk, bandwidth, traffic, defense, ip_count, gpu, price, region_id, tags, line_id) 
                                VALUES (:cpu, :memory, :disk, :bandwidth, :traffic, :defense, :ip_count, :gpu, :price, :region_id, :tags, :line_id)");
            // 开始事务
            $db->beginTransaction();
            for ($i = 0; $i < count($_POST['cpu']); $i++) {
                // 处理 defense 可能为空的情况
                $defense = !empty($_POST['defense'][$i]) ? $_POST['defense'][$i] : null;
                // 处理流量字段 - 如果为"不限"或为空，则设置为NULL
                $traffic = null;
                if (!empty($_POST['traffic'][$i]) && $_POST['traffic'][$i] !== '不限' && $_POST['traffic'][$i] !== '0') {
                    $traffic = $_POST['traffic'][$i];
                }
                // 处理价格可能为空的情况
                $price = !empty($_POST['price'][$i]) ? $_POST['price'][$i] : null;

                // 调试标签数据
                error_log("行 {$i} 的标签数据: " . print_r(isset($_POST['tags'][$i]) ? $_POST['tags'][$i] : 'null', true));

                // 处理多选标签，将数组转为逗号分隔的字符串
                $tags = null;
                if (isset($_POST['tags'][$i]) && is_array($_POST['tags'][$i])) {
                    $tags = implode(',', $_POST['tags'][$i]);
                    error_log("处理后的标签字符串: " . $tags);
                }
                $stmt->execute([
                    ':cpu' => $_POST['cpu'][$i],
                    ':memory' => $_POST['memory'][$i],
                    ':disk' => $_POST['disk'][$i],
                    ':bandwidth' => $_POST['bandwidth'][$i],
                    ':traffic' => $traffic,
                    ':defense' => $defense,
                    ':ip_count' => $_POST['ip_count'][$i],
                    ':gpu' => $_POST['gpu'][$i],
                    ':price' => $price,
                    ':region_id' => $_POST['region_id'][$i],
                    ':tags' => $tags,
                    ':line_id' => $_POST['line_id'][$i]
                ]);
            }
            // 提交事务
            $db->commit();
            $formSubmitted = true;
        } catch (Exception $e) {
            // 如果有事务正在进行，回滚它
            if ($db->inTransaction()) {
                $db->rollBack();
            }
            $error_message = "错误：" . $e->getMessage();
        }
    }
    
    // 如果表单已成功提交，则执行重定向
    if ($formSubmitted) {
        header('Location: product.html?success=1');
        exit;
    }
    
    include 'public/header.php';
    ?>
    <div class="sidebar">
        <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
        <?php
        if (isset($error_message)) {
            echo "<div class='alert alert-danger'>$error_message</div>";
        }
        ?>
        <div class="form-container">
            <div class="row-controls">
                <button type="button" class="btn btn-secondary" id="addRow">添加行</button>
                <button type="button" class="btn btn-secondary" id="removeRow">删除行</button>
                <span>当前行数: <span id="rowCount">15</span></span>
            </div>
            <form method="POST" class="standard-form">
                <div class="batch-form">
                    <!-- 添加表头 -->
                    <div class="batch-header">
                        <div class="header-item">序号</div>
                        <div class="header-item">CPU</div>
                        <div class="header-item">内存</div>
                        <div class="header-item">硬盘</div>
                        <div class="header-item">带宽</div>
                        <div class="header-item">流量</div>
                        <div class="header-item">防御</div>
                        <div class="header-item">IP数量</div>
                        <div class="header-item">GPU</div>
                        <div class="header-item">价格</div>
                        <div class="header-item">地区</div>
                        <div class="header-item">标签</div>
                        <div class="header-item">线路</div>
                    </div>
                    <?php for ($i = 0; $i < 15; $i++): ?>
                        <div class="batch-row" data-row="<?= $i ?>">
                            <div class="form-group row-number">
                                <?= $i + 1 ?>
                            </div>
                            <div class="form-group">
                                <input type="text" name="cpu[]" class="form-control" placeholder="cpu" required>
                            </div>
                            <div class="form-group">
                                <input type="text" name="memory[]" class="form-control" placeholder="内存" required>
                            </div>
                            <div class="form-group">
                                <input type="text" name="disk[]" class="form-control" placeholder="硬盘" required>
                            </div>
                            <div class="form-group">
                                <input type="text" name="bandwidth[]" class="form-control" placeholder="带宽" required>
                            </div>
                            <div class="form-group">
                                <input type="text" name="traffic[]" class="form-control" placeholder="流量">
                            </div>
                            <div class="form-group">
                                <input type="text" name="defense[]" class="form-control" placeholder="防御">
                            </div>
                            <div class="form-group">
                                <input type="number" name="ip_count[]" class="form-control" placeholder="IP数量" required min="1">
                            </div>
                            <div class="form-group">
                                <input type="text" name="gpu[]" class="form-control" placeholder="GPU">
                            </div>
                            <div class="form-group">
                                <input type="number" name="price[]" class="form-control" placeholder="价格" step="0.01" min="0">
                            </div>
                            <div class="form-group">
                                <select name="region_id[]" class="form-control region-select" required data-row="<?= $i ?>">
                                    <option value="">请选择地区</option>
                                    <?php
                                    // 获取所有地区数据
                                    $query = "SELECT * FROM area ORDER BY sort_order ASC";
                                    $stmt = $db->query($query);
                                    $allRegions = $stmt->fetchAll();
                                    // 组织父子关系
                                    $parentRegions = [];
                                    $childRegions = [];
                                    foreach ($allRegions as $region) {
                                        if ($region['parent_id'] === null) {
                                            $parentRegions[] = $region;
                                        } else {
                                            $childRegions[$region['parent_id']][] = $region;
                                        }
                                    }
                                    // 按照父子关系显示
                                    foreach ($parentRegions as $parent):
                                    ?>
                                        <option value="<?= $parent['id'] ?>"><?= $parent['name'] ?></option>
                                        <?php if (isset($childRegions[$parent['id']])): ?>
                                            <?php foreach ($childRegions[$parent['id']] as $child): ?>
                                                <option value="<?= $child['id'] ?>" class="sub-option" data-display-text="└─ <?= $child['name'] ?>" data-clean-text="<?= $child['name'] ?>">
                                                    <?= $child['name'] ?>
                                                </option>
                                            <?php endforeach; ?>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="form-group">
                                <div class="select-wrapper">
                                    <div class="tag-display" data-row="<?= $i ?>">
                                        <div class="selected-tags hidden" data-row="<?= $i ?>"><span class="placeholder"></span></div>
                                        <button type="button" class="tag-select-btn" data-row="<?= $i ?>">选择</button>
                                    </div>
                                    <select name="tags[<?= $i ?>][]" class="tag-select hidden" data-row="<?= $i ?>" multiple>
                                        <?php
                                        // 获取所有标签数据
                                        $query = "SELECT t1.*, t2.name as parent_name 
                             FROM tags t1 
                             LEFT JOIN tags t2 ON t1.parent_id = t2.id 
                             ORDER BY t1.parent_id = 0 DESC, t1.parent_id ASC, t1.sort_order ASC";
                                        $stmt = $db->query($query);
                                        $allTags = $stmt->fetchAll();
                                        // 组织父子关系
                                        $parentTags = [];
                                        $childTags = [];
                                        foreach ($allTags as $tag) {
                                            if ($tag['parent_id'] == 0) {
                                                $parentTags[] = $tag;
                                            } else {
                                                $childTags[$tag['parent_id']][] = $tag;
                                            }
                                        }
                                        // 按照父子关系显示
                                        foreach ($parentTags as $parent):
                                        ?>
                                            <option value="<?= $parent['id'] ?>"><?= $parent['name'] ?></option>
                                            <?php if (isset($childTags[$parent['id']])): ?>
                                                <?php foreach ($childTags[$parent['id']] as $child): ?>
                                                    <option value="<?= $child['id'] ?>" class="sub-option">└─ <?= $child['name'] ?></option>
                                                <?php endforeach; ?>
                                            <?php endif; ?>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <select name="line_id[]" class="form-control line-select" required data-row="<?= $i ?>">
                                    <option value="">请选择线路</option>
                                    <?php
                                    // 按供应商分组显示线路
                                    $currentSupplierId = null;
                                    foreach ($lines as $line):
                                        if ($currentSupplierId !== $line['supplier_id']):
                                            $currentSupplierId = $line['supplier_id'];
                                            if ($currentSupplierId !== $lines[0]['supplier_id']):
                                    ?>
                                                </optgroup>
                                            <?php endif; ?>
                                            <optgroup label="<?= $line['supplier_name'] ?>">
                                            <?php endif; ?>
                                            <option value="<?= $line['id'] ?>"><?= $line['name'] ?></option>
                                        <?php endforeach; ?>
                                            </optgroup>
                                </select>
                            </div>
                        </div>
                    <?php endfor; ?>
                </div>
                <div class="form-buttons">
                    <button type="submit" class="btn btn-primary">批量添加产品</button>

                </div>
            </form>
        </div>
    </div>

    <!-- 标签选择模态窗口 -->
    <div id="tagModalOverlay" class="modal-overlay">
        <div id="tagModal" class="modal">
            <div class="modal-header">
                <h3>选择标签</h3>
                <button type="button" class="close-modal">&times;</button>
            </div>
            <div class="modal-body">
                <div class="tag-tree">
                    <?php foreach ($parentTags as $parent): ?>
                        <div class="tag-parent">
                            <label class="tag-checkbox">
                                <input type="checkbox" class="parent-tag" value="<?= $parent['id'] ?>" data-tag-name="<?= $parent['name'] ?>">
                                <span><?= $parent['name'] ?></span>
                            </label>
                            <?php if (isset($childTags[$parent['id']])): ?>
                                <div class="tag-children">
                                    <?php foreach ($childTags[$parent['id']] as $child): ?>
                                        <label class="tag-checkbox">
                                            <input type="checkbox" class="child-tag" value="<?= $child['id'] ?>" data-parent="<?= $parent['id'] ?>" data-tag-name="<?= $child['name'] ?>">
                                            <span><?= $child['name'] ?></span>
                                        </label>
                                    <?php endforeach; ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-primary" id="confirmTagSelection">确认</button>
                <button type="button" class="btn btn-secondary close-modal">取消</button>
            </div>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const batchForm = document.querySelector('.batch-form');
            const rowCountDisplay = document.getElementById('rowCount');
            const addRowBtn = document.getElementById('addRow');
            const removeRowBtn = document.getElementById('removeRow');
            // 为所有input和select元素添加联动效果
            batchForm.addEventListener('change', function(e) {
                const target = e.target;
                // 检查是否是input或select元素
                if (target.matches('input, select')) {
                    const currentRow = parseInt(target.closest('.batch-row').dataset.row);
                    const fieldName = target.name.replace('[]', ''); // 获取字段名称
                    const selectedValue = target.value;
                    // 获取所有相同字段的元素
                    const sameFields = document.querySelectorAll(`[name="${fieldName}[]"]`);
                    // 更新当前行之后的所有对应字段
                    sameFields.forEach(field => {
                        const fieldRow = parseInt(field.closest('.batch-row').dataset.row);
                        if (fieldRow > currentRow) {
                            field.value = selectedValue;
                        }
                    });
                }
            });
            // 获取行模板
            const getRowTemplate = (rowIndex) => {
                const row = document.querySelector('.batch-row').cloneNode(true);
                row.dataset.row = rowIndex;
                // 更新行号
                row.querySelector('.row-number').textContent = rowIndex + 1;
                // 重置所有输入值
                row.querySelectorAll('input, select').forEach(input => {
                    input.value = '';
                    if (input.hasAttribute('data-row')) {
                        input.dataset.row = rowIndex;
                    }
                    // 不需要为流量字段设置默认值，因为空值会被处理为"不限"
                });
                return row;
            };
            // 更新行号和数据属性
            const updateRowNumbers = () => {
                const rows = batchForm.querySelectorAll('.batch-row');
                rows.forEach((row, index) => {
                    row.dataset.row = index;
                    row.querySelector('.row-number').textContent = index + 1;
                    row.querySelectorAll('[data-row]').forEach(el => {
                        el.dataset.row = index;
                    });
                });
                rowCountDisplay.textContent = rows.length;
            };
            // 添加行
            addRowBtn.addEventListener('click', () => {
                const currentRows = batchForm.querySelectorAll('.batch-row');
                const newRow = getRowTemplate(currentRows.length);
                batchForm.appendChild(newRow);
                updateRowNumbers();
            });
            // 删除行
            removeRowBtn.addEventListener('click', () => {
                const rows = batchForm.querySelectorAll('.batch-row');
                if (rows.length > 1) { // 保持至少一行
                    const lastClickedRow = document.querySelector('.batch-row.clicked');
                    if (lastClickedRow) {
                        // 删除被点击的行
                        lastClickedRow.remove();
                    } else {
                        // 如果没有被点击的行，删除最后一行
                        rows[rows.length - 1].remove();
                    }
                    updateRowNumbers();
                }
            });
            // 点击行时标记
            batchForm.addEventListener('click', (e) => {
                const row = e.target.closest('.batch-row');
                if (row) {
                    // 移除其他行的点击标记
                    document.querySelectorAll('.batch-row').forEach(r => {
                        r.classList.remove('clicked');
                    });
                    // 标记当前行
                    row.classList.add('clicked');
                }
            });
            // 处理多选标签的显示和联动
            const tagSelects = document.querySelectorAll('.tag-select');
            const tagButtons = document.querySelectorAll('.tag-select-btn');
            const tagModal = document.getElementById('tagModal');
            const tagModalOverlay = document.getElementById('tagModalOverlay');
            const confirmTagBtn = document.getElementById('confirmTagSelection');
            let currentTagRow = null;
            // 初始化标签显示
            tagSelects.forEach(select => {
                // 为隐藏的select设置change事件，用于在编程方式修改选择后更新显示
                select.addEventListener('change', function() {
                    updateSelectedTags(this);
                });
                // 初始化显示
                updateSelectedTags(select);
            });
            // 打开标签选择模态窗口
            tagButtons.forEach(btn => {
                btn.addEventListener('click', function(e) {
                    e.preventDefault();
                    currentTagRow = parseInt(this.dataset.row);
                    // 清除之前的选择状态
                    document.querySelectorAll('#tagModal input[type="checkbox"]').forEach(checkbox => {
                        checkbox.checked = false;
                    });
                    // 获取当前行已选标签
                    const select = document.querySelector(`.tag-select[data-row="${currentTagRow}"]`);
                    const selectedValues = Array.from(select.selectedOptions).map(opt => opt.value);
                    // 设置复选框选中状态
                    selectedValues.forEach(value => {
                        const checkbox = document.querySelector(`#tagModal input[value="${value}"]`);
                        if (checkbox) checkbox.checked = true;
                    });
                    // 显示模态窗口
                    tagModalOverlay.style.display = 'flex';
                });
            });
            // 关闭模态窗口
            document.querySelectorAll('.close-modal').forEach(btn => {
                btn.addEventListener('click', function() {
                    tagModalOverlay.style.display = 'none';
                });
            });
            // 点击模态窗口外部区域关闭
            tagModalOverlay.addEventListener('click', function(e) {
                if (e.target === this) {
                    this.style.display = 'none';
                }
            });
            // 父标签与子标签联动
            document.querySelectorAll('.parent-tag').forEach(parent => {
                parent.addEventListener('change', function() {
                    const parentId = this.value;
                    const isChecked = this.checked;
                    document.querySelectorAll(`.child-tag[data-parent="${parentId}"]`).forEach(child => {
                        child.checked = isChecked;
                    });
                });
            });
            // 子标签与父标签联动
            document.querySelectorAll('.child-tag').forEach(child => {
                child.addEventListener('change', function() {
                    const parentId = this.dataset.parent;
                    const parentCheckbox = document.querySelector(`.parent-tag[value="${parentId}"]`);
                    const siblingCheckboxes = document.querySelectorAll(`.child-tag[data-parent="${parentId}"]`);
                    const allChecked = Array.from(siblingCheckboxes).every(box => box.checked);
                    if (parentCheckbox) {
                        parentCheckbox.checked = allChecked;
                    }
                });
            });
            // 确认标签选择
            confirmTagBtn.addEventListener('click', function() {
                // 只有当前有选中的行时才处理
                if (currentTagRow === null) return;
                // 获取当前选中的标签
                const checkedBoxes = document.querySelectorAll('#tagModal input[type="checkbox"]:checked');
                // 按用户选择顺序记录标签
                const selectedValues = [];
                document.querySelectorAll('#tagModal input[type="checkbox"]').forEach(box => {
                    if (box.checked && (!box.classList.contains('parent-tag') ||
                            !document.querySelector(`.child-tag[data-parent="${box.value}"]:checked`))) {
                        selectedValues.push(box.value);
                    }
                });
                // 更新当前行和后续行的标签
                const rows = document.querySelectorAll('.batch-row');
                rows.forEach(row => {
                    const rowIndex = parseInt(row.dataset.row);
                    if (rowIndex >= currentTagRow) {
                        // 更新隐藏的select元素
                        const select = row.querySelector(`select[name="tags[${rowIndex}][]"]`);
                        if (!select) return;
                        // 清除现有选择
                        Array.from(select.options).forEach(opt => opt.selected = false);
                        // 设置新选择,保持用户选择的顺序
                        selectedValues.forEach(value => {
                            const option = select.querySelector(`option[value="${value}"]`);
                            if (option) {
                                option.selected = true;
                            }
                        });
                        // 不再显示标签内容，只用于数据记录
                        // 但仍需更新selected-tags为空以保持一致性
                        const selectedTagsContainer = row.querySelector('.selected-tags');
                        if (selectedTagsContainer) {
                            selectedTagsContainer.innerHTML = '<span class="placeholder"></span>';
                        }
                    }
                });
                // 关闭模态窗口
                tagModalOverlay.style.display = 'none';
            });
            // 更新已选标签显示
            function updateSelectedTags(select) {
                const row = select.dataset.row;
                // selected-tags元素被隐藏，但我们仍需更新其内容以保持一致性
                const selectedTagsContainer = document.querySelector(`.selected-tags[data-row="${row}"]`);
                if (selectedTagsContainer) {
                    selectedTagsContainer.innerHTML = '<span class="placeholder"></span>';
                }
                // 重点更新按钮的状态
                const tagSelectBtn = document.querySelector(`.tag-select-btn[data-row="${row}"]`);
                if (tagSelectBtn) {
                    const selectedOptions = Array.from(select.selectedOptions);
                    if (selectedOptions.length > 0) {
                        tagSelectBtn.classList.add('has-tags');
                        // 可以在按钮上显示已选标签数量
                        tagSelectBtn.setAttribute('title', `已选择${selectedOptions.length}个标签`);
                    } else {
                        tagSelectBtn.classList.remove('has-tags');
                        tagSelectBtn.removeAttribute('title');
                    }
                }
            }
            // 处理地区选择器的显示
            const regionSelects = document.querySelectorAll('.region-select');
            regionSelects.forEach(select => {
                // 初始化显示文本
                Array.from(select.options).forEach(option => {
                    if (option.classList.contains('sub-option')) {
                        const displayText = option.getAttribute('data-display-text');
                        if (displayText) {
                            option.text = displayText;
                        }
                    }
                });
                // 当下拉框打开时，显示带前缀的文本
                select.addEventListener('mousedown', function() {
                    Array.from(this.options).forEach(option => {
                        if (option.classList.contains('sub-option')) {
                            const displayText = option.getAttribute('data-display-text');
                            if (displayText) {
                                option.text = displayText;
                            }
                        }
                    });
                });
                // 当选择改变时，显示不带前缀的文本
                select.addEventListener('change', function() {
                    if (this.selectedIndex > 0) {
                        const selectedOption = this.options[this.selectedIndex];
                        if (selectedOption.classList.contains('sub-option')) {
                            const cleanText = selectedOption.getAttribute('data-clean-text');
                            if (cleanText) {
                                selectedOption.text = cleanText;
                            }
                        }
                    }
                });
            });
        });
    </script>
    <style>
        /* 整体风格重置 */
        :root {
            --primary-color: #2196F3;
            --primary-hover: #1976D2;
            --secondary-color: #607D8B;
            --border-color: #eeeeee;
            --light-bg: #f9f9f9;
            --text-color: #333;
            --placeholder-color: #757575;
            --shadow: 0 1px 2px rgba(0, 0, 0, 0.1);
        }

        body {

            color: var(--text-color);
            font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif;
        }

        /* 表单容器 */
        .form-container {
            padding: 0;
            background-color: #fff;
            box-shadow: var(--shadow);
            border-radius: 3px;
            margin-top: 15px;
        }

        /* 行控制按钮区域 */
        .row-controls {
            margin: 15px 0;
            display: flex;
            align-items: center;
            gap: 10px;
            padding: 0 10px;
        }

        .row-controls span {
            margin-left: 15px;
            font-size: 14px;
            color: var(--text-color);
        }

        .row-controls span#rowCount {
            font-weight: 500;
            color: var(--primary-color);
        }

        /* 按钮样式 */
        .btn {
            padding: 8px 15px;
            font-size: 14px;
            border-radius: 3px;
            border: none;
            cursor: pointer;
            text-decoration: none;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            font-weight: 400;
        }

        .btn-primary {
            background-color: var(--primary-color);
            color: white;
        }

        .btn-primary:hover {
            background-color: var(--primary-hover);
        }

        .btn-secondary {
            background-color: var(--secondary-color);
            color: white;
        }

        .btn-secondary:hover {
            background-color: #546E7A;
        }

        /* 表格样式 */
        .batch-form {
            border: 1px solid var(--border-color);
            margin-bottom: 0;
            width: 100%;
            border-collapse: collapse;
        }

        /* 表头样式 */
        .batch-header {
            display: flex;
            background-color: #f2f2f2;
            border-bottom: 1px solid var(--border-color);
            padding: 0;
            height: 36px;
            font-weight: 500;
            width: 100%;
        }

        .header-item {
            flex: 1;
            padding: 8px 0;
            font-weight: 500;
            color: var(--text-color);
            font-size: 14px;
            border-right: 1px solid var(--border-color);
            text-align: center;
            display: flex;
            align-items: center;
            justify-content: center;
            box-sizing: border-box;
            overflow: hidden;
        }

        .header-item:last-child {
            border-right: none;
        }

        /* 行样式 */
        .batch-row {
            display: flex;
            border-bottom: 1px solid var(--border-color);
            height: 36px;
            background-color: #fff;
            width: 100%;
            padding: 1px 0 5px 0;
        }

        .batch-row:hover {
            border-top: 1px solid #ff0000;
            transition: background-color 0.2s ease;

        }

        .batch-row:nth-child(even) {
            background-color: #fff;
        }

        .batch-row:nth-child(even):hover {
            background-color: #f5f5f5;
        }

        .batch-row:last-child {
            border-bottom: none;
        }

        .batch-row.clicked {
            background-color: #f0f7ff;
        }

        .batch-row.clicked:hover {
            background-color: #e3f2fd;
        }

        /* 确保特殊列的表头与内容对齐 */
        /* 行号列 */
        .batch-header .header-item:first-child,
        .batch-row .row-number {
            flex: 0.3;
            width: 40px;
            min-width: 40px;
            max-width: 40px;
            justify-content: center;
            text-align: center;
        }

        /* 标签列 */
        .batch-header .header-item:nth-child(12),
        .batch-row .form-group:nth-child(12) {
            flex: 0.1;
            max-width: 34px;
            min-width: 34px;
            width: 34px;
            box-sizing: border-box;
        }

        /* 地区列 */
        .batch-header .header-item:nth-child(11),
        .batch-row .form-group:nth-child(11) {
            flex: 1.5;
            min-width: 140px;
            box-sizing: border-box;
        }

        /* cpu列和线路列 */
        .batch-header .header-item:nth-child(2),
        .batch-row .form-group:nth-child(2),
        .batch-header .header-item:nth-child(13),
        .batch-row .form-group:nth-child(13) {
            flex: 1.2;
            box-sizing: border-box;
        }

        /* 中间各列 */
        .batch-header .header-item:nth-child(3),
        .batch-row .form-group:nth-child(3),
        .batch-header .header-item:nth-child(4),
        .batch-row .form-group:nth-child(4),
        .batch-header .header-item:nth-child(5),
        .batch-row .form-group:nth-child(5),
        .batch-header .header-item:nth-child(6),
        .batch-row .form-group:nth-child(6),
        .batch-header .header-item:nth-child(7),
        .batch-row .form-group:nth-child(7),
        .batch-header .header-item:nth-child(8),
        .batch-row .form-group:nth-child(8),
        .batch-header .header-item:nth-child(9),
        .batch-row .form-group:nth-child(9),
        .batch-header .header-item:nth-child(10),
        .batch-row .form-group:nth-child(10) {
            flex: 0.7;
            box-sizing: border-box;
        }

        /* 调整标签列内部元素 */
        .form-group:nth-child(12) .selected-tags {
            max-width: 0;
            padding: 0;
            visibility: hidden;
        }

        .form-group:nth-child(12) .tag-select-btn {
            width: 100%;
            border-left: none;
            padding: 0;
            font-size: 11px;
            background-color: #e3f2fd;
            font-weight: 500;
        }

        .form-group:nth-child(12) .tag-select-btn:hover {
            background-color: #bbdefb;
        }

        .form-group:nth-child(12) .tag-select-btn.has-tags {
            background-color: #bbdefb;
            position: relative;
        }

        .form-group:nth-child(12) .tag-select-btn.has-tags::after {
            content: "✓";
            font-size: 10px;
            position: absolute;
            top: 2px;
            right: 2px;
            color: #1976D2;
        }

        /* 警告消息 */
        .alert {
            padding: 12px 15px;
            margin-bottom: 15px;
            border-radius: 3px;
            font-size: 14px;
        }

        .alert-danger {
            background-color: #ffebee;
            border-left: 4px solid #f44336;
            color: #d32f2f;
        }

        .hidden {
            display: none !important;
        }

        /* 响应式调整 */
        @media (max-width: 1200px) {
            .batch-form {
                overflow-x: auto;
            }

            .batch-header,
            .batch-row {
                min-width: 1000px;
            }
        }

        /* 表单组样式 */
        .form-group {
            flex: 1;
            margin: 0;
            border-right: 1px solid var(--border-color);
            height: 36px;
        }

        .form-group:last-child {
            border-right: none;
        }

        /* 表单控件样式 */
        .form-control {
            border: none;
            border-radius: 0;
            padding: 8px 10px;
            width: 100%;
            font-size: 14px;
            height: 36px;
            box-sizing: border-box;
            color: var(--text-color);
            text-align: center;
            background-color: transparent;
        }

        .form-control:focus {
            outline: none;
            background-color: #f5f5f5;
        }

        .form-control::placeholder {
            color: var(--placeholder-color);
        }

        /* 下拉框样式 */
        select.form-control {
            padding: 7px 10px;
            background-color: white;
            cursor: pointer;
            color: var(--text-color);
            background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="12" height="12" viewBox="0 0 24 24" fill="none" stroke="%23757575" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M6 9l6 6 6-6"/></svg>');
            background-repeat: no-repeat;
            background-position: right 8px center;
            appearance: none;
            -webkit-appearance: none;
            -moz-appearance: none;
            padding-right: 24px;
            text-align: left;
        }

        select.form-control option {
            color: var(--text-color);
            padding: 8px;
        }

        select.form-control option:first-child {
            color: var(--placeholder-color);
        }

        select.form-control option.sub-option {
            padding-left: 20px;
            color: var(--text-color);
        }

        /* 提交按钮区域 */
        .form-buttons {
            margin: 15px 0;
            display: flex;
            gap: 10px;
            padding: 0 10px;
        }

        /* 多选标签样式 */
        .select-wrapper {
            position: relative;
            width: 100%;
            height: 100%;
        }

        select.hidden {
            display: none;
        }

        .tag-display {
            display: flex;
            flex-direction: row;
            align-items: center;
            height: 36px;
            width: 100%;
            box-sizing: border-box;
            background-color: white;
            overflow: hidden;
        }

        .selected-tags {
            height: 100%;
            padding: 0px 8px;
            background-color: white;
            border-radius: 0;
            display: flex;
            flex-wrap: wrap;
            gap: 4px;
            align-items: center;
            overflow-y: auto;
            flex-grow: 1;
            max-width: 100%;
        }

        .selected-tags .placeholder {
            color: var(--placeholder-color);
        }

        .selected-tags .tag {
            background-color: #e3f2fd;
            padding: 2px 6px;
            border-radius: 2px;
            font-size: 12px;
            white-space: nowrap;
            margin: 1px 0;
            color: var(--primary-color);
        }

        .tag-select-btn {
            height: 100%;
            padding: 0px 6px;
            background-color: #e3f2fd;
            border: none;
            cursor: pointer;
            color: var(--primary-color);
            font-size: 12px;
            text-align: center;
            width: 100%;
            flex-grow: 1;
        }

        .form-group:nth-child(12) .tag-select-btn {
            width: 100%;
            border-left: none;
            padding: 0;
            font-size: 11px;
            background-color: #e3f2fd;
            font-weight: 500;
        }

        .form-group:nth-child(12) .tag-select-btn:hover {
            background-color: #bbdefb;
        }

        .form-group:nth-child(12) .tag-select-btn.has-tags {
            background-color: #bbdefb;
            position: relative;
        }

        .form-group:nth-child(12) .tag-select-btn.has-tags::after {
            content: "✓";
            font-size: 10px;
            position: absolute;
            top: 2px;
            right: 2px;
            color: #1976D2;
        }

        /* 模态窗口样式 */
        .modal-overlay {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(0, 0, 0, 0.4);
            z-index: 1000;
            justify-content: center;
            align-items: center;
            padding: 0;
        }

        .modal {
            background-color: white;
            border-radius: 4px;
            width: 500px;
            max-width: 90%;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.15);
            display: flex;
            flex-direction: column;
            position: absolute;
            left: 50%;
            top: 50%;
            transform: translate(-50%, -50%);
        }

        .modal-header {
            padding: 12px;
            border-bottom: 1px solid var(--border-color);
            display: flex;
            justify-content: space-between;
            align-items: center;
            background-color: #f5f5f5;
        }

        .modal-header h3 {
            margin: 0;
            font-size: 16px;
            color: var(--text-color);
            font-weight: 500;
        }

        .close-modal {
            background: none;
            border: none;
            font-size: 20px;
            cursor: pointer;
            color: #999;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .modal-body {
            padding: 12px;
        }

        .modal-footer {
            padding: 10px 12px;
            border-top: 1px solid var(--border-color);
            display: flex;
            justify-content: flex-end;
            gap: 10px;
            background-color: #f5f5f5;
        }

        /* 标签树样式 */
        .tag-tree {
            display: flex;
            flex-direction: column;
            gap: 8px;
        }

        .tag-parent {
            border: 1px solid var(--border-color);
            border-radius: 3px;
            overflow: hidden;
        }

        .tag-parent>label {
            background-color: #f5f5f5;
            padding: 8px 12px;
            display: block;
            border-bottom: 1px solid var(--border-color);
            font-weight: 500;
            color: var(--text-color);
            cursor: pointer;
        }

        .tag-children {
            padding: 8px;
            display: flex;
            flex-wrap: wrap;
            gap: 6px;
            background-color: white;
        }

        .tag-checkbox {
            display: inline-flex;
            align-items: center;
            margin: 0;
            cursor: pointer;
            padding: 3px 6px;
            border-radius: 3px;
        }

        .tag-checkbox:hover {
            background-color: #f5f5f5;
        }

        .tag-checkbox input {
            margin-right: 6px;
            cursor: pointer;
        }
    </style>
</body>

</html>