/**
 * 后台管理系统登录脚本
 */
document.addEventListener('DOMContentLoaded', function() {
    const loginForm = document.getElementById('login-form');
    const errorMessage = document.getElementById('error-message');
    
    if (loginForm) {
        loginForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // 清除错误信息
            errorMessage.textContent = '';
            errorMessage.style.display = 'none';
            
            // 获取表单数据
            const formData = new FormData(loginForm);
            
            // 发送登录请求
            fetch('auth.php', {
                method: 'POST',
                body: formData,
                credentials: 'same-origin'
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('网络响应错误');
                }
                return response.json();
            })
            .then(data => {
                if (data.success) {
                    // 登录成功
                    console.log('登录成功，准备跳转');
                    if (data.redirect) {
                        window.location.href = data.redirect;
                    } else {
                        window.location.href = 'dashboard.php';
                    }
                } else {
                    // 显示错误信息
                    console.log('登录失败:', data.message);
                    errorMessage.textContent = data.message || '登录失败，请重试';
                    errorMessage.style.display = 'block';
                }
            })
            .catch(error => {
                console.error('登录请求出错:', error);
                errorMessage.textContent = '系统错误，请稍后重试';
                errorMessage.style.display = 'block';
            });
        });
    }
});
