document.addEventListener('DOMContentLoaded', function () {
    // 表单提交前确认
    const forms = document.querySelectorAll('form');
    forms.forEach(form => {
        form.addEventListener('submit', function (e) {
            const statusSelect = this.querySelector('select[name="status"]');
            if (statusSelect && statusSelect.value === 'closed') {
                if (!confirm('确定要关闭此工单吗?')) {
                    e.preventDefault();
                }
            }
        });
    });

    // 操作链接确认
    const actionLinks = document.querySelectorAll('.action-links a');
    actionLinks.forEach(link => {
        link.addEventListener('click', function (e) {
            if (this.textContent.trim() === '关闭工单') {
                if (!confirm('确定要关闭此工单吗?')) {
                    e.preventDefault();
                }
            }
        });
    });

    // 多文件上传预览功能
    const attachmentsInput = document.getElementById('attachments');
    const fileList = document.getElementById('fileList');

    if (attachmentsInput) {
        attachmentsInput.addEventListener('change', function () {
            fileList.innerHTML = '';

            if (this.files && this.files.length > 0) {
                for (let i = 0; i < this.files.length; i++) {
                    const file = this.files[i];
                    const fileItem = document.createElement('div');
                    fileItem.className = 'file-item';

                    const fileIcon = document.createElement('i');
                    if (file.type.match('image.*')) {
                        fileIcon.className = 'fas fa-file-image';
                    } else {
                        fileIcon.className = 'fas fa-file';
                    }

                    const fileName = document.createElement('span');
                    fileName.className = 'file-name';
                    fileName.textContent = file.name;

                    fileItem.appendChild(fileIcon);
                    fileItem.appendChild(fileName);

                    fileList.appendChild(fileItem);
                }
            }
        });
    }

    // 监听ESC键关闭模态框
    document.addEventListener('keydown', function (event) {
        if (event.key === 'Escape') {
            closeImageModal();
        }
    });

    // 点击模态框背景关闭
    const modal = document.getElementById('imageModal');
    if (modal) {
        modal.addEventListener('click', function (e) {
            if (e.target === this) {
                closeImageModal();
            }
        });
    }
    
    // 确保模态框关闭按钮能正常工作
    const closeButton = document.querySelector('.modal-close');
    if (closeButton) {
        closeButton.addEventListener('click', function(e) {
            e.preventDefault();
            closeImageModal();
        });
    }
    
    // 确保返回链接不会触发模态框
    const backLinks = document.querySelectorAll('.back-link');
    backLinks.forEach(link => {
        // 移除可能的冲突事件
        if (link.hasAttribute('onclick')) {
            link.removeAttribute('onclick');
        }
    });
});

// 打开图片模态框
function openImageModal(img) {
    const modal = document.getElementById('imageModal');
    const modalImg = document.getElementById('modalImage');
    const captionText = document.getElementById('modalCaption');

    modal.style.display = 'block';
    modalImg.src = img.src;
    captionText.innerHTML = img.alt || '附件图片';
}

// 关闭图片模态框
function closeImageModal() {
    const modal = document.getElementById('imageModal');
    modal.style.display = 'none';
}

