document.addEventListener('DOMContentLoaded', function() {
    // 添加会员按钮点击事件
    document.getElementById('add-user-btn').addEventListener('click', function() {
        window.location.href = 'user_add.php';
    });

    // 搜索功能
    document.getElementById('search-btn').addEventListener('click', function() {
        const searchTerm = document.getElementById('search-input').value.toLowerCase();
        document.querySelectorAll('tbody tr').forEach(row => {
            const username = row.querySelector('td:nth-child(2)').textContent.toLowerCase();
            if (username.includes(searchTerm)) {
                row.style.display = '';
            } else {
                row.style.display = 'none';
            }
        });
    });

    // 删除功能
    const deleteModal = document.getElementById('delete-modal');
    const deleteUserName = document.getElementById('delete-user-name');
    let deleteUserId = null;

    // 删除按钮点击事件
    document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
            deleteUserId = this.dataset.id;
            const username = this.dataset.name;
            deleteUserName.textContent = username;
            deleteModal.style.display = 'block';
        });
    });

    // 确认删除按钮点击事件
    document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteUserId) {
            // 发送删除请求
            fetch('user_delete.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: 'id=' + deleteUserId
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // 删除成功，移除对应的行
                        const row = document.querySelector(`tr[data-id="${deleteUserId}"]`);
                        if (row) {
                            row.remove();
                        }
                        // 显示成功消息
                        showSuccessMessage(data.message);
                    } else {
                        alert(data.message);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('删除失败，请重试');
                })
                .finally(() => {
                    deleteModal.style.display = 'none';
                    deleteUserId = null;
                });
        }
    });

    // 取消删除按钮点击事件
    document.getElementById('cancel-delete').addEventListener('click', function() {
        deleteModal.style.display = 'none';
        deleteUserId = null;
    });

    // 代管功能
    const manageModal = document.getElementById('manage-modal');
    const manageActionText = document.getElementById('manage-action-text');
    let manageUserId = null;
    let isManaged = false;

    // 代管按钮点击事件
    document.querySelectorAll('.btn-manage').forEach(button => {
        button.addEventListener('click', function() {
            manageUserId = this.dataset.id;
            isManaged = this.dataset.managed === '1';
            manageActionText.textContent = isManaged ? '取消' : '开启';
            manageModal.style.display = 'block';
        });
    });

    // 确认代管按钮点击事件
    document.getElementById('confirm-manage').addEventListener('click', function() {
        if (manageUserId) {
            // 发送代管状态更新请求
            fetch('user_manage.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `id=${manageUserId}&is_managed=${isManaged ? 0 : 1}`
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // 更新成功，更新对应行的代管状态
                        const row = document.querySelector(`tr[data-id="${manageUserId}"]`);
                        if (row) {
                            const managedCell = row.querySelector('td:nth-child(8)');
                            const manageButton = row.querySelector('.btn-manage');
                            // 更新代管状态显示
                            managedCell.textContent = isManaged ? '否' : '是';
                            // 更新按钮的data-managed属性
                            manageButton.dataset.managed = isManaged ? '0' : '1';
                        }
                        // 显示成功消息
                        showSuccessMessage(data.message || '代管状态更新成功！');
                    } else {
                        alert(data.message || '操作失败，请重试');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('操作失败，请重试');
                })
                .finally(() => {
                    manageModal.style.display = 'none';
                    manageUserId = null;
                });
        }
    });

    // 取消代管按钮点击事件
    document.getElementById('cancel-manage').addEventListener('click', function() {
        manageModal.style.display = 'none';
        manageUserId = null;
    });

    // 点击模态框外部关闭
    window.addEventListener('click', function(event) {
        if (event.target === deleteModal) {
            deleteModal.style.display = 'none';
            deleteUserId = null;
        }
        if (event.target === manageModal) {
            manageModal.style.display = 'none';
            manageUserId = null;
        }
    });

    // 编辑按钮点击事件
    document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
            const userId = this.dataset.id;
            window.location.href = `user_edit.php?id=${userId}`;
        });
    });

    // 显示成功消息的通用函数
    function showSuccessMessage(message) {
        const successMessage = document.getElementById('success-message');
        successMessage.textContent = message;
        successMessage.style.display = 'block';
        setTimeout(() => {
            successMessage.style.display = 'none';
        }, 3000);
    }

    // 如果有成功消息参数，显示成功消息
    if (new URLSearchParams(window.location.search).has('success')) {
        showSuccessMessage('操作成功！');
    }
}); 