/**
 * 视频编辑页面JavaScript功能
 */
$(document).ready(function() {
    // 初始化Select2增强下拉框
    $('.select2').select2({
        placeholder: "请选择...",
        allowClear: true,
        width: '100%'
    });

    // 缩略图预览功能
    $('#thumbnail').on('input', function() {
        updateThumbnailPreview($(this).val().trim());
    });

    // 缩略图验证
    $('#thumbnail').on('blur', function() {
        const imgUrl = $(this).val().trim();
        if (imgUrl) {
            validateImageUrl(imgUrl);
        }
    });

    // 上传按钮事件
    $('#uploadBtn').on('click', function() {
        Swal.fire({
            title: '上传缩略图',
            text: '请选择一个图片文件上传',
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: '选择文件',
            cancelButtonText: '取消',
            confirmButtonColor: '#3490dc'
        }).then((result) => {
            if (result.isConfirmed) {
                // 创建文件选择器
                const fileInput = document.createElement('input');
                fileInput.type = 'file';
                fileInput.accept = 'image/*';
                fileInput.click();

                fileInput.onchange = function() {
                    if (fileInput.files && fileInput.files[0]) {
                        // 这里应该添加文件上传逻辑
                        // 实际项目中应该将文件上传到服务器
                        Swal.fire({
                            title: '上传成功',
                            text: '文件将被上传到服务器',
                            icon: 'success'
                        });

                        // 模拟成功上传，设置临时URL
                        // 实际项目中应该使用服务器返回的URL
                        const tempUrl = URL.createObjectURL(fileInput.files[0]);
                        $('#thumbnail').val(tempUrl);
                        updateThumbnailPreview(tempUrl);
                    }
                };
            }
        });
    });

    // 浏览按钮事件
    $('#browseBtn').on('click', function() {
        Swal.fire({
            title: '浏览媒体库',
            text: '请从媒体库中选择图片',
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: '打开媒体库',
            cancelButtonText: '取消',
            confirmButtonColor: '#3490dc'
        }).then((result) => {
            if (result.isConfirmed) {
                // 这里应该打开媒体库浏览界面
                // 因为没有实际的媒体库，所以这里只是一个示例提示
                Swal.fire({
                    title: '功能开发中',
                    text: '媒体库浏览功能正在开发中',
                    icon: 'info'
                });
            }
        });
    });

    // 预览按钮事件
    $('#previewBtn').on('click', function() {
        const videoUrl = $('#video_url').val().trim();
        const title = $('#title').val().trim();
        const thumbnail = $('#thumbnail').val().trim();
        const description = $('#description').val().trim();

        if (!videoUrl) {
            Swal.fire({
                title: '无法预览',
                text: '请先输入视频链接',
                icon: 'warning'
            });
            return;
        }

        // 创建视频预览内容
        let previewHtml = `
            <div class="video-preview-container">
                <div class="video-iframe-container">
                    <iframe src="${videoUrl}" frameborder="0" allowfullscreen></iframe>
                </div>
                <div class="video-preview-info">
                    <h3>${title || '无标题'}</h3>
                    <div class="video-preview-meta">
                        <span><i class="fas fa-clock"></i> ${$('#duration').val() || '未知时长'}</span>
                        <span><i class="fas fa-folder"></i> ${$('#category_id option:selected').text() || '未分类'}</span>
                    </div>
                    <div class="video-preview-description">
                        ${description || '无描述信息'}
                    </div>
                </div>
            </div>
        `;

        Swal.fire({
            title: '视频预览',
            html: previewHtml,
            width: '80%',
            confirmButtonText: '关闭预览',
            confirmButtonColor: '#3490dc',
            showClass: {
                popup: 'animate__animated animate__fadeIn'
            }
        });
    });

    // 表单验证
    $('#videoForm').on('submit', function(event) {
        if (this.checkValidity() === false) {
            event.preventDefault();
            event.stopPropagation();
            
            // 显示表单验证提示
            Swal.fire({
                title: '表单验证失败',
                text: '请检查必填字段是否已填写',
                icon: 'error',
                confirmButtonColor: '#dc3545'
            });
        }
        
        $(this).addClass('was-validated');
    });
});

/**
 * 更新缩略图预览
 * @param {string} imgUrl 图片URL
 */
function updateThumbnailPreview(imgUrl) {
    const $inputGroup = $('#thumbnail').closest('.input-group');
    
    // 移除已有的预览元素
    $inputGroup.find('.has-thumbnail-icon').remove();
    $inputGroup.find('.thumbnail-hover-preview').remove();
    
    if (imgUrl) {
        // 添加预览图标和悬停预览
        $inputGroup.find('.input-group-append').append(`
            <span class="input-group-text has-thumbnail-icon" title="预览缩略图">
                <i class="fas fa-eye"></i>
            </span>
            <div class="thumbnail-hover-preview">
                <img src="${imgUrl}" alt="缩略图预览">
            </div>
        `);
    }
}

/**
 * 验证图片URL是否有效
 * @param {string} imgUrl 图片URL
 */
function validateImageUrl(imgUrl) {
    const img = new Image();
    img.onload = function() {
        // 图片加载成功
    };
    img.onerror = function() {
        // 图片加载失败 - 移除预览
        const $inputGroup = $('#thumbnail').closest('.input-group');
        $inputGroup.find('.has-thumbnail-icon').remove();
        $inputGroup.find('.thumbnail-hover-preview').remove();
        
        Swal.fire({
            icon: 'warning',
            title: '图片链接可能无效',
            text: '无法加载该图片，请检查URL是否正确',
            confirmButtonColor: '#3490dc'
        });
    };
    img.src = imgUrl;
}
