<?php
require_once '../config/database.php';
require_once 'code/auth_check.php';
require_once 'classes/ScriptSearch.php';
require_once 'classes/ScriptManager.php';
require_once 'code/script_code.php';
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>脚本管理 - 管理后台</title>
        <link rel="stylesheet" href="public/css/style.css">
        <link rel="stylesheet" href="public/css/index.css">
        <link rel="stylesheet" href="public/css/script.css">
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="container-fluid">
            <div class="row">
                <?php include 'public/letf.php'; ?>
                <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4 main-content">
                    <div class="page-header d-flex justify-content-between align-items-center">
                        <h1>脚本管理</h1>
                        <div class="action-buttons">
                            <button class="btn-action btn-edit btn-action-gap" id="batch-toggle-status" disabled>
                                批量修改状态
                            </button>
                            <button class="btn-action btn-delete btn-action-gap" id="batch-delete" disabled>
                                批量删除
                            </button>
                            <a href="script_add.php" class="btn-action btn-edit btn-action-gap"> 添加脚本</a>
                            <a class="btn-action btn-edit" id="manage-category-btn" href="script_category.php">
                                管理分类
                            </a>
                        </div>
                    </div>
                    <!-- 搜索框 -->
                    <div class="search-card">
                        <form id="search-form" class="search-form">
                            <div class="search-form-col-1">
                                <select name="category_id" class="search-select" id="category-filter">
                                    <option value="">所有分类</option>
                                    <?php foreach ($categories as $category): ?>
                                    <option value="<?= $category['id'] ?>" <?= isset($_GET['category_id']) && $_GET['category_id'] == $category['id'] ? 'selected' : '' ?>>
                                        <?= htmlspecialchars($category['name']) ?>
                                    </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="search-form-col-2">
                                <input type="text" name="keyword" class="search-input" id="keyword-input"
                                       placeholder="搜索脚本名称或描述..."
                                       value="<?= isset($_GET['keyword']) ? htmlspecialchars($_GET['keyword']) : '' ?>">
                            </div>
                            <div class="search-form-col-button">
                                <button type="submit" class="search-button">搜索</button>
                            </div>
                        </form>
                    </div>
                    <!-- 脚本列表 -->
                    <div class="table-container">
                        <table class="custom-table">
                            <thead>
                                <tr>
                                    <th>
                                        <input type="checkbox" id="select-all">
                                    </th>
                                    <th>ID</th>
                                    <th>名称</th>
                                    <th>分类</th>
                                    <th>来源</th>
                                    <th>排序</th>
                                    <th>状态</th>
                                    <th>创建时间</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($scripts)): ?>
                                <tr>
                                    <td colspan="9" class="no-data-cell">暂无数据</td>
                                </tr>
                                <?php else: ?>
                                <?php foreach ($scripts as $script): ?>
                                <tr>
                                    <td>
                                        <input type="checkbox" class="script-checkbox" value="<?= $script['id'] ?>">
                                    </td>
                                    <td><?= $script['id'] ?></td>
                                    <td><?= htmlspecialchars($script['name']) ?></td>
                                    <td><?= htmlspecialchars($script['category_name']) ?></td>
                                    <td><?= $script['source_type'] === 'original' ? '原创' : '网络' ?></td>
                                    <td><?= $script['sort_order'] ?></td>
                                    <td>
                                        <button type="button"
                                                class="btn-action btn-status <?= $script['status'] ? '' : 'disabled' ?>"
                                                data-id="<?= $script['id'] ?>"
                                                data-status="<?= $script['status'] ?>">
                                            <?= $script['status'] ? '启用' : '禁用' ?>
                                        </button>
                                    </td>
                                    <td><?= $script['created_at'] ?></td>
                                    <td>
                                        <button type="button" class="btn-action btn-edit edit-btn"
                                                data-id="<?= $script['id'] ?>">
                                            编辑
                                        </button>
                                        <button type="button" class="btn-action btn-delete delete-btn"
                                                data-id="<?= $script['id'] ?>"
                                                data-name="<?= htmlspecialchars($script['name']) ?>">
                                            删除
                                        </button>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <!-- 分页 -->
                    <?php if ($totalPages > 1): ?>
                    <nav aria-label="Page navigation" class="pagination-container">
                        <ul class="pagination">
                            <?php if ($page > 1): ?>
                            <li>
                                <a href="?page=1<?= isset($_GET['category_id']) ? '&category_id=' . $_GET['category_id'] : '' ?><?= isset($_GET['keyword']) ? '&keyword=' . urlencode($_GET['keyword']) : '' ?>">
                                    首页
                                </a>
                            </li>
                            <li>
                                <a href="?page=<?= $page - 1 ?><?= isset($_GET['category_id']) ? '&category_id=' . $_GET['category_id'] : '' ?><?= isset($_GET['keyword']) ? '&keyword=' . urlencode($_GET['keyword']) : '' ?>">
                                    上一页
                                </a>
                            </li>
                            <?php endif; ?>
                            <?php
                            $start = max(1, min($page - 2, $totalPages - 4));
                            $end = min($totalPages, max($page + 2, 5));
                            for ($i = $start; $i <= $end; $i++):
                            ?>
                            <li class="<?= $i === $page ? 'active' : '' ?>">
                                <a href="?page=<?= $i ?><?= isset($_GET['category_id']) ? '&category_id=' . $_GET['category_id'] : '' ?><?= isset($_GET['keyword']) ? '&keyword=' . urlencode($_GET['keyword']) : '' ?>">
                                    <?= $i ?>
                                </a>
                            </li>
                            <?php endfor; ?>
                            <?php if ($page < $totalPages): ?>
                            <li>
                                <a href="?page=<?= $page + 1 ?><?= isset($_GET['category_id']) ? '&category_id=' . $_GET['category_id'] : '' ?><?= isset($_GET['keyword']) ? '&keyword=' . urlencode($_GET['keyword']) : '' ?>">
                                    下一页
                                </a>
                            </li>
                            <li>
                                <a href="?page=<?= $totalPages ?><?= isset($_GET['category_id']) ? '&category_id=' . $_GET['category_id'] : '' ?><?= isset($_GET['keyword']) ? '&keyword=' . urlencode($_GET['keyword']) : '' ?>">
                                    末页
                                </a>
                            </li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                    <?php endif; ?>
                </main>
            </div>
        </div>
        <!-- 删除确认对话框 -->
        <div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="deleteModalLabel">确认删除</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        确定要删除脚本 "<span id="delete-script-name"></span>" 吗?
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">取消</button>
                        <button type="button" class="btn btn-danger" id="confirm-delete">确认删除</button>
                    </div>
                </div>
            </div>
        </div>
        <!-- 批量操作确认对话框 -->
        <div class="modal fade" id="batchModal" tabindex="-1" aria-labelledby="batchModalLabel" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="batchModalLabel">确认操作</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body" id="batch-modal-body">
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">取消</button>
                        <button type="button" class="btn btn-primary" id="confirm-batch">确认</button>
                    </div>
                </div>
            </div>
        </div>
        <script src="assets/js/bootstrap.bundle.min.js"></script>
        <script src="assets/js/jquery.min.js"></script>
        <script>
        $(document).ready(function() {
            // 自动隐藏提示消息
            setTimeout(function() {
                $('.alert').alert('close');
            }, 3000);

            // 全选/取消全选
            $('#select-all').change(function() {
                $('.script-checkbox').prop('checked', $(this).prop('checked'));
                updateBatchButtons();
            });

            // 单个复选框变化时更新批量操作按钮状态
            $('.script-checkbox').change(function() {
                updateBatchButtons();
            });

            // 更新批量操作按钮状态
            function updateBatchButtons() {
                const checkedCount = $('.script-checkbox:checked').length;
                $('#batch-toggle-status, #batch-delete').prop('disabled', checkedCount === 0);
            }

            // 添加脚本按钮
            $('#add-script-btn').click(function() {
                window.location.href = 'script_add.php';
            });

            // 编辑按钮
            $('.edit-btn').click(function() {
                const id = $(this).data('id');
                window.location.href = `script_edit.php?id=${id}`;
            });

            // 删除按钮
            $('.delete-btn').click(function() {
                const id = $(this).data('id');
                const name = $(this).data('name');
                $('#delete-script-name').text(name);
                $('#confirm-delete').data('id', id);
                $('#deleteModal').modal('show');
            });

            // 确认删除
            $('#confirm-delete').click(function() {
                const id = $(this).data('id');
                $.ajax({
                    url: 'script.php',
                    method: 'POST',
                    data: {
                        action: 'delete',
                        id: id
                    },
                    success: function(response) {
                        const result = JSON.parse(response);
                        if (result.success) {
                            location.reload();
                        } else {
                            alert(result.message);
                        }
                        $('#deleteModal').modal('hide');
                    },
                    error: function() {
                        alert('删除失败,请稍后重试');
                        $('#deleteModal').modal('hide');
                    }
                });
            });

            // 状态切换
            $('.btn-status').click(function() {
                const btn = $(this);
                const id = btn.data('id');
                $.ajax({
                    url: 'script.php',
                    method: 'POST',
                    data: {
                        action: 'toggle_status',
                        id: id
                    },
                    success: function(response) {
                        const result = JSON.parse(response);
                        if (result.success) {
                            btn.toggleClass('disabled')
                                .text(result.new_status ? '启用' : '禁用');
                        } else {
                            alert(result.message);
                        }
                    },
                    error: function() {
                        alert('状态更新失败,请稍后重试');
                    }
                });
            });

            // 批量删除
            $('#batch-delete').click(function() {
                const selectedIds = $('.script-checkbox:checked').map(function() {
                    return $(this).val();
                }).get();

                if (selectedIds.length === 0) return;

                $('#batchModalLabel').text('确认批量删除');
                $('#batch-modal-body').text(`确定要删除选中的 ${selectedIds.length} 个脚本吗?`);
                $('#confirm-batch').data('action', 'batch_delete').data('ids', selectedIds);
                $('#batchModal').modal('show');
            });

            // 批量修改状态
            $('#batch-toggle-status').click(function() {
                const selectedIds = $('.script-checkbox:checked').map(function() {
                    return $(this).val();
                }).get();

                if (selectedIds.length === 0) return;

                $('#batchModalLabel').text('确认批量修改状态');
                $('#batch-modal-body').html(`
                <p>请选择要将选中的 ${selectedIds.length} 个脚本改为什么状态:</p>
                <select id="batch-status" class="form-select">
                    <option value="1">启用</option>
                    <option value="0">禁用</option>
                </select>
            `);
                $('#confirm-batch').data('action', 'batch_toggle_status').data('ids', selectedIds);
                $('#batchModal').modal('show');
            });

            // 确认批量操作
            $('#confirm-batch').click(function() {
                const action = $(this).data('action');
                const ids = $(this).data('ids');
                const data = {
                    action: action,
                    ids: ids
                };

                if (action === 'batch_toggle_status') {
                    data.status = $('#batch-status').val();
                }

                $.ajax({
                    url: 'script.php',
                    method: 'POST',
                    data: data,
                    success: function(response) {
                        const result = JSON.parse(response);
                        if (result.success) {
                            location.reload();
                        } else {
                            alert(result.message);
                        }
                        $('#batchModal').modal('hide');
                    },
                    error: function() {
                        alert('操作失败,请稍后重试');
                        $('#batchModal').modal('hide');
                    }
                });
            });

            // 搜索表单提交
            $('#search-form').on('submit', function(e) {
                e.preventDefault();
                const categoryId = $('#category-filter').val();
                const keyword = $('#keyword-input').val().trim();
                let url = 'script.php?';
                if (categoryId) url += `category_id=${categoryId}&`;
                if (keyword) url += `keyword=${encodeURIComponent(keyword)}&`;
                window.location.href = url.slice(0, -1);
            });
        });
        </script>
    </body>
</html>
