<?php
// 引入逻辑代码文件
require_once 'code/script_add_code.php';
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>添加脚本 - 管理后台</title>
        <link rel="stylesheet" href="public/css/style.css">
        <link rel="stylesheet" href="public/css/index.css">
    
        <link rel="stylesheet" href="public/css/script_add.css">
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="container-fluid">
            <div class="row">
                <?php include 'public/letf.php'; ?>
                <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4 main-content">
                    <div class="page-header d-flex justify-content-between align-items-center">
                        <h1>添加脚本</h1>
                        <div class="action-buttons">
                            <a href="script.php" class="btn-action btn-edit">返回脚本列表</a>
                        </div>
                    </div>
                    <?php if (isset($error)): ?>
                    <div class="alert alert-danger" role="alert">
                        <?= $error ?>
                    </div>
                    <?php endif; ?>
                    <div class="card">
                        <div class="card-body">
                            <form method="post" id="scriptForm">
                                <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                                <!-- 基本信息 -->
                                <div class="form-section">
                                    <div class="form-section-title">基本信息</div>
                                    <div class="mb-4">
                                        <label for="name" class="form-label">脚本名称 <span class="required-mark">*</span></label>
                                        <input type="text" class="form-control" id="name" name="name" required
                                               value="<?= isset($_POST['name']) ? htmlspecialchars($_POST['name']) : '' ?>"
                                               placeholder="请输入脚本名称">
                                    </div>
                                    <div class="mb-4">
                                        <label for="category_id" class="form-label">所属分类 <span class="required-mark">*</span></label>
                                        <div class="category-select-container">
                                            <select class="form-select" id="category_id" name="category_id" required>
                                                <option value="">请选择分类</option>
                                                <?php foreach ($categories as $category): ?>
                                                <option value="<?= $category['id'] ?>" <?= isset($_POST['category_id']) && $_POST['category_id'] == $category['id'] ? 'selected' : '' ?>>
                                                    <?= htmlspecialchars($category['name']) ?>
                                                </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                    </div>
                                    <div class="mb-4">
                                        <label for="description" class="form-label">脚本描述</label>
                                        <textarea class="form-control" id="description" name="description" rows="4"
                                                  placeholder="请输入脚本功能、用途等描述信息"><?= isset($_POST['description']) ? htmlspecialchars($_POST['description']) : '' ?></textarea>
                                    </div>
                                </div>
                                <!-- 脚本来源 -->
                                <div class="form-section">
                                    <div class="form-section-title">脚本来源</div>
                                    <div class="mb-4">
                                        <div class="form-check form-check-inline"><input class="form-check-input" type="radio" name="source_type" id="source_original" value="original" <?= (!isset($_POST['source_type']) || $_POST['source_type'] === 'original') ? 'checked' : '' ?>><label class="form-check-label" for="source_original">原创</label></div><div class="form-check form-check-inline"><input class="form-check-input" type="radio" name="source_type" id="source_network" value="network" <?= isset($_POST['source_type']) && $_POST['source_type'] === 'network' ? 'checked' : '' ?>><label class="form-check-label" for="source_network">网络</label></div>
                                    </div>
                                </div>
                                <!-- 脚本URL -->
                                <div class="form-section">
                                    <div class="form-section-title">脚本URL <span class="required-mark">*</span></div>
                                    <div class="mb-4 url-input-container">
                                        <label for="script_url" class="form-label">脚本URL地址</label>
                                        <input type="url" class="form-control" id="script_url" name="script_url" required
                                               value="<?= isset($_POST['script_url']) ? htmlspecialchars($_POST['script_url']) : '' ?>"
                                               placeholder="https://example.com/script.sh">
                                   
                                    </div>
                                </div>
                                <!-- 其他设置 -->
                                <div class="form-section">
                                    <div class="form-section-title">其他设置</div>
                                    <div class="mb-4">
                                        <label for="sort_order" class="form-label">排序顺序</label>
                                        <input type="number" class="form-control" id="sort_order" name="sort_order"
                                               value="<?= isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0 ?>"
                                               placeholder="数字越大排序越靠前">
                                        <div class="form-text">默认为0，数字越大排序越靠前</div>
                                    </div>
                                </div>
                                <div class="text-end mt-4">
                                    <button type="button" class="btn btn-secondary me-2" onclick="history.back()">
                                        取消
                                    </button>
                                    <button type="submit" class="btn btn-primary">
                                        保存
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </main>
            </div>
        </div>
        <script src="assets/js/bootstrap.bundle.min.js"></script>
        <script src="assets/js/jquery.min.js"></script>
        <script>
        $(document).ready(function() {
            // 自动隐藏提示消息
            setTimeout(function() {
                $('.alert-danger').alert('close');
            }, 5000);

            // 表单提交前验证
            $('#scriptForm').on('submit', function(e) {
                const scriptUrl = $('#script_url').val().trim();
                if (!scriptUrl) {
                    e.preventDefault();
                    alert('请提供脚本URL！');
                    $('#script_url').focus();
                    return false;
                }

                // 简单的URL格式验证
                if (!scriptUrl.startsWith('http://') && !scriptUrl.startsWith('https://')) {
                    e.preventDefault();
                    alert('请输入完整的URL地址，包含http://或https://前缀');
                    $('#script_url').focus();
                    return false;
                }

                return true;
            });
        });
        </script>
    </body>
</html> 