<?php
require_once '../config/database.php';


// 获取数据库连接
$db = getDbConnection();

// 处理添加分类
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] === 'add') {
        $name = trim($_POST['name']);
        $description = trim($_POST['description']);
        $sort_order = intval($_POST['sort_order']);
        
        try {
            $stmt = $db->prepare("INSERT INTO script_categories (name, description, sort_order) VALUES (?, ?, ?)");
            $stmt->execute([$name, $description, $sort_order]);
            header("Location: script_category.php?msg=add_success");
            exit;
        } catch (PDOException $e) {
            $error = "添加失败：" . $e->getMessage();
        }
    }
    // 处理删除分类
    elseif ($_POST['action'] === 'delete' && isset($_POST['id'])) {
        $id = intval($_POST['id']);
        try {
            // 检查是否有关联的脚本
            $stmt = $db->prepare("SELECT COUNT(*) FROM scripts WHERE category_id = ?");
            $stmt->execute([$id]);
            if ($stmt->fetchColumn() > 0) {
                $error = "该分类下还有脚本，无法删除！";
            } else {
                $stmt = $db->prepare("DELETE FROM script_categories WHERE id = ?");
                $stmt->execute([$id]);
                header("Location: script_category.php?msg=delete_success");
                exit;
            }
        } catch (PDOException $e) {
            $error = "删除失败：" . $e->getMessage();
        }
    }
    // 处理更新分类
    elseif ($_POST['action'] === 'update' && isset($_POST['id'])) {
        $id = intval($_POST['id']);
        $name = trim($_POST['name']);
        $description = trim($_POST['description']);
        $sort_order = intval($_POST['sort_order']);
        
        try {
            $stmt = $db->prepare("UPDATE script_categories SET name = ?, description = ?, sort_order = ? WHERE id = ?");
            $stmt->execute([$name, $description, $sort_order, $id]);
            header("Location: script_category.php?msg=update_success");
            exit;
        } catch (PDOException $e) {
            $error = "更新失败：" . $e->getMessage();
        }
    }
    // 处理状态切换
    elseif ($_POST['action'] === 'toggle_status' && isset($_POST['id'])) {
        $id = intval($_POST['id']);
        try {
            $stmt = $db->prepare("UPDATE script_categories SET status = NOT status WHERE id = ?");
            $stmt->execute([$id]);
            header("Location: script_category.php?msg=update_success");
            exit;
        } catch (PDOException $e) {
            $error = "状态更新失败：" . $e->getMessage();
        }
    }
}

// 获取分类列表
$categories = $db->query("SELECT * FROM script_categories ORDER BY sort_order ASC, id DESC")->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>脚本分类管理 - 管理后台</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/index.css">
    <style>
    .main-content {
      padding: 20px;
      background: #f8f9fa;
      margin-top: 60px;
      /* 添加顶部边距，避免被顶部导航栏遮挡 */
    }

    .page-header {
      margin-bottom: 25px;
      padding-bottom: 15px;
      border-bottom: 1px solid #dee2e6;
    }

    .container-fluid {
      padding-left: 240px;
      /* 添加左侧边距，避免被侧边栏遮挡 */
      width: 100%;
      padding-right: 15px;
    }

    @media (max-width: 768px) {
      .container-fluid {
        padding-left: 15px;
        /* 在移动设备上重置padding */
      }
    }

    .table-container {
      background: white;
      border-radius: 4px;
      padding: 20px;
      box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
      overflow-x: auto;
      /* 添加横向滚动 */
    }

    .custom-table {
      width: 100%;
      border-collapse: collapse;
    }

    .custom-table th {
      background: #f8f9fa;
      padding: 12px 16px;
      font-weight: normal;
      text-align: left;
      border-bottom: 1px solid #dee2e6;
      color: #333;
      font-size: 14px;
    }

    .custom-table td {
      padding: 12px 16px;
      border-bottom: 1px solid #dee2e6;
      vertical-align: middle;
      font-size: 14px;
      color: #333;
    }

    .custom-table tr:hover {
      background-color: #f8f9fa;
    }

    .btn-action {
      padding: 4px 12px;
      margin: 0 4px;
      border-radius: 3px;
      border: none;
      cursor: pointer;
      transition: all 0.2s;
      font-size: 13px;
      min-width: 60px;
    }

    .btn-edit {
      background: #20c997;
      color: white;
    }

    .btn-edit:hover {
      background: #1ba97e;
    }

    .btn-delete {
      background: #dc3545;
      color: white;
    }

    .btn-delete:hover {
      background: #c82333;
    }

    .btn-status {
      min-width: 60px;
      background: #20c997;
    }

    .btn-status.disabled {
      background: #6c757d;
    }

    .alert {
      padding: 12px 20px;
      margin-bottom: 20px;
      border-radius: 4px;
      font-size: 14px;
    }

    .alert-success {
      background-color: #d4edda;
      border-color: #c3e6cb;
      color: #155724;
    }

    .alert-danger {
      background-color: #f8d7da;
      border-color: #f5c6cb;
      color: #721c24;
    }

    .modal {
      display: none;
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background: rgba(0, 0, 0, 0.5);
      z-index: 1050;
    }

    .modal.show {
      display: block;
    }

    .modal-dialog {
      position: relative;
      width: auto;
      max-width: 500px;
      margin: 1.75rem auto;
    }

    .modal-content {
      position: relative;
      background-color: #fff;
      border-radius: 4px;
      box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    }

    .modal-header {
      display: flex;
      align-items: center;
      justify-content: space-between;
      padding: 15px 20px;
      border-bottom: 1px solid #dee2e6;
    }

    .modal-title {
      margin: 0;
      font-size: 16px;
      font-weight: 500;
    }

    .modal-body {
      padding: 20px;
    }

    .form-group {
      margin-bottom: 1rem;
    }

    .form-label {
      display: block;
      margin-bottom: 0.5rem;
      font-size: 14px;
      color: #333;
    }

    .form-control {
      display: block;
      width: 100%;
      padding: 0.375rem 0.75rem;
      font-size: 14px;
      line-height: 1.5;
      color: #495057;
      background-color: #fff;
      border: 1px solid #ced4da;
      border-radius: 3px;
      transition: border-color 0.15s ease-in-out;
    }

    .form-control:focus {
      border-color: #80bdff;
      outline: 0;
      box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
    }

    .modal-footer {
      display: flex;
      align-items: center;
      justify-content: flex-end;
      gap: 10px;
      padding: 15px 20px;
      border-top: 1px solid #dee2e6;
    }

    .btn-close {
      padding: 0;
      background: transparent;
      border: 0;
      font-size: 20px;
      cursor: pointer;
      color: #6c757d;
    }

    </style>
  </head>
  <body> <?php include 'public/header.php'; ?> <div class="container-fluid">
      <div class="row"> <?php include 'public/letf.php'; ?> <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
          <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
            <h1 class="h2">脚本分类管理</h1>
            <div class="btn-toolbar mb-2 mb-md-0">
              <button type="button" class="btn btn-sm btn-primary" data-bs-toggle="modal" data-bs-target="#addCategoryModal">
                <i class="fa fa-plus"></i> 添加分类 </button>
            </div>
          </div> <?php if (isset($error)): ?> <div class="alert alert-danger alert-dismissible fade show" role="alert"> <?= $error ?> <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
          </div> <?php endif; ?> <?php if (isset($_GET['msg'])): ?> <div class="alert alert-success alert-dismissible fade show" role="alert"> <?php
                    $msg = $_GET['msg'];
                    switch ($msg) {
                        case 'add_success':
                            echo '添加分类成功！';
                            break;
                        case 'update_success':
                            echo '更新分类成功！';
                            break;
                        case 'delete_success':
                            echo '删除分类成功！';
                            break;
                    }
                    ?> <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
          </div> <?php endif; ?>
          <!-- 分类列表 -->
          <div class="table-container">
            <table class="custom-table">
              <thead>
                <tr>
                  <th>ID</th>
                  <th>名称</th>
                  <th>描述</th>
                  <th>排序</th>
                  <th>状态</th>
                  <th>创建时间</th>
                  <th>操作</th>
                </tr>
              </thead>
              <tbody> <?php foreach ($categories as $category): ?> <tr>
                  <td><?= $category['id'] ?></td>
                  <td><?= htmlspecialchars($category['name']) ?></td>
                  <td><?= htmlspecialchars($category['description']) ?></td>
                  <td><?= $category['sort_order'] ?></td>
                  <td>
                    <button type="button"
                            class="btn-action btn-status <?= $category['status'] ? '' : 'disabled' ?>"
                            onclick="toggleStatus(<?= $category['id'] ?>)"> <?= $category['status'] ? '启用' : '禁用' ?> </button>
                  </td>
                  <td><?= $category['created_at'] ?></td>
                  <td>
                    <button type="button" class="btn-action btn-edit" onclick="editCategory(<?= htmlspecialchars(json_encode($category)) ?>)"> 编辑 </button>
                    <button type="button" class="btn-action btn-delete" onclick="deleteCategory(<?= $category['id'] ?>, '<?= htmlspecialchars($category['name']) ?>')"> 删除 </button>
                  </td>
                </tr> <?php endforeach; ?> </tbody>
            </table>
          </div>
        </main>
      </div>
    </div>
    <!-- 添加分类模态框 -->
    <div class="modal fade" id="addCategoryModal" tabindex="-1" aria-labelledby="addCategoryModalLabel" aria-hidden="true">
      <div class="modal-dialog">
        <div class="modal-content">
          <div class="modal-header">
            <h5 class="modal-title" id="addCategoryModalLabel">添加分类</h5>
            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
          </div>
          <form method="post">
            <div class="modal-body">
              <input type="hidden" name="action" value="add">
              <div class="mb-3">
                <label for="name" class="form-label">分类名称</label>
                <input type="text" class="form-control" id="name" name="name" required>
              </div>
              <div class="mb-3">
                <label for="description" class="form-label">分类描述</label>
                <textarea class="form-control" id="description" name="description" rows="3"></textarea>
              </div>
              <div class="mb-3">
                <label for="sort_order" class="form-label">排序顺序</label>
                <input type="number" class="form-control" id="sort_order" name="sort_order" value="0">
              </div>
            </div>
            <div class="modal-footer">
              <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">取消</button>
              <button type="submit" class="btn btn-primary">保存</button>
            </div>
          </form>
        </div>
      </div>
    </div>
    <!-- 编辑分类模态框 -->
    <div class="modal fade" id="editCategoryModal" tabindex="-1" aria-labelledby="editCategoryModalLabel" aria-hidden="true">
      <div class="modal-dialog">
        <div class="modal-content">
          <div class="modal-header">
            <h5 class="modal-title" id="editCategoryModalLabel">编辑分类</h5>
            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
          </div>
          <form method="post">
            <div class="modal-body">
              <input type="hidden" name="action" value="update">
              <input type="hidden" name="id" id="edit_id">
              <div class="mb-3">
                <label for="edit_name" class="form-label">分类名称</label>
                <input type="text" class="form-control" id="edit_name" name="name" required>
              </div>
              <div class="mb-3">
                <label for="edit_description" class="form-label">分类描述</label>
                <textarea class="form-control" id="edit_description" name="description" rows="3"></textarea>
              </div>
              <div class="mb-3">
                <label for="edit_sort_order" class="form-label">排序顺序</label>
                <input type="number" class="form-control" id="edit_sort_order" name="sort_order">
              </div>
            </div>
            <div class="modal-footer">
              <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">取消</button>
              <button type="submit" class="btn btn-primary">保存更改</button>
            </div>
          </form>
        </div>
      </div>
    </div>
    <script src="assets/js/bootstrap.bundle.min.js"></script>
    <script src="assets/js/jquery.min.js"></script>
    <script>
    function editCategory(category) {
      $('#edit_id').val(category.id);
      $('#edit_name').val(category.name);
      $('#edit_description').val(category.description);
      $('#edit_sort_order').val(category.sort_order);
      $('#editCategoryModal').modal('show');
    }
    $(document).ready(function() {
      // 自动隐藏提示消息
      setTimeout(function() {
        $('.alert').alert('close');
      }, 3000);
    });
    </script>
  </body>
</html>
