<?php
/**
 * 添加region字段到area表
 * 
 * 此脚本用于为area表添加region字段，并初始化现有的一级地区值
 */
// 引入数据库配置文件
require_once '../../config/database.php';
// 获取数据库连接
$db = getDbConnection();

try {
    // 检查字段是否已存在
    $checkFieldQuery = "SHOW COLUMNS FROM `area` LIKE 'region'";
    $checkStmt = $db->query($checkFieldQuery);
    
    if ($checkStmt->rowCount() === 0) {
        // 字段不存在，添加字段
        $addFieldSQL = "ALTER TABLE `area` ADD COLUMN `region` int(11) DEFAULT NULL COMMENT '所属大区域：1-亚太地区，2-欧洲地区，3-美洲地区，4-中东非洲' AFTER `parent_id`";
        $db->exec($addFieldSQL);
        echo "成功添加region字段到area表<br>";
        
        // 初始化一级地区的region值
        // 实现一个简单的自动分配算法，根据地区名称判断应该属于哪个大区域
        $parentAreasQuery = "SELECT id, name FROM area WHERE parent_id IS NULL";
        $parentStmt = $db->query($parentAreasQuery);
        $parentAreas = $parentStmt->fetchAll(PDO::FETCH_ASSOC);
        
        foreach ($parentAreas as $area) {
            $regionValue = 1; // 默认为亚太地区
            $areaName = strtolower($area['name']);
            
            // 根据地区名称判断大区域
            if (
                strpos($areaName, 'china') !== false || 
                strpos($areaName, '中国') !== false ||
                strpos($areaName, 'japan') !== false || 
                strpos($areaName, '日本') !== false ||
                strpos($areaName, 'singapore') !== false || 
                strpos($areaName, '新加坡') !== false ||
                strpos($areaName, 'asia') !== false || 
                strpos($areaName, '亚洲') !== false ||
                strpos($areaName, 'korea') !== false || 
                strpos($areaName, '韩国') !== false
            ) {
                $regionValue = 1; // 亚太地区
            } 
            else if (
                strpos($areaName, 'europe') !== false || 
                strpos($areaName, '欧洲') !== false ||
                strpos($areaName, 'germany') !== false || 
                strpos($areaName, '德国') !== false ||
                strpos($areaName, 'france') !== false || 
                strpos($areaName, '法国') !== false ||
                strpos($areaName, 'uk') !== false || 
                strpos($areaName, '英国') !== false
            ) {
                $regionValue = 2; // 欧洲地区
            }
            else if (
                strpos($areaName, 'usa') !== false || 
                strpos($areaName, '美国') !== false ||
                strpos($areaName, 'canada') !== false || 
                strpos($areaName, '加拿大') !== false ||
                strpos($areaName, 'america') !== false || 
                strpos($areaName, '美洲') !== false
            ) {
                $regionValue = 3; // 美洲地区
            }
            else if (
                strpos($areaName, 'africa') !== false || 
                strpos($areaName, '非洲') !== false ||
                strpos($areaName, 'middle east') !== false || 
                strpos($areaName, '中东') !== false
            ) {
                $regionValue = 4; // 中东非洲
            }
            
            // 更新region值
            $updateSQL = "UPDATE area SET region = :region WHERE id = :id";
            $updateStmt = $db->prepare($updateSQL);
            $updateStmt->execute([
                'region' => $regionValue,
                'id' => $area['id']
            ]);
            
            echo "更新地区 {$area['name']} 的region值为 {$regionValue}<br>";
        }
        
        echo "<br>所有一级地区的region值初始化完成！<br>";
        echo "1 = 亚太地区<br>";
        echo "2 = 欧洲地区<br>";
        echo "3 = 美洲地区<br>";
        echo "4 = 中东非洲<br>";
    } else {
        echo "region字段已存在，无需添加";
    }
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?> 