<?php
/**
 * 地区管理表设置脚本
 * 
 * 此脚本用于创建地区管理表并插入初始数据
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
// 创建地区表
$createTableSQL = "
CREATE TABLE IF NOT EXISTS `area` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '地区ID，主键',
  `name` varchar(100) NOT NULL COMMENT '地区名称',
  `slug` varchar(100) NOT NULL COMMENT '静态页面名称，用于URL',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '地区排序，数值越小排序越靠前',
  `category_index` int(11) NOT NULL DEFAULT 100 COMMENT '分类索引',
  `parent_id` int(11) DEFAULT NULL COMMENT '父级地区ID，NULL表示顶级地区',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `slug_unique` (`slug`),
  KEY `parent_id_index` (`parent_id`),
  KEY `sort_order_index` (`sort_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='地区管理表';
";
try {
    $db->exec($createTableSQL);
    echo "地区表创建成功！<br>";
    // 检查表是否已有数据
    $checkData = $db->query("SELECT COUNT(*) as count FROM area");
    $rowCount = $checkData->fetch()['count'];
    if ($rowCount > 0) {
        echo "地区表已有数据，跳过初始数据插入。<br>";
    } else {
        // 插入初始数据
        $initialData = [
            // 父级地区
            ['id' => 1, 'name' => '中国', 'slug' => 'china', 'sort_order' => -10, 'category_index' => 100, 'parent_id' => NULL],
            ['id' => 4, 'name' => '美国', 'slug' => 'usa', 'sort_order' => -7, 'category_index' => 100, 'parent_id' => NULL],
            ['id' => 7, 'name' => '日本', 'slug' => 'japan', 'sort_order' => -4, 'category_index' => 100, 'parent_id' => NULL],
            ['id' => 10, 'name' => '新加坡', 'slug' => 'singapore', 'sort_order' => -1, 'category_index' => 100, 'parent_id' => NULL],
            // 中国的子地区
            ['id' => 2, 'name' => '香港', 'slug' => 'hongkong', 'sort_order' => -9, 'category_index' => 100, 'parent_id' => 1],
            ['id' => 3, 'name' => '台湾', 'slug' => 'taiwan', 'sort_order' => -8, 'category_index' => 100, 'parent_id' => 1],
            // 美国的子地区
            ['id' => 5, 'name' => '洛杉矶', 'slug' => 'losangeles', 'sort_order' => -6, 'category_index' => 100, 'parent_id' => 4],
            ['id' => 6, 'name' => '纽约', 'slug' => 'newyork', 'sort_order' => -5, 'category_index' => 100, 'parent_id' => 4],
            // 日本的子地区
            ['id' => 8, 'name' => '东京', 'slug' => 'tokyo', 'sort_order' => -3, 'category_index' => 100, 'parent_id' => 7],
            ['id' => 9, 'name' => '大阪', 'slug' => 'osaka', 'sort_order' => -2, 'category_index' => 100, 'parent_id' => 7],
        ];
        $insertSQL = "INSERT INTO area (id, name, slug, sort_order, category_index, parent_id) VALUES (:id, :name, :slug, :sort_order, :category_index, :parent_id)";
        $stmt = $db->prepare($insertSQL);
        foreach ($initialData as $data) {
            $stmt->execute($data);
        }
        echo "初始数据插入成功！<br>";
    }
    echo "地区管理表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?>
