<?php
/**
 * 聊天对话数据库表创建脚本
 * 用于初始化会员与管理员之间的聊天对话系统所需的数据库表结构
 */

// 引入数据库配置文件
require_once '../../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 检查chat_messages表是否已存在
    $tableExistsQuery = "SHOW TABLES LIKE 'chat_messages'";
    $tableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    // 开始事务
    $db->beginTransaction();
    
    if ($tableExists) {
        echo "<p>聊天消息表(chat_messages)已存在，跳过创建。</p>";
    } else {
        // 创建chat_messages表
        $createTableQuery = "
        CREATE TABLE `chat_messages` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `user_id` int(11) NOT NULL COMMENT '会员ID',
          `admin_id` int(11) DEFAULT NULL COMMENT '管理员ID(空表示会员发送)',
          `message` text NOT NULL COMMENT '消息内容',
          `is_read` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否已读：0未读，1已读',
          `created_at` datetime NOT NULL COMMENT '发送时间',
          PRIMARY KEY (`id`),
          KEY `idx_user_id` (`user_id`),
          KEY `idx_admin_id` (`admin_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='聊天消息表';
        ";
        
        $db->exec($createTableQuery);
        echo "<p>聊天消息表(chat_messages)创建成功！</p>";
        
        // 插入示例聊天数据
        $insertChatDataQuery = "
        INSERT INTO `chat_messages` (`user_id`, `admin_id`, `message`, `is_read`, `created_at`) VALUES
        (1, NULL, '您好，我有一个关于产品的问题想咨询一下', 1, '2025-04-18 05:00:00'),
        (1, 1, '您好，很高兴为您服务，请问有什么可以帮助您的？', 1, '2025-04-18 05:00:00'),
        (1, NULL, '我想了解一下最新的产品功能', 1, '2025-04-18 05:00:00'),
        (1, 1, '我们最新的产品增加了多项功能，包括AI助手和自动化处理流程，您可以在用户手册中查看详细说明', 1, '2025-04-18 05:00:00'),
        (1, NULL, '谢谢您的解答，非常有帮助', 1, '2025-04-19 05:00:00'),
        (1, 1, '不客气，如果您有其他问题，随时可以联系我们', 1, '2025-04-19 05:00:00'),
        (1, NULL, '最近系统升级后，我发现一个小问题', 0, '2025-04-20 05:00:00'),
        (1, NULL, '登录后偶尔会提示超时，这个是怎么回事？', 0, '2025-04-20 05:00:00'),
        (1, NULL, '这是一条测试消息 - 2025-04-20 09:21:26', 1, '2025-04-20 05:00:00'),
        (4, NULL, '这是一条测试消息 - 2025-04-20 09:21:38', 1, '2025-04-20 05:00:00'),
        (4, NULL, '这是一条测试消息 - 2025-04-20 09:24:44', 1, '2025-04-20 05:00:00'),
        (4, NULL, '这是一条测试消息 - 2025-04-20 09:24:52', 1, '2025-04-20 05:00:00'),
        (4, NULL, '这是一条测试消息 - 2025-04-20 09:24:56', 1, '2025-04-20 05:00:00'),
        (4, NULL, '这是一条测试消息 - 2025-04-20 09:27:22', 1, '2025-04-20 05:00:00'),
        (4, NULL, '这是一条测试消息 - 2025-04-20 09:27:28', 1, '2025-04-20 05:00:00'),
        (4, NULL, '你好', 1, '2025-04-20 05:00:00'),
        (4, NULL, '你好', 1, '2025-04-20 05:00:00'),
        (4, NULL, '好的 没问题', 1, '2025-04-20 05:00:00'),
        (4, NULL, '年后', 1, '2025-04-20 05:00:00'),
        (4, NULL, '你好', 1, '2025-04-20 05:00:00'),
        (4, 1, '感谢您的咨询，我会尽快处理您的问题。', 1, '2025-04-20 05:00:00'),
        (4, NULL, '111', 1, '2025-04-20 05:00:00'),
        (4, 1, '感谢您的咨询，我会尽快处理您的问题。', 1, '2025-04-20 05:00:00'),
        (4, NULL, '1111', 1, '2025-04-20 05:00:00'),
        (4, NULL, '222', 1, '2025-04-20 05:00:00'),
        (4, NULL, '你是', 1, '2025-04-20 05:00:00'),
        (4, 1, '感谢您的咨询，我会尽快处理您的问题。', 1, '2025-04-20 05:00:00'),
        (4, NULL, '真的很棒', 1, '2025-04-20 05:00:00'),
        (4, 1, '感谢您的咨询，我会尽快处理您的问题。', 1, '2025-04-20 05:00:00');
        ";
        
        $db->exec($insertChatDataQuery);
        echo "<p>示例聊天数据添加成功！</p>";
    }
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "聊天对话系统初始化完成！<br>";
    echo "已创建聊天消息表并添加了示例数据。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>聊天对话系统初始化</title>
    <style>
    body {
      font-family: Arial, sans-serif;
      line-height: 1.6;
      margin: 0;
      padding: 20px;
      background-color: #f5f5f5;
    }

    .container {
      max-width: 800px;
      margin: 0 auto;
      background-color: #fff;
      padding: 20px;
      border-radius: 5px;
      box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
    }

    h1 {
      color: #333;
      border-bottom: 1px solid #eee;
      padding-bottom: 10px;
    }

    p {
      margin: 10px 0;
    }

    .success {
      color: #3c763d;
    }

    .error {
      color: #a94442;
    }

    </style>
  </head>
  <body>
    <div class="container">
      <h1>聊天对话系统初始化</h1>
      <!-- PHP脚本输出的内容会显示在这里 -->
    </div>
  </body>
</html>
