<?php
/**
 * 配置表设置脚本
 * 
 * 此脚本用于创建配置相关的数据表并插入初始数据
 */
// 引入数据库配置文件
require_once __DIR__ . '/../../config/database.php';
// 获取数据库连接
$db = getDbConnection();

// 创建配置表
$createConfigTableSQL = "
CREATE TABLE IF NOT EXISTS `config` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '配置ID，主键',
  `name` varchar(100) NOT NULL COMMENT '配置名称',
  `cn_name` varchar(100) NOT NULL COMMENT '配置中文名称',
  `content` text NOT NULL COMMENT '配置内容',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序顺序',
  PRIMARY KEY (`id`),
  UNIQUE KEY `name_unique` (`name`),
  KEY `sort_order_index` (`sort_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='系统配置表';
";

try {
    // 创建配置表
    $db->exec($createConfigTableSQL);
    echo "配置表创建成功！<br>";
    
    // 检查配置表是否已有数据
    $checkConfigData = $db->query("SELECT COUNT(*) as count FROM config");
    $configRowCount = $checkConfigData->fetch()['count'];
    
    if ($configRowCount > 0) {
        echo "配置表已有数据，跳过初始数据插入。<br>";
    } else {
        // 插入初始示例配置数据
        $initialConfigData = [
            [
                'name' => 'site_name',
                'cn_name' => '网站名称',
                'content' => '服务器管理系统',
                'sort_order' => 1
            ],
            [
                'name' => 'site_description',
                'cn_name' => '网站描述',
                'content' => '专业的服务器管理系统',
                'sort_order' => 2
            ],
            [
                'name' => 'contact_email',
                'cn_name' => '联系邮箱',
                'content' => 'support@example.com',
                'sort_order' => 3
            ]
        ];
        
        $insertConfigSQL = "INSERT INTO config (name, cn_name, content, sort_order) 
                          VALUES (:name, :cn_name, :content, :sort_order)";
        $configStmt = $db->prepare($insertConfigSQL);
        
        foreach ($initialConfigData as $data) {
            $configStmt->execute($data);
        }
        
        echo "初始配置数据插入成功！<br>";
    }
    
    echo "配置表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?> 