<?php
require_once '../config/database.php';
try {
    $db = getDbConnection();
    // 删除已存在的表（如果需要重新创建）
    $db->exec("DROP TABLE IF EXISTS finance");
    // 创建财务表
    $sql = "CREATE TABLE finance (
        id INT AUTO_INCREMENT PRIMARY KEY COMMENT '财务ID',
        type TINYINT NOT NULL COMMENT '类型(1:会员充值,2:管理员操作,3:系统订单)',
        amount DECIMAL(10,2) NOT NULL COMMENT '金额(正数表示收入,负数表示支出)',
        member_id INT NOT NULL COMMENT '会员ID',
        description VARCHAR(255) DEFAULT '' COMMENT '描述',
        payment_status TINYINT DEFAULT 1 COMMENT '支付状态(1:已支付,0:未支付)',
        operator_id INT DEFAULT 0 COMMENT '操作员ID',
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
        INDEX idx_member_id (member_id),
        INDEX idx_type (type),
        INDEX idx_created_at (created_at)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='财务管理表'";
    $db->exec($sql);
    
    // 添加一些测试数据
    $testData = [
        ['type' => 1, 'amount' => 100.00, 'member_id' => 1, 'description' => '会员充值', 'payment_status' => 1],
        ['type' => 1, 'amount' => 200.50, 'member_id' => 2, 'description' => '会员充值', 'payment_status' => 1],
        ['type' => 2, 'amount' => -50.00, 'member_id' => 1, 'description' => '管理员调整账户', 'payment_status' => 1],
        ['type' => 3, 'amount' => -120.00, 'member_id' => 2, 'description' => '购买服务', 'payment_status' => 0],
        ['type' => 3, 'amount' => -80.00, 'member_id' => 1, 'description' => '续费服务', 'payment_status' => 0],
        ['type' => 2, 'amount' => 300.00, 'member_id' => 3, 'description' => '管理员添加余额', 'payment_status' => 1]
    ];
    
    $stmt = $db->prepare("INSERT INTO finance (type, amount, member_id, description, payment_status) VALUES (?, ?, ?, ?, ?)");
    foreach ($testData as $data) {
        $stmt->execute([
            $data['type'],
            $data['amount'],
            $data['member_id'],
            $data['description'],
            $data['payment_status']
        ]);
    }
    
    echo "财务表创建成功，并已添加测试数据！";
} catch (PDOException $e) {
    die("设置失败: " . $e->getMessage());
} 