<?php
/**
 * 合作伙伴表修复脚本
 * 
 * 此脚本用于修复合作伙伴分类表和联盟链接表的问题
 */
// 定义根目录路径
$rootDir = dirname(dirname(__DIR__));

// 引入数据库配置文件
require_once $rootDir . '/config/database.php';
// 获取数据库连接
$db = getDbConnection();

try {
    // 检查分类表是否有数据
    $checkCategoryData = $db->query("SELECT COUNT(*) as count FROM alliance_category");
    $categoryRowCount = $checkCategoryData->fetch()['count'];
    
    if ($categoryRowCount == 0) {
        echo "分类表无数据，将重新插入初始分类数据...<br>";
        
        // 插入初始分类数据
        $initialCategoryData = [
            ['name' => '推荐商家', 'code' => 'recommended', 'subtitle' => '免费测试!可换退~', 'sort_order' => 10],
            ['name' => '高防服务器', 'code' => 'high_defense', 'subtitle' => '先测试(不收费),扛不住全退!', 'sort_order' => 20],
            ['name' => '物理服务器', 'code' => 'physical_server', 'subtitle' => '独享资源,提供真机测试!', 'sort_order' => 30],
            ['name' => '站群服务器', 'code' => 'site_cluster', 'subtitle' => '原生很贵,根据业务选择!', 'sort_order' => 40],
            ['name' => '云服务器', 'code' => 'cloud_server', 'subtitle' => '不提供测试，建议者勿扰!', 'sort_order' => 50],
            ['name' => '技术博客', 'code' => 'tech_blog', 'subtitle' => '没事看看,万一学到嘞~', 'sort_order' => 60],
            ['name' => '行业工具', 'code' => 'industry_tools', 'subtitle' => '第三方网络检测网站~', 'sort_order' => 70],
            ['name' => '服务项目', 'code' => 'services', 'subtitle' => '量身定制,满意为止~', 'sort_order' => 80],
            ['name' => '原创软件', 'code' => 'original_software', 'subtitle' => '轻量级行业实用工具~', 'sort_order' => 90]
        ];
        
        $insertCategorySQL = "INSERT INTO alliance_category (name, code, subtitle, sort_order) VALUES (:name, :code, :subtitle, :sort_order)";
        $categoryStmt = $db->prepare($insertCategorySQL);
        
        foreach ($initialCategoryData as $data) {
            $categoryStmt->execute($data);
        }
        
        echo "初始合作伙伴分类数据插入成功！<br>";
    } else {
        // 检查分类代码是否正确
        $categoryCodesCheck = [
            'recommended', 'high_defense', 'physical_server', 'site_cluster', 
            'cloud_server', 'tech_blog', 'industry_tools', 'services', 'original_software'
        ];
        
        $missingCodes = [];
        
        foreach ($categoryCodesCheck as $code) {
            $checkSQL = "SELECT COUNT(*) FROM alliance_category WHERE code = :code";
            $checkStmt = $db->prepare($checkSQL);
            $checkStmt->execute(['code' => $code]);
            
            if ($checkStmt->fetchColumn() == 0) {
                $missingCodes[] = $code;
            }
        }
        
        if (count($missingCodes) > 0) {
            echo "发现缺少的分类代码: " . implode(", ", $missingCodes) . "<br>";
            echo "将修复缺少的分类...<br>";
            
            // 添加缺少的分类
            $categoryMap = [
                'recommended' => ['name' => '推荐商家', 'subtitle' => '免费测试!可换退~', 'sort_order' => 10],
                'high_defense' => ['name' => '高防服务器', 'subtitle' => '先测试(不收费),扛不住全退!', 'sort_order' => 20],
                'physical_server' => ['name' => '物理服务器', 'subtitle' => '独享资源,提供真机测试!', 'sort_order' => 30],
                'site_cluster' => ['name' => '站群服务器', 'subtitle' => '原生很贵,根据业务选择!', 'sort_order' => 40],
                'cloud_server' => ['name' => '云服务器', 'subtitle' => '不提供测试，建议者勿扰!', 'sort_order' => 50],
                'tech_blog' => ['name' => '技术博客', 'subtitle' => '没事看看,万一学到嘞~', 'sort_order' => 60],
                'industry_tools' => ['name' => '行业工具', 'subtitle' => '第三方网络检测网站~', 'sort_order' => 70],
                'services' => ['name' => '服务项目', 'subtitle' => '量身定制,满意为止~', 'sort_order' => 80],
                'original_software' => ['name' => '原创软件', 'subtitle' => '轻量级行业实用工具~', 'sort_order' => 90]
            ];
            
            $insertCategorySQL = "INSERT INTO alliance_category (name, code, subtitle, sort_order) VALUES (:name, :code, :subtitle, :sort_order)";
            $categoryStmt = $db->prepare($insertCategorySQL);
            
            foreach ($missingCodes as $code) {
                $data = $categoryMap[$code];
                $data['code'] = $code;
                $categoryStmt->execute($data);
                echo "已添加缺少的分类: {$data['name']} (代码: {$code})<br>";
            }
        } else {
            echo "所有分类代码都存在，无需修复。<br>";
        }
    }
    
    // 检查链接表数据是否正确
    $checkLinkData = $db->query("SELECT COUNT(*) as count FROM alliance_link");
    $linkRowCount = $checkLinkData->fetch()['count'];
    
    if ($linkRowCount == 0) {
        echo "链接表无数据，请运行alliance_setup.php脚本来插入初始数据。<br>";
    } else {
        echo "链接表已有{$linkRowCount}条数据。<br>";
        
        // 检查是否有空category_id的记录
        $checkEmptyCategorySQL = "SELECT COUNT(*) FROM alliance_link WHERE category_id = 0 OR category_id IS NULL";
        $emptyCategories = $db->query($checkEmptyCategorySQL)->fetchColumn();
        
        if ($emptyCategories > 0) {
            echo "警告: 发现{$emptyCategories}条空分类ID的记录，请手动检查并修复。<br>";
        }
    }
    
    echo "修复完成！现在您可以运行alliance_update.php来更新数据。";
    
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?> 