<?php
/**
 * 线路管理表设置脚本
 * 
 * 此脚本用于创建线路管理表并插入初始数据
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
// 创建线路表
$createLineTableSQL = "
CREATE TABLE IF NOT EXISTS `line` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '线路ID，主键',
  `supplier_id` int(11) NOT NULL COMMENT '供应商ID，关联suppliers表',
  `name` varchar(100) NOT NULL COMMENT '线路名称',
  `code` varchar(50) NOT NULL COMMENT '线路代码，用于标识',
  `description` text DEFAULT NULL COMMENT '线路描述',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `supplier_code_unique` (`supplier_id`, `code`),
  KEY `supplier_id_index` (`supplier_id`),
  KEY `sort_order_index` (`sort_order`),
  CONSTRAINT `fk_line_supplier` FOREIGN KEY (`supplier_id`) REFERENCES `suppliers` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='线路管理表';
";
try {
    // 创建线路表
    $db->exec($createLineTableSQL);
    echo "线路表创建成功！<br>";
    // 检查线路表是否已有数据
    $checkLineData = $db->query("SELECT COUNT(*) as count FROM line");
    $lineRowCount = $checkLineData->fetch()['count'];
    if ($lineRowCount > 0) {
        echo "线路表已有数据，跳过初始数据插入。<br>";
    } else {
        // 获取供应商数据
        $suppliersQuery = "SELECT id FROM suppliers LIMIT 2";
        $suppliersStmt = $db->query($suppliersQuery);
        $suppliers = $suppliersStmt->fetchAll();
        if (count($suppliers) > 0) {
            // 插入初始线路数据
            $initialLineData = [];
            // 为第一个供应商添加线路
            if (isset($suppliers[0])) {
                $supplier1Id = $suppliers[0]['id'];
                $initialLineData[] = ['supplier_id' => $supplier1Id, 'name' => '大陆优化', 'code' => 'mainland_optimized', 'description' => '提供的大陆优化线路', 'sort_order' => -10];
                $initialLineData[] = ['supplier_id' => $supplier1Id, 'name' => '精品网', 'code' => 'premium', 'description' => '提供的精品网线路', 'sort_order' => -9];
                $initialLineData[] = ['supplier_id' => $supplier1Id, 'name' => 'CN2', 'code' => 'cn2', 'description' => '提供的CN2线路', 'sort_order' => -8];
                $initialLineData[] = ['supplier_id' => $supplier1Id, 'name' => '国际BGP', 'code' => 'international_bgp', 'description' => '提供的国际BGP线路', 'sort_order' => -7];
            }
            // 为第二个供应商添加线路
            if (isset($suppliers[1])) {
                $supplier2Id = $suppliers[1]['id'];
                $initialLineData[] = ['supplier_id' => $supplier2Id, 'name' => '大陆优化', 'code' => 'mainland_optimized', 'description' => '提供的大陆优化线路', 'sort_order' => -10];
                $initialLineData[] = ['supplier_id' => $supplier2Id, 'name' => '精品网', 'code' => 'premium', 'description' => '提供的精品网线路', 'sort_order' => -9];
                $initialLineData[] = ['supplier_id' => $supplier2Id, 'name' => 'CN2', 'code' => 'cn2', 'description' => '提供的CN2线路', 'sort_order' => -8];
            }
            if (!empty($initialLineData)) {
                $insertLineSQL = "INSERT INTO line (supplier_id, name, code, description, sort_order) VALUES (:supplier_id, :name, :code, :description, :sort_order)";
                $lineStmt = $db->prepare($insertLineSQL);
                foreach ($initialLineData as $data) {
                    $lineStmt->execute($data);
                }
                echo "初始线路数据插入成功！<br>";
            } else {
                echo "没有找到供应商，跳过初始数据插入。<br>";
            }
        } else {
            echo "没有找到供应商，请先添加供应商数据。<br>";
        }
    }
    echo "线路管理表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 