<?php
/**
 * 订单管理表设置脚本
 * 
 * 此脚本用于创建订单相关的数据表并插入初始数据
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();

// 创建订单表
$createOrderTableSQL = "
CREATE TABLE IF NOT EXISTS `orders` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单ID，主键',
  `product_type` varchar(100) NOT NULL COMMENT '产品/服务类型',
  `hostname` varchar(100) NOT NULL COMMENT '主机名称',
  `ip_address` varchar(100) NOT NULL COMMENT 'IP地址',
  `price` decimal(10,2) NOT NULL COMMENT '价格',
  `currency` varchar(10) NOT NULL DEFAULT 'USD' COMMENT '货币单位',
  `next_payment_date` date DEFAULT NULL COMMENT '下次付款日期',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-有效，2-审核中，3-已暂停，4-已终止，5-已取消',
  `vpc` varchar(50) DEFAULT NULL COMMENT 'VPC信息',
  `auto_renew` tinyint(1) NOT NULL DEFAULT 0 COMMENT '自动续费：1-是，0-否',
  `server_specs` varchar(255) DEFAULT NULL COMMENT '服务器配置规格',
  `is_multiple_ip` tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否多IP服务器：1-是，0-否',
  `ip_count` int(11) DEFAULT 0 COMMENT 'IP数量',
  `notes` varchar(255) DEFAULT NULL COMMENT '备注/额外信息',
  `os_type` varchar(100) DEFAULT NULL COMMENT '操作系统类型',
  `username` varchar(50) DEFAULT NULL COMMENT '服务器登录用户名',
  `password` varchar(100) DEFAULT NULL COMMENT '服务器登录密码',
  `port` int(11) DEFAULT NULL COMMENT '服务器登录端口',
  `panel_password` varchar(100) DEFAULT NULL COMMENT '面板密码',
  `is_manual_order` tinyint(1) NOT NULL DEFAULT 1 COMMENT '订单类型：1-人工订单，0-会员系统自动订单',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `status_index` (`status`),
  KEY `hostname_index` (`hostname`),
  KEY `ip_address_index` (`ip_address`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='服务器订单表';
";

try {
    // 创建订单表
    $db->exec($createOrderTableSQL);
    echo "订单表创建成功！<br>";
    
    // 检查订单表是否已有数据
    $checkOrderData = $db->query("SELECT COUNT(*) as count FROM orders");
    $orderRowCount = $checkOrderData->fetch()['count'];
    
    if ($orderRowCount > 0) {
        echo "订单表已有数据，跳过初始数据插入。<br>";
    } else {
        // 插入初始示例订单数据
        $initialOrderData = [
            [
                'product_type' => 'LA Bare - Metal E5',
                'hostname' => 'C202502250196903',
                'ip_address' => '104.219.214.114',
                'price' => 48.51,
                'currency' => 'USD',
                'next_payment_date' => '2025-03-24',
                'status' => 1,
                'vpc' => NULL,
                'auto_renew' => 0,
                'server_specs' => '2620, 32G RAM, 1T 硬碟盘',
                'is_multiple_ip' => 0,
                'ip_count' => 1,
                'notes' => 'x51',
                'os_type' => 'Ubuntu-22.04-x64',
                'username' => 'root',
                'password' => 'Af8nG9A5eDoz',
                'port' => 22,
                'panel_password' => 'T15keLHx',
                'is_manual_order' => 1
            ],
            [
                'product_type' => 'LA Bare - Metal E5',
                'hostname' => 'C202502250197981',
                'ip_address' => '104.219.214.75',
                'price' => 48.51,
                'currency' => 'USD',
                'next_payment_date' => '2025-03-24',
                'status' => 1,
                'vpc' => NULL,
                'auto_renew' => 0,
                'server_specs' => '2620, 32G RAM, 1T 硬碟盘',
                'is_multiple_ip' => 0,
                'ip_count' => 1,
                'notes' => 'x51',
                'os_type' => 'CentOS-7-x64',
                'username' => 'root',
                'password' => 'B7xmP3R9eLqt',
                'port' => 22,
                'panel_password' => 'S29paNGx',
                'is_manual_order' => 1
            ],
            [
                'product_type' => 'LA Bare - Metal E5',
                'hostname' => 'C202502161336635',
                'ip_address' => '104.233.248.146',
                'price' => 113.41,
                'currency' => 'USD',
                'next_payment_date' => '2025-03-15',
                'status' => 1,
                'vpc' => NULL,
                'auto_renew' => 0,
                'server_specs' => '2620, 32G RAM, 1T HDD, 5+253 IPs',
                'is_multiple_ip' => 1,
                'ip_count' => 258,
                'notes' => 'x49|3',
                'os_type' => 'Windows-2019-x64',
                'username' => 'Administrator',
                'password' => 'W2kLp7Z9vQxY',
                'port' => 3389,
                'panel_password' => 'R45dsTGw',
                'is_manual_order' => 1
            ]
        ];
        
        $insertOrderSQL = "INSERT INTO orders (product_type, hostname, ip_address, price, currency, next_payment_date, 
                          status, vpc, auto_renew, server_specs, is_multiple_ip, ip_count, notes, os_type, username, 
                          password, port, panel_password, is_manual_order) 
                          VALUES (:product_type, :hostname, :ip_address, :price, :currency, :next_payment_date, 
                          :status, :vpc, :auto_renew, :server_specs, :is_multiple_ip, :ip_count, :notes, :os_type, 
                          :username, :password, :port, :panel_password, :is_manual_order)";
        $orderStmt = $db->prepare($insertOrderSQL);
        
        foreach ($initialOrderData as $data) {
            $orderStmt->execute($data);
        }
        
        echo "初始订单数据插入成功！<br>";
    }
    
    echo "订单管理表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?>
