<?php
/**
 * 产品管理表设置脚本
 * 
 * 此脚本用于创建产品管理表并插入初始数据
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
// 检查表是否存在
$checkTable = $db->query("SHOW TABLES LIKE 'products'");
$tableExists = $checkTable->rowCount() > 0;
if ($tableExists) {
    // 如果表已存在，先删除它
    $db->exec("DROP TABLE IF EXISTS `products`");
    echo "已删除旧的产品表<br>";
}
// 创建产品表 - 不包含UPC唯一键约束
$createTableSQL = "
CREATE TABLE IF NOT EXISTS `products` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '产品ID，主键',
  `cpu` varchar(100) NOT NULL COMMENT 'CPU规格',
  `memory` varchar(50) NOT NULL COMMENT '内存配置',
  `disk` varchar(50) NOT NULL COMMENT '硬盘配置',
  `bandwidth` varchar(50) NOT NULL COMMENT '带宽配置',
  `traffic` varchar(50) DEFAULT NULL COMMENT '流量配置，NULL表示不限',
  `defense` varchar(50) DEFAULT NULL COMMENT '防御配置',
  `ip_count` int(11) NOT NULL DEFAULT 1 COMMENT 'IP数量',
  `price` decimal(10,2) DEFAULT NULL COMMENT '产品价格',
  `region_id` int(11) DEFAULT NULL COMMENT '关联的地区ID',
  `tags` varchar(255) DEFAULT NULL COMMENT '关联的标签ID，多个用逗号分隔',
  `line_id` int(11) DEFAULT NULL COMMENT '关联的线路ID',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `region_id_index` (`region_id`),
  KEY `line_id_index` (`line_id`),
  CONSTRAINT `fk_products_region` FOREIGN KEY (`region_id`) REFERENCES `area` (`id`) ON DELETE SET NULL,
  CONSTRAINT `fk_products_line` FOREIGN KEY (`line_id`) REFERENCES `line` (`id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='产品管理表';
";
try {
    // 创建表
    $db->exec($createTableSQL);
    echo "产品表创建成功！<br>";
    // 获取线路数据
    $lineQuery = "SELECT id FROM line LIMIT 2";
    $lineStmt = $db->query($lineQuery);
    $lines = $lineStmt->fetchAll();
    // 插入示例数据
    $initialData = [];
    if (count($lines) > 0) {
        $initialData = [
            [
                'cpu' => 'E3-1230v3',
                'memory' => '8GB',
                'disk' => '500GB SSD',
                'bandwidth' => '100Mbps',
                'traffic' => null, // 不限流量
                'defense' => '10Gbps',
                'ip_count' => 1,
                'price' => 299.99,
                'region_id' => 2, // 香港
                'tags' => '1,3', // 多个标签
                'line_id' => $lines[0]['id']
            ]
        ];
        if (count($lines) > 1) {
            $initialData[] = [
                'cpu' => 'E5-2680v4',
                'memory' => '16GB',
                'disk' => '1TB SSD',
                'bandwidth' => '200Mbps',
                'traffic' => null, // 不限流量
                'defense' => '20Gbps',
                'ip_count' => 2,
                'price' => 499.99,
                'region_id' => 5, // 洛杉矶
                'tags' => '2,4', // 多个标签
                'line_id' => $lines[1]['id']
            ];
        }
        $insertSQL = "INSERT INTO products (cpu, memory, disk, bandwidth, traffic, defense, ip_count, price, region_id, tags, line_id) 
                      VALUES (:cpu, :memory, :disk, :bandwidth, :traffic, :defense, :ip_count, :price, :region_id, :tags, :line_id)";
        $stmt = $db->prepare($insertSQL);
        foreach ($initialData as $data) {
            $stmt->execute($data);
        }
        echo "示例数据插入成功！<br>";
    } else {
        echo "没有找到线路数据，请先添加线路数据。<br>";
    }
    echo "产品管理表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?>
