<?php
/**
 * repositor数据库表创建脚本
 * 用于初始化repositor系统所需的分类和问题数据表结构
 */

// 引入数据库配置文件
require_once '../../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 检查表是否已存在
    $categoryTableExists = $db->query("SHOW TABLES LIKE 'repositor_category'")->rowCount() > 0;
    $itemTableExists = $db->query("SHOW TABLES LIKE 'repositor_item'")->rowCount() > 0;
    
    // 开始事务
    $db->beginTransaction();
    
    // 创建分类表
    if (!$categoryTableExists) {
        $createCategoryTable = "
        CREATE TABLE `repositor_category` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `name` varchar(100) NOT NULL COMMENT '分类名称',
          `slug` varchar(100) NOT NULL COMMENT '分类标识(用于URL)',
          `icon` varchar(50) DEFAULT NULL COMMENT '分类图标',
          `description` varchar(255) DEFAULT NULL COMMENT '分类描述',
          `sort_order` int(11) NOT NULL DEFAULT '0' COMMENT '排序(数字越小越靠前)',
          `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          UNIQUE KEY `slug` (`slug`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='repositor分类表';
        ";
        $db->exec($createCategoryTable);
        echo "<p>repositor分类表(repositor_category)创建成功！</p>";
    } else {
        echo "<p>repositor分类表(repositor_category)已存在，跳过创建。</p>";
    }
    
    // 创建问题表
    if (!$itemTableExists) {
        $createItemTable = "
        CREATE TABLE `repositor_item` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `category_id` int(11) NOT NULL COMMENT '所属分类ID',
          `question` varchar(255) NOT NULL COMMENT '问题标题',
          `answer` text NOT NULL COMMENT '问题答案(支持HTML)',
          `sort_order` int(11) NOT NULL DEFAULT '0' COMMENT '排序(数字越小越靠前)',
          `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `category_id` (`category_id`),
          CONSTRAINT `fk_repositor_item_category` FOREIGN KEY (`category_id`) REFERENCES `repositor_category` (`id`) ON DELETE CASCADE
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='repositor问题表';
        ";
        $db->exec($createItemTable);
        echo "<p>repositor问题表(repositor_item)创建成功！</p>";
    } else {
        echo "<p>repositor问题表(repositor_item)已存在，跳过创建。</p>";
    }
    
    // 只有当表是新创建的时候才插入数据
    if (!$categoryTableExists || !$itemTableExists) {
        // 插入分类数据
        $categories = [
            ['服务器选择', 'server-selection', 'computer', '如何选择最适合您业务需求的服务器', 1],
            ['技术支持', 'technical-support', 'build', '服务器使用过程中的技术问题解答', 2],
            ['账户管理', 'account-management', 'person', '关于账户注册、管理和安全的常见问题', 3],
            ['付款与账单', 'payment-billing', 'payment', '关于支付方式、账单和退款的常见问题', 4],
            ['网络与安全', 'network-security', 'security', '关于网络连接、线路选择和安全防护的常见问题', 5]
        ];
        
        $insertCategoryQuery = "
        INSERT INTO `repositor_category` (`name`, `slug`, `icon`, `description`, `sort_order`, `status`, `created_at`) 
        VALUES (?, ?, ?, ?, ?, 1, NOW())
        ";
        
        $categoryStmt = $db->prepare($insertCategoryQuery);
        foreach ($categories as $index => $category) {
            $categoryStmt->execute($category);
            echo "<p>分类 '{$category[0]}' 添加成功！</p>";
        }
        
        // 获取刚插入的分类ID
        $categoryIds = [];
        $getCategoriesQuery = "SELECT id, slug FROM repositor_category";
        $categoryResults = $db->query($getCategoriesQuery);
        while ($row = $categoryResults->fetch(PDO::FETCH_ASSOC)) {
            $categoryIds[$row['slug']] = $row['id'];
        }
        
        // 插入问题数据
        $repositorItems = [
            // 服务器选择分类下的问题
            [
                $categoryIds['server-selection'],
                '香港服务器和美国服务器哪个更适合中国大陆访问？',
                '<p>从网络延迟角度看，香港服务器明显优于美国服务器：</p>
                <ul>
                    <li><strong>香港服务器：</strong>距离中国大陆地理位置近，ping值通常在30-80ms之间，BGP多线接入，全国各地延迟相对均衡。</li>
                    <li><strong>美国服务器：</strong>距离中国大陆较远，普通线路ping值通常在180-280ms之间，CN2线路可优化至140-200ms。</li>
                </ul>
                <p>如果您的目标用户主要在中国大陆，且业务对延迟敏感或需要高防护，香港服务器是首选；而如果您预算有限，或目标用户分布全球，美国CN2服务器可能更具性价比。</p>',
                1
            ],
            [
                $categoryIds['server-selection'],
                '如何选择适合我业务的服务器配置？',
                '<p>选择服务器配置需要考虑以下几个因素：</p>
                <ul>
                    <li><strong>CPU：</strong>对于计算密集型应用（如数据分析、视频处理），选择高性能多核CPU；对于一般网站，4-8核心通常足够。</li>
                    <li><strong>内存：</strong>数据库应用建议16GB以上，网站和应用服务器根据并发用户数决定，一般8-32GB。</li>
                    <li><strong>存储：</strong>考虑SSD（速度快）或HDD（容量大），根据数据量和性能需求选择。</li>
                    <li><strong>带宽：</strong>视频流媒体需要大带宽，一般网站5-10Mbps起步，根据访问量增加。</li>
                </ul>
                <p>我们提供免费技术咨询，可以根据您的具体业务需求推荐最合适的配置。</p>',
                2
            ],
            [
                $categoryIds['server-selection'],
                '什么是CN2/CN2 GIA线路？有什么优势？',
                '<p>CN2和CN2 GIA是中国电信提供的优质国际线路：</p>
                <ul>
                    <li><strong>CN2：</strong>中国电信的下一代承载网，相比普通国际线路，拥有更低的延迟和更稳定的连接。</li>
                    <li><strong>CN2 GIA（Global Internet Access）：</strong>是CN2的高级版本，提供端到端的优化连接，全程走CN2网络，不经过公网，延迟更低，稳定性更高。</li>
                </ul>
                <p>CN2 GIA线路特别适合对网络质量要求高的业务，如游戏服务器、视频流媒体、金融交易等。虽然价格较高，但对于面向中国大陆用户的国际业务，其性能提升非常显著。</p>',
                3
            ],
            [
                $categoryIds['server-selection'],
                '物理服务器和云服务器有什么区别？我应该选择哪种？',
                '<p><strong>物理服务器（独立服务器）：</strong></p>
                <ul>
                    <li>优势：资源独享、性能稳定、可定制化程度高、适合高负载应用</li>
                    <li>劣势：价格较高、扩展不够灵活、部署时间较长</li>
                </ul>
                <p><strong>云服务器：</strong></p>
                <ul>
                    <li>优势：价格低廉、即时部署、弹性扩展、按需付费</li>
                    <li>劣势：资源共享可能导致性能波动、定制化程度有限</li>
                </ul>
                <p>选择建议：</p>
                <ul>
                    <li>如果您需要稳定的高性能、有特殊硬件需求或对安全有极高要求，选择物理服务器</li>
                    <li>如果您注重成本效益、需要快速部署或业务负载波动较大，选择云服务器</li>
                </ul>',
                4
            ],
            [
                $categoryIds['server-selection'],
                '什么是高防服务器？我的业务需要吗？',
                '<p>高防服务器是指配备了大流量DDoS防护能力的服务器，可以抵御大规模的网络攻击。</p>
                <p>以下业务类型通常需要考虑高防服务器：</p>
                <ul>
                    <li>游戏服务器（容易成为攻击目标）</li>
                    <li>金融相关网站（支付系统、交易平台等）</li>
                    <li>有竞争对手的电商网站</li>
                    <li>曾经遭受过DDoS攻击的网站</li>
                    <li>高流量、高知名度的网站</li>
                </ul>
                <p>我们提供不同防护能力的高防服务器，从100G到600G不等，可以根据您的业务风险评估选择合适的防护级别。</p>',
                5
            ],
            
            // 技术支持分类下的问题
            [
                $categoryIds['technical-support'],
                '服务器无法访问或连接中断怎么办？',
                '<p>当服务器无法访问时，请按以下步骤排查：</p>
                <ol>
                    <li>检查本地网络连接是否正常</li>
                    <li>尝试ping服务器IP地址，查看是否有网络连通性</li>
                    <li>检查服务器防火墙设置，确保没有阻止您的连接</li>
                    <li>确认服务器相关服务是否正常运行</li>
                    <li>检查服务器负载情况，是否因资源耗尽导致响应缓慢</li>
                </ol>
                <p>如果以上步骤无法解决问题，请立即联系我们的技术支持团队，提供服务器IP和详细问题描述，我们会优先处理您的问题。</p>',
                1
            ],
            [
                $categoryIds['technical-support'],
                '如何提高服务器的安全性？',
                '<p>提高服务器安全性的基本措施：</p>
                <ul>
                    <li><strong>更新系统：</strong>定期安装操作系统和软件的安全更新</li>
                    <li><strong>配置防火墙：</strong>只开放必要的端口，限制访问来源</li>
                    <li><strong>使用强密码：</strong>为所有账户设置复杂密码，定期更换</li>
                    <li><strong>禁用root远程登录：</strong>使用普通用户+sudo权限管理服务器</li>
                    <li><strong>启用SSH密钥认证：</strong>禁用密码登录，使用密钥对认证</li>
                    <li><strong>安装安全软件：</strong>部署防病毒软件和入侵检测系统</li>
                    <li><strong>定期备份：</strong>建立自动备份机制，确保数据安全</li>
                </ul>
                <p>我们提供服务器安全加固服务，可以帮助您全面提升服务器安全性。</p>',
                2
            ],
            [
                $categoryIds['technical-support'],
                '服务器性能优化有哪些方法？',
                '<p>服务器性能优化的主要方法：</p>
                <ul>
                    <li><strong>系统层面：</strong>
                        <ul>
                            <li>优化内核参数（如TCP连接数、文件描述符限制等）</li>
                            <li>使用SSD存储提升I/O性能</li>
                            <li>合理配置swap分区</li>
                        </ul>
                    </li>
                    <li><strong>应用层面：</strong>
                        <ul>
                            <li>配置缓存系统（如Redis、Memcached）</li>
                            <li>优化数据库查询和索引</li>
                            <li>实施内容分发网络(CDN)</li>
                        </ul>
                    </li>
                    <li><strong>资源监控：</strong>
                        <ul>
                            <li>部署监控工具及时发现性能瓶颈</li>
                            <li>设置资源使用告警</li>
                        </ul>
                    </li>
                </ul>
                <p>我们的技术团队可以根据您的具体应用场景提供专业的性能优化方案。</p>',
                3
            ],
            
            // 账户管理分类下的问题
            [
                $categoryIds['account-management'],
                '如何注册账户？',
                '<p>注册账户的步骤：</p>
                <ol>
                    <li>访问我们的官方网站首页</li>
                    <li>点击右上角的"注册"按钮</li>
                    <li>填写您的电子邮箱、设置密码</li>
                    <li>验证您的电子邮箱（我们会发送验证链接）</li>
                    <li>完善个人资料和联系信息</li>
                </ol>
                <p>注册成功后，您可以立即访问客户中心，浏览产品并进行订购。如果注册过程中遇到任何问题，请联系我们的客服团队获取帮助。</p>',
                1
            ],
            [
                $categoryIds['account-management'],
                '忘记密码怎么办？',
                '<p>如果您忘记了账户密码，可以通过以下步骤重置：</p>
                <ol>
                    <li>访问登录页面，点击"忘记密码"链接</li>
                    <li>输入您注册时使用的电子邮箱</li>
                    <li>系统会向该邮箱发送密码重置链接</li>
                    <li>点击邮件中的链接，设置新密码</li>
                </ol>
                <p>如果您无法访问注册邮箱，请联系客服提供您的账户信息和身份证明，我们会协助您恢复账户访问权限。</p>',
                2
            ],
            
            // 付款与账单分类下的问题
            [
                $categoryIds['payment-billing'],
                '支持哪些付款方式？',
                '<p>我们支持多种付款方式，包括：</p>
                <ul>
                    <li><strong>信用卡/借记卡：</strong>支持Visa、MasterCard、American Express等</li>
                    <li><strong>PayPal：</strong>支持PayPal账户付款</li>
                    <li><strong>加密货币：</strong>支持比特币、以太坊等主流加密货币</li>
                    <li><strong>银行转账：</strong>支持国际电汇</li>
                    <li><strong>支付宝/微信支付：</strong>支持中国大陆用户常用的支付方式</li>
                </ul>
                <p>不同地区可能支持的付款方式有所不同，您可以在结账页面查看适用于您地区的所有可用付款选项。</p>',
                1
            ],
            [
                $categoryIds['payment-billing'],
                '如何查看和下载账单？',
                '<p>查看和下载账单的步骤：</p>
                <ol>
                    <li>登录您的客户中心账户</li>
                    <li>点击导航菜单中的"账单"选项</li>
                    <li>您可以看到所有历史账单列表</li>
                    <li>点击特定账单旁的"查看"按钮查看详情</li>
                    <li>点击"下载PDF"按钮可下载账单的PDF版本</li>
                </ol>
                <p>我们保存最近24个月的账单记录。如果您需要更早的账单记录，请联系客服团队。</p>',
                2
            ],
            
            // 网络与安全分类下的问题
            [
                $categoryIds['network-security'],
                '如何选择最适合我业务的网络线路？',
                '<p>选择网络线路时需要考虑以下因素：</p>
                <ul>
                    <li><strong>目标用户地区：</strong>如果主要面向中国大陆用户，建议选择CN2或CN2 GIA线路；如果面向全球用户，可选择国际BGP线路。</li>
                    <li><strong>业务类型：</strong>对延迟敏感的业务（如游戏、直播）需要选择优质线路；内容分发类业务可考虑配合CDN使用。</li>
                    <li><strong>预算考量：</strong>高质量线路价格较高，需要在性能和成本间平衡。</li>
                </ul>
                <p>我们提供的主要线路类型：</p>
                <ul>
                    <li><strong>普通BGP线路：</strong>成本较低，适合一般网站。</li>
                    <li><strong>CN2线路：</strong>中国电信优质国际线路，访问中国大陆稳定性好。</li>
                    <li><strong>CN2 GIA线路：</strong>全程CN2网络，访问中国大陆体验最佳。</li>
                    <li><strong>多线BGP：</strong>自动选择最优路径，适合面向多地区用户。</li>
                </ul>',
                1
            ],
            [
                $categoryIds['network-security'],
                '什么是DDoS攻击？如何防护？',
                '<p><strong>DDoS（分布式拒绝服务）攻击</strong>是指攻击者利用大量受控制的计算机向目标服务器发送大量请求，耗尽服务器资源，导致正常用户无法访问服务。</p>
                <p>防护DDoS攻击的方法：</p>
                <ul>
                    <li><strong>使用高防服务器：</strong>我们提供100G-600G不等的DDoS防护能力，可以抵御大多数攻击。</li>
                    <li><strong>CDN加速：</strong>使用CDN可以分散流量，减轻源站压力。</li>
                    <li><strong>流量清洗：</strong>通过专业设备过滤恶意流量，只允许正常流量通过。</li>
                    <li><strong>多IP轮换：</strong>在遭受攻击时可以快速切换IP，避免服务中断。</li>
                </ul>
                <p>我们的高防服务器采用多层防护架构，可以有效抵御各类DDoS攻击，保障您的业务稳定运行。</p>',
                2
            ]
        ];
        
        $insertItemQuery = "
        INSERT INTO `repositor_item` (`category_id`, `question`, `answer`, `sort_order`, `status`, `created_at`) 
        VALUES (?, ?, ?, ?, 1, NOW())
        ";
        
        $itemStmt = $db->prepare($insertItemQuery);
        foreach ($repositorItems as $index => $item) {
            $itemStmt->execute($item);
            echo "<p>问题 '{$item[1]}' 添加成功！</p>";
        }
    }
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "repositor数据表初始化完成！<br>";
    echo "现在您可以修改repositor.php文件，让它从数据库中读取repositor数据而不是使用静态内容。<br>";
    echo "<a href='../../cn/repositor.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 查看repositor页面。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>repositor系统初始化</title>
        <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }

        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        p {
            margin: 10px 0;
        }

        .success {
            color: #3c763d;
        }

        .error {
            color: #a94442;
        }

        </style>
    </head>
    <body>
        <div class="container">
            <h1>repositor系统初始化</h1>
            <!-- PHP脚本输出的内容会显示在这里 -->
        </div>
    </body>
</html>
