<?php
/**
 * 脚本管理数据库表创建脚本
 * 用于初始化脚本分类和脚本内容数据库表结构
 */

// 引入数据库配置文件
require_once '../../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 检查script_categories表是否存在
    $tableExistsQuery = "SHOW TABLES LIKE 'script_categories'";
    $tableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    if (!$tableExists) {
        // 创建script_categories表
        $createCategoriesTableQuery = "
        CREATE TABLE `script_categories` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `name` varchar(100) NOT NULL COMMENT '分类名称',
          `description` text DEFAULT NULL COMMENT '分类描述',
          `sort_order` int(11) NOT NULL DEFAULT '0' COMMENT '排序顺序',
          `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
          PRIMARY KEY (`id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='脚本分类表';
        ";
        
        $db->exec($createCategoriesTableQuery);
        echo "<p>脚本分类表(script_categories)创建成功！</p>";
        
        // 添加初始分类数据
        $insertCategoriesQuery = "
        INSERT INTO `script_categories` (`name`, `description`, `sort_order`, `status`, `created_at`) VALUES
        ('系统工具', '系统维护和优化相关脚本', 1, 1, NOW()),
        ('安全防护', '系统安全和防护相关脚本', 2, 1, NOW()),
        ('性能优化', '系统性能提升相关脚本', 3, 1, NOW()),
        ('备份恢复', '数据备份和恢复相关脚本', 4, 1, NOW()),
        ('监控告警', '系统监控和告警相关脚本', 5, 1, NOW());
        ";
        
        $db->exec($insertCategoriesQuery);
        echo "<p>已添加初始脚本分类数据。</p>";
    } else {
        echo "<p>脚本分类表(script_categories)已存在，跳过创建。</p>";
    }
    
    // 检查scripts表是否存在
    $tableExistsQuery = "SHOW TABLES LIKE 'scripts'";
    $tableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    if (!$tableExists) {
        // 创建scripts表
        $createScriptsTableQuery = "
        CREATE TABLE `scripts` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `category_id` int(11) NOT NULL COMMENT '分类ID',
          `name` varchar(255) NOT NULL COMMENT '脚本名称',
          `url` varchar(255) NOT NULL COMMENT '脚本链接',
          `description` text DEFAULT NULL COMMENT '脚本描述',
          `source_type` enum('original','network') NOT NULL DEFAULT 'original' COMMENT '脚本来源：original-原创，network-网络',
          `sort_order` int(11) NOT NULL DEFAULT '0' COMMENT '排序顺序',
          `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `category_id` (`category_id`),
          CONSTRAINT `scripts_ibfk_1` FOREIGN KEY (`category_id`) REFERENCES `script_categories` (`id`) ON DELETE CASCADE
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='脚本内容表';
        ";
        
        $db->exec($createScriptsTableQuery);
        echo "<p>脚本内容表(scripts)创建成功！</p>";
        
        // 添加初始脚本数据
        $insertScriptsQuery = "
        INSERT INTO `scripts` (`category_id`, `name`, `url`, `description`, `source_type`, `sort_order`, `status`, `created_at`) VALUES
        (1, '系统清理工具', 'https://example.com/scripts/system-cleaner.sh', '自动清理系统临时文件和缓存', 'original', 1, 1, NOW()),
        (1, '磁盘空间分析', 'https://example.com/scripts/disk-analyzer.sh', '分析磁盘空间使用情况并生成报告', 'network', 2, 1, NOW()),
        (2, '防火墙配置脚本', 'https://example.com/scripts/firewall-setup.sh', '自动配置系统防火墙规则', 'original', 1, 1, NOW()),
        (2, '安全漏洞扫描', 'https://example.com/scripts/security-scan.sh', '扫描系统安全漏洞并提供修复建议', 'network', 2, 1, NOW()),
        (3, '性能监控脚本', 'https://example.com/scripts/performance-monitor.sh', '监控系统性能指标并记录日志', 'original', 1, 1, NOW()),
        (3, '资源优化工具', 'https://example.com/scripts/resource-optimizer.sh', '优化系统资源分配和使用', 'network', 2, 1, NOW()),
        (4, '自动备份脚本', 'https://example.com/scripts/auto-backup.sh', '自动备份重要数据到远程服务器', 'original', 1, 1, NOW()),
        (4, '数据恢复工具', 'https://example.com/scripts/data-recovery.sh', '从备份中恢复数据', 'network', 2, 1, NOW()),
        (5, '服务监控脚本', 'https://example.com/scripts/service-monitor.sh', '监控关键服务状态并在异常时发送通知', 'original', 1, 1, NOW()),
        (5, '日志分析工具', 'https://example.com/scripts/log-analyzer.sh', '分析系统日志并生成报告', 'network', 2, 1, NOW());
        ";
        
        $db->exec($insertScriptsQuery);
        echo "<p>已添加初始脚本数据。</p>";
    } else {
        // 检查是否需要添加source_type字段
        $checkSourceTypeField = "SHOW COLUMNS FROM `scripts` LIKE 'source_type'";
        $sourceTypeFieldExists = $db->query($checkSourceTypeField)->rowCount() > 0;
        
        if (!$sourceTypeFieldExists) {
            // 添加source_type字段
            $addSourceTypeField = "ALTER TABLE `scripts` ADD COLUMN `source_type` enum('original','network') NOT NULL DEFAULT 'original' COMMENT '脚本来源：original-原创，network-网络' AFTER `description`";
            $db->exec($addSourceTypeField);
            echo "<p>已向脚本表添加来源类型字段。</p>";
            
            // 更新现有脚本的source_type
            $updateSourceTypeQuery = "UPDATE `scripts` SET `source_type` = 'original' WHERE `source_type` IS NULL";
            $db->exec($updateSourceTypeQuery);
            echo "<p>已更新现有脚本的来源类型。</p>";
        }
        
        echo "<p>脚本内容表(scripts)已存在，跳过创建。</p>";
    }
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "脚本管理系统数据库表初始化完成！<br>";
    echo "<a href='../login.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 进入后台登录页面。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>脚本管理系统初始化</title>
    <style>
    body {
      font-family: Arial, sans-serif;
      line-height: 1.6;
      margin: 0;
      padding: 20px;
      background-color: #f5f5f5;
    }

    .container {
      max-width: 800px;
      margin: 0 auto;
      background-color: #fff;
      padding: 20px;
      border-radius: 5px;
      box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
    }

    h1 {
      color: #333;
      border-bottom: 1px solid #eee;
      padding-bottom: 10px;
    }

    p {
      margin: 10px 0;
    }

    .success {
      color: #3c763d;
    }

    .error {
      color: #a94442;
    }

    </style>
  </head>
  <body>
    <div class="container">
      <h1>脚本管理系统初始化</h1>
      <!-- PHP脚本输出的内容会显示在这里 -->
    </div>
  </body>
</html>
