<?php
require_once '../../config/database.php';
try {
    $db = getDbConnection();
    // 删除已存在的表（如果需要重新创建）
    $db->exec("DROP TABLE IF EXISTS systems");
    // 创建系统设置表
    $sql = "CREATE TABLE systems (
        id INT AUTO_INCREMENT PRIMARY KEY COMMENT '系统ID',
        parent_id INT DEFAULT 0 COMMENT '父级ID(0为一级分类)',
        name VARCHAR(255) NOT NULL COMMENT '系统名称',
        sort_order INT DEFAULT 0 COMMENT '排序顺序',
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        INDEX idx_parent_id (parent_id),
        INDEX idx_sort_order (sort_order)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='系统设置表'";
    $db->exec($sql);
    // 添加一些测试数据
    $testData = [
        // 一级分类
        ['parent_id' => 0, 'name' => '基础设置', 'sort_order' => 1],
        ['parent_id' => 0, 'name' => '安全设置', 'sort_order' => 2],
        ['parent_id' => 0, 'name' => '性能设置', 'sort_order' => 3],
        // 基础设置的子分类
        ['parent_id' => 1, 'name' => '站点信息', 'sort_order' => 1],
        ['parent_id' => 1, 'name' => '邮件设置', 'sort_order' => 2],
        // 安全设置的子分类
        ['parent_id' => 2, 'name' => '登录设置', 'sort_order' => 1],
        ['parent_id' => 2, 'name' => '权限设置', 'sort_order' => 2],
        // 性能设置的子分类
        ['parent_id' => 3, 'name' => '缓存设置', 'sort_order' => 1],
        ['parent_id' => 3, 'name' => '数据库设置', 'sort_order' => 2]
    ];
    $stmt = $db->prepare("INSERT INTO systems (parent_id, name, sort_order) VALUES (?, ?, ?)");
    foreach ($testData as $data) {
        $stmt->execute([
            $data['parent_id'],
            $data['name'],
            $data['sort_order']
        ]);
    }
    echo "系统设置表创建成功，并已添加测试数据！";
} catch (PDOException $e) {
    die("设置失败: " . $e->getMessage());
} 