<?php
require_once '../config/database.php';
try {
    $db = getDbConnection();
    // 删除已存在的表（如果需要重新创建）
    $db->exec("DROP TABLE IF EXISTS tags");
    // 创建标签表
    $sql = "CREATE TABLE tags (
        id INT AUTO_INCREMENT PRIMARY KEY COMMENT '标签ID',
        parent_id INT DEFAULT 0 COMMENT '父标签ID',
        name VARCHAR(255) NOT NULL COMMENT '标签名称',
        slug VARCHAR(255) NOT NULL COMMENT '标签别名',
        sort_order INT DEFAULT 0 COMMENT '排序顺序',
        status TINYINT(1) DEFAULT 1 COMMENT '状态(1:启用,0:禁用)',
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
        INDEX idx_parent_id (parent_id),
        INDEX idx_sort_order (sort_order)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='标签管理表'";
    $db->exec($sql);
    // 添加一些测试数据
    $testData = [
        // 主标签
        ['parent_id' => 0, 'name' => '站群', 'slug' => 'site-group', 'sort_order' => 1],
        ['parent_id' => 0, 'name' => '服务器', 'slug' => 'server', 'sort_order' => 2],
        // 站群的子标签
        ['parent_id' => 1, 'name' => '1C', 'slug' => '1c', 'sort_order' => 1],
        ['parent_id' => 1, 'name' => '2C', 'slug' => '2c', 'sort_order' => 2],
        ['parent_id' => 1, 'name' => '4C', 'slug' => '4c', 'sort_order' => 3],
        ['parent_id' => 1, 'name' => '8C', 'slug' => '8c', 'sort_order' => 4],
        // 服务器的子标签
        ['parent_id' => 2, 'name' => '虚拟主机', 'slug' => 'virtual-host', 'sort_order' => 1],
        ['parent_id' => 2, 'name' => 'VPS', 'slug' => 'vps', 'sort_order' => 2],
        ['parent_id' => 2, 'name' => '独立服务器', 'slug' => 'dedicated-server', 'sort_order' => 3]
    ];
    $stmt = $db->prepare("INSERT INTO tags (parent_id, name, slug, sort_order) VALUES (?, ?, ?, ?)");
    foreach ($testData as $data) {
        $stmt->execute([
            $data['parent_id'],
            $data['name'],
            $data['slug'],
            $data['sort_order']
        ]);
    }
    echo "标签表创建成功，并已添加测试数据！";
} catch (PDOException $e) {
    die("设置失败: " . $e->getMessage());
} 
