<?php

require_once '../../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 检查tickets表是否已存在
    $tableExistsQuery = "SHOW TABLES LIKE 'tickets'";
    $ticketsTableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    if (!$ticketsTableExists) {
        // 创建tickets表
        $createTicketsTableQuery = "
        CREATE TABLE `tickets` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `user_id` int(11) NOT NULL COMMENT '用户ID',
          `subject` varchar(255) NOT NULL COMMENT '工单主题',
          `priority` enum('low','medium','high') NOT NULL DEFAULT 'medium' COMMENT '优先级',
          `status` enum('open','pending','answered','closed') NOT NULL DEFAULT 'open' COMMENT '状态',
          `conversation_id` varchar(50) DEFAULT NULL COMMENT '会话ID（回复时共用）',
          `last_reply` datetime DEFAULT NULL COMMENT '最后回复时间',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `user_id` (`user_id`),
          KEY `conversation_id` (`conversation_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='工单主表';
        ";
        
        $db->exec($createTicketsTableQuery);
        echo "<p>工单主表(tickets)创建成功！</p>";
    } else {
        // 检查是否需要添加conversation_id字段
        $checkConversationField = "SHOW COLUMNS FROM `tickets` LIKE 'conversation_id'";
        $conversationFieldExists = $db->query($checkConversationField)->rowCount() > 0;
        
        if (!$conversationFieldExists) {
            // 添加conversation_id字段
            $addConversationField = "ALTER TABLE `tickets` ADD COLUMN `conversation_id` varchar(50) DEFAULT NULL COMMENT '会话ID（回复时共用）' AFTER `status`";
            $db->exec($addConversationField);
            echo "<p>已向工单主表添加会话ID字段。</p>";
        } else {
            echo "<p>工单主表(tickets)已存在且包含会话ID字段，跳过创建。</p>";
        }
    }

    // 检查ticket_replies表是否已存在
    $tableExistsQuery = "SHOW TABLES LIKE 'ticket_replies'";
    $repliesTableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    if (!$repliesTableExists) {
        // 创建ticket_replies表
        $createRepliesTableQuery = "
        CREATE TABLE `ticket_replies` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `ticket_id` int(11) NOT NULL COMMENT '关联的工单ID',
          `user_id` int(11) DEFAULT NULL COMMENT '用户ID（客户回复）',
          `admin_id` int(11) DEFAULT NULL COMMENT '管理员ID（管理员回复）',
          `conversation_id` varchar(50) NOT NULL COMMENT '会话ID（与主表关联）',
          `message` text NOT NULL COMMENT '回复内容',
          `attachments` text DEFAULT NULL COMMENT '附件列表（JSON格式）',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          PRIMARY KEY (`id`),
          KEY `ticket_id` (`ticket_id`),
          KEY `conversation_id` (`conversation_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='工单回复表';
        ";
        
        $db->exec($createRepliesTableQuery);
        echo "<p>工单回复表(ticket_replies)创建成功！</p>";
    } else {
        // 检查是否需要添加conversation_id字段
        $checkConversationField = "SHOW COLUMNS FROM `ticket_replies` LIKE 'conversation_id'";
        $conversationFieldExists = $db->query($checkConversationField)->rowCount() > 0;
        
        if (!$conversationFieldExists) {
            // 添加conversation_id字段
            $addConversationField = "ALTER TABLE `ticket_replies` ADD COLUMN `conversation_id` varchar(50) NOT NULL COMMENT '会话ID（与主表关联）' AFTER `admin_id`";
            $db->exec($addConversationField);
            echo "<p>已向工单回复表添加会话ID字段。</p>";
        } else {
            echo "<p>工单回复表(ticket_replies)已存在且包含会话ID字段，跳过创建。</p>";
        }
    }

    // 检查ticket_attachments表是否已存在
    $tableExistsQuery = "SHOW TABLES LIKE 'ticket_attachments'";
    $attachmentsTableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    if (!$attachmentsTableExists) {
        // 创建ticket_attachments表
        $createAttachmentsTableQuery = "
        CREATE TABLE `ticket_attachments` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `ticket_id` int(11) NOT NULL COMMENT '关联的工单ID',
          `reply_id` int(11) DEFAULT NULL COMMENT '关联的回复ID',
          `file_name` varchar(255) NOT NULL COMMENT '文件名',
          `file_path` varchar(255) NOT NULL COMMENT '文件路径',
          `file_type` varchar(100) NOT NULL COMMENT '文件类型',
          `file_size` int(11) NOT NULL COMMENT '文件大小(字节)',
          `created_at` datetime NOT NULL COMMENT '上传时间',
          PRIMARY KEY (`id`),
          KEY `ticket_id` (`ticket_id`),
          KEY `reply_id` (`reply_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='工单附件表';
        ";
        
        $db->exec($createAttachmentsTableQuery);
        echo "<p>工单附件表(ticket_attachments)创建成功！</p>";
    } else {
        echo "<p>工单附件表(ticket_attachments)已存在，跳过创建。</p>";
    }

    // 创建示例工单数据
    $insertSampleTicket = "
    INSERT INTO `tickets` (`user_id`, `subject`, `priority`, `status`, `conversation_id`, `last_reply`, `created_at`, `updated_at`)
    VALUES
    (1, 'USDT充值问题', 'medium', 'open', NULL, NOW(), NOW(), NOW()),
    (2, '账户无法登录', 'high', 'pending', NULL, NOW(), NOW(), NOW()),
    (1, '提现延迟', 'medium', 'answered', NULL, NOW(), NOW(), NOW());
    ";
    
    $db->exec($insertSampleTicket);
    echo "<p>示例工单数据创建成功！</p>";
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "工单系统数据库初始化完成！<br>";
    echo "<a href='../../user/ticket.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 进入工单管理页面。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>工单系统数据库初始化</title>
        <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }

        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        p {
            margin: 10px 0;
        }

        .success {
            color: #3c763d;
        }

        .error {
            color: #a94442;
        }
        </style>
    </head>
    <body>
        <div class="container">
            <h1>工单系统数据库初始化</h1>
            <!-- PHP脚本输出的内容会显示在这里 -->
        </div>
    </body>
</html>
