<?php
/**
 * 视频数据库表创建脚本
 * 用于初始化视频系统所需的数据库表结构和示例数据
 */

// 引入数据库配置文件
require_once '../../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 检查视频分类表是否已存在
    $categoryTableExistsQuery = "SHOW TABLES LIKE 'video_categories'";
    $categoryTableExists = $db->query($categoryTableExistsQuery)->rowCount() > 0;
    
    if (!$categoryTableExists) {
        // 创建视频分类表
        $createCategoryTableQuery = "
        CREATE TABLE `video_categories` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `name` varchar(100) NOT NULL COMMENT '分类名称',
          `description` text DEFAULT NULL COMMENT '分类描述',
          `parent_id` int(11) DEFAULT 0 COMMENT '父分类ID，0表示顶级分类',
          `icon` varchar(255) DEFAULT NULL COMMENT '分类图标',
          `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序顺序',
          `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `parent_id` (`parent_id`),
          KEY `sort_order` (`sort_order`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='视频分类表';
        ";
        
        $db->exec($createCategoryTableQuery);
        echo "<p>视频分类表(video_categories)创建成功！</p>";
        
        // 插入初始分类数据
        $insertCategoryDataQuery = "
        INSERT INTO `video_categories` (`name`, `description`, `parent_id`, `sort_order`, `status`, `created_at`) VALUES
        ('宝塔教程', '宝塔面板相关的教程视频', 0, 1, 1, NOW()),
        ('服务器搭建', '各类服务器环境搭建教程', 0, 2, 1, NOW()),
        ('服务器小白科普', '面向初学者的服务器基础知识和操作指南', 0, 3, 1, NOW());
        ";
        
        $db->exec($insertCategoryDataQuery);
        echo "<p>视频分类初始数据导入成功！</p>";
    } else {
        echo "<p>视频分类表(video_categories)已存在，跳过创建。</p>";
    }
    
    // 检查视频表是否已存在
    $videoTableExistsQuery = "SHOW TABLES LIKE 'videos'";
    $videoTableExists = $db->query($videoTableExistsQuery)->rowCount() > 0;
    
    if (!$videoTableExists) {
        // 创建视频表
        $createVideoTableQuery = "
        CREATE TABLE `videos` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `title` varchar(255) NOT NULL COMMENT '视频标题',
          `description` text DEFAULT NULL COMMENT '视频描述',
          `category_id` int(11) NOT NULL COMMENT '所属分类ID',
          `video_url` varchar(255) DEFAULT NULL COMMENT '视频URL',
          `thumbnail` varchar(255) DEFAULT NULL COMMENT '缩略图URL',
          `duration` varchar(20) DEFAULT NULL COMMENT '视频时长',
          `views` int(11) NOT NULL DEFAULT 0 COMMENT '观看次数',
          `likes` int(11) NOT NULL DEFAULT 0 COMMENT '点赞数',
          `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1已发布，0草稿',
          `featured` tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否推荐：1是，0否',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `category_id` (`category_id`),
          KEY `status` (`status`),
          KEY `featured` (`featured`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='视频表';
        ";
        
        $db->exec($createVideoTableQuery);
        echo "<p>视频表(videos)创建成功！</p>";
        
        // 插入示例视频数据
        $insertVideoDataQuery = "
        INSERT INTO `videos` (`title`, `description`, `category_id`, `thumbnail`, `duration`, `views`, `likes`, `status`, `featured`, `created_at`) VALUES
        ('「精讲宝塔」①：宝塔纯净版免登录免会员可用全部插件', '<p>本视频教程详细讲解了如何安装和配置宝塔纯净版，完全免登录、免会员，并且可以使用全部插件功能。适合新手站长和服务器管理员快速上手使用。</p><p>主要内容包括：</p><ul><li>宝塔纯净版的获取途径</li><li>安装步骤详解</li><li>免登录免会员的配置方法</li><li>常见问题解答</li></ul><p>如有问题，欢迎在下方留言或联系我们的客服。</p>', 1, 'http://temp.im/320x180', '0:42', 1234, 42, 1, 1, '2023-10-15 10:00:00'),
        
        ('「精讲宝塔」②：纯净宝塔安装演示|小白教程', '<p>这是一个专门为小白用户设计的宝塔面板安装教程，演示了如何从零开始安装纯净版宝塔面板。</p><p>主要内容包括：</p><ul><li>服务器环境准备</li><li>安装命令详解</li><li>安装过程中常见问题的解决方法</li><li>安装后的基本设置</li></ul><p>按照本教程操作，即使是第一次接触服务器的用户也能轻松完成安装。</p>', 1, 'http://temp.im/320x180', '1:46', 856, 38, 1, 0, '2023-10-14 09:30:00'),
        
        ('「精讲宝塔」③：宝塔修改帐号和密码', '<p>本视频讲解如何安全地修改宝塔面板的账号和密码，保护您的服务器安全。</p><p>主要内容包括：</p><ul><li>通过面板界面修改密码</li><li>使用命令行重置密码的方法</li><li>修改默认用户名</li><li>设置强密码的建议</li></ul><p>为了服务器安全，请务必修改宝塔面板默认的账号和密码。</p>', 1, 'http://temp.im/320x180', '1:14', 723, 31, 1, 0, '2023-10-12 14:20:00'),
        
        ('「精讲宝塔」④： 一键迁移宝塔服务器数据！快速切换服务器必备教程', '<p>本教程详细讲解如何使用宝塔面板的数据迁移功能，快速将网站和数据迁移到新服务器。</p><p>主要内容包括：</p><ul><li>迁移前的准备工作</li><li>使用一键迁移工具的步骤</li><li>数据迁移过程中的注意事项</li><li>迁移后的检查和配置</li></ul><p>使用此方法可以大大减少服务器迁移的时间和难度，降低出错风险。</p>', 1, 'http://temp.im/320x180', '3:21', 512, 27, 1, 0, '2023-10-10 16:45:00'),
        
        ('「全自动」快速搭建多IP站群SK5/SOCKS5脚本', '<p>本视频教程展示了如何使用自动化脚本快速搭建多IP站群SOCKS5代理服务。</p><p>主要内容包括：</p><ul><li>多IP站群服务器的基本概念</li><li>SOCKS5代理的工作原理</li><li>自动化脚本的获取和配置</li><li>一键部署的详细步骤</li></ul><p>通过本教程，您可以在最短时间内完成多IP站群代理服务器的搭建。</p>', 2, 'https://ke.irqm.com/imeag/0020.png', '2:38', 968, 55, 1, 1, '2023-10-08 11:30:00'),
        
        ('原创:搭建Socks5代理服务器,支持多IP站群服务器一键搭建各类节点socks5搭建脚本！', '<p>本教程介绍如何搭建支持多IP的Socks5代理服务器，适用于站群服务器环境。</p><p>主要内容包括：</p><ul><li>Socks5代理服务器的工作原理</li><li>多IP环境的配置方法</li><li>一键脚本的使用说明</li><li>常见问题排查</li></ul>', 2, 'http://temp.im/320x180', '3:13', 743, 48, 1, 0, '2023-10-07 09:15:00'),
        
        ('多IP站群服务器设置socks5一键设置脚本教程(不同端口版)', '<p>详细讲解如何在多IP站群服务器上设置不同端口的socks5代理，便于管理和使用。</p><p>本教程特别适合需要管理大量IP的用户。</p>', 2, 'http://temp.im/320x180', '2:22', 631, 36, 1, 0, '2023-10-05 13:25:00'),
        
        ('一键搭建多IP站群服务器设置http代理脚本,支持多IP出口', '<p>本视频展示了使用脚本快速搭建支持多IP出口的HTTP代理服务器的方法。</p><p>主要内容涵盖：脚本获取、配置参数说明、验证代理可用性等方面。</p>', 2, 'http://temp.im/320x180', '2:37', 582, 29, 1, 0, '2023-10-03 15:40:00'),
        
        ('何为多IP站群C段?', '<p>本视频介绍多IP站群C段的概念、用途以及如何辨别不同类型的IP。适合新手了解站群服务器的基础知识。</p>', 3, 'http://temp.im/320x180', '0:31', 425, 18, 1, 0, '2023-10-01 10:20:00'),
        
        ('「纯小白教程」FinalShell链接服务器', '<p>这是一个面向完全没有服务器使用经验的用户的教程，详细讲解了如何使用FinalShell软件连接和管理Linux服务器。</p><p>内容包括软件下载、安装、连接参数设置、常用操作等。</p>', 3, 'http://temp.im/320x180', '3:04', 892, 67, 1, 1, '2023-09-28 14:10:00');
        ";
        
        $db->exec($insertVideoDataQuery);
        echo "<p>示例视频数据导入成功！</p>";
    } else {
        echo "<p>视频表(videos)已存在，跳过创建。</p>";
    }
    
    // 检查视频评论表是否已存在
    $commentTableExistsQuery = "SHOW TABLES LIKE 'video_comments'";
    $commentTableExists = $db->query($commentTableExistsQuery)->rowCount() > 0;
    
    if (!$commentTableExists) {
        // 创建视频评论表
        $createCommentTableQuery = "
        CREATE TABLE `video_comments` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `video_id` int(11) NOT NULL COMMENT '视频ID',
          `user_id` int(11) DEFAULT NULL COMMENT '用户ID，NULL表示匿名评论',
          `author_name` varchar(100) DEFAULT NULL COMMENT '作者名称（用于匿名评论）',
          `content` text NOT NULL COMMENT '评论内容',
          `likes` int(11) NOT NULL DEFAULT 0 COMMENT '点赞数',
          `parent_id` int(11) DEFAULT 0 COMMENT '父评论ID，0表示顶级评论',
          `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1已审核，0待审核',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `video_id` (`video_id`),
          KEY `user_id` (`user_id`),
          KEY `parent_id` (`parent_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='视频评论表';
        ";
        
        $db->exec($createCommentTableQuery);
        echo "<p>视频评论表(video_comments)创建成功！</p>";
        
        // 插入示例评论数据
        $insertCommentDataQuery = "
        INSERT INTO `video_comments` (`video_id`, `author_name`, `content`, `likes`, `parent_id`, `status`, `created_at`) VALUES
        (1, '用户123', '视频很实用，讲解得非常清晰，作为小白也能听懂，谢谢分享！', 12, 0, 1, '2023-10-16 09:15:00'),
        (1, '站长007', '按照教程操作成功了，之前一直被宝塔的会员限制困扰，这个方法太棒了！', 8, 0, 1, '2023-10-15 14:30:00'),
        (1, '服务器新手', '请问这个方法在最新版的宝塔面板上还有效吗？', 3, 0, 1, '2023-10-14 16:45:00'),
        (1, '技术小哥', '还是有效的，我昨天刚试过。不过要注意一下安装时的系统要求。', 5, 3, 1, '2023-10-14 18:20:00'),
        (2, '学习中', '非常感谢这个教程，让我第一次成功安装了宝塔面板！', 7, 0, 1, '2023-10-15 10:25:00'),
        (5, '网站管理员', '这个脚本真的节省了我很多时间，强烈推荐给需要管理多IP的朋友们！', 15, 0, 1, '2023-10-12 11:30:00'),
        (5, 'SEO优化师', '用这个搭建了10台服务器，效果非常好，感谢分享！', 9, 0, 1, '2023-10-10 15:45:00'),
        (10, '完全小白', '太感谢了，这个教程对我这种新手非常友好，终于能自己管理服务器了！', 21, 0, 1, '2023-10-05 16:40:00');
        ";
        
        $db->exec($insertCommentDataQuery);
        echo "<p>示例评论数据导入成功！</p>";
    } else {
        echo "<p>视频评论表(video_comments)已存在，跳过创建。</p>";
    }
    
    // 创建视频标签关联表（如果需要的话）
    $tagRelationTableExistsQuery = "SHOW TABLES LIKE 'video_tag_relations'";
    $tagRelationTableExists = $db->query($tagRelationTableExistsQuery)->rowCount() > 0;
    
    if (!$tagRelationTableExists) {
        // 创建视频标签关联表
        $createTagRelationTableQuery = "
        CREATE TABLE `video_tag_relations` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `video_id` int(11) NOT NULL COMMENT '视频ID',
          `tag_id` int(11) NOT NULL COMMENT '标签ID',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          PRIMARY KEY (`id`),
          UNIQUE KEY `video_tag_unique` (`video_id`, `tag_id`),
          KEY `video_id` (`video_id`),
          KEY `tag_id` (`tag_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='视频标签关联表';
        ";
        
        $db->exec($createTagRelationTableQuery);
        echo "<p>视频标签关联表(video_tag_relations)创建成功！</p>";
    } else {
        echo "<p>视频标签关联表(video_tag_relations)已存在，跳过创建。</p>";
    }
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "视频系统数据库初始化完成！<br>";
    echo "<a href='/cn/video.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 查看视频列表页面。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>视频系统数据库初始化</title>
        <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }

        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        p {
            margin: 10px 0;
        }

        .success {
            color: #3c763d;
        }

        .error {
            color: #a94442;
        }

        </style>
    </head>
    <body>
        <div class="container">
            <h1>视频系统数据库初始化</h1>
            <!-- PHP脚本输出的内容会显示在这里 -->
        </div>
    </body>
</html>
