<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>供应商管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/supplier.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>

      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-supplier-btn">+ 添加供应商</button>
        </div>
        <div class="filter">
          <input type="text" id="search-input" placeholder="搜索供应商名称" class="search-input">
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>

      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>供应商ID</th>
              <th>供应商名称</th>
              <th>账号</th>
              <th>密码</th>
              <th>网站</th>
              <th>状态</th>
              <th>创建时间</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php
            require_once '../config/database.php';
            $db = getDbConnection();
            $query = "SELECT * FROM suppliers ORDER BY id DESC";
            $stmt = $db->query($query);
            $suppliers = $stmt->fetchAll();
            foreach ($suppliers as $supplier) {
              $statusBadge = $supplier['status'] ? 'status-active' : 'status-inactive';
              $statusText = $supplier['status'] ? 'status-text-active' : 'status-text-inactive';
              echo "<tr data-id=\"{$supplier['id']}\">";
              echo "<td>{$supplier['id']}</td>";
              echo "<td>{$supplier['name']}</td>";
              echo "<td>{$supplier['account']}</td>";
              echo "<td>{$supplier['password']}</td>";
              echo "<td>";
              if (!empty($supplier['website'])) {
                echo "<a href=\"{$supplier['website']}\" target=\"_blank\">{$supplier['website']}</a>";
              }
              echo "</td>";
              echo "<td class=\"{$statusText}\">" . ($supplier['status'] ? '启用' : '禁用') . "</td>";
              echo "<td>{$supplier['created_at']}</td>";
              echo "<td class=\"action-buttons\">";
              echo "<button class=\"btn btn-edit\" data-id=\"{$supplier['id']}\">修改</button>";
              echo "<button class=\"btn btn-delete\" data-id=\"{$supplier['id']}\" data-name=\"{$supplier['name']}\">删除</button>";
              echo "</td>";
              echo "</tr>";
            }
            ?>
          </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除供应商 "<span id="delete-supplier-name"></span>" 吗？</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 状态文本样式
      document.querySelectorAll('tbody tr').forEach(row => {
        const statusCell = row.querySelector('td:nth-child(6)');
        if (statusCell) {
          if (statusCell.textContent.trim() === '启用') {
            statusCell.classList.add('status-text-active');
          } else if (statusCell.textContent.trim() === '禁用') {
            statusCell.classList.add('status-text-inactive');
          }
        }
      });
      // 表格行悬停效果
      document.querySelectorAll('tbody tr').forEach(row => {
        row.addEventListener('mouseenter', function() {
          this.style.transform = 'translateY(-2px)';
          this.style.boxShadow = '0 4px 10px rgba(0, 0, 0, 0.05)';
          this.style.zIndex = '1';
        });
        row.addEventListener('mouseleave', function() {
          this.style.transform = '';
          this.style.boxShadow = '';
          this.style.zIndex = '';
        });
      });
      // 添加供应商按钮点击事件
      document.getElementById('add-supplier-btn').addEventListener('click', function() {
        window.location.href = 'supplier_add.php';
      });
      // 搜索功能
      document.getElementById('search-btn').addEventListener('click', performSearch);
      document.getElementById('search-input').addEventListener('keypress', function(e) {
        if (e.key === 'Enter') {
          performSearch();
        }
      });

      function performSearch() {
        const searchText = document.getElementById('search-input').value.toLowerCase();
        let hasResults = false;
        document.querySelectorAll('tbody tr').forEach(row => {
          const supplierName = row.querySelector('td:nth-child(2)').textContent.toLowerCase();
          const supplierAccount = row.querySelector('td:nth-child(3)').textContent.toLowerCase();
          if (supplierName.includes(searchText) || supplierAccount.includes(searchText)) {
            row.style.display = '';
            row.classList.add('highlight-row');
            setTimeout(() => {
              row.classList.remove('highlight-row');
            }, 1500);
            hasResults = true;
          } else {
            row.style.display = 'none';
          }
        });
        // 搜索无结果提示
        const noResultsElem = document.getElementById('no-results-message');
        if (!hasResults && searchText.length > 0) {
          if (!noResultsElem) {
            const message = document.createElement('div');
            message.id = 'no-results-message';
            message.className = 'no-results';
            message.textContent = `没有找到与 "${searchText}" 相关的供应商`;
            document.querySelector('.table-container').before(message);
          } else {
            noResultsElem.textContent = `没有找到与 "${searchText}" 相关的供应商`;
            noResultsElem.style.display = 'block';
          }
        } else if (noResultsElem) {
          noResultsElem.style.display = 'none';
        }
      }
      // 删除功能
      const modal = document.getElementById('delete-modal');
      const deleteSupplierName = document.getElementById('delete-supplier-name');
      let deleteSupplierId = null;
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteSupplierId = this.dataset.id;
          deleteSupplierName.textContent = this.dataset.name;
          modal.style.display = 'flex';
          // 添加动画效果
          setTimeout(() => {
            const modalContent = document.querySelector('.modal-content');
            if (modalContent) {
              modalContent.classList.add('modal-show');
            }
          }, 10);
        });
      });
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteSupplierId) {
          // 添加删除按钮加载状态
          this.innerHTML = '<span class="loading-spinner"></span> 删除中...';
          this.disabled = true;
          fetch('supplier_delete.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
              },
              body: 'id=' + deleteSupplierId
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                const row = document.querySelector(`tr[data-id="${deleteSupplierId}"]`);
                if (row) {
                  row.style.background = 'rgba(239, 68, 68, 0.1)';
                  row.style.opacity = '0.5';
                  setTimeout(() => {
                    row.style.height = '0';
                    row.style.padding = '0';
                    row.style.overflow = 'hidden';
                    setTimeout(() => {
                      row.remove();
                    }, 300);
                  }, 300);
                }
                const successMessage = document.getElementById('success-message');
                successMessage.textContent = data.message;
                successMessage.style.display = 'block';
                setTimeout(() => {
                  successMessage.style.opacity = '0';
                  setTimeout(() => {
                    successMessage.style.display = 'none';
                    successMessage.style.opacity = '1';
                  }, 300);
                }, 3000);
              } else {
                alert(data.message);
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('删除失败，请重试');
            })
            .finally(() => {
              modal.style.display = 'none';
              deleteSupplierId = null;
              // 恢复按钮状态
              document.getElementById('confirm-delete').innerHTML = '确认删除';
              document.getElementById('confirm-delete').disabled = false;
            });
        }
      });
      document.getElementById('cancel-delete').addEventListener('click', function() {
        const modalContent = document.querySelector('.modal-content');
        if (modalContent) {
          modalContent.classList.remove('modal-show');
        }
        setTimeout(() => {
          modal.style.display = 'none';
          deleteSupplierId = null;
        }, 200);
      });
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          const modalContent = document.querySelector('.modal-content');
          if (modalContent) {
            modalContent.classList.remove('modal-show');
          }
          setTimeout(() => {
            modal.style.display = 'none';
            deleteSupplierId = null;
          }, 200);
        }
      });
      // 编辑按钮点击事件
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          // 添加点击效果
          this.classList.add('btn-clicked');
          const supplierId = this.dataset.id;
          setTimeout(() => {
            window.location.href = `supplier_edit.php?id=${supplierId}`;
          }, 200);
        });
      });
    });
    </script>

    <style>
    /* 内联样式，用于动态效果 */
    .highlight-row {
      animation: highlight 1.5s ease;
    }

    @keyframes highlight {
      0% {
        background-color: rgba(59, 130, 246, 0.1);
      }

      100% {
        background-color: transparent;
      }
    }

    .btn-clicked {
      transform: scale(0.95);
    }

    .modal-show {
      transform: scale(1) translateY(0) !important;
      opacity: 1 !important;
    }

    .no-results {
      padding: 15px;
      background-color: #fff7ed;
      color: #c2410c;
      border-left: 4px solid #f97316;
      margin-bottom: 20px;
      border-radius: 6px;
      box-shadow: 0 2px 5px rgba(249, 115, 22, 0.1);
      animation: slideIn 0.3s ease;
    }

    @keyframes slideIn {
      from {
        transform: translateY(-10px);
        opacity: 0;
      }

      to {
        transform: translateY(0);
        opacity: 1;
      }
    }

    .loading-spinner {
      display: inline-block;
      width: 12px;
      height: 12px;
      border: 2px solid rgba(255, 255, 255, 0.3);
      border-radius: 50%;
      border-top-color: white;
      animation: spin 0.8s linear infinite;
      margin-right: 6px;
    }

    @keyframes spin {
      to {
        transform: rotate(360deg);
      }
    }

    </style>
  </body>
</html>
