<?php
require_once '../config/database.php';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取表单数据
    $id = isset($_POST['id']) ? (int)$_POST['id'] : 0;
    $name = trim($_POST['name'] ?? '');
    $website = trim($_POST['website'] ?? '');
    $status = isset($_POST['status']) ? (int)$_POST['status'] : 1;
    $account = trim($_POST['account'] ?? '');
    $password = trim($_POST['password'] ?? '');
    // 验证数据
    $errors = [];
    if ($id <= 0) {
        $errors[] = '无效的供应商ID';
    }
    if (empty($name)) {
        $errors[] = '供应商名称不能为空';
    }
    if (empty($account)) {
        $errors[] = '登录账号不能为空';
    }
    // 如果没有错误，则更新数据
    if (empty($errors)) {
        try {
            $db = getDbConnection();
            // 如果提供了新密码，则更新密码
            if (!empty($password)) {
                $sql = "UPDATE suppliers SET name = :name, website = :website, status = :status, account = :account, password = :password WHERE id = :id";
            } else {
                $sql = "UPDATE suppliers SET name = :name, website = :website, status = :status, account = :account WHERE id = :id";
            }
            $stmt = $db->prepare($sql);
            $stmt->bindParam(':id', $id);
            $stmt->bindParam(':name', $name);
            $stmt->bindParam(':website', $website);
            $stmt->bindParam(':status', $status);
            $stmt->bindParam(':account', $account);
            if (!empty($password)) {
                $stmt->bindParam(':password', $password);
            }
            if ($stmt->execute()) {
                // 重定向到供应商列表页面，并显示成功消息
                header('Location: supplier.php?success=1&message=' . urlencode('供应商更新成功'));
                exit;
            } else {
                $errors[] = '保存失败，请重试';
            }
        } catch (PDOException $e) {
            $errors[] = '数据库错误: ' . $e->getMessage();
        }
    }
    // 如果有错误，重定向回表单页面并显示错误
    if (!empty($errors)) {
        $errorString = implode(',', $errors);
        header('Location: supplier_edit.php?id=' . $id . '&error=1&message=' . urlencode($errorString));
        exit;
    }
} else {
    // 如果不是POST请求，重定向到供应商列表页面
    header('Location: supplier.php');
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
  <!-- 头部内容 -->
</head>
<body>
  <?php include 'public/header.php'; ?>
  <!-- 其他内容 -->
</body>
</html> 