<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>系统管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/tag.css">
  </head>
  <body> <?php include 'public/header.php'; ?> <div class="sidebar"> <?php include 'public/letf.php'; ?> </div>
    <div class="main-content">
      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>
      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-system-btn">+ 添加系统</button>
          <button class="btn btn-secondary" id="save-all-btn">保存所有修改</button>
        </div>
        <div class="filter">
          <select class="select-filter" id="parent-filter">
            <option value="0">父级系统</option>
            <option value="-1">不限</option> <?php
            require_once '../config/database.php';
            $db = getDbConnection();
            // 获取所有父级系统
            $parentQuery = "SELECT id, name FROM systems WHERE parent_id = 0 ORDER BY sort_order ASC";
            $parentStmt = $db->query($parentQuery);
            $parents = $parentStmt->fetchAll();
            foreach ($parents as $parent) {
              echo "<option value=\"{$parent['id']}\">{$parent['name']}</option>";
            }
            ?>
          </select>
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>
      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>系统ID</th>
              <th>系统名称</th>
              <th class="sortable">排序 <span class="sort-indicator"></span></th>
              <th>创建时间</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody> <?php
            // 获取所有系统数据，按排序值排序父系统，然后是子系统
            $query = "SELECT t1.*, t2.name as parent_name, t2.sort_order as parent_sort_order
                     FROM systems t1 
                     LEFT JOIN systems t2 ON t1.parent_id = t2.id 
                     ORDER BY 
                        CASE WHEN t1.parent_id = 0 THEN t1.sort_order ELSE t2.sort_order END ASC,
                        t1.parent_id ASC, 
                        t1.sort_order ASC";
            $stmt = $db->query($query);
            $systems = $stmt->fetchAll();
            
            // 组织父子关系
            $systemTree = [];
            foreach ($systems as $system) {
              if ($system['parent_id'] == 0) {
                $systemTree[$system['id']] = $system;
                $systemTree[$system['id']]['children'] = [];
              }
            }
            foreach ($systems as $system) {
              if ($system['parent_id'] != 0 && isset($systemTree[$system['parent_id']])) {
                $systemTree[$system['parent_id']]['children'][] = $system;
              }
            }
            
            // 输出父级系统和子系统
            foreach ($systemTree as $parentId => $parent) {
              echo "<tr class='parent-system' data-id=\"{$parent['id']}\">";
              echo "<td>{$parent['id']}</td>";
              echo "<td><span class=\"toggle-icon\">" . (count($parent['children']) > 0 ? "-" : "") . "</span> • <span class=\"editable-text\" data-id=\"{$parent['id']}\" data-field=\"name\">{$parent['name']}</span></td>";
              echo "<td><input type='number' class='sort-input' data-id=\"{$parent['id']}\" value=\"{$parent['sort_order']}\" min='0'></td>";
              echo "<td>" . date('Y-m-d H:i:s', strtotime($parent['created_at'])) . "</td>";
              echo "<td class=\"action-buttons\">";
              echo "<button class='btn btn-edit' data-id='{$parent['id']}'>修改</button>";
              echo "<button class='btn btn-delete' data-id='{$parent['id']}' data-name='{$parent['name']}'>删除</button>";
              echo "</td>";
              echo "</tr>";
              
              // 输出子系统
              foreach ($parent['children'] as $child) {
                echo "<tr class='child-system' data-id=\"{$child['id']}\" data-parent=\"{$parent['id']}\">";
                echo "<td>{$child['id']}</td>";
                echo "<td><span class=\"indent\"><span class=\"editable-text\" data-id=\"{$child['id']}\" data-field=\"name\">{$child['name']}</span></span></td>";
                echo "<td><input type='number' class='sort-input' data-id=\"{$child['id']}\" value=\"{$child['sort_order']}\" min='0'></td>";
                echo "<td>" . date('Y-m-d H:i:s', strtotime($child['created_at'])) . "</td>";
                echo "<td class=\"action-buttons\">";
                echo "<button class='btn btn-edit' data-id='{$child['id']}'>修改</button>";
                echo "<button class='btn btn-delete' data-id='{$child['id']}' data-name='{$child['name']}'>删除</button>";
                echo "</td>";
                echo "</tr>";
              }
            }
            ?> </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除系统 "<span id="delete-system-name"></span>" 吗？</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 展开/折叠功能
      const toggleIcons = document.querySelectorAll('.toggle-icon');
      toggleIcons.forEach(icon => {
        icon.addEventListener('click', function() {
          const parentRow = this.closest('tr');
          const parentId = parentRow.dataset.id;
          const isExpanded = this.textContent === '-';
          this.textContent = isExpanded ? '+' : '-';
          const childRows = document.querySelectorAll(`tr[data-parent="${parentId}"]`);
          childRows.forEach(row => {
            row.style.display = isExpanded ? 'none' : '';
          });
        });
      });
      // 添加系统按钮
      document.getElementById('add-system-btn').addEventListener('click', function() {
        window.location.href = 'system_add.php';
      });
      // 父级系统筛选
      document.getElementById('search-btn').addEventListener('click', function() {
        const parentId = document.getElementById('parent-filter').value;
        if (parentId === '0') return;
        if (parentId === '-1') {
          document.querySelectorAll('tbody tr').forEach(row => {
            row.style.display = '';
          });
        } else {
          document.querySelectorAll('tbody tr').forEach(row => {
            if (row.dataset.id === parentId || row.dataset.parent === parentId) {
              row.style.display = '';
            } else {
              row.style.display = 'none';
            }
          });
        }
      });
      // 删除功能
      const modal = document.getElementById('delete-modal');
      const deleteSystemName = document.getElementById('delete-system-name');
      let deleteSystemId = null;
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteSystemId = this.dataset.id;
          deleteSystemName.textContent = this.dataset.name;
          modal.style.display = 'block';
        });
      });
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteSystemId) {
          window.location.href = `system_delete.php?id=${deleteSystemId}`;
        }
      });
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteSystemId = null;
      });
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteSystemId = null;
        }
      });
      // 编辑按钮
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const systemId = this.dataset.id;
          window.location.href = `system_edit.php?id=${systemId}`;
        });
      });
      // 可编辑文本功能
      document.querySelectorAll('.editable-text').forEach(element => {
        element.addEventListener('click', function() {
          const id = this.dataset.id;
          const field = this.dataset.field;
          const currentValue = this.textContent;
          const input = document.createElement('input');
          input.type = 'text';
          input.value = currentValue;
          input.className = 'inline-edit';
          this.textContent = '';
          this.appendChild(input);
          input.focus();
          input.addEventListener('blur', function() {
            const newValue = this.value.trim();
            if (newValue && newValue !== currentValue) {
              updateSystemField(id, field, newValue);
            }
            element.textContent = newValue || currentValue;
          });
          input.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
              this.blur();
            }
          });
        });
      });
      // 更新系统字段的函数
      function updateSystemField(id, field, value) {
        fetch('system_update_field.php', {
          method: 'POST',
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
          },
          body: `id=${id}&field=${field}&value=${encodeURIComponent(value)}`
        }).then(response => response.json()).then(data => {
          if (data.success) {
            const successMessage = document.getElementById('success-message');
            successMessage.textContent = '更新成功';
            successMessage.style.display = 'block';
            setTimeout(() => {
              successMessage.style.display = 'none';
            }, 3000);
          } else {
            alert('更新失败: ' + data.message);
          }
        }).catch(error => {
          console.error('Error:', error);
          alert('更新请求失败');
        });
      }
      // 添加排序功能
      document.querySelectorAll('th').forEach((header, index) => {
        if (index === 2) { // 排序列
          header.style.cursor = 'pointer';
          header.addEventListener('click', function() {
            sortTable(index, this);
          });
        }
      });
      // 表格排序函数
      function sortTable(columnIndex, headerElement) {
        const table = document.querySelector('table');
        const tbody = table.querySelector('tbody');
        const rows = Array.from(tbody.querySelectorAll('tr'));
        const currentDirection = headerElement.getAttribute('data-sort') === 'asc' ? 'desc' : 'asc';
        headerElement.setAttribute('data-sort', currentDirection);
        const indicator = headerElement.querySelector('.sort-indicator');
        if (indicator) {
          indicator.textContent = currentDirection === 'asc' ? '↑' : '↓';
        }
        const parentRows = rows.filter(row => row.classList.contains('parent-system'));
        const childRowsMap = {};
        rows.forEach(row => {
          if (row.classList.contains('child-system')) {
            const parentId = row.dataset.parent;
            if (!childRowsMap[parentId]) {
              childRowsMap[parentId] = [];
            }
            childRowsMap[parentId].push(row);
          }
        });
        parentRows.sort((a, b) => {
          const aValue = a.querySelectorAll('td')[columnIndex].textContent.trim();
          const bValue = b.querySelectorAll('td')[columnIndex].textContent.trim();
          if (!isNaN(aValue) && !isNaN(bValue)) {
            return currentDirection === 'asc' ? parseInt(aValue) - parseInt(bValue) : parseInt(bValue) - parseInt(aValue);
          }
          return currentDirection === 'asc' ? aValue.localeCompare(bValue) : bValue.localeCompare(aValue);
        });
        while (tbody.firstChild) {
          tbody.removeChild(tbody.firstChild);
        }
        parentRows.forEach(parentRow => {
          tbody.appendChild(parentRow);
          const parentId = parentRow.dataset.id;
          if (childRowsMap[parentId]) {
            if (columnIndex === 2) {
              childRowsMap[parentId].sort((a, b) => {
                const aValue = parseInt(a.querySelectorAll('td')[columnIndex].textContent.trim());
                const bValue = parseInt(b.querySelectorAll('td')[columnIndex].textContent.trim());
                return currentDirection === 'asc' ? aValue - bValue : bValue - aValue;
              });
            }
            childRowsMap[parentId].forEach(childRow => {
              const toggleIcon = parentRow.querySelector('.toggle-icon');
              if (toggleIcon && toggleIcon.textContent === '+') {
                childRow.style.display = 'none';
              } else {
                childRow.style.display = '';
              }
              tbody.appendChild(childRow);
            });
          }
        });
      }
      // 保存所有修改按钮点击事件
      document.getElementById('save-all-btn').addEventListener('click', function() {
        const sortInputs = document.querySelectorAll('.sort-input');
        const updates = [];
        sortInputs.forEach(input => {
          updates.push({
            id: input.dataset.id,
            sort_order: input.value
          });
        });
        if (updates.length > 0) {
          fetch('system_update_sort.php', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({
              updates: updates
            })
          }).then(response => response.json()).then(data => {
            if (data.success) {
              alert(data.message || '排序更新成功！');
            } else {
              alert(data.message || '更新失败，请重试');
            }
          }).catch(error => {
            console.error('Error:', error);
            alert('更新失败，请重试');
          });
        }
      });
    });
    </script>
  </body>
</html>
