<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>标签管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/tag.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>

      <!-- 功能区域 -->
      <div class="function-area">
        <div class="button-group">
          <button class="btn btn-primary" id="add-tag-btn">+ 添加标签</button>
          <button class="btn btn-secondary" id="save-all-btn">保存所有修改</button>
        </div>
        <div class="filter">
          <select class="select-filter" id="parent-filter">
            <option value="0">父级标签</option>
            <option value="-1">不限</option>
            <?php
            require_once '../config/database.php';
            $db = getDbConnection();
            // 获取所有父级标签
            $parentQuery = "SELECT id, name FROM tags WHERE parent_id = 0 ORDER BY sort_order ASC";
            $parentStmt = $db->query($parentQuery);
            $parents = $parentStmt->fetchAll();
            foreach ($parents as $parent) {
              echo "<option value=\"{$parent['id']}\">{$parent['name']}</option>";
            }
            ?>
          </select>
          <button class="btn btn-search" id="search-btn">查询</button>
        </div>
      </div>

      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>标签ID</th>
              <th>标签名称</th>
              <th>静态页面名称</th>
              <th class="sortable">排序 <span class="sort-indicator"></span></th>
              <th>状态</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php
            // 获取所有标签数据，按排序值排序父标签，然后是子标签
            $query = "SELECT t1.*, t2.name as parent_name, t2.sort_order as parent_sort_order
                     FROM tags t1 
                     LEFT JOIN tags t2 ON t1.parent_id = t2.id 
                     ORDER BY 
                        CASE WHEN t1.parent_id = 0 THEN t1.sort_order ELSE t2.sort_order END ASC,
                        t1.parent_id ASC, 
                        t1.sort_order ASC";
            $stmt = $db->query($query);
            $tags = $stmt->fetchAll();
            // 然后用原来的代码组织父子关系
            $tagTree = [];
            foreach ($tags as $tag) {
              if ($tag['parent_id'] == 0) {
                $tagTree[$tag['id']] = $tag;
                $tagTree[$tag['id']]['children'] = [];
              }
            }
            foreach ($tags as $tag) {
              if ($tag['parent_id'] != 0 && isset($tagTree[$tag['parent_id']])) {
                $tagTree[$tag['parent_id']]['children'][] = $tag;
              }
            }
            // 输出父级标签和子标签
            foreach ($tagTree as $parentId => $parent) {
              echo "<tr class='parent-tag' data-id=\"{$parent['id']}\">";
              echo "<td>{$parent['id']}</td>";
              echo "<td><span class=\"toggle-icon\">" . (count($parent['children']) > 0 ? "-" : "") . "</span> • <span class=\"editable-text\" data-id=\"{$parent['id']}\" data-field=\"name\">{$parent['name']}</span></td>";
              echo "<td><span class=\"editable-text\" data-id=\"{$parent['id']}\" data-field=\"slug\">{$parent['slug']}</span></td>";
              echo "<td><input type='number' class='sort-input' data-id=\"{$parent['id']}\" value=\"{$parent['sort_order']}\" min='0'></td>";
              echo "<td>" . ($parent['status'] ? '启用' : '禁用') . "</td>";
              echo "<td class=\"action-buttons\">";
              echo "<button class='btn btn-view'>预览</button>";
              echo "<button class='btn btn-edit' data-id='{$parent['id']}'>修改</button>";
              echo "<button class='btn btn-delete' data-id='{$parent['id']}' data-name='{$parent['name']}'>删除</button>";
              echo "</td>";
              echo "</tr>";
              // 输出子标签
              foreach ($parent['children'] as $child) {
                echo "<tr class='child-tag' data-id=\"{$child['id']}\" data-parent=\"{$parent['id']}\">";
                echo "<td>{$child['id']}</td>";
                echo "<td><span class=\"indent\"><span class=\"editable-text\" data-id=\"{$child['id']}\" data-field=\"name\">{$child['name']}</span></span></td>";
                echo "<td><span class=\"editable-text\" data-id=\"{$child['id']}\" data-field=\"slug\">{$child['slug']}</span></td>";
                echo "<td><input type='number' class='sort-input' data-id=\"{$child['id']}\" value=\"{$child['sort_order']}\" min='0'></td>";
                echo "<td>" . ($child['status'] ? '启用' : '禁用') . "</td>";
                echo "<td class=\"action-buttons\">";
                echo "<button class='btn btn-view'>预览</button>";
                echo "<button class='btn btn-edit' data-id='{$child['id']}'>修改</button>";
                echo "<button class='btn btn-delete' data-id='{$child['id']}' data-name='{$child['name']}'>删除</button>";
                echo "</td>";
                echo "</tr>";
              }
            }
            ?>
          </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除标签 "<span id="delete-tag-name"></span>" 吗？</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 展开/折叠功能
      const toggleIcons = document.querySelectorAll('.toggle-icon');
      toggleIcons.forEach(icon => {
        icon.addEventListener('click', function() {
          const parentRow = this.closest('tr');
          const parentId = parentRow.dataset.id;
          const isExpanded = this.textContent === '-';
          this.textContent = isExpanded ? '+' : '-';
          const childRows = document.querySelectorAll(`tr[data-parent="${parentId}"]`);
          childRows.forEach(row => {
            row.style.display = isExpanded ? 'none' : '';
          });
        });
      });
      // 添加标签按钮
      document.getElementById('add-tag-btn').addEventListener('click', function() {
        window.location.href = 'tag_add.php';
      });
      // 父级标签筛选
      document.getElementById('search-btn').addEventListener('click', function() {
        const parentId = document.getElementById('parent-filter').value;
        if (parentId === '0') return;
        if (parentId === '-1') {
          document.querySelectorAll('tbody tr').forEach(row => {
            row.style.display = '';
          });
        } else {
          document.querySelectorAll('tbody tr').forEach(row => {
            if (row.dataset.id === parentId || row.dataset.parent === parentId) {
              row.style.display = '';
            } else {
              row.style.display = 'none';
            }
          });
        }
      });
      // 删除功能
      const modal = document.getElementById('delete-modal');
      const deleteTagName = document.getElementById('delete-tag-name');
      let deleteTagId = null;
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteTagId = this.dataset.id;
          deleteTagName.textContent = this.dataset.name;
          modal.style.display = 'block';
        });
      });
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteTagId) {
          window.location.href = `tag_delete.php?id=${deleteTagId}`;
        }
      });
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteTagId = null;
      });
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteTagId = null;
        }
      });
      // 编辑按钮
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const tagId = this.dataset.id;
          window.location.href = `tag_edit.php?id=${tagId}`;
        });
      });
      // 可编辑文本功能
      document.querySelectorAll('.editable-text').forEach(element => {
        element.addEventListener('click', function() {
          const id = this.dataset.id;
          const field = this.dataset.field;
          const currentValue = this.textContent;
          // 创建输入框
          const input = document.createElement('input');
          input.type = 'text';
          input.value = currentValue;
          input.className = 'inline-edit';
          // 替换文本为输入框
          this.textContent = '';
          this.appendChild(input);
          input.focus();
          // 处理输入完成
          input.addEventListener('blur', function() {
            const newValue = this.value.trim();
            if (newValue && newValue !== currentValue) {
              // 发送AJAX请求更新数据
              updateTagField(id, field, newValue);
            }
            element.textContent = newValue || currentValue;
          });
          // 处理回车键
          input.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
              this.blur();
            }
          });
        });
      });
      // 更新标签字段的函数
      function updateTagField(id, field, value) {
        fetch('tag_update_field.php', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: `id=${id}&field=${field}&value=${encodeURIComponent(value)}`
          })
          .then(response => response.json())
          .then(data => {
            if (data.success) {
              // 显示成功消息
              const successMessage = document.getElementById('success-message');
              successMessage.textContent = '更新成功';
              successMessage.style.display = 'block';
              setTimeout(() => {
                successMessage.style.display = 'none';
              }, 3000);
            } else {
              alert('更新失败: ' + data.message);
            }
          })
          .catch(error => {
            console.error('Error:', error);
            alert('更新请求失败');
          });
      }
      // 添加排序功能
      document.querySelectorAll('th').forEach((header, index) => {
        if (index === 3) { // 排序列
          header.style.cursor = 'pointer';
          header.addEventListener('click', function() {
            sortTable(index, this);
          });
        }
      });
      // 表格排序函数
      function sortTable(columnIndex, headerElement) {
        const table = document.querySelector('table');
        const tbody = table.querySelector('tbody');
        const rows = Array.from(tbody.querySelectorAll('tr'));
        // 获取当前排序方向
        const currentDirection = headerElement.getAttribute('data-sort') === 'asc' ? 'desc' : 'asc';
        headerElement.setAttribute('data-sort', currentDirection);
        // 更新排序指示器
        const indicator = headerElement.querySelector('.sort-indicator');
        if (indicator) {
          indicator.textContent = currentDirection === 'asc' ? '↑' : '↓';
        }
        // 分离父标签和子标签
        const parentRows = rows.filter(row => row.classList.contains('parent-tag'));
        const childRowsMap = {};
        // 为每个父标签收集其子标签
        rows.forEach(row => {
          if (row.classList.contains('child-tag')) {
            const parentId = row.dataset.parent;
            if (!childRowsMap[parentId]) {
              childRowsMap[parentId] = [];
            }
            childRowsMap[parentId].push(row);
          }
        });
        // 按照指定列排序父标签
        parentRows.sort((a, b) => {
          const aValue = a.querySelectorAll('td')[columnIndex].textContent.trim();
          const bValue = b.querySelectorAll('td')[columnIndex].textContent.trim();
          // 如果是数字列，进行数字比较
          if (!isNaN(aValue) && !isNaN(bValue)) {
            return currentDirection === 'asc' ?
              parseInt(aValue) - parseInt(bValue) :
              parseInt(bValue) - parseInt(aValue);
          }
          // 否则进行字符串比较
          return currentDirection === 'asc' ?
            aValue.localeCompare(bValue) :
            bValue.localeCompare(aValue);
        });
        // 清空表格
        while (tbody.firstChild) {
          tbody.removeChild(tbody.firstChild);
        }
        // 重新添加父标签和其对应的子标签
        parentRows.forEach(parentRow => {
          tbody.appendChild(parentRow);
          const parentId = parentRow.dataset.id;
          if (childRowsMap[parentId]) {
            // 可以选择是否对子标签进行排序
            if (columnIndex === 3) { // 如果是按排序列排序
              childRowsMap[parentId].sort((a, b) => {
                const aValue = parseInt(a.querySelectorAll('td')[columnIndex].textContent.trim());
                const bValue = parseInt(b.querySelectorAll('td')[columnIndex].textContent.trim());
                return currentDirection === 'asc' ? aValue - bValue : bValue - aValue;
              });
            }
            // 添加子标签
            childRowsMap[parentId].forEach(childRow => {
              // 检查父标签是否展开
              const toggleIcon = parentRow.querySelector('.toggle-icon');
              if (toggleIcon && toggleIcon.textContent === '+') {
                childRow.style.display = 'none';
              } else {
                childRow.style.display = '';
              }
              tbody.appendChild(childRow);
            });
          }
        });
      }
      // 添加保存所有修改按钮点击事件
      document.getElementById('save-all-btn').addEventListener('click', function() {
        const sortInputs = document.querySelectorAll('.sort-input');
        const updates = [];
        sortInputs.forEach(input => {
          updates.push({
            id: input.dataset.id,
            sort_order: input.value
          });
        });
        if (updates.length > 0) {
          // 发送批量更新请求
          fetch('tag_update_sort.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json',
              },
              body: JSON.stringify({
                updates: updates
              })
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                // 使用弹出对话框显示成功消息
                alert(data.message || '排序更新成功！');
              } else {
                alert(data.message || '更新失败，请重试');
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('更新失败，请重试');
            });
        }
      });
    });
    </script>
  </body>
</html>
