<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>添加标签</title>
    <link rel="stylesheet" href="public/css/style.css">
    <style>
    .form-container {
      background-color: #fff;
      border-radius: 8px;
      box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
      padding: 25px;
      max-width: 800px;
      margin: 20px auto;
    }

    .form-group {
      margin-bottom: 20px;
    }

    .form-group label {
      display: block;
      margin-bottom: 8px;
      font-weight: 600;
      color: #333;
    }

    .form-group input,
    .form-group select {
      width: 100%;
      padding: 10px;
      border: 1px solid #ddd;
      border-radius: 4px;
      font-size: 14px;
      transition: border-color 0.3s;
    }

    .form-group input:focus,
    .form-group select:focus {
      border-color: #4a90e2;
      outline: none;
      box-shadow: 0 0 0 2px rgba(74, 144, 226, 0.2);
    }

    .form-buttons {
      display: flex;
      gap: 15px;
      margin-top: 30px;
    }

    .btn {
      padding: 10px 20px;
      border: none;
      border-radius: 4px;
      cursor: pointer;
      font-weight: 500;
      transition: all 0.3s;
    }

    .btn-primary {
      background-color: #4a90e2;
      color: white;
    }

    .btn-primary:hover {
      background-color: #3a7bc8;
    }

    .btn:not(.btn-primary) {
      background-color: #f5f5f5;
      color: #333;
    }

    .btn:not(.btn-primary):hover {
      background-color: #e5e5e5;
    }

    .page-title {
      font-size: 24px;
      font-weight: 600;
      margin-bottom: 25px;
      color: #333;
      border-bottom: 2px solid #4a90e2;
      padding-bottom: 10px;
    }

    #success-message {
      background-color: #d4edda;
      color: #155724;
      border: 1px solid #c3e6cb;
      border-radius: 4px;
      padding: 10px 15px;
      margin-bottom: 20px;
      display: none;
    }

    </style>
  </head>
  <?php
  require_once '../config/database.php';
  $db = getDbConnection();
  ?>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <div class="form-container">
        <form action="tag_add_process.php" method="POST">
          <div class="form-group">
            <label for="parent_id">父级标签</label>
            <select id="parent_id" name="parent_id">
              <option value="0">-- 作为主标签 --</option>
              <?php
              // 获取所有可能的父标签
              $stmt = $db->prepare("SELECT id, name FROM tags WHERE parent_id = 0 ORDER BY sort_order ASC");
              $stmt->execute();
              while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                  echo "<option value='{$row['id']}'>" . htmlspecialchars($row['name']) . "</option>";
              }
              ?>
            </select>
          </div>
          <div class="form-group">
            <label for="name">标签名称</label>
            <input type="text" id="name" name="name" required>
          </div>
          <div class="form-group">
            <label for="slug">静态页面名称</label>
            <input type="text" id="slug" name="slug" required>
          </div>
          <div class="form-group">
            <label for="sort_order">排序</label>
            <input type="number" id="sort_order" name="sort_order" value="0">
          </div>
          <div class="form-group">
            <label for="status">状态</label>
            <select id="status" name="status">
              <option value="1" selected>启用</option>
              <option value="0">禁用</option>
            </select>
          </div>
          <div class="form-buttons">
            <button type="submit" class="btn btn-primary">保存</button>
            <button type="button" class="btn" onclick="location.href='tag.php'">返回</button>
          </div>
        </form>
      </div>
      <div id="success-message">
        <p>添加成功！</p>
      </div>
      <script>
      // 检查URL参数是否包含添加成功的标志
      const urlParams = new URLSearchParams(window.location.search);
      if (urlParams.has('added') && urlParams.get('added') === 'true') {
        const messageElement = document.getElementById('success-message');
        messageElement.style.display = 'block';
        // 5秒后自动隐藏消息
        setTimeout(() => {
          messageElement.style.display = 'none';
        }, 5000);
      }
      // 自动生成slug
      document.getElementById('name').addEventListener('input', function() {
        const nameValue = this.value.trim();
        const slugField = document.getElementById('slug');
        // 如果slug字段为空或未被手动修改过，则自动生成
        if (!slugField.dataset.modified) {
          // 转换为小写，替换空格为连字符，移除特殊字符
          const slugValue = nameValue.toLowerCase()
            .replace(/\s+/g, '-')
            .replace(/[^\w\-]+/g, '');
          slugField.value = slugValue;
        }
      });
      // 标记slug是否被手动修改过
      document.getElementById('slug').addEventListener('input', function() {
        this.dataset.modified = 'true';
      });
      </script>
    </div>
  </body>
</html>
