<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>编辑标签</title>
        <link rel="stylesheet" href="public/css/style.css">
        <style>
        .form-container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 25px;
            max-width: 800px;
            margin: 20px auto;
        }

        .form-group {
            margin-bottom: 20px;
        }

        .form-group label {
            display: block;
            margin-bottom: 8px;
            font-weight: 600;
            color: #333;
        }

        .form-group input,
        .form-group select {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group select:focus {
            border-color: #4a90e2;
            outline: none;
            box-shadow: 0 0 0 2px rgba(74, 144, 226, 0.2);
        }

        .form-buttons {
            display: flex;
            gap: 15px;
            margin-top: 30px;
        }

        .btn {
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: 500;
            transition: all 0.3s;
        }

        .btn-primary {
            background-color: #4a90e2;
            color: white;
        }

        .btn-primary:hover {
            background-color: #3a7bc8;
        }

        .btn:not(.btn-primary) {
            background-color: #f5f5f5;
            color: #333;
        }

        .btn:not(.btn-primary):hover {
            background-color: #e5e5e5;
        }

        .page-title {
            font-size: 24px;
            font-weight: 600;
            margin-bottom: 25px;
            color: #333;
            border-bottom: 2px solid #4a90e2;
            padding-bottom: 10px;
        }

        #update-message {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
            border-radius: 4px;
            padding: 10px 15px;
            margin-bottom: 20px;
            display: none;
        }

        </style>
        <?php
    require_once '../config/database.php';
    $id = isset($_GET['id']) ? intval($_GET['id']) : 0;
    if (!$id) {
        header('Location: tag.php');
        exit;
    }
    try {
        $db = getDbConnection();
        $stmt = $db->prepare("SELECT * FROM tags WHERE id = ?");
        $stmt->execute([$id]);
        $tag = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$tag) {
            header('Location: tag.php');
            exit;
        }
    } catch (PDOException $e) {
        die("Error: " . $e->getMessage());
    }
    ?>
        <div class="sidebar">
            <?php include 'public/header.php'; ?>
            <?php include 'public/letf.php'; ?>
        </div>
        <div class="main-content">

            <div class="form-container">
                <form action="tag_edit_process.php" method="POST">
                    <input type="hidden" name="id" value="<?php echo $tag['id']; ?>">
                    <div class="form-group">
                        <label for="parent_id">父级标签</label>
                        <select id="parent_id" name="parent_id">
                            <option value="0">-- 作为主标签 --</option>
                            <?php
                        // 获取所有可能的父标签（排除自己和自己的子标签）
                        $stmt = $db->prepare("SELECT id, name FROM tags WHERE parent_id = 0 AND id != ? ORDER BY sort_order ASC");
                        $stmt->execute([$id]);
                        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                            $selected = ($row['id'] == $tag['parent_id']) ? 'selected' : '';
                            echo "<option value='{$row['id']}' {$selected}>" . htmlspecialchars($row['name']) . "</option>";
                        }
                        ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="name">标签名称</label>
                        <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($tag['name']); ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="slug">静态页面名称</label>
                        <input type="text" id="slug" name="slug" value="<?php echo htmlspecialchars($tag['slug']); ?>" required oninput="this.value = this.value.replace(/\s+/g, '')">
                    </div>
                    <div class="form-group">
                        <label for="sort_order">排序</label>
                        <input type="number" id="sort_order" name="sort_order" value="<?php echo $tag['sort_order']; ?>">
                    </div>
                    <div class="form-group">
                        <label for="status">状态</label>
                        <select id="status" name="status">
                            <option value="1" <?php echo $tag['status'] ? 'selected' : ''; ?>>启用</option>
                            <option value="0" <?php echo !$tag['status'] ? 'selected' : ''; ?>>禁用</option>
                        </select>
                    </div>
                    <div class="form-buttons">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <button type="button" class="btn" onclick="history.back()">返回</button>
                    </div>
                </form>
            </div>
            <div id="update-message" style="display: none;">
                <p>更新成功！</p>
            </div>
            <script>
            // 检查URL参数是否包含更新成功的标志
            const urlParams = new URLSearchParams(window.location.search);
            if (urlParams.has('updated') && urlParams.get('updated') === 'true') {
                const messageElement = document.getElementById('update-message');
                messageElement.style.display = 'block';
                // 5秒后自动隐藏消息
                setTimeout(() => {
                    messageElement.style.display = 'none';
                }, 5000);
            }
            </script>
        </div>
        </body>
</html>
