<?php
require_once '../config/database.php';

// 获取POST数据
$data = json_decode(file_get_contents('php://input'), true);

if (!isset($data['updates']) || !is_array($data['updates'])) {
    echo json_encode(['success' => false, 'message' => '无效的请求数据']);
    exit;
}

try {
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 准备更新语句
    $stmt = $db->prepare("UPDATE tags SET sort_order = :sort_order WHERE id = :id");
    
    // 执行批量更新
    foreach ($data['updates'] as $update) {
        $stmt->execute([
            ':id' => $update['id'],
            ':sort_order' => $update['sort_order']
        ]);
    }
    
    // 提交事务
    $db->commit();
    
    echo json_encode(['success' => true, 'message' => '排序更新成功']);
} catch (Exception $e) {
    // 回滚事务
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    echo json_encode(['success' => false, 'message' => '更新失败: ' . $e->getMessage()]);
} 