<?php
require_once 'code/ticket_detail_code.php';
?>
<!DOCTYPE html>
<html lang="zh-CN">

  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工单详情 #<?php echo $ticketId; ?></title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/ticket_detail.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <script src="public/js/ticket_detail.js"></script>
  </head>

  <body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <a href="ticket.php" class="back-link"><i class="fas fa-arrow-left"></i> 返回工单列表</a>
      <?php if (!empty($message)): ?>
      <div class="alert alert-success">
        <i class="fas fa-check-circle"></i> <?php echo $message; ?>
      </div>

      <?php endif; ?>
      <?php if (!empty($error)): ?>
      <div class="alert alert-danger">
        <div class="ticket-sidebar">
          <form action="ticket_detail.php?id=<?php echo $ticketId; ?>" method="post">
            <div class="ticket-compact-row">
              <div class="form-inline-group">
                <label for="status">状态:</label>
                <select id="status" name="status" class="compact-select">
                  <?php foreach ($statusMap as $key => $value): ?>
                  <option value="<?php echo $key; ?>" <?php echo $ticket['status'] === $key ? 'selected' : ''; ?>>
                    <?php echo $value; ?>
                  </option>
                  <?php endforeach; ?>
                </select>
              </div>
              <div class="form-inline-group">
                <label for="priority">优先级:</label>
                <select id="priority" name="priority" class="compact-select">
                  <?php foreach ($priorityMap as $key => $value): ?>
                  <option value="<?php echo $key; ?>" <?php echo $ticket['priority'] === $key ? 'selected' : ''; ?>>
                    <?php echo $value; ?>
                  </option>
                  <?php endforeach; ?>
                </select>
              </div>
              <div class="form-inline-group">
                <?php if ($ticket['status'] !== 'closed'): ?>
                <a href="ticket_detail.php?id=<?php echo $ticketId; ?>&action=close" class="compact-btn close-btn">关闭</a>
                <?php else: ?>
                <a href="ticket_detail.php?id=<?php echo $ticketId; ?>&action=reopen" class="compact-btn reopen-btn">重开</a>
                <?php endif; ?>
              </div>
              <div class="form-inline-group">
                <button type="submit" class="compact-btn update-btn">更新</button>
              </div>
              <textarea name="reply_content" style="display:none;"></textarea>
            </div>
          </form>
        </div> <i class="fas fa-exclamation-circle"></i> <?php echo $error; ?>
      </div>
      <?php endif; ?>
      <?php if ($ticket): ?>
      <div class="ticket-header">
        <div>
          <h1 class="ticket-title">#<?php echo $ticket['id']; ?>: <?php echo htmlspecialchars($ticket['subject']); ?></h1>
          <div class="ticket-meta">
            ID:<?php echo $ticket['user_id']; ?> | <?php echo $ticket['formatted_created_at']; ?>
          </div>
        </div>
      </div>

      <!-- 将原始工单内容移到上方，紧接在标题下方 -->
      <div class="ticket-message user-reply">
        <div class="reply-avatar">U</div>
        <div class="reply-user">
          <span class="reply-username">
            <i class="fas fa-user"></i> ID:<?php echo $ticket['user_id']; ?>
          </span>
          <span class="reply-time">
            <i class="far fa-clock"></i> <?php echo $ticket['formatted_created_at']; ?>
          </span>
        </div>
        <div class="reply-content">
          <?php if (!empty(trim($ticket['message']))): ?>
          <?php echo nl2br(htmlspecialchars($ticket['message'])); ?>
          <?php endif; ?>

          <?php
          // 查询工单原始内容的附件(reply_id=0)
          $originalAttachmentsQuery = "SELECT * FROM ticket_attachments WHERE ticket_id = :ticket_id AND (reply_id = 0 OR reply_id IS NULL)";
          $stmt = $db->prepare($originalAttachmentsQuery);
          $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
          $stmt->execute();
          $originalAttachments = $stmt->fetchAll(PDO::FETCH_ASSOC);

          if (!empty($originalAttachments)):
          ?>
          <div class="attachments-section">

            <div class="attached-images">
              <?php foreach ($originalAttachments as $attachment): ?>
              <?php if (strpos($attachment['file_type'], 'image/') === 0): ?>
              <div class="attached-image">
                <img src="<?php echo $attachment['file_path']; ?>" alt="附件图片" onclick="openImageModal(this)">
              </div>
              <?php else: ?>
              <div class="attachment-item">
                <span class="attachment-icon"><i class="fas fa-file"></i></span>
                <a href="<?php echo $attachment['file_path']; ?>" class="attachment-link" target="_blank">
                  <?php echo htmlspecialchars($attachment['file_name']); ?>
                </a>
              </div>
              <?php endif; ?>
              <?php endforeach; ?>
            </div>
          </div>
          <?php endif; ?>
        </div>
      </div>

      <div class="ticket-container">

        <div class="ticket-details">
          <div class="ticket-content">
            <div class="ticket-info">
              <span class="status-badge status-<?php echo $ticket['status']; ?>">
                <?php echo $statusMap[$ticket['status']]; ?>
              </span>
              <span class="priority-badge priority-<?php echo $ticket['priority']; ?>">
                <?php echo $priorityMap[$ticket['priority']]; ?>
              </span>
            </div>

            <!-- 原始工单内容已移至上方 -->

            <?php if (!empty($replies)): ?>
            <div class="replies-section">
              <h2 class="replies-title">回复记录</h2>
              <?php foreach ($replies as $reply): ?>
              <?php
                  $isAdmin = !empty($reply['admin_id']);
                  $replyClass = $isAdmin ? 'admin-reply' : 'user-reply';
                  $username = $isAdmin ?
                    '管理员 (ID: ' . $reply['admin_id'] . ')' :
                    '用户 (ID: ' . $reply['user_id'] . ')';
                  $initial = $isAdmin ? 'A' : 'U'; // 头像显示的首字母
                  ?>
              <div class="reply-item <?php echo $replyClass; ?>">
                <div class="reply-avatar"><?php echo $initial; ?></div>
                <div class="reply-user">
                  <span class="reply-username">
                    <?php if ($isAdmin): ?>
                    <i class="fas fa-user-shield"></i>
                    <?php echo htmlspecialchars($username); ?>
                    <span class="admin-badge">管理员</span>
                    <?php else: ?>
                    <i class="fas fa-user"></i>
                    <?php echo htmlspecialchars($username); ?>
                    <?php endif; ?>
                  </span>
                  <span class="reply-time">
                    <i class="far fa-clock"></i>
                    <?php echo $reply['formatted_created_at']; ?>
                  </span>
                </div>
                <div class="reply-content">
                  <?php if (!empty(trim($reply['message']))): ?>
                  <?php echo nl2br(htmlspecialchars($reply['message'])); ?>
                  <?php endif; ?>
                  <?php if (isset($attachments[$reply['id']]) && !empty($attachments[$reply['id']])): ?>
                  <div class="attachments-section">
                    <div class="attachments-title">附件:</div>
                    <div class="attached-images">
                      <?php foreach ($attachments[$reply['id']] as $attachment): ?>
                      <?php if (strpos($attachment['file_type'], 'image/') === 0): ?>
                      <div class="attached-image">
                        <img src="<?php echo $attachment['file_path']; ?>" alt="附件图片" onclick="openImageModal(this)">
                      </div>
                      <?php else: ?>
                      <div class="attachment-item">
                        <span class="attachment-icon"><i class="fas fa-file"></i></span>
                        <a href="<?php echo $attachment['file_path']; ?>" class="attachment-link" target="_blank">
                          <?php echo htmlspecialchars($attachment['file_name']); ?>
                        </a>
                      </div>
                      <?php endif; ?>
                      <?php endforeach; ?>
                    </div>
                  </div>
                  <?php endif; ?>
                </div>
              </div>
              <?php endforeach; ?>
            </div>
            <?php endif; ?>
          </div>
          <div class="reply-form">
            <h2 class="replies-title">回复</h2>
            <form action="ticket_detail.php?id=<?php echo $ticketId; ?>" method="post" enctype="multipart/form-data">
              <textarea name="reply_content" placeholder="请输入回复内容..." required></textarea>
              <div class="file-upload">
                <label for="attachments">附件:</label>
                <div class="file-upload-field">
                  <span class="file-upload-btn">
                    <i class="fas fa-paperclip"></i> 选择文件
                  </span>
                  <input type="file" name="attachments[]" id="attachments" class="file-upload-input" multiple>
                </div>
                <div class="file-list" id="fileList"></div>
              </div>
              <button type="submit" class="reply-btn">提交</button>
            </form>
          </div>
        </div>
      </div>
      <?php else: ?>
      <div class="alert alert-danger">
        <i class="fas fa-exclamation-triangle"></i> 找不到指定的工单
      </div>
      <?php endif; ?>
    </div>
    <!-- 图片放大模态框 -->
    <div id="imageModal" class="image-modal">
      <span class="modal-close" onclick="closeImageModal()">&times;</span>
      <img class="modal-content" id="modalImage">
      <div id="modalCaption" class="modal-caption"></div>
    </div>
  </body>

</html>
