<?php
/**
 * 管理员回复工单
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 检查请求方法
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: ticket.php');
    exit;
}

// 获取表单数据
$conversationId = isset($_POST['conversation_id']) ? intval($_POST['conversation_id']) : 0;
$adminId = isset($_POST['admin_id']) ? intval($_POST['admin_id']) : 0;
$content = isset($_POST['content']) ? trim($_POST['content']) : '';

// 验证数据
if ($conversationId <= 0) {
    echo "无效的工单ID";
    exit;
}

if (empty($content)) {
    echo "回复内容不能为空";
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 检查工单是否存在并且未关闭
    $checkQuery = "SELECT status FROM conversation WHERE id = :id";
    $checkStmt = $db->prepare($checkQuery);
    $checkStmt->execute(['id' => $conversationId]);
    $ticket = $checkStmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$ticket) {
        echo "工单不存在";
        exit;
    }
    
    if ($ticket['status'] === 'closed') {
        echo "此工单已关闭，无法回复";
        exit;
    }
    
    // 插入回复消息
    $insertQuery = "INSERT INTO message (conversation_id, admin_id, content, created_at, is_read) 
                    VALUES (:conversation_id, :admin_id, :content, NOW(), 1)";
    $insertStmt = $db->prepare($insertQuery);
    $result = $insertStmt->execute([
        'conversation_id' => $conversationId,
        'admin_id' => $adminId,
        'content' => $content
    ]);
    
    if (!$result) {
        throw new Exception("回复添加失败");
    }
    
    // 如果工单状态是open，更新为pending（处理中）
    if ($ticket['status'] === 'open') {
        $updateQuery = "UPDATE conversation SET status = 'pending', updated_at = NOW() WHERE id = :id";
        $updateStmt = $db->prepare($updateQuery);
        $updateStmt->execute(['id' => $conversationId]);
    } else {
        // 更新工单的更新时间
        $updateTimeQuery = "UPDATE conversation SET updated_at = NOW() WHERE id = :id";
        $updateTimeStmt = $db->prepare($updateTimeQuery);
        $updateTimeStmt->execute(['id' => $conversationId]);
    }
    
    // 提交事务
    $db->commit();
    
    // 重定向回工单详情页面
    header("Location: ticket_detail.php?id={$conversationId}&replied=1");
    exit;
    
} catch (Exception $e) {
    // 回滚事务
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "错误：" . $e->getMessage();
    exit;
} 