<?php
/**
 * 更新工单状态
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 设置响应类型为JSON
header('Content-Type: application/json');

// 检查请求方法
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
    exit;
}

// 获取请求参数
$ticketId = isset($_POST['id']) ? intval($_POST['id']) : 0;
$status = isset($_POST['status']) ? $_POST['status'] : '';

// 验证参数
if ($ticketId <= 0) {
    echo json_encode(['success' => false, 'message' => '无效的工单ID']);
    exit;
}

// 验证状态值
$validStatuses = ['open', 'pending', 'closed'];
if (!in_array($status, $validStatuses)) {
    echo json_encode(['success' => false, 'message' => '无效的状态值']);
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 更新工单状态
    $query = "UPDATE conversation SET status = :status, updated_at = NOW() WHERE id = :id";
    $stmt = $db->prepare($query);
    $result = $stmt->execute([
        'status' => $status,
        'id' => $ticketId
    ]);
    
    if ($result) {
        // 如果是关闭工单，添加一条系统消息
        if ($status === 'closed') {
            $systemMessage = "此工单已被管理员关闭。";
            $insertQuery = "INSERT INTO message (conversation_id, admin_id, content, created_at, is_read) 
                            VALUES (:conversation_id, NULL, :content, NOW(), 1)";
            $insertStmt = $db->prepare($insertQuery);
            $insertStmt->execute([
                'conversation_id' => $ticketId,
                'content' => $systemMessage
            ]);
        } else if ($status === 'open') {
            $systemMessage = "此工单已被管理员重新开启。";
            $insertQuery = "INSERT INTO message (conversation_id, admin_id, content, created_at, is_read) 
                            VALUES (:conversation_id, NULL, :content, NOW(), 1)";
            $insertStmt = $db->prepare($insertQuery);
            $insertStmt->execute([
                'conversation_id' => $ticketId,
                'content' => $systemMessage
            ]);
        }
        
        echo json_encode(['success' => true, 'message' => '工单状态更新成功']);
    } else {
        echo json_encode(['success' => false, 'message' => '工单状态更新失败']);
    }
} catch (PDOException $e) {
    echo json_encode(['success' => false, 'message' => '数据库错误: ' . $e->getMessage()]);
} 