<?php
/**
 * 添加会员页面
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>添加会员</title>
        <link rel="stylesheet" href="public/css/style.css">
        <style>
        .avatar-preview {
            width: 100px;
            height: 100px;
            border-radius: 50%;
            object-fit: cover;
            margin-top: 10px;
            border: 1px solid #ddd;
        }

        </style>
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="sidebar">
            <?php include 'public/letf.php'; ?>
        </div>
        <div class="main-content">
            <div class="form-container">
                <form id="user-form" method="post" action="user_create.php" enctype="multipart/form-data">
                    <div class="form-group">
                        <label for="username">会员名</label>
                        <input type="text" id="username" name="username" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="password">密码</label>
                        <input type="password" id="password" name="password" class="form-control" required>
                        <small>请输入至少6位的密码</small>
                    </div>
                    <div class="form-group">
                        <label for="confirm_password">确认密码</label>
                        <input type="password" id="confirm_password" name="confirm_password" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="avatar">头像</label>
                        <input type="file" id="avatar" name="avatar" class="form-control" accept="image/*">
                        <img id="avatar-preview" src="public/images/default-avatar.png" class="avatar-preview" alt="头像预览">
                    </div>
                    <div class="form-group">
                        <label for="group_id">群ID</label>
                        <input type="text" id="group_id" name="group_id" class="form-control">
                    </div>
                    <div class="form-group">
                        <label for="group_link">群连接</label>
                        <input type="url" id="group_link" name="group_link" class="form-control" placeholder="https://">
                    </div>
                    <div class="form-group">
                        <label for="status">状态</label>
                        <select id="status" name="status" class="form-control">
                            <option value="1" selected>启用</option>
                            <option value="0">禁用</option>
                        </select>
                    </div>
                    <div class="btn-container">
                        <button type="submit" class="btn-save">保存</button>
                        <a href="user.php" class="btn-cancel">取消</a>
                    </div>
                </form>
            </div>
        </div>
        <script>
        document.addEventListener('DOMContentLoaded', function() {
            // 头像预览功能
            const avatarInput = document.getElementById('avatar');
            const avatarPreview = document.getElementById('avatar-preview');

            avatarInput.addEventListener('change', function() {
                if (this.files && this.files[0]) {
                    const reader = new FileReader();
                    reader.onload = function(e) {
                        avatarPreview.src = e.target.result;
                    };
                    reader.readAsDataURL(this.files[0]);
                }
            });

            // 表单验证
            document.getElementById('user-form').addEventListener('submit', function(e) {
                const username = document.getElementById('username').value.trim();
                const password = document.getElementById('password').value;
                const confirmPassword = document.getElementById('confirm_password').value;

                if (!username) {
                    e.preventDefault();
                    alert('请输入会员名');
                    return false;
                }

                if (password.length < 6) {
                    e.preventDefault();
                    alert('密码长度至少为6位');
                    return false;
                }

                if (password !== confirmPassword) {
                    e.preventDefault();
                    alert('两次输入的密码不一致');
                    return false;
                }

                // 验证群连接格式
                const groupLink = document.getElementById('group_link').value.trim();
                if (groupLink && !isValidUrl(groupLink)) {
                    e.preventDefault();
                    alert('请输入有效的群连接URL');
                    return false;
                }
            });

            // 验证URL格式
            function isValidUrl(url) {
                try {
                    new URL(url);
                    return true;
                } catch (e) {
                    return false;
                }
            }
        });
        </script>
    </body>
</html>
