<?php
/**
 * 会员添加处理
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 检查是否有POST请求
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取表单数据
    $username = isset($_POST['username']) ? trim($_POST['username']) : '';
    $password = isset($_POST['password']) ? $_POST['password'] : '';
    $groupId = isset($_POST['group_id']) ? trim($_POST['group_id']) : '';
    $groupLink = isset($_POST['group_link']) ? trim($_POST['group_link']) : '';
    $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
    
    // 验证数据
    if (empty($username)) {
        echo "会员名不能为空";
        exit;
    }
    
    if (strlen($password) < 6) {
        echo "密码长度至少为6位";
        exit;
    }
    
    // 处理头像上传
    $avatarPath = '';
    if (isset($_FILES['avatar']) && $_FILES['avatar']['error'] === UPLOAD_ERR_OK) {
        $uploadDir = '../uploads/avatars/';
        
        // 确保上传目录存在
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0777, true);
        }
        
        // 生成唯一文件名
        $fileExtension = pathinfo($_FILES['avatar']['name'], PATHINFO_EXTENSION);
        $newFileName = uniqid() . '.' . $fileExtension;
        $uploadFile = $uploadDir . $newFileName;
        
        // 验证文件类型
        $allowedTypes = ['image/jpeg', 'image/png', 'image/gif', 'image/webp'];
        $fileType = mime_content_type($_FILES['avatar']['tmp_name']);
        
        if (!in_array($fileType, $allowedTypes)) {
            echo "只允许上传JPEG、PNG、GIF或WEBP格式的图片";
            exit;
        }
        
        // 移动上传的文件
        if (move_uploaded_file($_FILES['avatar']['tmp_name'], $uploadFile)) {
            $avatarPath = 'uploads/avatars/' . $newFileName;
        } else {
            echo "头像上传失败";
            exit;
        }
    }
    
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 检查会员名是否已存在
        $checkQuery = "SELECT COUNT(*) as count FROM user WHERE username = :username";
        $checkStmt = $db->prepare($checkQuery);
        $checkStmt->execute(['username' => $username]);
        $usernameCount = $checkStmt->fetch()['count'];
        
        if ($usernameCount > 0) {
            echo "会员名已存在，请使用其他名称";
            exit;
        }
        
        // 对密码进行加密
        $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
        
        // 插入会员数据
        $insertQuery = "INSERT INTO user (username, password, avatar, group_id, group_link, status, created_at) 
                        VALUES (:username, :password, :avatar, :group_id, :group_link, :status, NOW())";
        $insertStmt = $db->prepare($insertQuery);
        $insertStmt->execute([
            'username' => $username,
            'password' => $hashedPassword,
            'avatar' => $avatarPath,
            'group_id' => $groupId,
            'group_link' => $groupLink,
            'status' => $status
        ]);
        
        // 重定向回会员列表页
        header('Location: user.php?success=1');
        exit;
    } catch (PDOException $e) {
        echo "数据库错误: " . $e->getMessage();
        exit;
    }
} else {
    echo "无效的请求方法";
    exit;
}
?> 