<?php
/**
 * 会员编辑页面
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 获取要编辑的会员ID
$userId = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 初始化会员数据
$user = null;
if ($userId > 0) {
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 获取会员数据
        $query = "SELECT * FROM user WHERE id = :id";
        $stmt = $db->prepare($query);
        $stmt->execute(['id' => $userId]);
        $user = $stmt->fetch();
        
        if (!$user) {
            echo "会员不存在";
            exit;
        }

        // 设置默认值，防止未定义的字段
        $user = array_merge([
            'username' => '',
            'email' => '',
            'role' => '',
            'status' => 1,
            'avatar' => '',
            'group_id' => '',
            'group_link' => '',
            'is_managed' => 0,
            'last_login' => null
        ], $user);

    } catch (PDOException $e) {
        echo "数据库错误: " . $e->getMessage();
        exit;
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>编辑会员 - <?php echo $user ? $user['username'] : ''; ?></title>
        <link rel="stylesheet" href="public/css/style.css">
        <link rel="stylesheet" href="public/css/user-edit.css">
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <div class="sidebar">
            <?php include 'public/letf.php'; ?>
        </div>
        <div class="main-content">
            <div class="form-container">
                <form id="user-form" method="post" action="user_update.php" enctype="multipart/form-data">
                    <input type="hidden" name="id" value="<?php echo $user['id']; ?>">

                    <!-- 基本信息 -->
                    <div class="form-section">
                        <div class="form-group">
                            <label for="username">会员名</label>
                            <div class="input-wrapper">
                                <input type="text" id="username" name="username" class="form-control"
                                       value="<?php echo htmlspecialchars($user['username']); ?>" required>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="email">邮箱</label>
                            <div class="input-wrapper">
                                <input type="email" id="email" name="email" class="form-control"
                                       value="<?php echo htmlspecialchars($user['email']); ?>">
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="role">角色</label>
                            <div class="input-wrapper">
                                <select id="role" name="role" class="form-control">
                                    <option value="">请选择角色</option>
                                    <option value="admin" <?php echo $user['role'] == 'admin' ? 'selected' : ''; ?>>管理员</option>
                                    <option value="user" <?php echo $user['role'] == 'user' ? 'selected' : ''; ?>>普通用户</option>
                                </select>
                            </div>
                        </div>
                    </div>

                    <!-- 安全设置 -->
                    <div class="form-section">
                        <div class="form-group">
                            <label for="password">密码</label>
                            <div class="input-wrapper">
                                <input type="password" id="password" name="password" class="form-control" placeholder="不修改请留空">
                                <small>如需修改密码，请输入至少6位的新密码，否则留空</small>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="confirm_password">确认密码</label>
                            <div class="input-wrapper">
                                <input type="password" id="confirm_password" name="confirm_password" class="form-control" placeholder="不修改请留空">
                            </div>
                        </div>
                    </div>

                    <!-- 头像设置 -->
                    <div class="form-section">
                        <div class="form-group">
                            <label for="avatar">头像</label>
                            <div class="input-wrapper">
                                <input type="file" id="avatar" name="avatar" class="form-control" accept="image/*">
                                <input type="hidden" name="current_avatar" value="<?php echo htmlspecialchars($user['avatar']); ?>">
                                <img id="avatar-preview"
                                     src="<?php echo !empty($user['avatar']) ? $user['avatar'] : 'public/images/default-avatar.png'; ?>"
                                     class="avatar-preview" alt="头像预览">
                            </div>
                        </div>
                    </div>

                    <!-- 群组信息 -->
                    <div class="form-section">
                        <div class="form-group">
                            <label for="group_id">群ID</label>
                            <div class="input-wrapper">
                                <input type="text" id="group_id" name="group_id" class="form-control"
                                       value="<?php echo htmlspecialchars($user['group_id']); ?>">
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="group_link">群连接</label>
                            <div class="input-wrapper">
                                <input type="url" id="group_link" name="group_link" class="form-control"
                                       value="<?php echo htmlspecialchars($user['group_link']); ?>" placeholder="https://">
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="status">状态</label>
                            <div class="input-wrapper">
                                <select id="status" name="status" class="form-control">
                                    <option value="1" <?php echo $user['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                    <option value="0" <?php echo $user['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                                </select>
                            </div>
                        </div>
                    </div>

                    <div class="btn-container">
                        <button type="submit" class="btn-save">保存</button>
                        <a href="user.php" class="btn-cancel">取消</a>
                    </div>
                </form>
            </div>
        </div>

        <script>
        document.addEventListener('DOMContentLoaded', function() {
            // 头像预览功能
            const avatarInput = document.getElementById('avatar');
            const avatarPreview = document.getElementById('avatar-preview');
            avatarInput.addEventListener('change', function() {
                if (this.files && this.files[0]) {
                    const reader = new FileReader();
                    reader.onload = function(e) {
                        avatarPreview.src = e.target.result;
                    };
                    reader.readAsDataURL(this.files[0]);
                }
            });
            // 表单验证
            document.getElementById('user-form').addEventListener('submit', function(e) {
                const username = document.getElementById('username').value.trim();
                const password = document.getElementById('password').value;
                const confirmPassword = document.getElementById('confirm_password').value;
                const email = document.getElementById('email').value.trim();
                const role = document.getElementById('role').value;
                if (!username) {
                    e.preventDefault();
                    alert('请输入会员名');
                    return false;
                }
                if (email && !isValidEmail(email)) {
                    e.preventDefault();
                    alert('请输入有效的邮箱地址');
                    return false;
                }
                // 只有当密码字段不为空时才验证密码
                if (password) {
                    if (password.length < 6) {
                        e.preventDefault();
                        alert('密码长度至少为6位');
                        return false;
                    }
                    if (password !== confirmPassword) {
                        e.preventDefault();
                        alert('两次输入的密码不一致');
                        return false;
                    }
                }
                // 验证群连接格式
                const groupLink = document.getElementById('group_link').value.trim();
                if (groupLink && !isValidUrl(groupLink)) {
                    e.preventDefault();
                    alert('请输入有效的群连接URL');
                    return false;
                }
            });
            // 验证URL格式
            function isValidUrl(url) {
                try {
                    new URL(url);
                    return true;
                } catch (e) {
                    return false;
                }
            }
            // 验证邮箱格式
            function isValidEmail(email) {
                const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
                return emailRegex.test(email);
            }
        });
        </script>
    </body>
</html>
