<?php
/**
 * 更新会员信息
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 检查请求方法
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: user.php');
    exit;
}

// 获取表单数据
$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
$username = isset($_POST['username']) ? trim($_POST['username']) : '';
$password = isset($_POST['password']) ? $_POST['password'] : '';
$currentAvatar = isset($_POST['current_avatar']) ? trim($_POST['current_avatar']) : '';
$groupId = isset($_POST['group_id']) ? trim($_POST['group_id']) : '';
$groupLink = isset($_POST['group_link']) ? trim($_POST['group_link']) : '';
$status = isset($_POST['status']) ? intval($_POST['status']) : 1;

// 验证数据
if (empty($username)) {
    echo "会员名不能为空";
    exit;
}

// 验证密码长度（如果提供了密码）
if (!empty($password) && strlen($password) < 6) {
    echo "密码长度至少为6位";
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 检查会员名是否已存在（排除当前记录）
    $checkQuery = "SELECT id FROM user WHERE username = :username AND id != :id";
    $checkStmt = $db->prepare($checkQuery);
    $checkStmt->execute([
        'username' => $username,
        'id' => $id
    ]);
    
    if ($checkStmt->rowCount() > 0) {
        echo "会员名已存在，请使用其他名称";
        exit;
    }
    
    // 处理头像上传
    $avatarPath = $currentAvatar;
    if (isset($_FILES['avatar']) && $_FILES['avatar']['error'] === UPLOAD_ERR_OK) {
        $uploadDir = dirname(__DIR__) . DIRECTORY_SEPARATOR . 'uploads' . DIRECTORY_SEPARATOR . 'avatars' . DIRECTORY_SEPARATOR;
        
        // 确保上传目录存在
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0777, true);
        }
        
        // 生成唯一文件名
        $fileExtension = pathinfo($_FILES['avatar']['name'], PATHINFO_EXTENSION);
        $newFileName = uniqid() . '.' . $fileExtension;
        $uploadFile = $uploadDir . $newFileName;
        
        // 验证文件类型
        $allowedExtensions = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
        $fileExtension = strtolower($fileExtension);
        
        if (!in_array($fileExtension, $allowedExtensions)) {
            echo "只允许上传JPEG、PNG、GIF或WEBP格式的图片";
            exit;
        }
        
        // 移动上传的文件
        if (move_uploaded_file($_FILES['avatar']['tmp_name'], $uploadFile)) {
            $avatarPath = '/uploads/avatars/' . $newFileName;
            
            // 删除旧头像
            if (!empty($currentAvatar)) {
                $oldAvatarPath = dirname(__DIR__) . $currentAvatar;
                if (file_exists($oldAvatarPath)) {
                    unlink($oldAvatarPath);
                }
            }
        } else {
            echo "头像上传失败";
            exit;
        }
    }
    
    // 准备更新语句和参数
    $updateFields = [
        'username' => $username,
        'avatar' => $avatarPath,
        'group_id' => $groupId,
        'group_link' => $groupLink,
        'status' => $status,
        'updated_at' => date('Y-m-d H:i:s'),
        'id' => $id
    ];
    
    $updateQuery = "UPDATE user SET 
                    username = :username, 
                    avatar = :avatar, 
                    group_id = :group_id, 
                    group_link = :group_link, 
                    status = :status, 
                    updated_at = :updated_at";
    
    // 如果提供了新密码，则更新密码
    if (!empty($password)) {
        $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
        $updateQuery .= ", password = :password";
        $updateFields['password'] = $hashedPassword;
    }
    
    $updateQuery .= " WHERE id = :id";
    
    $updateStmt = $db->prepare($updateQuery);
    $result = $updateStmt->execute($updateFields);
    
    if ($result) {
        // 更新成功，重定向回会员列表页面
        header('Location: user.php?success=1');
        exit;
    } else {
        echo "更新失败，请重试";
    }
} catch (PDOException $e) {
    echo "数据库错误: " . $e->getMessage();
}
?> 