<?php
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();
// 获取所有供应商
$vendorQuery = "SELECT * FROM vendor ORDER BY sort_order ASC, id ASC";
$vendorStmt = $db->query($vendorQuery);
$vendors = $vendorStmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>供应商管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <style>
      .success-message {
        background-color: #4CAF50;
        color: white;
        padding: 10px;
        margin-bottom: 15px;
        border-radius: 4px;
        display: none;
      }
      .status-badge {
        display: inline-block;
        width: 10px;
        height: 10px;
        border-radius: 50%;
        margin-right: 5px;
      }
      .status-active {
        background-color: #4CAF50;
      }
      .status-inactive {
        background-color: #f44336;
      }
    </style>
  </head>
  <body>
    <div class="sidebar">
      <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">

      <!-- 添加成功消息显示区域 -->
      <div id="success-message" class="success-message"></div>
      <div class="header">
        <div class="button-group">
          <button class="btn" id="add-vendor-btn">+ 添加供应商</button>
          <a href="line.php" class="btn">返回线路管理</a>
        </div>
      </div>
      <div class="table-container">
        <table>
          <thead>
            <tr>
              <th>供应商ID</th>
              <th>供应商名称</th>
              <th>供应商代码</th>
              <th>排序</th>
              <th>状态</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php if (empty($vendors)): ?>
              <tr>
                <td colspan="6" style="text-align: center;">暂无供应商数据</td>
              </tr>
            <?php else: ?>
              <?php foreach ($vendors as $vendor): ?>
                <tr data-id="<?php echo $vendor['id']; ?>">
                  <td><?php echo $vendor['id']; ?></td>
                  <td>
                    <span class="status-badge <?php echo $vendor['status'] ? 'status-active' : 'status-inactive'; ?>"></span>
                    <?php echo $vendor['name']; ?>
                  </td>
                  <td><?php echo $vendor['code']; ?></td>
                  <td><?php echo $vendor['sort_order']; ?></td>
                  <td><?php echo $vendor['status'] ? '启用' : '禁用'; ?></td>
                  <td class="action-buttons">
                    <button class="btn btn-edit" data-id="<?php echo $vendor['id']; ?>">修改</button>
                    <button class="btn btn-view-lines" data-id="<?php echo $vendor['id']; ?>">查看线路</button>
                    <button class="btn btn-delete" data-id="<?php echo $vendor['id']; ?>" 
                            data-name="<?php echo $vendor['name']; ?>">删除</button>
                  </td>
                </tr>
              <?php endforeach; ?>
            <?php endif; ?>
          </tbody>
        </table>
      </div>
    </div>
    <!-- 删除确认对话框 -->
    <div id="delete-modal" class="modal">
      <div class="modal-content">
        <h3>确认删除</h3>
        <p>您确定要删除供应商 "<span id="delete-vendor-name"></span>" 吗？</p>
        <p class="warning">注意：删除供应商将同时删除该供应商下的所有线路！</p>
        <div class="modal-buttons">
          <button class="btn-confirm" id="confirm-delete">确认删除</button>
          <button class="btn-cancel" id="cancel-delete">取消</button>
        </div>
      </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
      // 添加供应商按钮点击事件
      document.getElementById('add-vendor-btn').addEventListener('click', function() {
        window.location.href = 'vendor_add.php';
      });
      // 删除功能相关代码
      const modal = document.getElementById('delete-modal');
      const deleteVendorName = document.getElementById('delete-vendor-name');
      let deleteVendorId = null;
      // 删除按钮点击事件
      document.querySelectorAll('.btn-delete').forEach(button => {
        button.addEventListener('click', function() {
          deleteVendorId = this.dataset.id;
          const vendorName = this.dataset.name;
          deleteVendorName.textContent = vendorName;
          modal.style.display = 'block';
        });
      });
      // 确认删除按钮点击事件
      document.getElementById('confirm-delete').addEventListener('click', function() {
        if (deleteVendorId) {
          // 发送删除请求
          fetch('vendor_delete.php', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
              },
              body: 'id=' + deleteVendorId
            })
            .then(response => response.json())
            .then(data => {
              if (data.success) {
                // 删除成功，移除对应的行
                const row = document.querySelector(`tr[data-id="${deleteVendorId}"]`);
                if (row) {
                  row.remove();
                }
                // 显示成功消息
                const successMessage = document.getElementById('success-message');
                successMessage.textContent = data.message;
                successMessage.style.display = 'block';
                setTimeout(() => {
                  successMessage.style.display = 'none';
                }, 3000);
              } else {
                alert(data.message);
              }
            })
            .catch(error => {
              console.error('Error:', error);
              alert('删除失败，请重试');
            })
            .finally(() => {
              modal.style.display = 'none';
              deleteVendorId = null;
            });
        }
      });
      // 取消删除按钮点击事件
      document.getElementById('cancel-delete').addEventListener('click', function() {
        modal.style.display = 'none';
        deleteVendorId = null;
      });
      // 点击模态框外部关闭
      window.addEventListener('click', function(event) {
        if (event.target === modal) {
          modal.style.display = 'none';
          deleteVendorId = null;
        }
      });
      // 编辑按钮点击事件
      document.querySelectorAll('.btn-edit').forEach(button => {
        button.addEventListener('click', function() {
          const vendorId = this.dataset.id;
          window.location.href = `vendor_edit.php?id=${vendorId}`;
        });
      });
      // 查看线路按钮点击事件
      document.querySelectorAll('.btn-view-lines').forEach(button => {
        button.addEventListener('click', function() {
          const vendorId = this.dataset.id;
          window.location.href = `line.php?vendor_id=${vendorId}`;
        });
      });
      // 如果有成功消息参数，显示成功消息
      if (new URLSearchParams(window.location.search).has('success')) {
        const successMessage = document.getElementById('success-message');
        successMessage.textContent = "操作成功！";
        successMessage.style.display = 'block';
        setTimeout(() => {
          successMessage.style.display = 'none';
        }, 3000);
      }
    });
    </script>
  </body>
</html> 