<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';
include 'public/header.php';

// 添加检查权限的函数,如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录,重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查,您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话(如果尚未启动)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 初始化状态消息变量
$statusMessage = '';
$errorMessage = '';
$statusClass = 'alert-success';

// 初始化表单数据
$video = [
    'title' => '',
    'description' => '',
    'category_id' => '',
    'video_url' => '',
    'thumbnail' => '',
    'duration' => '',
    'status' => 1,
    'featured' => 0
];

// 获取数据库连接
$db = getDbConnection();

// 添加YouTube API相关功能
function getYoutubeVideoInfo($url) {
    // 从YouTube URL中提取视频ID
    $videoId = '';
    $pattern = '/(?:youtube\.com\/(?:[^\/\n\s]+\/\S+\/|(?:v|e(?:mbed)?)\/|\S*?[?&]v=)|youtu\.be\/)([a-zA-Z0-9_-]{11})/';
    if (preg_match($pattern, $url, $matches)) {
        $videoId = $matches[1];
    }
    
    if (empty($videoId)) {
        return [
            'success' => false,
            'message' => '无法从URL中提取YouTube视频ID'
        ];
    }
    
    // 记录日志
    error_log("尝试获取YouTube视频信息，视频ID: " . $videoId);
    
    // 尝试多种方式获取视频信息
    $result = getYoutubeInfoByOembed($videoId);
    
    if (!$result['success']) {
        // 备用方式获取信息
        $result = getYoutubeInfoByAlternative($videoId);
    }
    
    return $result;
}

// 通过oEmbed API获取视频信息
function getYoutubeInfoByOembed($videoId) {
    // 尝试通过YouTube的oEmbed API获取信息
    $apiUrl = "https://www.youtube.com/oembed?url=https://www.youtube.com/watch?v={$videoId}&format=json";
    
    // 记录日志
    error_log("正在请求YouTube oEmbed API: " . $apiUrl);
    
    // 设置curl请求
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_URL, $apiUrl);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($curl, CURLOPT_TIMEOUT, 30); // 将超时时间增加到30秒
    curl_setopt($curl, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
    
    // 添加请求头，模拟浏览器
    curl_setopt($curl, CURLOPT_HTTPHEADER, [
        'Accept: application/json',
        'Accept-Language: zh-CN,zh;q=0.9,en;q=0.8',
        'Cache-Control: no-cache',
        'Connection: keep-alive',
        'Pragma: no-cache',
        'Referer: https://www.youtube.com/'
    ]);
    
    $response = curl_exec($curl);
    $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
    $error = curl_error($curl);
    curl_close($curl);
    
    error_log("YouTube oEmbed API响应代码: " . $httpCode . ", 错误: " . $error);
    
    if ($httpCode !== 200) {
        return [
            'success' => false,
            'message' => '使用oEmbed API获取视频信息失败，HTTP代码: ' . $httpCode . ', 错误: ' . $error
        ];
    }
    
    $data = json_decode($response, true);
    if (!$data) {
        return [
            'success' => false,
            'message' => '解析oEmbed API返回数据失败'
        ];
    }
    
    // 获取高清缩略图
    $thumbnail = $data['thumbnail_url'] ?? '';
    if (!empty($thumbnail)) {
        // 尝试获取高清版缩略图
        $thumbnail = str_replace('hqdefault.jpg', 'maxresdefault.jpg', $thumbnail);
    }
    
    // 构建返回结果
    return [
        'success' => true,
        'title' => $data['title'] ?? '',
        'thumbnail' => $thumbnail,
        'author' => $data['author_name'] ?? '',
        'video_id' => $videoId,
        'provider' => 'youtube',
        'source' => 'oembed',
        'embed_html' => $data['html'] ?? ''
    ];
}

// 备用方式获取YouTube视频信息
function getYoutubeInfoByAlternative($videoId) {
    // 使用视频ID直接构建缩略图URL
    $thumbnail = "https://img.youtube.com/vi/{$videoId}/maxresdefault.jpg";
    $thumbnailHq = "https://img.youtube.com/vi/{$videoId}/hqdefault.jpg";
    
    // 验证缩略图是否存在
    $thumbnailExists = checkImageExists($thumbnail);
    if (!$thumbnailExists) {
        $thumbnail = $thumbnailHq; // 使用备用缩略图
    }
    
    // 这种方式无法获取标题，但至少可以获取缩略图
    return [
        'success' => true,
        'title' => "YouTube视频 {$videoId}", // 使用ID作为临时标题
        'thumbnail' => $thumbnail,
        'author' => 'YouTube',
        'video_id' => $videoId,
        'provider' => 'youtube',
        'source' => 'alternative',
        'note' => '目前只能获取缩略图，请手动输入视频标题'
    ];
}

// 检查远程图片是否存在
function checkImageExists($url) {
    $curl = curl_init($url);
    curl_setopt($curl, CURLOPT_NOBODY, true);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, false);
    curl_setopt($curl, CURLOPT_TIMEOUT, 5);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
    curl_exec($curl);
    $responseCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
    curl_close($curl);
    return $responseCode == 200;
}

// 添加多种视频平台支持
function getVideoInfo($url) {
    // 根据URL类型选择适当的处理方法
    if (strpos($url, 'youtube.com') !== false || strpos($url, 'youtu.be') !== false) {
        return getYoutubeVideoInfo($url);
    } else {
        // 默认处理方法
        return [
            'success' => false,
            'message' => '目前仅支持YouTube视频链接'
        ];
    }
}

// 处理异步请求获取视频信息
if (isset($_POST['action']) && $_POST['action'] === 'fetch_youtube_info') {
    try {
        // 关闭输出缓冲区，确保只输出JSON
        ob_clean();
        
        $videoUrl = trim($_POST['url'] ?? '');
        $result = getVideoInfo($videoUrl);
        
        // 返回JSON响应
        header('Content-Type: application/json');
        echo json_encode($result);
        exit;
    } catch (Exception $e) {
        // 处理异常
        ob_clean();
        header('Content-Type: application/json');
        echo json_encode([
            'success' => false,
            'message' => '获取视频信息时发生错误: ' . $e->getMessage()
        ]);
        exit;
    }
}

// 处理上传文件处理功能
if (isset($_POST['action']) && $_POST['action'] === 'upload_thumbnail') {
    // 确保在处理开始时没有任何输出
    ob_clean();
    
    // 设置响应头为JSON格式
    header('Content-Type: application/json');
    
    // 调试信息收集
    $debugInfo = [
        'received_post' => $_POST,
        'received_files' => isset($_FILES) ? array_keys($_FILES) : 'no files',
        'php_version' => phpversion(),
        'upload_max_filesize' => ini_get('upload_max_filesize'),
        'post_max_size' => ini_get('post_max_size'),
    ];
    
    // 设置上传文件夹
    $uploadDir = '../uploads/video/';
    $absolutePath = realpath(dirname(__FILE__) . '/../uploads/video/');
    
    // 记录上传请求和路径信息
    error_log("收到缩略图上传请求");
    error_log("相对路径: " . $uploadDir);
    error_log("绝对路径: " . $absolutePath);
    
    $debugInfo['paths'] = [
        'relative_path' => $uploadDir,
        'absolute_path' => $absolutePath
    ];
    
    // 确保上传文件夹存在
    if (!file_exists($uploadDir)) {
        error_log("上传目录不存在，尝试创建: " . $uploadDir);
        if (!mkdir($uploadDir, 0777, true)) {
            error_log("创建目录失败: " . $uploadDir);
            echo json_encode([
                'success' => false,
                'message' => '上传目录不存在且无法创建',
                'debug' => $debugInfo
            ]);
            exit;
        } else {
            // 确保新创建的目录有正确的权限
            chmod($uploadDir, 0777);
            error_log("目录创建成功，设置权限为777");
            $debugInfo['directory_created'] = true;
        }
    }
    
    if (!is_writable($uploadDir)) {
        error_log("上传目录不可写: " . $uploadDir);
        chmod($uploadDir, 0777);
        error_log("尝试更改目录权限为777");
        $debugInfo['changed_permissions'] = true;
        
        if (!is_writable($uploadDir)) {
            echo json_encode([
                'success' => false,
                'message' => '上传目录没有写入权限，请联系管理员设置/uploads/video目录的权限',
                'debug' => $debugInfo
            ]);
            exit;
        }
    }
    
    // 处理上传的文件
    if (isset($_FILES['thumbnail_file'])) {
        $debugInfo['file_details'] = $_FILES['thumbnail_file'];
        error_log("收到文件上传: " . print_r($_FILES['thumbnail_file'], true));
        
        if ($_FILES['thumbnail_file']['error'] === UPLOAD_ERR_OK) {
            $tempFile = $_FILES['thumbnail_file']['tmp_name'];
            $originalName = $_FILES['thumbnail_file']['name'];
            $fileInfo = pathinfo($originalName);
            $extension = strtolower($fileInfo['extension']);
            
            $debugInfo['temp_file'] = [
                'path' => $tempFile,
                'exists' => file_exists($tempFile),
                'readable' => is_readable($tempFile),
                'size' => filesize($tempFile)
            ];
            
            // 仅允许特定图片格式
            $allowedExtensions = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
            if (in_array($extension, $allowedExtensions)) {
                // 生成唯一文件名，保留原始文件名的一部分
                $baseName = preg_replace('/[^a-zA-Z0-9_-]/', '', $fileInfo['filename']);
                $baseName = substr($baseName, 0, 20); // 限制基本名称长度
                $newFileName = 'thumb_' . $baseName . '_' . uniqid() . '.' . $extension;
                $targetFile = $uploadDir . $newFileName;
                
                error_log("尝试移动上传文件到: " . $targetFile);
                $debugInfo['target_file'] = $targetFile;
                
                // 检查文件是否可读
                if (!is_readable($tempFile)) {
                    error_log("临时文件不可读: " . $tempFile);
                    echo json_encode([
                        'success' => false,
                        'message' => '无法读取上传的临时文件',
                        'debug' => $debugInfo
                    ]);
                    exit;
                }
                
                // 尝试使用多种方式上传文件
                $uploadSuccess = false;
                $uploadMethod = '';
                $uploadError = '';
                
                // 方法1: 使用move_uploaded_file
                if (move_uploaded_file($tempFile, $targetFile)) {
                    $uploadSuccess = true;
                    $uploadMethod = 'move_uploaded_file';
                    error_log("方法1成功: move_uploaded_file成功");
                } else {
                    $uploadError .= "方法1失败: " . error_get_last()['message'] . "; ";
                    error_log("方法1失败: move_uploaded_file失败");
                    
                    // 方法2: 尝试使用copy函数
                    if (copy($tempFile, $targetFile)) {
                        $uploadSuccess = true;
                        $uploadMethod = 'copy';
                        error_log("方法2成功: copy函数成功");
                    } else {
                        $uploadError .= "方法2失败: " . error_get_last()['message'] . "; ";
                        error_log("方法2失败: copy函数失败");
                        
                        // 方法3: 尝试读取文件内容再写入
                        $content = file_get_contents($tempFile);
                        if ($content !== false && file_put_contents($targetFile, $content)) {
                            $uploadSuccess = true;
                            $uploadMethod = 'file_put_contents';
                            error_log("方法3成功: file_get_contents/file_put_contents成功");
                        } else {
                            $uploadError .= "方法3失败: " . error_get_last()['message'] . "; ";
                            error_log("方法3失败: file_get_contents/file_put_contents失败");
                        }
                    }
                }
                
                $debugInfo['upload_attempt'] = [
                    'success' => $uploadSuccess,
                    'method' => $uploadMethod,
                    'error' => $uploadError
                ];
                
                if ($uploadSuccess) {
                    // 确保上传的文件有正确的权限
                    chmod($targetFile, 0644);
                    error_log("文件上传成功: " . $targetFile);
                    
                    // 返回成功消息和文件URL
                    echo json_encode([
                        'success' => true,
                        'file_url' => '/uploads/video/' . $newFileName,
                        'full_path' => $targetFile,
                        'original_name' => $originalName,
                        'method' => $uploadMethod,
                        'debug' => $debugInfo
                    ]);
                } else {
                    error_log("所有上传方法均失败。PHP错误: " . error_get_last()['message']);
                    echo json_encode([
                        'success' => false,
                        'message' => '文件上传失败，所有上传方法均失败。请检查目录权限或联系管理员',
                        'error' => $uploadError,
                        'debug' => $debugInfo
                    ]);
                }
            } else {
                error_log("不支持的文件格式: " . $extension);
                echo json_encode([
                    'success' => false,
                    'message' => '不支持的文件格式。请上传jpg, jpeg, png, gif或webp格式的图片',
                    'debug' => $debugInfo
                ]);
            }
        } else {
            error_log("文件上传错误码: " . $_FILES['thumbnail_file']['error']);
            $errorMessages = [
                UPLOAD_ERR_INI_SIZE => '文件大小超过了php.ini中upload_max_filesize的限制',
                UPLOAD_ERR_FORM_SIZE => '文件大小超过了表单中MAX_FILE_SIZE的限制',
                UPLOAD_ERR_PARTIAL => '文件只有部分被上传',
                UPLOAD_ERR_NO_FILE => '没有文件被上传',
                UPLOAD_ERR_NO_TMP_DIR => '找不到临时文件夹',
                UPLOAD_ERR_CANT_WRITE => '文件写入失败',
                UPLOAD_ERR_EXTENSION => '文件上传因PHP扩展而停止'
            ];
            $errorMessage = isset($errorMessages[$_FILES['thumbnail_file']['error']]) ? 
                            $errorMessages[$_FILES['thumbnail_file']['error']] : 
                            '未知错误';
            
            echo json_encode([
                'success' => false,
                'message' => '文件上传出错: ' . $errorMessage,
                'error_code' => $_FILES['thumbnail_file']['error'],
                'debug' => $debugInfo
            ]);
        }
    } else {
        error_log("没有收到文件上传");
        echo json_encode([
            'success' => false,
            'message' => '没有收到文件，请确保正确选择了文件',
            'debug' => $debugInfo
        ]);
    }
    exit;
}

// 处理获取现有图片列表请求
if (isset($_POST['action']) && $_POST['action'] === 'get_images') {
    $uploadDir = '../uploads/video/';
    $images = [];
    
    error_log("尝试获取图片列表，目录: " . $uploadDir);
    
    // 确保上传文件夹存在
    if (file_exists($uploadDir)) {
        error_log("上传目录存在");
        // 获取所有图片文件
        $allowedExtensions = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
        $files = scandir($uploadDir);
        
        if ($files === false) {
            error_log("无法扫描目录: " . $uploadDir);
        } else {
            error_log("扫描到文件数: " . count($files));
            foreach ($files as $file) {
                if ($file === '.' || $file === '..') continue;
                
                $extension = strtolower(pathinfo($file, PATHINFO_EXTENSION));
                if (in_array($extension, $allowedExtensions)) {
                    $fullPath = $uploadDir . $file;
                    $fileTime = filemtime($fullPath);
                    $images[] = [
                        'name' => $file,
                        'url' => '/uploads/video/' . $file,
                        'date' => date('Y-m-d H:i:s', $fileTime)
                    ];
                    error_log("找到图片: " . $file . " 修改时间: " . date('Y-m-d H:i:s', $fileTime));
                }
            }
            
            // 按日期排序，最新的在前
            usort($images, function($a, $b) {
                return strtotime($b['date']) - strtotime($a['date']);
            });
        }
    } else {
        error_log("上传目录不存在: " . $uploadDir);
    }
    
    header('Content-Type: application/json');
    echo json_encode([
        'success' => true,
        'images' => $images,
        'directory' => $uploadDir,
        'directory_exists' => file_exists($uploadDir)
    ]);
    exit;
}

try {
    // 获取所有视频分类
    $categoriesSql = "SELECT id, name FROM video_categories WHERE status = 1 ORDER BY sort_order ASC";
    $categoriesStmt = $db->query($categoriesSql);
    $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 处理表单提交
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // 获取表单数据
        $video['title'] = trim($_POST['title'] ?? '');
        $video['description'] = trim($_POST['description'] ?? '');
        $video['category_id'] = (int)($_POST['category_id'] ?? 0);
        $video['video_url'] = trim($_POST['video_url'] ?? '');
        $video['thumbnail'] = trim($_POST['thumbnail'] ?? '');
        $video['duration'] = trim($_POST['duration'] ?? '');
        $video['status'] = isset($_POST['status']) ? 1 : 0;
        $video['featured'] = isset($_POST['featured']) ? 1 : 0;
        
        // 验证必填字段
        $errors = [];
        if (empty($video['title'])) {
            $errors[] = '视频标题不能为空';
        }
        if (empty($video['category_id'])) {
            $errors[] = '请选择视频分类';
        }
        if (empty($video['video_url'])) {
            $errors[] = '视频URL不能为空';
        }
        
        // 如果没有错误,则保存数据
        if (empty($errors)) {
            $insertSql = "INSERT INTO videos (
                title, description, category_id, video_url, thumbnail, 
                duration, status, featured, views, likes, created_at
            ) VALUES (
                :title, :description, :category_id, :video_url, :thumbnail,
                :duration, :status, :featured, 0, 0, NOW()
            )";
            
            $stmt = $db->prepare($insertSql);
            $stmt->bindParam(':title', $video['title']);
            $stmt->bindParam(':description', $video['description']);
            $stmt->bindParam(':category_id', $video['category_id'], PDO::PARAM_INT);
            $stmt->bindParam(':video_url', $video['video_url']);
            $stmt->bindParam(':thumbnail', $video['thumbnail']);
            $stmt->bindParam(':duration', $video['duration']);
            $stmt->bindParam(':status', $video['status'], PDO::PARAM_INT);
            $stmt->bindParam(':featured', $video['featured'], PDO::PARAM_INT);
            
            if ($stmt->execute()) {
                $videoId = $db->lastInsertId();
                $statusMessage = '视频添加成功!';
                $statusClass = 'alert-success';
                
                // 重定向到视频列表页面或编辑页面
                header("Location: video_list.php?status=added");
                exit;
            } else {
                $errorMessage = '保存视频时出错,请重试';
            }
        } else {
            $errorMessage = implode('<br>', $errors);
        }
    }
} catch (PDOException $e) {
    // 记录错误日志
    error_log($e->getMessage());
    $errorMessage = '数据库操作出错,请稍后再试或联系管理员';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>添加视频 - 后台管理系统</title>
        <!-- 使用CDN引用替代本地文件 -->
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
        <link href="https://fonts.googleapis.com/css2?family=Nunito:wght@300;400;600;700&display=swap" rel="stylesheet">
        <link rel="stylesheet" href="public/css/style.css">
        <style>
        /* 美化视频添加页面样式 */
        body {
            background-color: #f8f9fc;
            color: #333;
            font-family: 'Nunito', sans-serif;
        }

        .main-content {
            padding-top: 20px;
            padding-bottom: 40px;
        }

        .page-header {
            color: white;
            border-radius: 10px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding-top: 50px
        }

        .page-title {
            margin: 0;
            font-weight: 700;
            font-size: 1.5rem;
            display: flex;
            align-items: center;
        }

        .page-title i {
            margin-right: 12px;
            font-size: 1.8rem;
            background: rgba(255, 255, 255, 0.2);
            padding: 10px;
            border-radius: 8px;
        }

        .page-actions {
            display: flex;
            gap: 10px;
        }

        .page-actions .btn {
            border-radius: 6px;
            padding: 8px 16px;
            font-weight: 600;
            transition: all 0.2s;
        }

        .form-section {
            margin-bottom: 30px;
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.05);
            padding: 25px;
            transition: transform 0.2s, box-shadow 0.2s;
            border: 1px solid rgba(0, 0, 0, 0.05);
            overflow: hidden;
        }

        .form-section:hover {
            transform: translateY(-3px);
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.08);
        }

        .section-title {
            margin: -25px -25px 25px -25px;
            padding: 15px 25px;
            background: linear-gradient(to right, #f8f9fa, #fff);
            border-bottom: 1px solid rgba(0, 0, 0, 0.05);
            font-weight: 700;
            color: #3a3b45;
            font-size: 1.1rem;
            display: flex;
            align-items: center;
        }

        .section-title i {
            margin-right: 10px;
            color: #4e73df;
            font-size: 1.2rem;
        }

        .field-group {
            margin-bottom: 25px;
            position: relative;
        }

        .field-group label {
            font-weight: 600;
            color: #495057;
            margin-bottom: 8px;
            display: block;
            font-size: 0.95rem;
        }

        .form-control {
            width: 100%;
            border-radius: 6px;
            border: 1px solid #e2e8f0;
            padding: 12px 15px;
            transition: all 0.2s;
            font-size: 0.95rem;
            background-color: #f9fafc;
        }

        .form-control:focus {
            box-shadow: 0 0 0 0.2rem rgba(78, 115, 223, 0.15);
            border-color: #4e73df;
            background-color: #fff;
        }

        .form-control.is-invalid {
            border-color: #e74a3b;
            background-image: none;
        }

        .form-control.is-invalid:focus {
            box-shadow: 0 0 0 0.2rem rgba(231, 74, 59, 0.15);
        }

        .required-label::after {
            content: " *";
            color: #e74a3b;
            font-weight: bold;
        }

        .form-text {
            font-size: 0.85rem;
            color: #6c757d;
            margin-top: 5px;
        }

        .form-check {
            padding-left: 30px;
            margin-top: 10px;
        }

        .form-check-input {
            margin-left: -30px;
            width: 20px;
            height: 20px;
            margin-top: 0;
            vertical-align: middle;
        }

        .form-check-label {
            font-weight: normal;
            padding-left: 5px;
            font-size: 0.95rem;
            color: #495057;
        }

        .preview-image {
            max-width: 100%;
            max-height: 180px;
            margin-top: 15px;
            border-radius: 6px;
            box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
            display: none;
            transition: all 0.3s;
        }

        .preview-container {
            margin-top: 15px;
            text-align: center;
        }

        .btn-form-submit {
            background: linear-gradient(135deg, #4e73df 0%, #224abe 100%);
            border: none;
            color: white;
            padding: 12px 25px;
            font-weight: 600;
            min-width: 150px;
            border-radius: 6px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
            transition: all 0.3s;
        }

        .btn-form-submit:hover {
            box-shadow: 0 6px 15px rgba(0, 0, 0, 0.2);
            transform: translateY(-2px);
        }

        .form-actions {
            padding-top: 25px;
            margin-top: 30px;
            border-top: 1px solid rgba(0, 0, 0, 0.05);
            display: flex;
            justify-content: flex-end;
            gap: 15px;
        }

        .description-field {
            min-height: 150px;
            resize: vertical;
        }

        /* 美化下拉选择框 */
        select.form-control {
            background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' fill='%234a5568'%3E%3Cpath d='M7 10l5 5 5-5z'/%3E%3C/svg%3E");
            background-repeat: no-repeat;
            background-position: right 10px center;
            background-size: 20px;
            -webkit-appearance: none;
            -moz-appearance: none;
            appearance: none;
            padding-right: 30px;
        }

        /* 美化警告框 */
        .alert {
            border-radius: 8px;
            padding: 15px 20px;
            margin-bottom: 25px;
            border: none;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.05);
            font-weight: 500;
        }

        .alert-success {
            background-color: #eefbf5;
            color: #2e7d5b;
        }

        .alert-danger {
            background-color: #feefef;
            color: #d84242;
        }

        /* 美化按钮组 */
        .btn-secondary {
            background-color: #eaecf2;
            border: none;
            color: #434a58;
            font-weight: 600;
            padding: 12px 20px;
            border-radius: 6px;
            transition: all 0.2s;
        }

        .btn-secondary:hover {
            background-color: #d8dbe5;
            color: #434a58;
        }

        /* 动画效果 */
        @keyframes fadeIn {
            from {
                opacity: 0;
                transform: translateY(20px);
            }

            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .form-section {
            animation: fadeIn 0.5s ease forwards;
        }

        .form-section:nth-child(2) {
            animation-delay: 0.1s;
        }

        /* 自定义切换开关 */
        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 50px;
            height: 24px;
            margin: 0;
        }

        .toggle-switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }

        .toggle-slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #ccc;
            transition: .4s;
            border-radius: 24px;
        }

        .toggle-slider:before {
            position: absolute;
            content: "";
            height: 18px;
            width: 18px;
            left: 3px;
            bottom: 3px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }

        input:checked+.toggle-slider {
            background-color: #4e73df;
        }

        input:checked+.toggle-slider:before {
            transform: translateX(26px);
        }

        .toggle-label {
            margin-left: 10px;
            font-weight: normal;
            vertical-align: middle;
        }

        /* 美化输入组，确保按钮与输入框对齐 */
        .input-group {
            display: flex;
            width: 100%;
        }

        /* 响应式调整 */
        @media (max-width: 768px) {
            .page-header {
                flex-direction: column;
                align-items: flex-start;
                gap: 15px;
            }

            .page-actions {
                width: 100%;
                justify-content: space-between;
            }
        }

        </style>
    </head>
    <body>
        <?php include 'public/letf.php'; ?>
        <div class="main-content">
            <div class="container-fluid pt-4">
                <?php if (!empty($statusMessage)): ?>
                <div class="alert <?php echo $statusClass; ?> alert-dismissible fade show" role="alert">
                    <i class="fas fa-check-circle mr-2"></i> <?php echo $statusMessage; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <?php endif; ?>
                <?php if (!empty($errorMessage)): ?>
                <div class="alert alert-danger alert-dismissible fade show" role="alert">
                    <i class="fas fa-exclamation-circle mr-2"></i> <?php echo $errorMessage; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <?php endif; ?>
                <!-- 页面标题 -->
                <div class="page-header">
                    <h4 class="page-title">
                        <i class="fas fa-video"></i>
                        添加新视频
                    </h4>
                    <div class="page-actions">
                        <a href="video_list.php" class="btn btn-back">
                            <i class="fas fa-arrow-left mr-1"></i> 返回视频列表
                        </a>
                    </div>
                </div>
                <form method="post" id="videoForm">
                    <!-- 基本信息 -->
                    <div class="form-section">
                        <h6 class="section-title"><i class="fas fa-info-circle"></i> 视频信息</h6>
                        <div class="row">
                            <div class="col-lg-12">
                                <div class="field-group">
                                    <label for="video_url" class="required-label">视频URL <i class="fas fa-link"></i></label>
                                    <input type="text" class="form-control" id="video_url" name="video_url" value="<?php echo htmlspecialchars($video['video_url']); ?>" required placeholder="请输入地址">
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-8">
                                <div class="field-group">
                                    <label for="title" class="required-label">视频标题</label>
                                    <input type="text" class="form-control" id="title" name="title" value="<?php echo htmlspecialchars($video['title']); ?>" required placeholder="请输入视频标题...">
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="field-group">
                                    <label for="category_id" class="required-label">所属分类</label>
                                    <select class="form-control" id="category_id" name="category_id" required>
                                        <option value="">-- 请选择分类 --</option>
                                        <?php foreach ($categories as $category): ?>
                                        <option value="<?php echo $category['id']; ?>" <?php echo ($video['category_id'] == $category['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($category['name']); ?>
                                        </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="field-group">
                            <label for="description">视频描述</label>
                            <textarea class="form-control description-field" id="description" name="description" rows="5" placeholder="请输入视频描述内容..."><?php echo htmlspecialchars($video['description']); ?></textarea>
                        </div>
                    </div>
                    <!-- 媒体信息 -->
                    <div class="form-section">
                        <h6 class="section-title"><i class="fas fa-film"></i> 媒体信息</h6>
                        <div class="row">
                            <div class="col-md-8">
                                <div class="field-group">
                                    <label for="thumbnail">缩略图URL</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <span class="input-group-text"><i class="fas fa-image"></i></span>
                                        </div>
                                        <input type="text" class="form-control" id="thumbnail" name="thumbnail" value="<?php echo htmlspecialchars($video['thumbnail']); ?>" placeholder="https://...">
                                        <div class="input-group-append">
                                            <button type="button" class="btn btn-outline-primary" id="uploadBtn">
                                                <i class="fas fa-upload"></i> 上传
                                            </button>
                                            <button type="button" class="btn btn-outline-secondary" id="browseBtn">
                                                <i class="fas fa-folder-open"></i> 浏览
                                            </button>
                                        </div>
                                    </div>
                                    <div class="preview-container mt-3">
                                        <img id="thumbnailPreview" src="<?php echo !empty($video['thumbnail']) ? htmlspecialchars($video['thumbnail']) : ''; ?>" class="preview-image" <?php echo !empty($video['thumbnail']) ? 'style="display: block;"' : ''; ?>>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="field-group">
                                    <label for="duration">视频时长</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <span class="input-group-text"><i class="fas fa-clock"></i></span>
                                        </div>
                                        <input type="text" class="form-control" id="duration" name="duration" value="<?php echo htmlspecialchars($video['duration']); ?>" placeholder="10:30">
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6">
                                <div class="field-group">
                                    <label>发布状态</label>
                                    <div class="d-flex align-items-center mt-2">
                                        <label class="toggle-switch">
                                            <input type="checkbox" id="status" name="status" <?php echo ($video['status'] == 1) ? 'checked' : ''; ?>>
                                            <span class="toggle-slider"></span>
                                        </label>
                                        <span class="toggle-label" id="statusLabel">立即发布</span>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="field-group">
                                    <label>推荐设置</label>
                                    <div class="d-flex align-items-center mt-2">
                                        <label class="toggle-switch">
                                            <input type="checkbox" id="featured" name="featured" <?php echo ($video['featured'] == 1) ? 'checked' : ''; ?>>
                                            <span class="toggle-slider"></span>
                                        </label>
                                        <span class="toggle-label">设为推荐视频</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- 提交按钮 -->
                    <div class="form-actions">
                        <a href="video_list.php" class="btn btn-secondary">
                            <i class="fas fa-times mr-1"></i> 取消
                        </a>
                        <button type="submit" class="btn btn-primary btn-form-submit">
                            <i class="fas fa-save mr-1"></i> 保存视频
                        </button>
                    </div>
                </form>
            </div>
        </div>
        <!-- JavaScript 脚本 -->
        <!-- 使用CDN资源代替本地可能缺失的资源 -->
        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/js/all.min.js"></script>
        <script>
        $(document).ready(function() {
            // 缩略图预览功能
            $('#thumbnail').on('input change', function() {
                var thumbnailUrl = $(this).val();
                if (thumbnailUrl) {
                    $('#thumbnailPreview').attr('src', thumbnailUrl).fadeIn(300);
                } else {
                    $('#thumbnailPreview').fadeOut(300);
                }
            });

            // 初始化缩略图预览
            if ($('#thumbnail').val()) {
                $('#thumbnailPreview').attr('src', $('#thumbnail').val()).show();
            }

            // 状态开关标签动态更新
            $('#status').change(function() {
                if ($(this).is(':checked')) {
                    $('#statusLabel').text('立即发布');
                } else {
                    $('#statusLabel').text('保存为草稿');
                }
            });

            // 初始化状态标签
            if ($('#status').is(':checked')) {
                $('#statusLabel').text('立即发布');
            } else {
                $('#statusLabel').text('保存为草稿');
            }

            // 上传按钮点击事件
            $('#uploadBtn').click(function() {
                // 重置上传表单和预览
                $('#uploadForm')[0].reset();
                $('.upload-preview').hide();
                $('.progress').hide();
                $('.progress-bar').css('width', '0%').attr('aria-valuenow', 0);
                $('#uploadError').remove();
                $('#uploadDebugInfo pre').empty();
                $('#uploadDebugInfo').hide();

                $('#uploadModal').modal('show');
            });

            // 浏览按钮点击事件
            $('#browseBtn').click(function() {
                $('#browseModal').modal('show');
                loadImages();
            });

            // 上传预览
            $('#thumbnailFile').change(function() {
                $('#uploadError').remove();
                if (this.files && this.files[0]) {
                    var reader = new FileReader();
                    reader.onload = function(e) {
                        $('#uploadPreview').attr('src', e.target.result);
                        $('.upload-preview').show();
                        $('.file-name-display').text(
                            '文件名: ' + $('#thumbnailFile')[0].files[0].name +
                            ' (' + formatFileSize($('#thumbnailFile')[0].files[0].size) + ')'
                        );
                    }
                    reader.readAsDataURL(this.files[0]);
                }
            });

            // 拖放上传功能
            $('.upload-area').on('dragover', function(e) {
                e.preventDefault();
                e.stopPropagation();
                $(this).addClass('border-primary');
            });

            $('.upload-area').on('dragleave', function(e) {
                e.preventDefault();
                e.stopPropagation();
                $(this).removeClass('border-primary');
            });

            $('.upload-area').on('drop', function(e) {
                e.preventDefault();
                e.stopPropagation();
                $(this).removeClass('border-primary');

                if (e.originalEvent.dataTransfer.files.length > 0) {
                    $('#thumbnailFile')[0].files = e.originalEvent.dataTransfer.files;
                    $('#thumbnailFile').trigger('change');

                    // 更新文件名显示
                    var fileName = e.originalEvent.dataTransfer.files[0].name;
                    $('.custom-file-label').text(fileName);
                }
            });

            // 点击上传区域触发文件选择
            $('.upload-area').on('click', function(e) {
                if (!$(e.target).hasClass('custom-file-input')) {
                    $('#thumbnailFile').click();
                }
            });

            // 格式化文件大小
            function formatFileSize(bytes) {
                if (bytes === 0) return '0 Bytes';
                var k = 1024,
                    sizes = ['Bytes', 'KB', 'MB', 'GB'],
                    i = Math.floor(Math.log(bytes) / Math.log(k));
                return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
            }

            // 显示/隐藏调试信息
            $('#toggleDebug').click(function() {
                $('#uploadDebugInfo').toggle();
            });

            // 开始上传
            $('#startUpload').click(function() {
                $('#uploadError').remove();
                $('#uploadDebugInfo pre').empty();
                var fileInput = $('#thumbnailFile')[0];

                if (fileInput.files.length === 0) {
                    $('.modal-body').prepend('<div id="uploadError" class="alert alert-danger">请选择要上传的图片</div>');
                    return;
                }

                // 检查文件大小 (5MB 限制)
                var maxSize = 5 * 1024 * 1024; // 5MB
                if (fileInput.files[0].size > maxSize) {
                    $('.modal-body').prepend('<div id="uploadError" class="alert alert-danger">文件大小超过5MB限制</div>');
                    return;
                }

                var formData = new FormData();
                formData.append('thumbnail_file', fileInput.files[0]);
                formData.append('action', 'upload_thumbnail');

                // 禁用上传按钮
                $('#startUpload').prop('disabled', true).html('<i class="fas fa-spinner fa-spin"></i> 上传中...');

                // 清除任何之前的错误消息
                $('.modal-body').find('.alert').remove();

                // 显示进度条
                $('.progress').show();
                $('.progress-bar').css('width', '0%').attr('aria-valuenow', 0).text('0%');

                $.ajax({
                    url: 'video_add.php',
                    type: 'POST',
                    data: formData,
                    processData: false,
                    contentType: false,
                    xhr: function() {
                        var xhr = new window.XMLHttpRequest();
                        xhr.upload.addEventListener('progress', function(e) {
                            if (e.lengthComputable) {
                                var percent = Math.round((e.loaded / e.total) * 100);
                                $('.progress-bar').css('width', percent + '%').attr('aria-valuenow', percent).text(percent + '%');
                            }
                        }, false);
                        return xhr;
                    },
                    success: function(response) {
                        try {
                            // 确保响应是一个JSON对象
                            if (typeof response === 'string') {
                                try {
                                    response = JSON.parse(response);
                                } catch (e) {
                                    // 如果无法解析为JSON，可能是PHP错误
                                    $('#uploadDebugInfo pre').html("非JSON响应:\n" + response);
                                    $('#uploadDebugInfo').show();
                                    throw new Error('服务器返回的不是有效的JSON格式');
                                }
                            }

                            console.log('上传响应:', response);

                            // 添加到调试信息
                            $('#uploadDebugInfo pre').text(JSON.stringify(response, null, 2));

                            if (response.success) {
                                // 更新缩略图URL输入框和预览
                                $('#thumbnail').val(response.file_url);
                                $('#thumbnailPreview').attr('src', response.file_url).show();

                                // 关闭模态框
                                $('#uploadModal').modal('hide');

                                // 显示成功消息
                                $('.container-fluid').prepend(
                                    '<div class="alert alert-success alert-dismissible fade show" role="alert">' +
                                    '<i class="fas fa-check-circle mr-2"></i> 图片上传成功' +
                                    '<button type="button" class="close" data-dismiss="alert" aria-label="Close">' +
                                    '<span aria-hidden="true">&times;</span></button></div>'
                                );
                            } else {
                                // 显示错误消息
                                $('.modal-body').prepend(
                                    '<div id="uploadError" class="alert alert-danger">' +
                                    '<i class="fas fa-exclamation-circle mr-2"></i> ' +
                                    (response.message || '上传失败，请重试') +
                                    (response.error ? '<br><small class="d-block mt-2">' + response.error + '</small>' : '') +
                                    '</div>'
                                );

                                // 显示调试区域
                                $('#uploadDebugInfo').show();
                            }
                        } catch (e) {
                            console.error('解析响应时出错:', e);
                            $('.modal-body').prepend(
                                '<div id="uploadError" class="alert alert-danger">' +
                                '<i class="fas fa-exclamation-circle mr-2"></i> 解析服务器响应时出错: ' + e.message +
                                '</div>'
                            );
                            $('#uploadDebugInfo').show();
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('上传错误:', status, error);

                        // 检查是否有响应文本
                        var responseText = xhr.responseText || '没有响应数据';

                        $('.modal-body').prepend(
                            '<div id="uploadError" class="alert alert-danger">' +
                            '<i class="fas fa-exclamation-circle mr-2"></i> 上传过程中发生错误，请重试' +
                            '<br><small class="d-block mt-2">错误: ' + error + '</small>' +
                            '</div>'
                        );

                        // 添加到调试信息
                        $('#uploadDebugInfo pre').html('状态: ' + status + '\n错误: ' + error + '\n响应:\n' + responseText);
                        $('#uploadDebugInfo').show();
                    },
                    complete: function() {
                        // 重置上传按钮和进度条
                        $('#startUpload').prop('disabled', false).html('<i class="fas fa-upload mr-1"></i>上传');
                        $('.progress').hide();
                    }
                });
            });

            // 加载图片库
            function loadImages() {
                $('#galleryError').remove();
                $('#imageGallery').html(
                    '<div class="text-center w-100 py-5">' +
                    '<div class="spinner-border text-primary" role="status">' +
                    '<span class="sr-only">正在加载...</span></div>' +
                    '<p class="mt-2">正在加载图片...</p></div>'
                );

                $.ajax({
                    url: 'video_add.php',
                    type: 'POST',
                    data: {
                        action: 'get_images'
                    },
                    dataType: 'json',
                    success: function(response) {
                        console.log('浏览响应:', response);

                        var gallery = $('#imageGallery');
                        gallery.empty();

                        if (response.success) {
                            if (response.images.length === 0) {
                                gallery.html(
                                    '<div class="col-12 text-center py-5">' +
                                    '<p>没有找到图片，请先上传。</p>' +
                                    '<p><small class="text-muted">目录: ' + response.directory + '</small></p>' +
                                    '<p><small class="text-muted">目录是否存在: ' + (response.directory_exists ? '是' : '否') + '</small></p>' +
                                    '</div>'
                                );
                                return;
                            }

                            $.each(response.images, function(i, image) {
                                var card = $(
                                    '<div class="col-md-4 mb-4">' +
                                    '<div class="card h-100">' +
                                    '<div class="card-img-container" style="height: 160px; overflow: hidden; display: flex; align-items: center; justify-content: center;">' +
                                    '<img src="' + image.url + '" class="card-img-top" style="object-fit: contain; max-height: 160px; max-width: 100%;">' +
                                    '</div>' +
                                    '<div class="card-body">' +
                                    '<h6 class="card-title text-truncate">' + image.name + '</h6>' +
                                    '<p class="card-text small text-muted">' + image.date + '</p>' +
                                    '<button type="button" class="btn btn-sm btn-primary select-image" data-url="' + image.url + '">选择</button>' +
                                    '</div></div></div>'
                                );
                                gallery.append(card);
                            });

                            // 图片选择事件
                            $('.select-image').click(function() {
                                var imageUrl = $(this).data('url');
                                $('#thumbnail').val(imageUrl);
                                $('#thumbnailPreview').attr('src', imageUrl).show();
                                $('#browseModal').modal('hide');
                            });
                        } else {
                            gallery.html(
                                '<div class="col-12 text-center py-5">' +
                                '<p>加载图片失败，请重试。</p>' +
                                '</div>'
                            );
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('加载图片错误:', status, error);
                        $('#imageGallery').html(
                            '<div class="col-12 text-center py-5">' +
                            '<p>加载图片失败，请重试。</p>' +
                            '</div>'
                        );
                    }
                });
            }

            // 表单验证
            $('#videoForm').submit(function(e) {
                var isValid = true;
                var title = $('#title').val().trim();
                var categoryId = $('#category_id').val();
                var videoUrl = $('#video_url').val().trim();

                // 重置错误提示
                $('.is-invalid').removeClass('is-invalid');

                // 验证标题
                if (!title) {
                    $('#title').addClass('is-invalid').after('<div class="invalid-feedback">请输入视频标题</div>');
                    isValid = false;
                }

                // 验证分类
                if (!categoryId) {
                    $('#category_id').addClass('is-invalid').after('<div class="invalid-feedback">请选择视频分类</div>');
                    isValid = false;
                }

                // 验证视频URL
                if (!videoUrl) {
                    $('#video_url').addClass('is-invalid').after('<div class="invalid-feedback">请输入视频URL</div>');
                    isValid = false;
                }

                // 如果有错误，滚动到第一个错误字段
                if (!isValid) {
                    $('html, body').animate({
                        scrollTop: $('.is-invalid:first').offset().top - 100
                    }, 500);
                    e.preventDefault();
                    return false;
                }

                return isValid;
            });

            // 表单字段焦点效果
            $('.form-control').focus(function() {
                $(this).closest('.field-group').addClass('focused');
            }).blur(function() {
                $(this).closest('.field-group').removeClass('focused');
            });

            // 工具提示初始化
            $('[data-toggle="tooltip"]').tooltip();

            // 刷新图片列表按钮
            $('#refreshImages').click(function() {
                loadImages();
            });

            // 自定义文件输入显示选中的文件名
            $('.custom-file-input').on('change', function() {
                var fileName = $(this).val().split('\\').pop();
                $(this).next('.custom-file-label').html(fileName || '选择文件...');
            });
        });
        </script>
        <!-- 图片上传模态框 -->
        <div class="modal fade" id="uploadModal" tabindex="-1" role="dialog" aria-labelledby="uploadModalLabel" aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="uploadModalLabel"><i class="fas fa-upload mr-2"></i>上传缩略图</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <form id="uploadForm" enctype="multipart/form-data">
                            <div class="form-group">
                                <label for="thumbnailFile">选择图片文件</label>
                                <div class="upload-area p-4 text-center border rounded"
                                     style="background-color: #f8f9fa; border-style: dashed !important; cursor: pointer;">
                                    <i class="fas fa-cloud-upload-alt fa-3x text-primary mb-3"></i>
                                    <p class="mb-2">点击此处选择文件或直接拖放文件</p>
                                    <div class="custom-file" style="width: 80%; margin: 0 auto;">
                                        <input type="file" class="custom-file-input" id="thumbnailFile" name="thumbnail_file" accept="image/*" style="cursor: pointer;">
                                        <label class="custom-file-label text-left" for="thumbnailFile">选择文件...</label>
                                    </div>
                                    <small class="form-text text-muted mt-2">
                                        <i class="fas fa-info-circle"></i> 支持JPG、PNG、GIF、WEBP格式，最大5MB
                                    </small>
                                </div>
                            </div>
                            <div class="upload-preview mt-3 text-center" style="display: none;">
                                <img id="uploadPreview" class="img-fluid rounded" style="max-height: 200px; max-width: 100%; box-shadow: 0 3px 10px rgba(0,0,0,0.1);">
                                <p class="mt-2 mb-0 text-muted small file-name-display"></p>
                            </div>
                        </form>
                        <div class="progress mt-3" style="display: none; height: 20px;">
                            <div class="progress-bar progress-bar-striped progress-bar-animated" role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" style="width: 0%">0%</div>
                        </div>
                        <div class="mt-3 small text-muted">
                            <p><strong>上传路径:</strong> /uploads/video/</p>
                            <p><i class="fas fa-exclamation-triangle text-warning"></i> 如果上传失败，可能是因为缺少目录权限</p>
                            <div id="uploadDebugInfo" class="mt-2" style="display: none;">
                                <p class="mb-1"><strong>调试信息:</strong></p>
                                <pre class="p-2 bg-light" style="font-size: 0.8rem; max-height: 100px; overflow: auto;"></pre>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-light" id="toggleDebug">
                            <i class="fas fa-bug mr-1"></i>调试
                        </button>
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">
                            <i class="fas fa-times mr-1"></i>取消
                        </button>
                        <button type="button" class="btn btn-primary" id="startUpload">
                            <i class="fas fa-upload mr-1"></i>上传
                        </button>
                    </div>
                </div>
            </div>
        </div>
        <!-- 图片浏览模态框 -->
        <div class="modal fade" id="browseModal" tabindex="-1" role="dialog" aria-labelledby="browseModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-lg" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="browseModalLabel"><i class="fas fa-folder-open mr-2"></i>浏览图片</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <div class="mb-3 d-flex justify-content-between align-items-center">
                            <div class="text-muted small">
                                <p class="mb-0"><i class="fas fa-info-circle"></i> 从 /uploads/video/ 目录中选择已上传的图片</p>
                            </div>
                            <button id="refreshImages" class="btn btn-sm btn-outline-secondary">
                                <i class="fas fa-sync-alt mr-1"></i> 刷新列表
                            </button>
                        </div>
                        <div class="row" id="imageGallery">
                            <div class="text-center w-100 py-5">
                                <div class="spinner-border text-primary" role="status">
                                    <span class="sr-only">正在加载...</span>
                                </div>
                                <p class="mt-2">正在加载图片...</p>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal"><i class="fas fa-times mr-1"></i>关闭</button>
                    </div>
                </div>
            </div>
        </div>
    </body>
</html>
