<?php
// 引入必要的配置文件和函数库
require_once 'code/auth_check.php';
include 'public/header.php';
require_once '../config/database.php'; // 直接引入数据库配置文件

// 原始的包含语句
// include 'header.php';
// include '../common/functions.php';

// 检查用户权限
// checkPermission();

// 获取数据库连接函数
// function getDbConnection() {
//     require_once '../config/database.php';
//     return $GLOBALS['db'] ?? null;
// }

// 处理表单提交 - 添加或更新分类
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $db = getDbConnection();

        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $name = trim($_POST['name']);
        $description = trim($_POST['description']);
        $parent_id = intval($_POST['parent_id']);
        $icon = trim($_POST['icon']);
        $sort_order = intval($_POST['sort_order']);
        $status = intval($_POST['status']);

        // 数据验证
        if (empty($name)) {
            throw new Exception('分类名称不能为空');
        }

        $now = date('Y-m-d H:i:s');

        if ($id > 0) {
            // 更新现有分类
            $sql = "UPDATE video_categories SET 
                    name = ?, 
                    description = ?, 
                    parent_id = ?, 
                    icon = ?, 
                    sort_order = ?, 
                    status = ?, 
                    updated_at = ? 
                    WHERE id = ?";
            $stmt = $db->prepare($sql);
            $stmt->execute([$name, $description, $parent_id, $icon, $sort_order, $status, $now, $id]);
            $message = '分类更新成功！';
        } else {
            // 添加新分类
            $sql = "INSERT INTO video_categories (name, description, parent_id, icon, sort_order, status, created_at) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)";
            $stmt = $db->prepare($sql);
            $stmt->execute([$name, $description, $parent_id, $icon, $sort_order, $status, $now]);
            $message = '分类添加成功！';
        }

        // 重定向以防止刷新页面时重复提交
        header("Location: video_category.php?message=" . urlencode($message));
        exit;

    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 处理删除请求
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    try {
        $db = getDbConnection();
        $id = intval($_GET['id']);

        // 检查是否有视频使用该分类
        $checkVideoSql = "SELECT COUNT(*) FROM videos WHERE category_id = ?";
        $checkVideoStmt = $db->prepare($checkVideoSql);
        $checkVideoStmt->execute([$id]);
        $videoCount = $checkVideoStmt->fetchColumn();

        if ($videoCount > 0) {
            throw new Exception("无法删除此分类，因为有 {$videoCount} 个视频正在使用该分类。");
        }

        // 检查是否有子分类
        $checkChildSql = "SELECT COUNT(*) FROM video_categories WHERE parent_id = ?";
        $checkChildStmt = $db->prepare($checkChildSql);
        $checkChildStmt->execute([$id]);
        $childCount = $checkChildStmt->fetchColumn();

        if ($childCount > 0) {
            throw new Exception("无法删除此分类，因为它有 {$childCount} 个子分类。");
        }

        // 删除分类
        $deleteSql = "DELETE FROM video_categories WHERE id = ?";
        $deleteStmt = $db->prepare($deleteSql);
        $deleteStmt->execute([$id]);

        $message = '分类删除成功！';
        header("Location: video_category.php?message=" . urlencode($message));
        exit;

    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 获取要编辑的分类
$editCategory = null;
if (isset($_GET['action']) && $_GET['action'] === 'edit' && isset($_GET['id'])) {
    try {
        $db = getDbConnection();
        $id = intval($_GET['id']);

        $editSql = "SELECT * FROM video_categories WHERE id = ?";
        $editStmt = $db->prepare($editSql);
        $editStmt->execute([$id]);
        $editCategory = $editStmt->fetch(PDO::FETCH_ASSOC);

        if (!$editCategory) {
            throw new Exception('未找到指定的分类');
        }
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 显示分类名称和图标的安全显示函数
function safeHtmlDisplay($value) {
    return htmlspecialchars($value ?? '', ENT_QUOTES, 'UTF-8');
}

// 获取所有分类数据
try {
    $db = getDbConnection();
    $categoriesSql = "SELECT c.*, 
                      (SELECT COUNT(*) FROM videos WHERE category_id = c.id) as video_count,
                      p.name as parent_name
                      FROM video_categories c
                      LEFT JOIN video_categories p ON c.parent_id = p.id
                      ORDER BY c.parent_id ASC, c.sort_order ASC";
    $categoriesStmt = $db->query($categoriesSql);
    $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);

    // 重新组织分类数据，支持分级显示
    $categoriesTree = [];
    $categoryOptions = [];
    
    // 先找出所有顶级分类
    foreach ($categories as $category) {
        if ($category['parent_id'] == 0) {
            $categoriesTree[$category['id']] = $category;
            $categoriesTree[$category['id']]['children'] = [];
            $categoryOptions[$category['id']] = $category['name'];
        }
    }
    
    // 再找出所有子分类
    foreach ($categories as $category) {
        if ($category['parent_id'] > 0 && isset($categoriesTree[$category['parent_id']])) {
            $categoriesTree[$category['parent_id']]['children'][$category['id']] = $category;
            $categoryOptions[$category['id']] = '-- ' . $category['name'];
        }
    }

} catch (Exception $e) {
    $error = $e->getMessage();
    $categories = [];
    $categoriesTree = [];
    $categoryOptions = [];
}

// 获取消息提示
$message = isset($_GET['message']) ? $_GET['message'] : '';
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>视频分类管理 - 后台管理系统</title>
        <!-- 引入样式文件 -->
        <link rel="stylesheet" href="public/css/style.css">
        <link href="/cn/public/css/style.css" rel="stylesheet" />
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
        <style>
        body {
            background-color: #f5f7fa;
            color: #333;
            font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
        }

        .main-content {
            padding: 25px;
            width: 100%;
            max-width: 100%;
        }

        .container-fluid {
            width: 100%;
            padding-right: 0;
            padding-left: 0;
        }

        .category-icon {
            width: 36px;
            height: 36px;
            text-align: center;
            line-height: 36px;
            border-radius: 8px;
            background-color: #e8f0fe;
            color: #4285f4;
            display: inline-block;
            margin-right: 12px;
            font-size: 18px;
            transition: all 0.3s;
        }

        .category-icon:hover {
            transform: scale(1.1);
            background-color: #d2e3fc;
        }

        .child-category {
            position: relative;
            background-color: #f9fafb;
            transition: background-color 0.2s;
        }

        .child-category:hover {
            background-color: #f0f4f8;
        }

        .child-category:before {
            content: '';
            position: absolute;
            left: 20px;
            top: 0;
            height: 100%;
            width: 2px;
            background-color: #e1e6ef;
        }

        .child-category td:nth-child(2) {
            padding-left: 35px;
        }

        .panel-default {
            border-radius: 12px;
            box-shadow: 0 5px 20px rgba(0, 0, 0, 0.05);
            border: none;
            background-color: #fff;
            overflow: hidden;
            transition: box-shadow 0.3s;
            margin-bottom: 30px;
        }

        .panel-default:hover {
            box-shadow: 0 8px 25px rgba(0, 0, 0, 0.08);
        }

        .panel-heading {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 20px 25px;
            background-color: #fff;
            border-bottom: 1px solid #edf2f9;
            border-top-left-radius: 12px;
            border-top-right-radius: 12px;
        }

        .panel-title {
            font-size: 18px;
            font-weight: 600;
            color: #3c4858;
            margin: 0;
            position: relative;
            padding-left: 15px;
        }

        .panel-title:before {
            content: '';
            position: absolute;
            left: 0;
            top: 50%;
            transform: translateY(-50%);
            width: 4px;
            height: 18px;
            background-color: #4285f4;
            border-radius: 2px;
        }

        .table {
            margin-bottom: 0;
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
        }

        .table>thead>tr>th {
            background-color: #f8fafd;
            border-bottom: 1px solid #edf2f9;
            color: #5e6e82;
            font-weight: 600;
            padding: 15px 20px;
            font-size: 14px;
            text-transform: uppercase;
            letter-spacing: 0.5px;
        }

        .table>tbody>tr {
            transition: all 0.2s;
        }

        .table>tbody>tr:hover {
            background-color: #f8fafd;
        }

        .table>tbody>tr>td {
            padding: 18px 20px;
            vertical-align: middle;
            border-top: 1px solid #edf2f9;
            color: #5e6e82;
            font-size: 14px;
        }

        .badge {
            padding: 6px 12px;
            font-weight: 500;
            border-radius: 30px;
            font-size: 12px;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            min-width: 80px;
            text-align: center;
        }

        .badge i {
            margin-right: 5px;
        }

        .bg-success {
            background-color: #00d97e;
            box-shadow: 0 4px 12px rgba(0, 217, 126, 0.2);
        }

        .bg-secondary {
            background-color: #748194;
            box-shadow: 0 4px 12px rgba(116, 129, 148, 0.2);
        }

        .bg-info {
            background-color: #4285f4;
            box-shadow: 0 4px 12px rgba(66, 133, 244, 0.2);
        }

        .text-white {
            color: #fff;
        }

        .btn {
            border-radius: 8px;
            font-weight: 500;
            padding: 8px 16px;
            transition: all 0.3s;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            letter-spacing: 0.3px;
        }

        .btn i {
            margin-right: 6px;
        }

        .btn:hover {
            transform: translateY(-2px);
        }

        .btn-sm {
            padding: 6px 12px;
            font-size: 13px;
        }

        .btn-primary {
            background-color: #4285f4;
            border-color: #4285f4;
            box-shadow: 0 4px 10px rgba(66, 133, 244, 0.2);
        }

        .btn-primary:hover {
            background-color: #3367d6;
            border-color: #3367d6;
            box-shadow: 0 6px 15px rgba(66, 133, 244, 0.3);
        }

        .btn-danger {
            background-color: #ea4335;
            border-color: #ea4335;
            box-shadow: 0 4px 10px rgba(234, 67, 53, 0.2);
        }

        .btn-danger:hover {
            background-color: #d33426;
            border-color: #d33426;
            box-shadow: 0 6px 15px rgba(234, 67, 53, 0.3);
        }

        .alert {
            border-radius: 10px;
            margin-bottom: 25px;
            padding: 16px 20px;
            display: flex;
            align-items: center;
            border-left: 4px solid;
        }

        .alert i {
            font-size: 20px;
            margin-right: 15px;
        }

        .alert-success {
            background-color: #d4edda;
            border-color: #00d97e;
            color: #155724;
        }

        .alert-danger {
            background-color: #f8d7da;
            border-color: #ea4335;
            color: #721c24;
        }

        .btn-add {
            background-color: #4285f4;
            border-color: #4285f4;
            color: white;
            border-radius: 30px;
            padding: 8px 20px;
            font-weight: 500;
            transition: all 0.3s;
            box-shadow: 0 4px 10px rgba(66, 133, 244, 0.2);
        }

        .btn-add:hover {
            background-color: #3367d6;
            border-color: #3367d6;
            transform: translateY(-2px);
            box-shadow: 0 6px 15px rgba(66, 133, 244, 0.3);
        }

        .btn-add i {
            margin-right: 8px;
        }

        .category-name {
            font-weight: 600;
            color: #3c4858;
            display: flex;
            align-items: center;
        }

        .category-name i {
            margin-right: 10px;
            color: #4285f4;
            font-size: 16px;
            width: 24px;
            text-align: center;
        }

        .action-btns .btn {
            margin-right: 8px;
        }

        .page-header {
            display: flex;
            align-items: center;
            margin-bottom: 30px;
            padding-bottom: 15px;
            border-bottom: 1px solid #edf2f9;
        }

        .page-header h1 {
            font-size: 28px;
            font-weight: 700;
            color: #3c4858;
            margin: 0;
            display: flex;
            align-items: center;
        }

        .page-header h1 i {
            margin-right: 15px;
            color: #4285f4;
            background-color: #e8f0fe;
            width: 48px;
            height: 48px;
            line-height: 48px;
            text-align: center;
            border-radius: 12px;
        }

        code {
            background-color: #f5f7fa;
            color: #5e6e82;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-family: Consolas, Monaco, 'Andale Mono', monospace;
        }

        /* 响应式表格 */
        @media (max-width: 767px) {
            .table-responsive {
                border: none;
                margin-bottom: 0;
            }

            .panel-heading {
                flex-direction: column;
                align-items: flex-start;
            }

            .panel-options {
                margin-top: 15px;
                align-self: flex-end;
            }
        }

        </style>
    </head>
    <body>
        <?php include 'public/letf.php'; ?>
        <div class="main-content">
            <div class="container-fluid">
                <div class="page-header">
                    <h1><i class="fas fa-folder-open"></i> 视频分类管理</h1>
                </div>
                <?php if (!empty($message)): ?>
                <div class="alert alert-success">
                    <i class="fas fa-check-circle"></i> <?php echo htmlspecialchars($message); ?>
                </div>
                <?php endif; ?>
                <?php if (isset($error)): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle"></i> <?php echo htmlspecialchars($error); ?>
                </div>
                <?php endif; ?>
                <div class="row">
                    <!-- 分类列表 -->
                    <div class="col-md-12">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title">分类列表</h3>
                                <div class="panel-options">
                                    <a href="video_category_edit.php" class="btn btn-add">
                                        <i class="fas fa-plus"></i> 添加新分类
                                    </a>
                                </div>
                            </div>
                            <div class="table-responsive">
                                <table class="table table-hover">
                                    <thead>
                                        <tr>
                                            <th width="5%">ID</th>
                                            <th width="20%">分类名称</th>
                                            <th width="15%">图标</th>
                                            <th width="10%">视频数量</th>
                                            <th width="10%">排序</th>
                                            <th width="10%">状态</th>
                                            <th width="30%">操作</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (empty($categories)): ?>
                                        <tr>
                                            <td colspan="7" class="text-center">暂无分类数据</td>
                                        </tr>
                                        <?php else: ?>
                                        <?php foreach ($categoriesTree as $category): ?>
                                        <tr>
                                            <td><?php echo $category['id']; ?></td>
                                            <td class="category-name">
                                                <?php if (!empty($category['icon'])): ?>
                                                <i class="<?php echo safeHtmlDisplay($category['icon']); ?>"></i>
                                                <?php endif; ?>
                                                <strong><?php echo safeHtmlDisplay($category['name']); ?></strong>
                                            </td>
                                            <td><code><?php echo safeHtmlDisplay($category['icon']); ?></code></td>
                                            <td>
                                                <span class="badge bg-info text-white">
                                                    <?php echo $category['video_count']; ?>
                                                </span>
                                            </td>
                                            <td><?php echo $category['sort_order']; ?></td>
                                            <td>
                                                <?php if ($category['status'] == 1): ?>
                                                <span class="badge bg-success text-white">
                                                    <i class="fas fa-check-circle"></i> 启用
                                                </span>
                                                <?php else: ?>
                                                <span class="badge bg-secondary text-white">
                                                    <i class="fas fa-ban"></i> 禁用
                                                </span>
                                                <?php endif; ?>
                                            </td>
                                            <td class="action-btns">
                                                <div class="btn-group">
                                                    <a href="video_category_edit.php?id=<?php echo $category['id']; ?>" class="btn btn-primary btn-sm">
                                                        <i class="fas fa-edit"></i> 编辑
                                                    </a>
                                                    <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $category['id']; ?>)" class="btn btn-danger btn-sm">
                                                        <i class="fas fa-trash"></i> 删除
                                                    </a>
                                                </div>
                                            </td>
                                        </tr>
                                        <?php if (!empty($category['children'])): ?>
                                        <?php foreach ($category['children'] as $child): ?>
                                        <tr class="child-category">
                                            <td><?php echo $child['id']; ?></td>
                                            <td class="category-name">
                                                <?php if (!empty($child['icon'])): ?>
                                                <i class="<?php echo safeHtmlDisplay($child['icon']); ?>"></i>
                                                <?php endif; ?>
                                                <?php echo safeHtmlDisplay($child['name']); ?>
                                            </td>
                                            <td><code><?php echo safeHtmlDisplay($child['icon']); ?></code></td>
                                            <td>
                                                <span class="badge bg-info text-white">
                                                    <?php echo $child['video_count']; ?>
                                                </span>
                                            </td>
                                            <td><?php echo $child['sort_order']; ?></td>
                                            <td>
                                                <?php if ($child['status'] == 1): ?>
                                                <span class="badge bg-success text-white">
                                                    <i class="fas fa-check-circle"></i> 启用
                                                </span>
                                                <?php else: ?>
                                                <span class="badge bg-secondary text-white">
                                                    <i class="fas fa-ban"></i> 禁用
                                                </span>
                                                <?php endif; ?>
                                            </td>
                                            <td class="action-btns">
                                                <div class="btn-group">
                                                    <a href="video_category_edit.php?id=<?php echo $child['id']; ?>" class="btn btn-primary btn-sm">
                                                        <i class="fas fa-edit"></i> 编辑
                                                    </a>
                                                    <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $child['id']; ?>)" class="btn btn-danger btn-sm">
                                                        <i class="fas fa-trash"></i> 删除
                                                    </a>
                                                </div>
                                            </td>
                                        </tr>
                                        <?php endforeach; ?>
                                        <?php endif; ?>
                                        <?php endforeach; ?>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- JavaScript 脚本 -->
        <script src="js/jquery.min.js"></script>
        <script src="js/bootstrap.min.js"></script>
        <script>
        function confirmDelete(id) {
            if (confirm('确定要删除这个分类吗？此操作不可恢复！')) {
                window.location.href = 'video_category.php?action=delete&id=' + id;
            }
        }
        </script>
    </body>
</html>
