<?php
// 引入必要的配置文件和函数库
require_once 'code/auth_check.php';
include 'public/header.php';
require_once '../config/database.php'; // 直接引入数据库配置文件

// 处理表单提交 - 添加或更新分类
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $db = getDbConnection();

        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $name = trim($_POST['name']);
        $description = trim($_POST['description']);
        $parent_id = intval($_POST['parent_id']);
        $icon = trim($_POST['icon']);
        $sort_order = intval($_POST['sort_order']);
        $status = intval($_POST['status']);

        // 数据验证
        if (empty($name)) {
            throw new Exception('分类名称不能为空');
        }

        $now = date('Y-m-d H:i:s');

        if ($id > 0) {
            // 更新现有分类
            $sql = "UPDATE video_categories SET 
                    name = ?, 
                    description = ?, 
                    parent_id = ?, 
                    icon = ?, 
                    sort_order = ?, 
                    status = ?, 
                    updated_at = ? 
                    WHERE id = ?";
            $stmt = $db->prepare($sql);
            $stmt->execute([$name, $description, $parent_id, $icon, $sort_order, $status, $now, $id]);
            $message = '分类更新成功！';
        } else {
            // 添加新分类
            $sql = "INSERT INTO video_categories (name, description, parent_id, icon, sort_order, status, created_at) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)";
            $stmt = $db->prepare($sql);
            $stmt->execute([$name, $description, $parent_id, $icon, $sort_order, $status, $now]);
            $message = '分类添加成功！';
        }

        // 重定向到分类列表页面
        header("Location: video_category.php?message=" . urlencode($message));
        exit;

    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 获取要编辑的分类
$editCategory = null;
if (isset($_GET['id'])) {
    try {
        $db = getDbConnection();
        $id = intval($_GET['id']);

        $editSql = "SELECT * FROM video_categories WHERE id = ?";
        $editStmt = $db->prepare($editSql);
        $editStmt->execute([$id]);
        $editCategory = $editStmt->fetch(PDO::FETCH_ASSOC);

        if (!$editCategory) {
            throw new Exception('未找到指定的分类');
        }
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 获取所有分类作为父分类选项
try {
    $db = getDbConnection();
    $categoriesSql = "SELECT id, name, parent_id FROM video_categories ORDER BY parent_id ASC, sort_order ASC";
    $categoriesStmt = $db->query($categoriesSql);
    $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);

    // 处理分类选项
    $categoryOptions = [];
    
    // 先找出所有顶级分类
    foreach ($categories as $category) {
        if ($category['parent_id'] == 0) {
            $categoryOptions[$category['id']] = $category['name'];
        }
    }
    
    // 再找出所有子分类
    foreach ($categories as $category) {
        if ($category['parent_id'] > 0 && isset($categoryOptions[$category['parent_id']])) {
            $categoryOptions[$category['id']] = '-- ' . $category['name'];
        }
    }

} catch (Exception $e) {
    $error = $e->getMessage();
    $categories = [];
    $categoryOptions = [];
}

// 安全显示函数
function safeHtmlDisplay($value) {
    return htmlspecialchars($value ?? '', ENT_QUOTES, 'UTF-8');
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title><?php echo $editCategory ? '编辑' : '添加'; ?>视频分类 - 后台管理系统</title>
        <!-- 引入样式文件 -->
        <link rel="stylesheet" href="public/css/style.css">
        <link href="/cn/public/css/style.css" rel="stylesheet" />
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
        <style>
        body {
            background-color: #f5f7fa;
            color: #333;
            font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
        }
        
        .main-content {
            padding: 25px;
            width: 100%;
            max-width: 100%;
        }
        
        .container-fluid {
            width: 100%;
            padding-right: 0;
            padding-left: 0;
        }
        
        .panel-default {
            border-radius: 12px;
            box-shadow: 0 5px 20px rgba(0, 0, 0, 0.05);
            border: none;
            background-color: #fff;
            overflow: hidden;
            transition: box-shadow 0.3s;
            margin-bottom: 30px;
        }
        
        .panel-default:hover {
            box-shadow: 0 8px 25px rgba(0, 0, 0, 0.08);
        }
        
        .panel-heading {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 20px 25px;
            background-color: #fff;
            border-bottom: 1px solid #edf2f9;
            border-top-left-radius: 12px;
            border-top-right-radius: 12px;
        }
        
        .panel-title {
            font-size: 18px;
            font-weight: 600;
            color: #3c4858;
            margin: 0;
            position: relative;
            padding-left: 15px;
        }
        
        .panel-title:before {
            content: '';
            position: absolute;
            left: 0;
            top: 50%;
            transform: translateY(-50%);
            width: 4px;
            height: 18px;
            background-color: #4285f4;
            border-radius: 2px;
        }
        
        .panel-body {
            padding: 25px;
        }
        
        .form-group {
            margin-bottom: 25px;
        }
        
        .form-control {
            height: 45px;
            border-radius: 8px;
            border: 1px solid #e1e6ef;
            box-shadow: none;
            padding: 10px 15px;
            font-size: 14px;
            color: #3c4858;
            transition: all 0.3s;
        }
        
        .form-control:focus {
            border-color: #4285f4;
            box-shadow: 0 0 0 3px rgba(66, 133, 244, 0.15);
        }
        
        textarea.form-control {
            height: auto;
            min-height: 100px;
        }
        
        label {
            font-weight: 600;
            color: #3c4858;
            margin-bottom: 8px;
            display: block;
        }
        
        .form-text {
            margin-top: 6px;
            font-size: 12px;
            color: #748194;
        }
        
        .alert {
            border-radius: 10px;
            margin-bottom: 25px;
            padding: 16px 20px;
            display: flex;
            align-items: center;
            border-left: 4px solid;
        }
        
        .alert i {
            font-size: 20px;
            margin-right: 15px;
        }
        
        .alert-success {
            background-color: #d4edda;
            border-color: #00d97e;
            color: #155724;
        }
        
        .alert-danger {
            background-color: #f8d7da;
            border-color: #ea4335;
            color: #721c24;
        }
        
        .btn {
            border-radius: 8px;
            font-weight: 500;
            padding: 12px 25px;
            transition: all 0.3s;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            letter-spacing: 0.3px;
            font-size: 14px;
        }
        
        .btn i {
            margin-right: 8px;
        }
        
        .btn:hover {
            transform: translateY(-2px);
        }
        
        .btn-primary {
            background-color: #4285f4;
            border-color: #4285f4;
            box-shadow: 0 4px 10px rgba(66, 133, 244, 0.2);
        }
        
        .btn-primary:hover {
            background-color: #3367d6;
            border-color: #3367d6;
            box-shadow: 0 6px 15px rgba(66, 133, 244, 0.3);
        }
        
        .btn-default {
            background-color: #f8f9fa;
            border-color: #e1e6ef;
            color: #5e6e82;
        }
        
        .btn-default:hover {
            background-color: #e9ecef;
            border-color: #dde2e6;
            color: #3c4858;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.05);
        }
        
        .page-header {
            display: flex;
            align-items: center;
            margin-bottom: 30px;
            padding-bottom: 15px;
            border-bottom: 1px solid #edf2f9;
        }
        
        .page-header h1 {
            font-size: 28px;
            font-weight: 700;
            color: #3c4858;
            margin: 0;
            display: flex;
            align-items: center;
        }
        
        .page-header h1 i {
            margin-right: 15px;
            color: #4285f4;
            background-color: #e8f0fe;
            width: 48px;
            height: 48px;
            line-height: 48px;
            text-align: center;
            border-radius: 12px;
        }
        
        /* 预览图标样式 */
        .icon-preview {
            width: 50px;
            height: 50px;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            background-color: #e8f0fe;
            color: #4285f4;
            border-radius: 8px;
            font-size: 22px;
            margin-top: 10px;
            transition: all 0.3s;
        }
        
        .icon-hint {
            display: flex;
            margin-top: 10px;
            align-items: center;
        }
        
        .icon-hint .badge {
            margin-right: 10px;
            background-color: #f0f4f8;
            color: #5e6e82;
            padding: 5px 10px;
            border-radius: 4px;
            font-weight: 600;
            font-size: 12px;
        }
        
        /* 响应式调整 */
        @media (max-width: 767px) {
            .form-actions {
                flex-direction: column;
            }
            
            .form-actions .btn {
                margin-bottom: 10px;
                width: 100%;
            }
        }
        </style>
    </head>
    <body>
        <?php include 'public/letf.php'; ?>
        <div class="main-content">
            <div class="container-fluid">
                <div class="page-header">
                    <h1>
                        <i class="fas fa-edit"></i> 
                        <?php echo $editCategory ? '编辑分类' : '添加新分类'; ?>
                    </h1>
                </div>
                <?php if (isset($error)): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle"></i> <?php echo htmlspecialchars($error); ?>
                </div>
                <?php endif; ?>
                <div class="row">
                    <div class="col-md-10 col-md-offset-1">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title"><?php echo $editCategory ? '编辑分类信息' : '填写分类信息'; ?></h3>
                            </div>
                            <div class="panel-body">
                                <form method="POST" action="">
                                    <?php if ($editCategory): ?>
                                    <input type="hidden" name="id" value="<?php echo $editCategory['id']; ?>">
                                    <?php endif; ?>
                                    
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label for="name">
                                                    <i class="fas fa-tag text-primary"></i> 分类名称
                                                </label>
                                                <input type="text" class="form-control" id="name" name="name" required
                                                       value="<?php echo $editCategory ? safeHtmlDisplay($editCategory['name']) : ''; ?>" 
                                                       placeholder="输入分类名称">
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label for="parent_id">
                                                    <i class="fas fa-sitemap text-primary"></i> 父分类
                                                </label>
                                                <select class="form-control" id="parent_id" name="parent_id">
                                                    <option value="0">无 (顶级分类)</option>
                                                    <?php foreach ($categoryOptions as $id => $name): ?>
                                                    <?php if ($editCategory && $id == $editCategory['id']) continue; ?>
                                                    <option value="<?php echo $id; ?>" <?php echo ($editCategory && $editCategory['parent_id'] == $id) ? 'selected' : ''; ?>>
                                                        <?php echo safeHtmlDisplay($name); ?>
                                                    </option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <div class="form-group">
                                        <label for="description">
                                            <i class="fas fa-align-left text-primary"></i> 分类描述
                                        </label>
                                        <textarea class="form-control" id="description" name="description" rows="4" 
                                               placeholder="输入分类描述信息"><?php echo $editCategory ? safeHtmlDisplay($editCategory['description']) : ''; ?></textarea>
                                    </div>
                                    
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label for="icon">
                                                    <i class="fas fa-icons text-primary"></i> 分类图标
                                                </label>
                                                <input type="text" class="form-control" id="icon" name="icon" 
                                                       placeholder="例如: fas fa-video"
                                                       value="<?php echo $editCategory ? safeHtmlDisplay($editCategory['icon']) : ''; ?>">
                                                <div class="icon-hint">
                                                    <span class="badge">预览</span>
                                                    <div class="icon-preview">
                                                        <i id="iconPreview" class="<?php echo $editCategory ? safeHtmlDisplay($editCategory['icon']) : 'fas fa-question'; ?>"></i>
                                                    </div>
                                                </div>
                                                <small class="form-text text-muted">输入FontAwesome图标类名，例如：fas fa-video</small>
                                            </div>
                                        </div>
                                        <div class="col-md-3">
                                            <div class="form-group">
                                                <label for="sort_order">
                                                    <i class="fas fa-sort-numeric-down text-primary"></i> 排序顺序
                                                </label>
                                                <input type="number" class="form-control" id="sort_order" name="sort_order" min="0"
                                                       value="<?php echo $editCategory ? intval($editCategory['sort_order']) : '0'; ?>">
                                                <small class="form-text text-muted">数字越小排序越靠前</small>
                                            </div>
                                        </div>
                                        <div class="col-md-3">
                                            <div class="form-group">
                                                <label for="status">
                                                    <i class="fas fa-toggle-on text-primary"></i> 状态
                                                </label>
                                                <select class="form-control" id="status" name="status">
                                                    <option value="1" <?php echo ($editCategory && $editCategory['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                                    <option value="0" <?php echo ($editCategory && $editCategory['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                                                </select>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <hr>
                                    
                                    <div class="form-actions" style="display: flex; justify-content: space-between;">
                                        <div>
                                            <button type="submit" class="btn btn-primary">
                                                <i class="fas fa-save"></i> <?php echo $editCategory ? '保存修改' : '添加分类'; ?>
                                            </button>
                                        </div>
                                        <div>
                                            <a href="video_category.php" class="btn btn-default">
                                                <i class="fas fa-arrow-left"></i> 返回列表
                                            </a>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- JavaScript 脚本 -->
        <script src="js/jquery.min.js"></script>
        <script src="js/bootstrap.min.js"></script>
        <script>
        $(document).ready(function() {
            // 图标预览功能
            $('#icon').on('input', function() {
                var iconClass = $(this).val();
                if(iconClass) {
                    $('#iconPreview').attr('class', iconClass);
                } else {
                    $('#iconPreview').attr('class', 'fas fa-question');
                }
            });
        });
        </script>
    </body>
</html> 