<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';
include 'public/header.php';
include_once '../common/functions.php';

// 检查权限函数
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录，重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话（如果尚未启动）
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 处理表单提交
$message = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // 获取表单数据
        $video_id = isset($_POST['video_id']) ? intval($_POST['video_id']) : 0;
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $author_name = isset($_POST['author_name']) ? trim($_POST['author_name']) : '虚拟用户';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $likes = isset($_POST['likes']) ? intval($_POST['likes']) : 0;
        
        // 验证数据
        if ($video_id <= 0) {
            throw new Exception('请选择一个视频');
        }
        
        if (empty($content)) {
            throw new Exception('评论内容不能为空');
        }
        
        // 连接数据库
        $db = getDbConnection();
        
        // 准备SQL语句
        $sql = "INSERT INTO video_comments (video_id, content, author_name, status, likes, created_at) 
                VALUES (?, ?, ?, ?, ?, NOW())";
        
        // 执行SQL
        $stmt = $db->prepare($sql);
        $stmt->execute([$video_id, $content, $author_name, $status, $likes]);
        
        // 成功消息
        $message = '评论已成功添加';
        
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 获取视频列表供选择
try {
    $db = getDbConnection();
    $sql = "SELECT id, title FROM videos ORDER BY title ASC";
    $stmt = $db->query($sql);
    $videos = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log($e->getMessage());
    $error = '获取视频列表失败，请稍后再试';
    $videos = [];
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>添加虚拟评论 - 后台管理系统</title>
    <!-- 引入样式文件 -->
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
    <link rel="stylesheet" href="public/css/video_comment.css">
</head>
<body>
    <?php include 'public/letf.php'; ?>
    <div class="main-content">
        <div class="container-fluid">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><i class="fas fa-plus-circle"></i> 添加虚拟评论</h3>
                </div>
                <div class="panel-body" style="padding: 20px;">
                    <?php if (!empty($message)): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle"></i> <?php echo htmlspecialchars($message); ?>
                    </div>
                    <?php endif; ?>
                    
                    <?php if (!empty($error)): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-circle"></i> <?php echo htmlspecialchars($error); ?>
                    </div>
                    <?php endif; ?>
                    
                    <form method="POST" action="">
                        <div class="form-group">
                            <label for="video_id">选择视频</label>
                            <select name="video_id" id="video_id" class="form-control" required>
                                <option value="">-- 请选择视频 --</option>
                                <?php foreach ($videos as $video): ?>
                                <option value="<?php echo $video['id']; ?>"><?php echo htmlspecialchars($video['title']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div class="form-group">
                            <label for="author_name">用户名</label>
                            <input type="text" name="author_name" id="author_name" class="form-control" value="虚拟用户" placeholder="输入评论者用户名">
                            <small class="text-muted">如不填写，将使用"虚拟用户"作为默认名称</small>
                        </div>
                        
                        <div class="form-group">
                            <label for="content">评论内容</label>
                            <textarea name="content" id="content" class="form-control" rows="5" required placeholder="请输入评论内容"></textarea>
                        </div>
                        
                        <div class="form-group">
                            <label for="likes">点赞数</label>
                            <input type="number" name="likes" id="likes" class="form-control" min="0" value="0">
                        </div>
                        
                        <div class="form-group">
                            <label>评论状态</label>
                            <div class="radio">
                                <label>
                                    <input type="radio" name="status" value="1" checked> 已审核
                                </label>
                            </div>
                            <div class="radio">
                                <label>
                                    <input type="radio" name="status" value="0"> 待审核
                                </label>
                            </div>
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary">
                                <i class="fas fa-save"></i> 保存评论
                            </button>
                            <a href="video_comment.php" class="btn btn-default">
                                <i class="fas fa-arrow-left"></i> 返回评论列表
                            </a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
    
    <!-- JavaScript 脚本 -->
    <script src="js/jquery.min.js"></script>
    <script src="js/bootstrap.min.js"></script>
</body>
</html> 