<?php
// 引入必要的配置文件和函数库
include 'header.php';
include '../common/functions.php';

// 检查用户权限
checkPermission();

// 定义设置项和默认值
$defaultSettings = [
    'player_type' => 'html5', // 播放器类型：html5, dplayer, videojs
    'autoplay' => '0', // 是否自动播放
    'comments_enabled' => '1', // 是否启用评论功能
    'related_videos' => '1', // 是否显示相关视频
    'player_width' => '100%', // 播放器宽度
    'player_height' => 'auto', // 播放器高度
    'player_theme' => '#3498db', // 播放器主题色
    'thumbnail_width' => '320', // 缩略图宽度
    'thumbnail_height' => '180', // 缩略图高度
    'allow_download' => '0', // 是否允许下载
    'default_quality' => 'auto', // 默认视频质量
    'max_comment_length' => '500', // 评论最大长度
    'comment_approval' => '1', // 评论是否需要审核
    'watermark_enabled' => '0', // 是否启用水印
    'watermark_position' => 'bottom-right', // 水印位置
    'watermark_image' => '', // 水印图片路径
    'analytics_enabled' => '1', // 是否启用数据统计
    'social_share' => '1' // 是否启用社交分享
];

// 保存配置
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $db = getDbConnection();
        
        // 遍历表单提交的所有设置项
        foreach ($defaultSettings as $key => $defaultValue) {
            $value = isset($_POST[$key]) ? trim($_POST[$key]) : $defaultValue;
            
            // 检查该设置是否已存在
            $checkSql = "SELECT id FROM config WHERE name = ? AND category = 'video'";
            $checkStmt = $db->prepare($checkSql);
            $checkStmt->execute(["video_{$key}"]);
            
            if ($checkStmt->fetchColumn()) {
                // 更新现有设置
                $updateSql = "UPDATE config SET value = ? WHERE name = ? AND category = 'video'";
                $updateStmt = $db->prepare($updateSql);
                $updateStmt->execute([$value, "video_{$key}"]);
            } else {
                // 插入新设置
                $insertSql = "INSERT INTO config (name, value, category, description) VALUES (?, ?, 'video', ?)";
                $insertStmt = $db->prepare($insertSql);
                $insertStmt->execute(["video_{$key}", $value, "视频设置 - {$key}"]);
            }
        }
        
        // 处理水印图片上传
        if (isset($_FILES['watermark_file']) && $_FILES['watermark_file']['error'] == 0) {
            $uploadDir = '../uploads/watermarks/';
            
            // 确保上传目录存在
            if (!file_exists($uploadDir)) {
                mkdir($uploadDir, 0755, true);
            }
            
            $fileInfo = pathinfo($_FILES['watermark_file']['name']);
            $extension = strtolower($fileInfo['extension']);
            
            // 检查文件类型
            $allowedExtensions = ['png', 'jpg', 'jpeg', 'gif'];
            if (in_array($extension, $allowedExtensions)) {
                $newFileName = 'watermark_' . time() . '.' . $extension;
                $uploadFile = $uploadDir . $newFileName;
                
                if (move_uploaded_file($_FILES['watermark_file']['tmp_name'], $uploadFile)) {
                    // 更新水印图片路径
                    $updateWatermarkSql = "UPDATE config SET value = ? WHERE name = 'video_watermark_image' AND category = 'video'";
                    $updateWatermarkStmt = $db->prepare($updateWatermarkSql);
                    $updateWatermarkStmt->execute([$uploadFile]);
                } else {
                    throw new Exception('水印图片上传失败！');
                }
            } else {
                throw new Exception('不支持的文件类型！请上传 PNG, JPG, JPEG 或 GIF 格式的图片。');
            }
        }
        
        $message = '视频播放设置已成功保存！';
        
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 获取当前设置
try {
    $db = getDbConnection();
    $settingsSql = "SELECT name, value FROM config WHERE category = 'video' AND name LIKE 'video_%'";
    $settingsStmt = $db->query($settingsSql);
    $settingsRows = $settingsStmt->fetchAll(PDO::FETCH_ASSOC);
    
    $settings = [];
    foreach ($settingsRows as $row) {
        $key = str_replace('video_', '', $row['name']);
        $settings[$key] = $row['value'];
    }
    
    // 合并默认设置和数据库中的设置
    $settings = array_merge($defaultSettings, $settings);
    
} catch (PDOException $e) {
    error_log($e->getMessage());
    $error = '获取设置失败，请稍后再试或联系管理员';
    $settings = $defaultSettings;
}

?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>视频播放设置 - 后台管理系统</title>
    <!-- 引入样式文件 -->
    <link rel="stylesheet" href="css/admin.css">
    <style>
        .setting-section {
            margin-bottom: 30px;
            border-bottom: 1px solid #eee;
            padding-bottom: 20px;
        }
        .setting-title {
            margin-bottom: 20px;
            color: #333;
        }
        .setting-subtitle {
            margin: 15px 0;
            font-size: 16px;
            color: #555;
        }
        .color-preview {
            display: inline-block;
            width: 24px;
            height: 24px;
            border: 1px solid #ddd;
            vertical-align: middle;
            margin-left: 10px;
        }
        .watermark-preview {
            max-width: 200px;
            max-height: 100px;
            margin-top: 10px;
            border: 1px dashed #ddd;
            padding: 5px;
        }
    </style>
</head>
<body>
    <?php include 'letf.php'; ?>
    
    <div class="main-content">
        <div class="container-fluid">
            <div class="page-header">
                <h1><i class="fas fa-sliders-h"></i> 视频播放设置</h1>
            </div>
            
            <?php if (isset($message)): ?>
                <div class="alert alert-success"><?php echo htmlspecialchars($message); ?></div>
            <?php endif; ?>
            
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
            <?php endif; ?>
            
            <div class="panel panel-default">
                <div class="panel-body">
                    <form method="POST" action="" enctype="multipart/form-data">
                        <!-- 播放器基本设置 -->
                        <div class="setting-section">
                            <h3 class="setting-title">播放器基本设置</h3>
                            
                            <div class="form-group">
                                <label for="player_type">播放器类型</label>
                                <select class="form-control" id="player_type" name="player_type">
                                    <option value="html5" <?php echo $settings['player_type'] == 'html5' ? 'selected' : ''; ?>>HTML5 原生播放器</option>
                                    <option value="dplayer" <?php echo $settings['player_type'] == 'dplayer' ? 'selected' : ''; ?>>DPlayer 播放器</option>
                                    <option value="videojs" <?php echo $settings['player_type'] == 'videojs' ? 'selected' : ''; ?>>Video.js 播放器</option>
                                </select>
                                <small class="form-text text-muted">选择视频播放器类型，不同播放器有不同的功能和兼容性。</small>
                            </div>
                            
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="player_width">播放器宽度</label>
                                        <input type="text" class="form-control" id="player_width" name="player_width" value="<?php echo htmlspecialchars($settings['player_width']); ?>">
                                        <small class="form-text text-muted">可以是具体像素值（如600px）或百分比（如100%）</small>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="player_height">播放器高度</label>
                                        <input type="text" class="form-control" id="player_height" name="player_height" value="<?php echo htmlspecialchars($settings['player_height']); ?>">
                                        <small class="form-text text-muted">可以是具体像素值（如400px）或auto（自动计算）</small>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="form-group">
                                <label for="player_theme">播放器主题色</label>
                                <input type="color" class="form-control" id="player_theme" name="player_theme" value="<?php echo htmlspecialchars($settings['player_theme']); ?>" style="width: 50px; display: inline-block;">
                                <span id="theme_color_value"><?php echo htmlspecialchars($settings['player_theme']); ?></span>
                                <div class="color-preview" style="background-color: <?php echo htmlspecialchars($settings['player_theme']); ?>;"></div>
                            </div>
                            
                            <div class="form-group">
                                <label>自动播放</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="autoplay" value="1" <?php echo $settings['autoplay'] == '1' ? 'checked' : ''; ?>> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="autoplay" value="0" <?php echo $settings['autoplay'] == '0' ? 'checked' : ''; ?>> 禁用
                                    </label>
                                </div>
                                <small class="form-text text-muted">注意：大多数浏览器默认禁止自动播放带声音的视频</small>
                            </div>
                            
                            <div class="form-group">
                                <label>允许下载</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="allow_download" value="1" <?php echo $settings['allow_download'] == '1' ? 'checked' : ''; ?>> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="allow_download" value="0" <?php echo $settings['allow_download'] == '0' ? 'checked' : ''; ?>> 禁用
                                    </label>
                                </div>
                                <small class="form-text text-muted">是否允许用户下载视频</small>
                            </div>
                            
                            <div class="form-group">
                                <label for="default_quality">默认视频质量</label>
                                <select class="form-control" id="default_quality" name="default_quality">
                                    <option value="auto" <?php echo $settings['default_quality'] == 'auto' ? 'selected' : ''; ?>>自动</option>
                                    <option value="1080p" <?php echo $settings['default_quality'] == '1080p' ? 'selected' : ''; ?>>1080p</option>
                                    <option value="720p" <?php echo $settings['default_quality'] == '720p' ? 'selected' : ''; ?>>720p</option>
                                    <option value="480p" <?php echo $settings['default_quality'] == '480p' ? 'selected' : ''; ?>>480p</option>
                                    <option value="360p" <?php echo $settings['default_quality'] == '360p' ? 'selected' : ''; ?>>360p</option>
                                </select>
                            </div>
                        </div>
                        
                        <!-- 缩略图设置 -->
                        <div class="setting-section">
                            <h3 class="setting-title">缩略图设置</h3>
                            
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="thumbnail_width">缩略图宽度（像素）</label>
                                        <input type="number" class="form-control" id="thumbnail_width" name="thumbnail_width" value="<?php echo htmlspecialchars($settings['thumbnail_width']); ?>">
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="thumbnail_height">缩略图高度（像素）</label>
                                        <input type="number" class="form-control" id="thumbnail_height" name="thumbnail_height" value="<?php echo htmlspecialchars($settings['thumbnail_height']); ?>">
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <!-- 水印设置 -->
                        <div class="setting-section">
                            <h3 class="setting-title">水印设置</h3>
                            
                            <div class="form-group">
                                <label>启用水印</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="watermark_enabled" value="1" <?php echo $settings['watermark_enabled'] == '1' ? 'checked' : ''; ?> id="watermark_enabled_yes"> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="watermark_enabled" value="0" <?php echo $settings['watermark_enabled'] == '0' ? 'checked' : ''; ?> id="watermark_enabled_no"> 禁用
                                    </label>
                                </div>
                            </div>
                            
                            <div id="watermark_settings" class="<?php echo $settings['watermark_enabled'] == '1' ? '' : 'hidden'; ?>">
                                <div class="form-group">
                                    <label for="watermark_position">水印位置</label>
                                    <select class="form-control" id="watermark_position" name="watermark_position">
                                        <option value="top-left" <?php echo $settings['watermark_position'] == 'top-left' ? 'selected' : ''; ?>>左上角</option>
                                        <option value="top-right" <?php echo $settings['watermark_position'] == 'top-right' ? 'selected' : ''; ?>>右上角</option>
                                        <option value="bottom-left" <?php echo $settings['watermark_position'] == 'bottom-left' ? 'selected' : ''; ?>>左下角</option>
                                        <option value="bottom-right" <?php echo $settings['watermark_position'] == 'bottom-right' ? 'selected' : ''; ?>>右下角</option>
                                        <option value="center" <?php echo $settings['watermark_position'] == 'center' ? 'selected' : ''; ?>>居中</option>
                                    </select>
                                </div>
                                
                                <div class="form-group">
                                    <label>水印图片</label>
                                    <input type="file" class="form-control" name="watermark_file" accept="image/*">
                                    <input type="hidden" name="watermark_image" value="<?php echo htmlspecialchars($settings['watermark_image']); ?>">
                                    <small class="form-text text-muted">推荐使用透明背景的PNG图片</small>
                                    
                                    <?php if (!empty($settings['watermark_image'])): ?>
                                        <div class="mt-2">
                                            <label>当前水印：</label>
                                            <div>
                                                <img src="<?php echo htmlspecialchars($settings['watermark_image']); ?>" class="watermark-preview" alt="水印预览">
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        
                        <!-- 评论设置 -->
                        <div class="setting-section">
                            <h3 class="setting-title">评论设置</h3>
                            
                            <div class="form-group">
                                <label>启用评论功能</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="comments_enabled" value="1" <?php echo $settings['comments_enabled'] == '1' ? 'checked' : ''; ?> id="comments_enabled_yes"> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="comments_enabled" value="0" <?php echo $settings['comments_enabled'] == '0' ? 'checked' : ''; ?> id="comments_enabled_no"> 禁用
                                    </label>
                                </div>
                            </div>
                            
                            <div id="comment_settings" class="<?php echo $settings['comments_enabled'] == '1' ? '' : 'hidden'; ?>">
                                <div class="form-group">
                                    <label for="max_comment_length">评论最大长度</label>
                                    <input type="number" class="form-control" id="max_comment_length" name="max_comment_length" value="<?php echo htmlspecialchars($settings['max_comment_length']); ?>">
                                    <small class="form-text text-muted">允许用户输入的最大字符数</small>
                                </div>
                                
                                <div class="form-group">
                                    <label>评论审核</label>
                                    <div>
                                        <label class="radio-inline">
                                            <input type="radio" name="comment_approval" value="1" <?php echo $settings['comment_approval'] == '1' ? 'checked' : ''; ?>> 需要审核
                                        </label>
                                        <label class="radio-inline">
                                            <input type="radio" name="comment_approval" value="0" <?php echo $settings['comment_approval'] == '0' ? 'checked' : ''; ?>> 无需审核
                                        </label>
                                    </div>
                                    <small class="form-text text-muted">选择是否需要管理员审核后评论才能显示</small>
                                </div>
                            </div>
                        </div>
                        
                        <!-- 其他设置 -->
                        <div class="setting-section">
                            <h3 class="setting-title">其他设置</h3>
                            
                            <div class="form-group">
                                <label>显示相关视频</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="related_videos" value="1" <?php echo $settings['related_videos'] == '1' ? 'checked' : ''; ?>> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="related_videos" value="0" <?php echo $settings['related_videos'] == '0' ? 'checked' : ''; ?>> 禁用
                                    </label>
                                </div>
                                <small class="form-text text-muted">在视频播放页面是否显示相关推荐视频</small>
                            </div>
                            
                            <div class="form-group">
                                <label>启用数据统计</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="analytics_enabled" value="1" <?php echo $settings['analytics_enabled'] == '1' ? 'checked' : ''; ?>> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="analytics_enabled" value="0" <?php echo $settings['analytics_enabled'] == '0' ? 'checked' : ''; ?>> 禁用
                                    </label>
                                </div>
                                <small class="form-text text-muted">收集视频观看数据和用户行为统计</small>
                            </div>
                            
                            <div class="form-group">
                                <label>启用社交分享</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="social_share" value="1" <?php echo $settings['social_share'] == '1' ? 'checked' : ''; ?>> 启用
                                    </label>
                                    <label class="radio-inline">
                                        <input type="radio" name="social_share" value="0" <?php echo $settings['social_share'] == '0' ? 'checked' : ''; ?>> 禁用
                                    </label>
                                </div>
                                <small class="form-text text-muted">是否显示社交媒体分享按钮</small>
                            </div>
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary">
                                <i class="fas fa-save"></i> 保存设置
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
    
    <!-- JavaScript 脚本 -->
    <script src="js/jquery.min.js"></script>
    <script src="js/bootstrap.min.js"></script>
    <script>
    $(document).ready(function() {
        // 水印设置的显示/隐藏
        $('input[name="watermark_enabled"]').change(function() {
            if ($(this).val() === '1') {
                $('#watermark_settings').removeClass('hidden');
            } else {
                $('#watermark_settings').addClass('hidden');
            }
        });
        
        // 评论设置的显示/隐藏
        $('input[name="comments_enabled"]').change(function() {
            if ($(this).val() === '1') {
                $('#comment_settings').removeClass('hidden');
            } else {
                $('#comment_settings').addClass('hidden');
            }
        });
        
        // 颜色选择器变化时更新显示值
        $('#player_theme').change(function() {
            var selectedColor = $(this).val();
            $('#theme_color_value').text(selectedColor);
            $('.color-preview').css('background-color', selectedColor);
        });
    });
    </script>
</body>
</html> 