<?php
/**
 * Telegram机器人命令处理文件
 * 处理所有的机器人命令
 */

class BotCommands {
    private $bot;
    private $chatId;
    private $message;

    /**
     * 构造函数
     * 
     * @param TelegramBot $bot 机器人实例
     * @param array $message 消息数据
     */
    public function __construct($bot, $message) {
        $this->bot = $bot;
        $this->message = $message;
        $this->chatId = $message['chat']['id'];
    }

    /**
     * 处理命令
     * 
     * @param string $command 命令名称
     * @return bool 是否成功处理
     */
    public function handleCommand($command) {
        $methodName = 'cmd' . ucfirst($command);
        
        if (method_exists($this, $methodName)) {
            logTelegramActivity("执行命令: $command");
            $this->$methodName();
            return true;
        }
        
        return false;
    }

    /**
     * 开始命令
     */
    private function cmdStart() {
        $response = "欢迎使用 " . e_config('SITE_NAME') . " 机器人！\n";
        $response .= "使用 /help 查看可用命令";
        $this->bot->sendMessage($this->chatId, $response);
    }

    /**
     * 帮助命令
     */
    private function cmdHelp() {
        $response = "可用命令列表：\n";
        $response .= "/start - 开始使用\n";
        $response .= "/help - 显示此帮助\n";
        $response .= "/id - 显示用户ID和聊天ID\n";
        $response .= "/usdt - 获取USDT充值地址";
        $this->bot->sendMessage($this->chatId, $response);
    }

    /**
     * ID命令
     */
    private function cmdId() {
        // 获取聊天类型
        $chatType = $this->message['chat']['type'] ?? 'unknown';
        
        // 根据聊天类型显示不同的信息
        if ($chatType == 'private') {
            // 个人聊天显示用户ID
            $userId = $this->message['from']['id'] ?? '未知';
            $response = $userId;
        } else {
            // 群组聊天显示群ID
            $response = $this->chatId;
        }
        
        $this->bot->sendMessage($this->chatId, $response);
    }

    /**
     * USDT命令
     */
    private function cmdUsdt() {
        logTelegramActivity("处理usdt命令");
        $usdtAddress = e_config('USDTaddress');
        
        logTelegramActivity("USDT地址: $usdtAddress");
        
        // 检查USDT地址是否获取成功
        if (empty($usdtAddress)) {
            $this->bot->sendMessage($this->chatId, "⚠️ 系统未配置USDT地址，请联系管理员。");
            return;
        }
        
        // 简化的响应，只包含纯文本地址和说明
        $response = "地址是\n";
        $response .= "<code>" . $usdtAddress . "</code>\n\n";
        $response .= "支付成功请截图告知，感谢您选择我们！";
        
        // 发送文本消息
        $this->bot->sendMessage($this->chatId, $response);
    }

    /**
     * 未知命令处理
     */
    public function handleUnknownCommand() {
        $response = "抱歉，我不明白这个命令。\n使用 /help 查看可用命令。";
        $this->bot->sendMessage($this->chatId, $response);
    }
} 