<?php
/**
 * Telegram机器人处理脚本
 * 主入口文件
 */
// 引入配置文件
require_once '../config/config.php';
require_once 'config/database.php';
// 确保配置已加载
ensureConfigsAvailable();
// 定义机器人相关常量
define('BOT_ROOT', __DIR__);
define('COMMANDS_DIR', BOT_ROOT . '/commands');
// 设置Telegram Bot API令牌，从配置中获取
define('TELEGRAM_BOT_TOKEN', e_config('bot'));
// 获取传入的数据
$update = json_decode(file_get_contents('php://input'), true);
// 初始化Telegram Bot API类
require_once BOT_ROOT . '/TelegramBot.php';
require_once BOT_ROOT . '/BotCommands.php';
$bot = new TelegramBot(TELEGRAM_BOT_TOKEN);
// 日志记录函数
function logTelegramActivity($message) {
    $logFile = BOT_ROOT . '/telegram_bot.log';
    $timestamp = date('Y-m-d H:i:s');
    file_put_contents($logFile, "[$timestamp] $message\n", FILE_APPEND);
}

// 处理接收到的请求
function processUpdate($update) {
    global $bot; // 使用传入的机器人API变量
    // 记录收到的更新
    logTelegramActivity("收到更新: " . json_encode($update, JSON_UNESCAPED_UNICODE));
    
    // 检查是否是消息
    if (isset($update['message'])) {
        $message = $update['message'];
        $chatId = $message['chat']['id'];
        $text = $message['text'] ?? '';
        
        // 记录接收到的消息
        logTelegramActivity("接收到消息: $text, 来自聊天ID: $chatId");
        
        // 解析命令
        if (!empty($text) && $text[0] === '/') {
            $parts = explode(' ', $text);
            $commandWithUsername = $parts[0];
            
            // 移除可能附加的机器人用户名 (/command@botname)
            $commandParts = explode('@', $commandWithUsername);
            $command = ltrim($commandParts[0], '/');
            
            // 记录解析到的命令
            logTelegramActivity("解析到命令: $command");
            
            // 创建命令处理器实例
            $commandHandler = new BotCommands($bot, $message);
            
            // 尝试处理命令
            if (!$commandHandler->handleCommand($command)) {
                // 如果命令不存在，处理未知命令
                $commandHandler->handleUnknownCommand();
            }
        }
    }
}

// 执行处理
try {
    processUpdate($update);
} catch (Exception $e) {
    logTelegramActivity("处理错误: " . $e->getMessage());
}
?>
