<?php
session_start();
include_once __DIR__ . '/code/cart_code.php';
// 引入必要的文件
require_once __DIR__ . '/config/config.php';
require_once __DIR__ . '/config/database.php';
// 添加auth.php的引入，提供getCurrentUserId函数
require_once __DIR__ . '/user/code/auth.php';

// 不再需要定义formatAmount函数，因为它已经在cart_code.php中定义
?> <?php include 'public/config.php'; ?> <?php
// 使用和index.php相同的方式获取用户ID
$userId = getCurrentUserId();
// 添加调试代码
error_log("Cart.php: 用户ID为 $userId");
// 使用config.php中定义的calculateUserBalance函数计算余额
$balance = calculateUserBalance($userId);
error_log("Cart.php: 计算出的余额为 $balance");
?>
<!DOCTYPE html>
<html lang="zh">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title> 购物车</title>
    <meta name="keywords" content="服务器购物车,服务器配置,主机定制,服务器订购,服务器购买流程,云服务器配置,服务器租用,增值服务,服务器参数选择">
    <meta name="description" content="通过我们的购物车系统灵活配置您的理想服务器，可自定义操作系统、带宽、IP地址数量等核心参数，并提供多种免费增值服务选项。支持月付、季付、年付多种付款方式，专业级服务器定制体验。">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="https://unpkg.com/aos@2.3.1/dist/aos.css" rel="stylesheet">
    <link href="/public/css/style.css" rel="stylesheet">
    <link rel="stylesheet" href="public/css/cart.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link href="/public/css/breadcrumb.css" rel="stylesheet">
    <script>
    // 将操作系统版本数据传递给前端JavaScript
    window.allOsVersions = <?php echo $allOsVersionsJson; ?>;
    // 调试信息
    window.debugInfo = <?php echo $debugJson ?? '{}'; ?>;
    // 购物车数据 - 用于结算功能
    window.cartData = {
      productId: <?php echo $product_id ?? 0; ?>,
      memberId: <?php echo isset($_SESSION['member_id']) ? $_SESSION['member_id'] : 0; ?>,
      directMemberId: <?php echo $userId ?? 0; ?>
    };
    window.debugMode = <?php echo defined('DEBUG_MODE') && DEBUG_MODE ? 'true' : 'false'; ?>;
    window.phpSessionId = '<?php echo session_id(); ?>';
    </script>
  </head>
  <body>
    <!-- 顶部导航 --> <?php include 'public/header.php'; ?>
    <!-- Banner 区域 --> <?php include 'public/banner.php'; ?>
    <!--内容区块-->
    <div class="container">
      <div class="main">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/">首页</a>
            <i class="material-icons">chevron_right</i>
            <a href="/product">产品服务</a>
            <i class="material-icons">chevron_right</i>
            <span>购物车</span>
          </div>
        </div>
        <div class="cart-container">
          <h2 class="cart-title">我的购物车</h2> <?php if ($product_id > 0 && isset($product)): ?> <div class="cart-items">
            <div class="cart-item">
              <div class="server-info">
                <h3 class="server-title"><?php echo $locationText . '高速服务器'; ?></h3>
                <div class="server-specs">
                  <p><i class="fas fa-hashtag"></i>编号: <span><?php echo str_pad($product['id'], 6, '0', STR_PAD_LEFT); ?></span></p>
                  <p><i class="fas fa-microchip"></i>CPU: <span><?php echo htmlspecialchars($product['upc'] ?? '未设置'); ?></span></p>
                  <p><i class="fas fa-memory"></i>内存: <span><?php echo htmlspecialchars($product['memory'] ?? '未设置'); ?></span></p>
                  <p><i class="fas fa-hdd"></i>硬盘: <span><?php echo htmlspecialchars($product['disk'] ?? '未设置'); ?></span></p>
                  <p><i class="fas fa-network-wired"></i>带宽: <span><?php echo htmlspecialchars($product['bandwidth'] ?? '未设置'); ?></span></p>
                  <p><i class="fas fa-tachometer-alt"></i>流量: <span><?php echo htmlspecialchars($product['traffic'] ?? '不限流量'); ?></span></p>
                  <p><i class="fas fa-shield-alt"></i>防护: <span><?php echo htmlspecialchars($product['defense'] ?? '可选'); ?></span></p>
                  <p><i class="fas fa-globe"></i>IP数量: <span><?php echo htmlspecialchars($product['ip_count'] ?? '1'); ?></span></p>
                  <p><i class="fas fa-map-marker-alt"></i>线路: <span><?php echo htmlspecialchars($lineName ?? 'CN2线路'); ?></span></p>
                  <p><i class="fas fa-server"></i>机房: <span><?php echo htmlspecialchars($locationText ?? '高速'); ?></span></p>
                </div>
              </div>
              <div class="server-pricing">
                <div class="price-plan">
                  <label>
                    <input type="radio" name="price-plan" value="monthly" data-price="397.05" checked> 月付 </label>
                  <span class="price">¥397.05/月</span>
                </div>
                <div class="price-plan">
                  <label>
                    <input type="radio" name="price-plan" value="quarterly" data-price="<?php echo 397.05 * 3 * 0.95; ?>"> 季付 </label>
                  <span class="price"> ¥<?php echo number_format(397.05 * 3 * 0.95, 2); ?>/季 <span class="discount-tag">95折</span>
                  </span>
                </div>
                <div class="price-plan">
                  <label><input type="radio" name="price-plan" value="half-year" data-price="<?php echo 397.05 * 6 * 0.98; ?>"> 半年付</label>
                  <span class="price">¥<?php echo number_format(397.05 * 6 * 0.98, 2); ?>/半年 <span class="discount-tag">98折</span></span>
                </div>
                <div class="price-plan">
                  <label><input type="radio" name="price-plan" value="yearly" data-price="<?php echo 397.05 * 12 * 0.9; ?>"> 年付</label>
                  <span class="price">¥<?php echo number_format(397.05 * 12 * 0.9, 2); ?>/年 <span class="discount-tag">9折</span></span>
                </div>
                <div class="config-item flex-row">
                  <div class="flex-group quantity-group">
                    <div class="config-label">数量:</div>
                    <div class="config-value">
                      <div class="quantity-control">
                        <button type="button" class="decrease">-</button>
                        <input type="number" value="1" min="1" class="quantity-input">
                        <button type="button" class="increase">+</button>
                      </div>
                    </div>
                  </div>
                  <div class="flex-group auto-renew-group">
                    <div class="config-label">自动续费:</div>
                    <div class="config-value">
                      <label class="switch-wrapper">
                        <input type="checkbox" id="auto-renew">
                        <span class="switch-slider"></span>
                      </label>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div> <?php else: ?> <div class="empty-cart">系统 <i class="material-icons">shopping_cart</i>
            <p>购物车是空的</p>
            <a href="/product" class="btn btn-primary">去选购</a>
          </div> <?php endif; ?> <?php if ($product_id > 0 && isset($product)): ?> <div class="section-divider"></div>
          <!-- 服务器配置部分 -->
          <div class="config-section">
            <h3><i class="fas fa-server"></i> 服务器配置</h3>
            <div class="config-item">
              <div class="config-label">主机名:</div>
              <div class="config-value">
                <input type="text" class="form-control" value="<?php echo htmlspecialchars(($product['code'] ?? 'My') . date('YmdHis')); ?>" placeholder="请输入主机名">
              </div>
            </div>
            <div class="config-item">
              <div class="config-label">控制台密码:</div>
              <div class="config-value">
                <div class="password-input-container">
                  <input type="password" value="<?php echo generateRandomPassword(); ?>" class="form-control" id="console-password" readonly>
                  <button type="button" class="toggle-password" onclick="togglePassword()">
                    <i class="fas fa-eye"></i>
                  </button>
                  <button type="button" class="refresh-password" onclick="refreshPassword()">
                    <i class="fas fa-sync-alt"></i>
                  </button>
                </div>
              </div>
            </div>
            <div class="config-item">
              <div class="config-label">操作系统:</div>
              <div class="config-value">
                <div class="os-selects-row">
                  <div class="os-brand-container">
                    <select class="form-control os-brand-select" id="os-brand"> <?php foreach ($osBrands as $id => $name): ?> <option value="<?php echo $id; ?>"><?php echo htmlspecialchars($name); ?></option> <?php endforeach; ?> </select>
                  </div>
                  <div class="os-version-container">
                    <select class="form-control os-version-select" id="os-version"> <?php 
                      // 默认显示第一个品牌的版本
                      $firstBrandId = array_key_first($osBrands);
                      if (isset($osVersions[$firstBrandId])):
                        foreach ($osVersions[$firstBrandId] as $version):
                      ?> <option value="<?php echo $version['id']; ?>"><?php echo htmlspecialchars($version['name']); ?></option> <?php 
                        endforeach;
                      endif;
                      ?> </select>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div class="section-divider"></div> <?php if ($product_id > 0 && isset($product)): ?> <div class="cart-bottom-summary">
            <div class="left-summary">
              <span>数量：</span><strong id="bottom-quantity">1</strong> 台 <span>总价：</span><span class="price-highlight" id="bottom-total-price">¥397.05</span>
            </div>
            <div class="right-summary"> 账户余额：<span class="balance-amount">¥<?php echo number_format($balance, 2); ?></span>
            </div>
            <button class="checkout-btn-large" onclick="validateAndSubmit()">
              <i class="fas fa-shopping-cart"></i> 结算 </button>
          </div> <?php endif; ?> <?php endif; ?>
        </div>
      </div>
    </div> <?php include 'public/footer.php'; ?> <?php include 'public/kf.php'; ?> <script src="/public/js/js.js"></script>
    <script src="public/js/cart.js"></script>
  </body>
</html>
