<?php
// 定义网站根目录路径常量
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(dirname(__DIR__)));
}
// 引入配置文件
require_once ROOT_PATH . '/public/config.php';

// 使用已有的数据库连接函数获取连接
global $db;

// 创建mysqli连接
try {
    require_once ROOT_PATH . '/config/database.php';
    
    // 获取PDO连接
    $pdo = getDbConnection();
    
    // 创建mysqli连接
    $conn = new mysqli(DB_HOST, DB_USER, DB_PASSWORD, DB_NAME);
    
    // 检查连接
    if ($conn->connect_error) {
        throw new Exception("数据库连接失败: " . $conn->connect_error);
    }
    
    // 设置字符集
    $conn->set_charset(DB_CHARSET);
    
    // 获取URL中的id参数
    $area_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
    
} catch (Exception $e) {
    // 记录错误但继续执行，避免白屏
    error_log('数据库连接错误: ' . $e->getMessage());
}

// 区域信息处理
$current_area_name = '';
$parent_area_name = '';

// 如果有区域ID参数，获取区域名称
if ($area_id) {
    // 查询当前区域和父区域信息
    $sql_current_area = "SELECT a.*, p.name as parent_name FROM area a LEFT JOIN area p ON a.parent_id = p.id WHERE a.id = ? AND a.status = 1";
    $stmt_current_area = $conn->prepare($sql_current_area);
    $stmt_current_area->bind_param("i", $area_id);
    $stmt_current_area->execute();
    $area_result = $stmt_current_area->get_result();
    
    if ($area_result->num_rows > 0) {
        $area_data = $area_result->fetch_assoc();
        $current_area_name = $area_data['name'];
        $parent_area_name = $area_data['parent_name'];
    }
    $stmt_current_area->close();
}

// 区域名称对照表 - 移除中东非洲
$regionNames = [
    '1' => '亚太地区',
    '2' => '欧洲地区',
    '3' => '美洲地区'
    // '4' => '中东非洲' 已移除
];

// 区域到CSS类的映射 - 移除中东非洲
$regionClasses = [
    '1' => 'asia',
    '2' => 'europe',
    '3' => 'america'
    // '4' => 'mideast' 已移除
];

// 区域图标映射
$regionIcons = [
    '1' => 'fa-globe-asia',
    '2' => 'fa-globe-europe',
    '3' => 'fa-globe-americas'
];

// 默认显示亚太地区(region=1)的区域
$defaultRegion = 1;

/**
 * 生成区域筛选按钮HTML
 */
function generateFilterButtons($area_id, $regionNames, $regionClasses, $regionIcons) {
    $html = '';
    
    // 如果有指定id参数，则隐藏过滤器
    if (!$area_id) {
        // 遍历固定区域
        $firstCategory = true;
        foreach ($regionNames as $regionValue => $regionLabel) {
            $regionClass = $regionClasses[$regionValue];
            $regionIcon = $regionIcons[$regionValue];
            $active = $firstCategory ? 'active' : '';
            $html .= '<div class="filter-btn ' . $active . '" data-region="' . $regionClass . '"><i class="fas ' . $regionIcon . '"></i> ' . $regionLabel . '</div>';
            $firstCategory = false;
        }
    }
    
    return $html;
}

/**
 * 生成指定区域产品列表HTML
 */
function generateAreaProducts($conn, $area_id, $Telegram) {
    $html = '';
    
    // 查询指定区域信息
    $sql_area = "SELECT * FROM area WHERE id = ? AND status = 1";
    $stmt_area = $conn->prepare($sql_area);
    $stmt_area->bind_param("i", $area_id);
    $stmt_area->execute();
    $area_result = $stmt_area->get_result();
    
    if ($area_result->num_rows > 0) {
        $area = $area_result->fetch_assoc();
        $area_name = $area['name'];
        $region_id = $area['id'];
        
        // 获取父区域信息（如果有）
        $parent_name = '';
        if (!empty($area['parent_id'])) {
            $sql_parent = "SELECT name FROM area WHERE id = ?";
            $stmt_parent = $conn->prepare($sql_parent);
            $stmt_parent->bind_param("i", $area['parent_id']);
            $stmt_parent->execute();
            $parent_result = $stmt_parent->get_result();
            if ($parent_result->num_rows > 0) {
                $parent = $parent_result->fetch_assoc();
                $parent_name = $parent['name'];
            }
            $stmt_parent->close();
        }
        
        // 显示区域标题
        $html .= '<div class="region-title-container">';
        $html .= '<h2 class="region-title">' . $area_name;
        if (!empty($parent_name) && $parent_name != '中国') {
            $html .= ' / ' . $parent_name;
        }
        $html .= '云服务器产品列表</h2>';
        $html .= '</div>';
        
        $html .= '<div class="region-section area-products-section" data-aos="fade-up">';
        
        // 查询该区域的所有云服务器产品，不限制数量
        $sql_products = "SELECT p.*, l.name as line_name FROM products p LEFT JOIN line l ON p.line_id = l.id WHERE p.region_id = ? AND FIND_IN_SET('7', p.tags) > 0 AND p.status = 1 ORDER BY p.price ASC";
        $stmt_products = $conn->prepare($sql_products);
        $stmt_products->bind_param("i", $region_id);
        $stmt_products->execute();
        $products_result = $stmt_products->get_result();
        
        if ($products_result->num_rows > 0) {
            $html .= '<div class="cloud-products">';
            $product_count = 0;
            
            while ($product = $products_result->fetch_assoc()) {
                $product_count++;
                $delay = ($product_count % 3) * 100; // 每行3个产品，重置动画延迟
                
                $html .= '<!-- 产品卡片 ' . $product_count . ' -->';
                $html .= '<div class="cloud-card" data-aos="fade-up" data-aos-delay="' . $delay . '">';
                $html .= '<div class="cloud-card-header">';
                $html .= '<h3 class="cloud-title">' . $area_name . '云服务器 ' . $product_count . '</h3>';
                $html .= '</div>';
                $html .= '<div class="cloud-card-body">';
                $html .= '<table class="cloud-specs-table">';
                $html .= '<tr>';
                $html .= '<td class="cloud-spec-label">编号:</td>';
                // 将产品ID格式化为5位数字，以8开头，不足位数用0补充
                $productCode = '8' . str_pad($product['id'], 4, '0', STR_PAD_LEFT);
                $html .= '<td class="cloud-spec-value">' . $productCode . '</td>';
                $html .= '<td class="cloud-spec-label">CPU:</td>';
                $html .= '<td class="cloud-spec-value">' . $product['cpu'] . '</td>';
                $html .= '</tr>';
                $html .= '<tr>';
                $html .= '<td class="cloud-spec-label">硬盘:</td>';
                $html .= '<td class="cloud-spec-value">' . $product['disk'] . '</td>';
                $html .= '<td class="cloud-spec-label">宽带:</td>';
                $html .= '<td class="cloud-spec-value">' . $product['bandwidth'] . '</td>';
                $html .= '</tr>';
                $html .= '<tr>';
                $html .= '<td class="cloud-spec-label">防御:</td>';
                $html .= '<td class="cloud-spec-value">' . (!empty($product['defense']) ? $product['defense'] : '可选') . '</td>';
                $html .= '<td class="cloud-spec-label">线路:</td>';
                $html .= '<td class="cloud-spec-value">' . (!empty($product['line_name']) ? $product['line_name'] : '') . '</td>';
                $html .= '</tr>';
                $html .= '<tr>';
                $html .= '<td class="cloud-spec-label">地区:</td>';
                $html .= '<td class="cloud-spec-value">' . $area_name . '</td>';
                $html .= '<td class="cloud-spec-label">内存:</td>';
                $html .= '<td class="cloud-spec-value">' . $product['memory'] . '</td>';
                $html .= '</tr>';
                $html .= '<tr>';
                $html .= '<td class="cloud-spec-label">IP数:</td>';
                $html .= '<td class="cloud-spec-value">' . $product['ip_count'] . '个</td>';
                $html .= '<td class="cloud-spec-label">流量:</td>';
                $html .= '<td class="cloud-spec-value">不限</td>';
                $html .= '</tr>';
                $html .= '</table>';
                $html .= '<div class="cloud-price-row">';
                $html .= '<span class="cloud-price-label">价格:</span>';
                $html .= '<span class="cloud-price-value">$' . number_format($product['price'], 2) . '/月</span>';
                $html .= '</div>';
                $html .= '<div class="cloud-action">';
                $html .= '<a href="/product/' . $product['id'] . '.html" class="btn primary-btn">产品详情</a>';
                $html .= '<a href="' . $Telegram . '" class="btn secondary-btn" target="_blank">申请测试</a>';
                $html .= '</div>';
                $html .= '</div>';
                $html .= '</div>';
            }
            $html .= '</div>'; // 结束 cloud-products
            $stmt_products->close();
        } else {
            $html .= '<div class="empty-products"><i class="fas fa-info-circle"></i> 该地区暂无可用的云服务器产品</div>';
        }
        
        $html .= '</div>'; // 结束 region-section
    } else {
        $html .= '<div class="error-message"><i class="fas fa-exclamation-circle"></i> 未找到指定的区域信息</div>';
    }
    $stmt_area->close();
    
    return $html;
}

/**
 * 生成所有区域产品列表HTML
 */
function generateAllRegionsProducts($conn, $defaultRegion, $regionClasses, $Telegram) {
    $html = '';
    
    // 首先获取所有的父区域（parent_id为空或为0的区域）且region=1，排除名称为'中国'的区域
    $sql_parent_regions = "SELECT * FROM area WHERE status = 1 AND (parent_id IS NULL OR parent_id = 0) AND region = ? AND name != '中国' ORDER BY sort_order ASC";
    $stmt = $conn->prepare($sql_parent_regions);
    $stmt->bind_param("i", $defaultRegion);
    $stmt->execute();
    $parent_regions = $stmt->get_result();
    
    if ($parent_regions->num_rows > 0) {
        while ($parent_region = $parent_regions->fetch_assoc()) {
            $parentId = $parent_region['id'];
            $parentName = $parent_region['name'];
            $regionValue = $parent_region['region'];
            $regionClass = isset($regionClasses[$regionValue]) ? $regionClasses[$regionValue] : 'asia';
            
            // 父区域
            $html .= '<!-- 父区域: ' . $parentName . ' -->';
            $html .= '<div class="parent-region ' . $regionClass . '" data-aos="fade-up">';
            
            // 获取该父区域下的子区域
            $sql_child_regions = "SELECT * FROM area WHERE status = 1 AND parent_id = ? ORDER BY sort_order ASC";
            $stmt_child = $conn->prepare($sql_child_regions);
            $stmt_child->bind_param("i", $parentId);
            $stmt_child->execute();
            $child_regions = $stmt_child->get_result();
            
            if ($child_regions->num_rows > 0) {
                while ($region = $child_regions->fetch_assoc()) {
                    $regionId = $region['id'];
                    $regionName = $region['name'];
                    $regionSlug = $region['slug'];
                    
                    // 查询region_id对应的产品数据，筛选包含tags=7的产品，按价格从低到高排序，限制3条数据
                    $sql_products = "SELECT p.*, l.name as line_name FROM products p LEFT JOIN line l ON p.line_id = l.id WHERE p.region_id = ? AND FIND_IN_SET('7', p.tags) > 0 AND p.status = 1 ORDER BY p.price ASC LIMIT 3";
                    $stmt_products = $conn->prepare($sql_products);
                    $stmt_products->bind_param("i", $regionId);
                    $stmt_products->execute();
                    $products_result = $stmt_products->get_result();
                    
                    // 只有当有产品时才显示该区域
                    if ($products_result->num_rows > 0) {
                        // 子区域
                        $html .= '<!-- 子区域: ' . $regionName . ' -->';
                        $html .= '<div class="region-section" data-aos="fade-up">';
                        $html .= '<div class="region-header">';
                        $html .= '<div class="region-name">';
                        $html .= '<i class="region-icon fas fa-server"></i>';
                        // 显示格式：地区/国家
                        $html .= $regionName;
                        // 添加父区域名称（国家），除非是中国
                        if($parentName != '中国') {
                            $html .= '/' . $parentName;
                        }
                        
                        if (!empty($region['tag1'])) {
                            $html .= '<span class="region-tag">' . $region['tag1'] . '</span>';
                        }
                        
                        if (!empty($region['tag2'])) {
                            $html .= '<span class="region-tag">' . $region['tag2'] . '</span>';
                        }
                        
                        $html .= '</div>';
                        $html .= '<a href="/cloud/' . $regionId . '" class="region-more">更多配置 <i class="fas fa-chevron-right"></i></a>';
                        $html .= '</div>';
                        $html .= '<div class="cloud-products">';
                        
                        $product_count = 0; // 产品计数器
                        
                        while ($product = $products_result->fetch_assoc()) {
                            $product_count++;
                            $delay = $product_count * 100; // 设置动画延迟
                            
                            $html .= '<!-- 产品卡片 ' . $product_count . ' -->';
                            $html .= '<div class="cloud-card" data-aos="fade-up" data-aos-delay="' . $delay . '">';
                            $html .= '<div class="cloud-card-header">';
                            $html .= '<h3 class="cloud-title">' . $regionName . '云服务器 ' . $product_count . '</h3>';
                            $html .= '</div>';
                            $html .= '<div class="cloud-card-body">';
                            $html .= '<table class="cloud-specs-table">';
                            $html .= '<tr>';
                            $html .= '<td class="cloud-spec-label">编号:</td>';
                            // 将产品ID格式化为5位数字，以8开头，不足位数用0补充
                            $productCode = '8' . str_pad($product['id'], 4, '0', STR_PAD_LEFT);
                            $html .= '<td class="cloud-spec-value">' . $productCode . '</td>';
                            $html .= '<td class="cloud-spec-label">CPU:</td>';
                            $html .= '<td class="cloud-spec-value">' . $product['cpu'] . '</td>';
                            $html .= '</tr>';
                            $html .= '<tr>';
                            $html .= '<td class="cloud-spec-label">硬盘:</td>';
                            $html .= '<td class="cloud-spec-value">' . $product['disk'] . '</td>';
                            $html .= '<td class="cloud-spec-label">宽带:</td>';
                            $html .= '<td class="cloud-spec-value">' . $product['bandwidth'] . '</td>';
                            $html .= '</tr>';
                            $html .= '<tr>';
                            $html .= '<td class="cloud-spec-label">防御:</td>';
                            $html .= '<td class="cloud-spec-value">' . (!empty($product['defense']) ? $product['defense'] : '可选') . '</td>';
                            $html .= '<td class="cloud-spec-label">线路:</td>';
                            $html .= '<td class="cloud-spec-value">' . (!empty($product['line_name']) ? $product['line_name'] : '') . '</td>';
                            $html .= '</tr>';
                            $html .= '<tr>';
                            $html .= '<td class="cloud-spec-label">地区:</td>';
                            $html .= '<td class="cloud-spec-value">' . $regionName . '</td>';
                            $html .= '<td class="cloud-spec-label">内存:</td>';
                            $html .= '<td class="cloud-spec-value">' . $product['memory'] . '</td>';
                            $html .= '</tr>';
                            $html .= '<tr>';
                            $html .= '<td class="cloud-spec-label">IP数:</td>';
                            $html .= '<td class="cloud-spec-value">' . $product['ip_count'] . '个</td>';
                            $html .= '<td class="cloud-spec-label">流量:</td>';
                            $html .= '<td class="cloud-spec-value">不限</td>';
                            $html .= '</tr>';
                            $html .= '</table>';
                            $html .= '<div class="cloud-price-row">';
                            $html .= '<span class="cloud-price-label">价格:</span>';
                            $html .= '<span class="cloud-price-value">$' . number_format($product['price'], 2) . '/月</span>';
                            $html .= '</div>';
                            $html .= '<div class="cloud-action">';
                            $html .= '<a href="/product/' . $product['id'] . '.html" class="btn primary-btn">产品详情</a>';
                            $html .= '<a href="' . $Telegram . '" class="btn secondary-btn" target="_blank">申请测试</a>';
                            $html .= '</div>';
                            $html .= '</div>';
                            $html .= '</div>';
                        }
                        $stmt_products->close();
                        
                        $html .= '</div>'; // 结束 cloud-products
                        $html .= '</div>'; // 结束 region-section
                    } // end if products exist
                } // end child regions while
                $stmt_child->close();
            } else {
                // 没有子区域，显示父区域本身
                
                // 查询region_id对应的产品数据，筛选包含tags=7的产品，按价格从低到高排序，限制3条数据
                $sql_products = "SELECT p.*, l.name as line_name FROM products p LEFT JOIN line l ON p.line_id = l.id WHERE p.region_id = ? AND FIND_IN_SET('7', p.tags) > 0 AND p.status = 1 ORDER BY p.price ASC LIMIT 3";
                $stmt_products = $conn->prepare($sql_products);
                $stmt_products->bind_param("i", $parentId);
                $stmt_products->execute();
                $products_result = $stmt_products->get_result();
                
                // 只有当有产品时才显示该区域
                if ($products_result->num_rows > 0) {
                    // 父区域（无子区域）
                    $html .= '<!-- 父区域（无子区域）: ' . $parentName . ' -->';
                    $html .= '<div class="region-section" data-aos="fade-up">';
                    $html .= '<div class="region-header">';
                    $html .= '<div class="region-name">';
                    $html .= '<i class="region-icon fas fa-globe-asia"></i>';
                    // 此处为父区域自身，不需要添加国家名称
                    $html .= $parentName;
                    
                    if (!empty($parent_region['tag1'])) {
                        $html .= '<span class="region-tag">' . $parent_region['tag1'] . '</span>';
                    }
                    
                    if (!empty($parent_region['tag2'])) {
                        $html .= '<span class="region-tag">' . $parent_region['tag2'] . '</span>';
                    }
                    
                    $html .= '</div>';
                    $html .= '<a href="/cloud/' . $parentId . '" class="region-more" target="_blank">更多配置 <i class="fas fa-chevron-right"></i></a>';
                    $html .= '</div>';
                    $html .= '<div class="cloud-products">';
                    
                    $product_count = 0; // 产品计数器
                    
                    while ($product = $products_result->fetch_assoc()) {
                        $product_count++;
                        $delay = $product_count * 100; // 设置动画延迟
                        
                        $html .= '<!-- 产品卡片 ' . $product_count . ' -->';
                        $html .= '<div class="cloud-card" data-aos="fade-up" data-aos-delay="' . $delay . '">';
                        $html .= '<div class="cloud-card-header">';
                        $html .= '<h3 class="cloud-title">' . $parentName . '云服务器 ' . $product_count . '</h3>';
                        $html .= '</div>';
                        $html .= '<div class="cloud-card-body">';
                        $html .= '<table class="cloud-specs-table">';
                        $html .= '<tr>';
                        $html .= '<td class="cloud-spec-label">编号:</td>';
                        // 将产品ID格式化为5位数字，以8开头，不足位数用0补充
                        $productCode = '8' . str_pad($product['id'], 4, '0', STR_PAD_LEFT);
                        $html .= '<td class="cloud-spec-value">' . $productCode . '</td>';
                        $html .= '<td class="cloud-spec-label">CPU:</td>';
                        $html .= '<td class="cloud-spec-value">' . $product['cpu'] . '</td>';
                        $html .= '</tr>';
                        $html .= '<tr>';
                        $html .= '<td class="cloud-spec-label">硬盘:</td>';
                        $html .= '<td class="cloud-spec-value">' . $product['disk'] . '</td>';
                        $html .= '<td class="cloud-spec-label">宽带:</td>';
                        $html .= '<td class="cloud-spec-value">' . $product['bandwidth'] . '</td>';
                        $html .= '</tr>';
                        $html .= '<tr>';
                        $html .= '<td class="cloud-spec-label">防御:</td>';
                        $html .= '<td class="cloud-spec-value">' . (!empty($product['defense']) ? $product['defense'] : '可选') . '</td>';
                        $html .= '<td class="cloud-spec-label">线路:</td>';
                        $html .= '<td class="cloud-spec-value">' . (!empty($product['line_name']) ? $product['line_name'] : '') . '</td>';
                        $html .= '</tr>';
                        $html .= '<tr>';
                        $html .= '<td class="cloud-spec-label">地区:</td>';
                        $html .= '<td class="cloud-spec-value">' . $parentName . '</td>';
                        $html .= '<td class="cloud-spec-label">内存:</td>';
                        $html .= '<td class="cloud-spec-value">' . $product['memory'] . '</td>';
                        $html .= '</tr>';
                        $html .= '<tr>';
                        $html .= '<td class="cloud-spec-label">IP数:</td>';
                        $html .= '<td class="cloud-spec-value">' . $product['ip_count'] . '个</td>';
                        $html .= '<td class="cloud-spec-label">流量:</td>';
                        $html .= '<td class="cloud-spec-value">不限</td>';
                        $html .= '</tr>';
                        $html .= '</table>';
                        $html .= '<div class="cloud-price-row">';
                        $html .= '<span class="cloud-price-label">价格:</span>';
                        $html .= '<span class="cloud-price-value">$' . number_format($product['price'], 2) . '/月</span>';
                        $html .= '</div>';
                        $html .= '<div class="cloud-action">';
                        $html .= '<a href="/product/' . $product['id'] . '.html" class="btn primary-btn">产品详情</a>';
                        $html .= '<a href="' . $Telegram . '" class="btn secondary-btn" target="_blank">申请测试</a>';
                        $html .= '</div>';
                        $html .= '</div>';
                        $html .= '</div>';
                    }
                    $stmt_products->close();
                    
                    $html .= '</div>'; // 结束 cloud-products
                    $html .= '</div>'; // 结束 region-section
                } // end if products exist
            } // end else (没有子区域)
            
            $html .= '</div>'; // 结束 parent-region
        } // end parent regions while
    } else {
        $html .= '<div class="error-message"><i class="fas fa-exclamation-circle"></i> 暂无区域数据</div>';
    }
    
    return $html;
}

// 生成页面内容HTML
$filtersHtml = generateFilterButtons($area_id, $regionNames, $regionClasses, $regionIcons);
$regionsHtml = '';

if ($area_id) {
    $regionsHtml = generateAreaProducts($conn, $area_id, $Telegram);
} else {
    $regionsHtml = generateAllRegionsProducts($conn, $defaultRegion, $regionClasses, $Telegram);
}
