<!DOCTYPE html>
<?php
// 定义网站根目录路径常量
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}
// 引入配置文件
require_once ROOT_PATH . '/public/config.php';

// 引入PHP逻辑代码
require_once ROOT_PATH . '/cloud/code/code_index.php';

// 使用已有的数据库连接函数获取连接
global $db;

// 创建mysqli连接
try {
    require_once ROOT_PATH . '/config/database.php';
    
    // 获取PDO连接
    $pdo = getDbConnection();
    
    // 创建mysqli连接
    $conn = new mysqli(DB_HOST, DB_USER, DB_PASSWORD, DB_NAME);
    
    // 检查连接
    if ($conn->connect_error) {
        throw new Exception("数据库连接失败: " . $conn->connect_error);
    }
    
    // 设置字符集
    $conn->set_charset(DB_CHARSET);
    
    // 获取URL中的id参数
    $area_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
    
} catch (Exception $e) {
    // 记录错误但继续执行，避免白屏
    error_log('数据库连接错误: ' . $e->getMessage());
}
?>
<?php echo getCommonCss(); ?>
<html lang="zh">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <?php if ($area_id && isset($current_area_name)) { ?>
    <title><?php echo $current_area_name; ?>云服务器 - 全球节点</title>
    <meta name="description" content="<?php echo $current_area_name; ?>云服务器产品列表，包含各种配置和价格，满足您不同的业务需求。">
    <meta name="keywords" content="<?php echo $current_area_name; ?>云服务器, <?php echo $current_area_name; ?>VPS, <?php echo $current_area_name; ?>云主机, 云服务器配置, 云服务器价格">
    <?php } else { ?>
    <title>云服务器 - 全球节点</title>
    <meta name="description" content="提供全球30多个地区云服务器/VPS产品，包括性能配置、节点特性、价格和购买方式。">
    <meta name="keywords" content="云服务器, VPS, 云计算, 虚拟专用服务器, 全球节点, 数据中心, 云主机, 云服务器租赁, 云服务器购买, 云服务器配置, 云服务器价格">
    <?php } ?>
    <?php echo getCommonCss(); ?>
    <link rel="stylesheet" href="/cloud/style/css/cloud_index.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css">
  </head>
  <body>
    <?php include ROOT_PATH . '/public/header.php'; ?>
    <div class="main-content">
      <?php include ROOT_PATH . '/public/banner.php'; ?>

      <!-- 面包屑导航 -->
      <div class="container">
        <div class="breadcrumb">
          <a href="/">
            首页
          </a>
          <i class="material-icons">chevron_right</i>
          <a href="/product">
            产品服务
          </a>
          <i class="material-icons">chevron_right</i>
          <?php if ($area_id) {
              // 如果有区域ID参数，获取区域名称
              $current_area_name = '';
              $parent_area_name = '';
              
              // 查询当前区域和父区域信息
              $sql_current_area = "SELECT a.*, p.name as parent_name FROM area a LEFT JOIN area p ON a.parent_id = p.id WHERE a.id = ? AND a.status = 1";
              $stmt_current_area = $conn->prepare($sql_current_area);
              $stmt_current_area->bind_param("i", $area_id);
              $stmt_current_area->execute();
              $area_result = $stmt_current_area->get_result();
              
              if ($area_result->num_rows > 0) {
                  $area_data = $area_result->fetch_assoc();
                  $current_area_name = $area_data['name'];
                  $parent_area_name = $area_data['parent_name'];
              }
              $stmt_current_area->close();
          ?>
          <a href="/cloud/index.php">
            云服务器
          </a>
          <i class="material-icons">chevron_right</i>
          <?php if (!empty($parent_area_name)) { ?>
          <span><?php echo $current_area_name; ?>/<?php echo $parent_area_name; ?></span>
          <?php } else { ?>
          <span><?php echo $current_area_name; ?></span>
          <?php } ?>
          <?php } else { ?>
          <span>云服务器</span>
          <?php } ?>
        </div>
      </div>

      <!-- 页面标题区域 -->
      <!-- <div class="page-header">
        <div class="container">
          <h1>高性能云服务器 / VPS</h1>
          <p>提供全球30多个地区的云服务器/VPS产品，稳定性能优，多种配置可选，满足您不同的业务需求</p>
        </div>
      </div> -->

      <div class="cloud-container">
        <?php
        // 区域名称对照表 - 移除中东非洲
        $regionNames = [
            '1' => '亚太地区',
            '2' => '欧洲地区',
            '3' => '美洲地区'
            // '4' => '中东非洲' 已移除
        ];

        // 区域到CSS类的映射 - 移除中东非洲
        $regionClasses = [
            '1' => 'asia',
            '2' => 'europe',
            '3' => 'america'
            // '4' => 'mideast' 已移除
        ];
        
        // 区域图标映射
        $regionIcons = [
            '1' => 'fa-globe-asia',
            '2' => 'fa-globe-europe',
            '3' => 'fa-globe-americas'
        ];
        ?>
        <div class="filters">
          <?php echo $filtersHtml; ?>
        </div>

        <!-- 区域内容容器 -->
        <div id="regions-container">
          <?php echo $regionsHtml; ?>
        </div><!-- 结束区域内容容器 -->

      </div>
    </div>

    <?php include ROOT_PATH . '/public/kf.php'; ?>
    <?php include ROOT_PATH . '/public/footer.php'; ?>
    <!-- 回到顶部按钮 -->
    <a href="#" class="back-to-top" id="backToTop" title="回到顶部">
      <i class="fas fa-arrow-up"></i>
    </a>
    <script src="https://unpkg.com/aos@2.3.1/dist/aos.js"></script>
    <script>
    // 初始化AOS动画库
    document.addEventListener('DOMContentLoaded', function() {
      AOS.init({
        duration: 800,
        easing: 'ease-in-out',
        once: true
      });
      // 区域筛选功能
      const filterBtns = document.querySelectorAll('.filter-btn');
      const cloudContainer = document.querySelector('.cloud-container');
      // 定义区域映射
      const regionMapping = {
        'asia': '1',
        'europe': '2',
        'america': '3'
      };
      // 为每个筛选按钮添加点击事件
      filterBtns.forEach(btn => {
        btn.addEventListener('click', function() {
          // 如果已经是激活状态，则不做任何操作
          if (this.classList.contains('active')) {
            return;
          }
          // 移除所有按钮的active类
          filterBtns.forEach(b => b.classList.remove('active'));
          // 给当前点击的按钮添加active类
          this.classList.add('active');
          // 获取要显示的地区类型和对应的区域值
          const regionClass = this.getAttribute('data-region');
          const regionValue = regionMapping[regionClass];
          // 使用AJAX加载对应地区的数据
          const regionsContainer = document.getElementById('regions-container');
          // 使用AJAX加载对应地区的数据
          fetch(`/cloud/load_regions.php?region=${regionValue}`)
            .then(response => response.text())
            .then(html => {
              regionsContainer.innerHTML = html;
              // 重新初始化AOS
              AOS.refresh();
            })
            .catch(error => {
              console.error('加载区域数据失败:', error);
              regionsContainer.innerHTML = '<div class="error-message"><i class="fas fa-exclamation-triangle"></i> 加载数据失败，请刷新页面重试</div>';
            });
        });
      });
      // 回到顶部按钮功能
      const backToTopBtn = document.getElementById('backToTop');
      // 监听滚动事件，当页面滚动超过300px时显示回到顶部按钮
      window.addEventListener('scroll', function() {
        if (window.pageYOffset > 300) {
          backToTopBtn.style.display = 'block';
        } else {
          backToTopBtn.style.display = 'none';
        }
      });
      // 点击回到顶部按钮时，平滑滚动到页面顶部
      backToTopBtn.addEventListener('click', function(e) {
        e.preventDefault();
        window.scrollTo({
          top: 0,
          behavior: 'smooth'
        });
      });
    });
    </script>
  </body>
</html>
