<?php
/**
 * anti_complaint_code.php - 抗投诉服务器数据处理逻辑
 * 用于获取抗投诉服务器相关数据
 */

// 防止直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}

// 引入数据库配置（如果需要）
if (!function_exists('getDbConnection')) {
    require_once dirname(dirname(__FILE__)) . '/config/database.php';
}

/**
 * 获取价格显示的倍率
 * 用于根据不同情况调整价格显示
 * 
 * @return float 价格倍率
 */
// 避免重复声明函数
if (!function_exists('getMultiplier')) {
    function getMultiplier() {
        // 默认倍率为1，可根据业务需求调整
        return 1.0;
    }
}

/**
 * 获取抗投诉服务器产品数据
 * 查询条件：tags包含11（抗投诉标签）
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 抗投诉服务器产品数据
 */
function getAntiComplaintProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    
    if (!$db) {
        if ($debug) {
            echo "Debug: Database connection failed\n";
        }
        return [];
    }
    
    try {
        // 查询抗投诉服务器产品（tags包含11）
        $query = "SELECT * FROM products WHERE FIND_IN_SET('11', tags) > 0 AND status = 1 ORDER BY price ASC";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if ($debug) {
            echo "Debug: Query executed successfully\n";
            echo "Debug: Found " . count($products) . " products\n";
        }

        return $products;
    } catch (PDOException $e) {
        if ($debug) {
            echo "Debug: Error occurred - " . $e->getMessage() . "\n";
        }
        return [];
    }
}
?> 