<?php
// 数据库连接测试脚本

// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';

// 获取数据库连接
$db = getDbConnection();

// 显示数据库连接信息
echo "<h2>数据库连接测试</h2>";
echo "<p>使用以下设置连接到数据库：</p>";
echo "<ul>";
echo "<li>主机: " . DB_HOST . "</li>";
echo "<li>数据库名: " . DB_NAME . "</li>";
echo "<li>用户名: " . DB_USER . "</li>";
echo "</ul>";

// 测试我们的查询
echo "<h2>查询测试</h2>";
echo "<p>执行SQL查询: <code>SELECT * FROM products WHERE region_id = 2 AND FIND_IN_SET(8, tags) AND status = 1 ORDER BY price ASC</code></p>";

try {
    // 执行查询
    $query = "SELECT * FROM products WHERE region_id = 2 AND FIND_IN_SET(8, tags) AND status = 1 ORDER BY price ASC";
    $stmt = $db->query($query);
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 显示结果计数
    $count = count($products);
    echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
    
    // 如果有结果，显示表格
    if ($count > 0) {
        echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
        echo "<tr style='background:#eee;'>";
        echo "<th>ID</th>";
        echo "<th>产品名称</th>";
        echo "<th>CPU</th>";
        echo "<th>内存</th>";
        echo "<th>硬盘</th>";
        echo "<th>带宽</th>";
        echo "<th>IP数量</th>";
        echo "<th>原价</th>";
        echo "<th>显示价格</th>";
        echo "<th>标签</th>";
        echo "<th>地区ID</th>";
        echo "</tr>";
        
        foreach ($products as $product) {
            echo "<tr>";
            echo "<td>" . $product['id'] . "</td>";
            echo "<td>" . $product['name'] . "</td>";
            echo "<td>" . $product['cpu'] . "</td>";
            echo "<td>" . $product['memory'] . "</td>";
            echo "<td>" . $product['disk'] . "</td>";
            echo "<td>" . $product['bandwidth'] . "</td>";
            echo "<td>" . $product['ip_count'] . "</td>";
            echo "<td>$" . number_format($product['price'], 2) . "</td>";
            echo "<td>$" . number_format($product['price'] * 1.5, 2) . "</td>"; // 假设倍率为1.5
            echo "<td>" . $product['tags'] . "</td>";
            echo "<td>" . $product['region_id'] . "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
        
        // 输出原始数据结构
        echo "<h3>原始数据结构</h3>";
        echo "<pre>";
        print_r($products);
        echo "</pre>";
    } else {
        echo "<p>没有找到匹配的记录</p>";
    }
} catch (PDOException $e) {
    echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
    echo "<h3>数据库错误</h3>";
    echo "<p>" . $e->getMessage() . "</p>";
    echo "</div>";
} 