<?php
// 获取热销服务器产品数据
function getHotServers() {
    $db = getDbConnection();
    $products = [];
    
    try {
        // 构建SQL查询语句 - 筛选tag为8的产品，不限制区域，不限制数量
        $query = "SELECT p.*, l.name as line_name 
                 FROM products p
                 LEFT JOIN line l ON p.line_id = l.id 
                 WHERE FIND_IN_SET(8, p.tags) 
                 AND p.status = 1 
                 ORDER BY p.uv DESC, p.price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
    } catch (Exception $e) {
        error_log("获取热销服务器产品错误: " . $e->getMessage());
    }
    
    return $products;
}

// 获取地区名称和国家名称
function getRegionName($regionId, $db) {
    $regionInfo = ['region' => '未知', 'country' => ''];
    
    try {
        if (!empty($regionId)) {
            // 查询地区信息及其父级信息（国家）
            $regionQuery = "SELECT a.name as region_name, p.name as country_name 
                           FROM area a 
                           LEFT JOIN area p ON a.parent_id = p.id 
                           WHERE a.id = ?";
            $regionStmt = $db->prepare($regionQuery);
            $regionStmt->execute([$regionId]);
            $regionResult = $regionStmt->fetch();
            
            if ($regionResult) {
                $regionInfo['region'] = $regionResult['region_name'];
                $regionInfo['country'] = $regionResult['country_name'] ?? '';
            }
        }
    } catch (Exception $e) {
        error_log("获取地区名称错误: " . $e->getMessage());
    }
    
    return $regionInfo;
}

// 渲染产品卡片
function renderProductCards() {
    $db = getDbConnection();
    $hotProducts = getHotServers();
    $output = '';
    
    if (!empty($hotProducts)) {
        $productCount = 0;
        foreach ($hotProducts as $product) {
            // 计算显示价格（原价乘以倍率）
            $displayPrice = $product['price'] * getMultiplier();
            
            // 获取地区和国家名称
            $regionInfo = getRegionName($product['region_id'], $db);
            
            $output .= '<div class="plan-card">
                <div class="plan-header">
                  <h4>' . ($regionInfo['country'] ? $regionInfo['country'] : '热销') . '服务器</h4>';
                  
            // 显示标签：25显示热销，26显示优惠，27显示新品
            if (strpos($product['tags'], '25') !== false) {
                $output .= '<span class="tag">热销</span>';
            } elseif (strpos($product['tags'], '26') !== false) {
                $output .= '<span class="tag">优惠</span>';
            } elseif (strpos($product['tags'], '27') !== false) {
                $output .= '<span class="tag">新品</span>';
            }
            
            $output .= '</div>
                <div class="cluster-specs">
                  <!-- 左侧规格列 -->
                  <div class="spec-column">
                    <div class="spec-item">
                      <div class="spec-label">编号:</div>
                      <div class="spec-value">' . '8' . str_pad($product['id'], 4, '0', STR_PAD_LEFT) . '</div>
                    </div>
                    <div class="spec-item">
                      <div class="spec-label">硬盘:</div>
                      <div class="spec-value">' . $product['disk'] . '</div>
                    </div>
                    <div class="spec-item">
                      <div class="spec-label">防御:</div>
                      <div class="spec-value">' . (!empty($product['defense']) ? $product['defense'] : '可选') . '</div>
                    </div>
                    <div class="spec-item">
                      <div class="spec-label">地区:</div>
                      <div class="spec-value">' . $regionInfo['region'] . '</div>
                    </div>
                  </div>
                  <!-- 右侧规格列 -->
                  <div class="spec-column">
                    <div class="spec-item">
                      <div class="spec-label">CPU:</div>
                      <div class="spec-value">' . $product['cpu'] . '</div>
                    </div>
                    <div class="spec-item">
                      <div class="spec-label">宽带:</div>
                      <div class="spec-value">' . $product['bandwidth'] . '</div>
                    </div>
                    <div class="spec-item">
                      <div class="spec-label">线路:</div>
                      <div class="spec-value">
                      ' . htmlspecialchars($product['line_name']) . '
                      </div>
                    </div>
                    <div class="spec-item">
                      <div class="spec-label">内存:</div>
                      <div class="spec-value">' . $product['memory'] . '</div>
                    </div>
                  </div>
                </div>
                <!-- IP数量和流量信息 -->
                <div class="cluster-bottom-specs">
                  <div class="spec-item">
                    <div class="spec-label">IP数:</div>
                    <div class="spec-value">' . $product['ip_count'] . '</div>
                  </div>
                  <div class="spec-item">
                    <div class="spec-label">流量:</div>
                    <div class="spec-value">不限</div>
                  </div>
                  <div class="spec-item">
                    <div class="spec-label">价格:</div>
                    <div class="spec-value price-value">$' . number_format($displayPrice, 2) . '/月</div>
                  </div>
                </div>
                <!-- 操作按钮 -->
                <div class="cluster-actions">
                  <a href="product_detail.html?id=' . $product['id'] . '" class="btn btn-primary btn-action">产品详情</a>
                  <a href="' . $GLOBALS['Telegram'] . '" class="btn btn-outline btn-action" target="_blank">申请测机</a>
                </div>
              </div>';
            
            $productCount++;
        }
    } else {
        // 如果没有数据，显示提示信息
        $output = '<div class="no-products">暂无热销产品</div>';
    }
    
    return $output;
}
?>
