<?php
/**
 * 购物车结算处理脚本
 * 这个脚本处理购物车结算按钮点击后的逻辑
 */
// 引入数据库配置文件
include_once __DIR__ . '/../public/config.php';

// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    $response = ['status' => 'error', 'message' => '无效请求方法'];
    echo json_encode($response);
    exit;
}

// 获取POST数据
$hostname = isset($_POST['hostname']) ? trim($_POST['hostname']) : '';
$panelPassword = isset($_POST['panel_password']) ? trim($_POST['panel_password']) : '';
$price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
$productType = isset($_POST['product_type']) ? trim($_POST['product_type']) : '';
$osType = isset($_POST['os_type']) ? trim($_POST['os_type']) : '';
$quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 1;
$autoRenew = isset($_POST['auto_renew']) ? 1 : 0;
$currency = isset($_POST['currency']) ? trim($_POST['currency']) : 'USD';
$productId = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
$memberID = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;

// 计算下次付款日期（默认为1个月后）
$paymentCycle = isset($_POST['payment_cycle']) ? trim($_POST['payment_cycle']) : 'monthly';
$nextPaymentDate = null;

switch($paymentCycle) {
    case 'quarterly':
        $nextPaymentDate = date('Y-m-d', strtotime('+3 months'));
        break;
    case 'half-year':
        $nextPaymentDate = date('Y-m-d', strtotime('+6 months'));
        break;
    case 'yearly':
        $nextPaymentDate = date('Y-m-d', strtotime('+1 year'));
        break;
    case 'monthly':
    default:
        $nextPaymentDate = date('Y-m-d', strtotime('+1 month'));
        break;
}

// 验证必填数据
if (empty($hostname) || empty($productType) || $price <= 0) {
    $response = ['status' => 'error', 'message' => '缺少必要参数'];
    echo json_encode($response);
    exit;
}

// 连接数据库并插入订单
try {
    $conn = getDbConnection();
    
    // 默认初始值
    $ipAddress = '待分配'; // IP地址将在后台分配
    $status = 2; // 2表示审核中
    $isMultipleIp = 0;
    $ipCount = 1;
    $isManualOrder = 0; // 会员系统自动订单
    
    // 构建服务器规格信息（如果可用）
    $serverSpecs = isset($_POST['server_specs']) ? trim($_POST['server_specs']) : null;
    
    // 构建插入SQL
    $insertQuery = "INSERT INTO orders (
                    hostname, panel_password, price, next_payment_date, 
                    product_type, ip_address, os_type, currency, quantity, 
                    product_id, status, auto_renew, server_specs, 
                    is_multiple_ip, ip_count, is_manual_order
                ) VALUES (
                    :hostname, :panel_password, :price, :next_payment_date, 
                    :product_type, :ip_address, :os_type, :currency, :quantity, 
                    :product_id, :status, :auto_renew, :server_specs, 
                    :is_multiple_ip, :ip_count, :is_manual_order
                )";
                   
    $stmt = $conn->prepare($insertQuery);
    $stmt->execute([
        'hostname' => $hostname,
        'panel_password' => $panelPassword,
        'price' => $price,
        'next_payment_date' => $nextPaymentDate,
        'product_type' => $productType,
        'ip_address' => $ipAddress,
        'os_type' => $osType,
        'currency' => $currency,
        'quantity' => $quantity,
        'product_id' => $productId,
        'status' => $status,
        'auto_renew' => $autoRenew,
        'server_specs' => $serverSpecs,
        'is_multiple_ip' => $isMultipleIp,
        'ip_count' => $ipCount,
        'is_manual_order' => $isManualOrder
    ]);
    
    // 获取新插入的订单ID
    $orderId = $conn->lastInsertId();
    
    // 返回成功响应
    $response = [
        'status' => 'success', 
        'message' => '订单已成功提交',
        'order_id' => $orderId
    ];
    echo json_encode($response);
    
} catch (Exception $e) {
    // 返回错误响应
    $response = ['status' => 'error', 'message' => '订单提交失败: ' . $e->getMessage()];
    echo json_encode($response);
} 