<?php
// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';
// 引入网站配置
require_once dirname(__FILE__) . '/../public/config.php';
// 引入产品数据功能
require_once dirname(__FILE__) . '/product_data.php';
// 获取数据库连接
$db = getDbConnection();

// 判断是否是AJAX调用
$isAjax = isset($_GET['ajax']) && $_GET['ajax'] == 1;

// 只有AJAX调用时才设置JSON响应头
if ($isAjax) {
    header('Content-Type: application/json');
}

// 获取筛选参数
$filters = getCurrentFilters();

// 获取地区和标签数据
$regionsData = getRegionsData($db);
$tagsData = getTagsData($db);
$areaNames = getAreaNames($db);
$allTags = getAllTags($db);

// 提取必要的变量
$parentRegions = $regionsData['parentRegions'];
$allRegions = $regionsData['allRegions'];
$childRegionsByParent = $regionsData['childRegionsByParent'];
$childTagsByParent = $tagsData['childTagsByParent'];

// 获取产品列表
$productsData = getProductsList($db, $filters);
$products = $productsData['products'];
$totalItems = $productsData['totalItems'];
$totalPages = $productsData['totalPages'];
$currentPage = $productsData['currentPage'];

// 产品标签映射
$tagClasses = getTagClasses();

// 开始捕获产品列表输出
ob_start();

// 如果没有产品，显示一条消息
if (empty($products)) {
    echo '<div class="no-products" style="text-align:center; padding:30px; font-size:18px;">暂无产品数据，请联系管理员添加产品。</div>';
} else {
    // 显示产品
    foreach ($products as $product):
    ?>
<div class="product-card">
    <div class="product-title">
        <a href="/product/<?php echo $product['id']; ?>.html">
            <?php 
                // 获取地区和国家信息
                $regionName = '';
                $countryName = '';
                if (isset($product['region_id']) && isset($areaNames[$product['region_id']])) {
                  $regionName = $areaNames[$product['region_id']];
                  // 查找该地区的父级地区(国家)
                  foreach ($allRegions as $region) {
                    if ($region['id'] == $product['region_id'] && !empty($region['parent_id'])) {
                      // 找到父级地区(国家)名称
                      foreach ($parentRegions as $parent) {
                        if ($parent['id'] == $region['parent_id']) {
                          $countryName = $parent['name'];
                          break;
                        }
                      }
                      break;
                    }
                  }
                }
                
                // 显示格式：地区(国家)服务器，如果没有国家信息则只显示地区
                if (!empty($regionName)) {
                  if (!empty($countryName) && $countryName != '中国') {
                    echo htmlspecialchars($regionName . '(' . $countryName . ')服务器');
                  } else {
                    echo htmlspecialchars($regionName . '服务器');
                  }
                } else {
                  echo htmlspecialchars($product['upc'] ?? '未命名产品');
                }
            ?>
        </a>
    </div>
    <div class="product-specs">
        <!-- 第一列：编号/硬盘/防御/地区 -->
        <div class="specs-column">
            <div class="spec-row">
                <span class="spec-label">编号:</span>
                <span><?php echo '8' . str_pad($product['id'] ?? '0', 4, '0', STR_PAD_LEFT); ?></span>
            </div>
            <div class="spec-row">
                <span class="spec-label">硬盘:</span>
                <span><?php echo htmlspecialchars($product['disk'] ?? '未设置'); ?></span>
            </div>
            <div class="spec-row">
                <span class="spec-label">防御:</span>
                <span>
                    <?php 
                      // 防御为空或null都显示"可选"
                      if (isset($product['defense']) && !empty($product['defense'])) {
                        echo htmlspecialchars($product['defense']);
                      } else {
                        echo '可选';
                      }
                    ?>
                </span>
            </div>
            <div class="spec-row">
                <span class="spec-label">地区:</span>
                <span>
                    <?php 
                      if (isset($product['region_id']) && isset($areaNames[$product['region_id']])) {
                          echo htmlspecialchars($areaNames[$product['region_id']]);
                      } else {
                          echo '未设置';
                      }
                  ?>
                </span>
            </div>
        </div>
        <!-- 第二列：CPU/宽带/线路/内存 -->
        <div class="specs-column">
            <div class="spec-row">
                <span class="spec-label">CPU:</span>
                <span><?php echo htmlspecialchars($product['upc'] ?? '未设置'); ?></span>
            </div>
            <div class="spec-row">
                <span class="spec-label">宽带:</span>
                <span><?php echo htmlspecialchars($product['bandwidth'] ?? '未设置'); ?></span>
            </div>
            <div class="spec-row">
                <span class="spec-label">线路:</span>
                <span>
                    <?php
                      // 获取线路信息
                      if (!empty($product['line_id'])) {
                        try {
                          $lineQuery = "SELECT l.name as line_name 
                                      FROM line l 
                                      WHERE l.id = :line_id";
                          $lineStmt = $db->prepare($lineQuery);
                          $lineStmt->bindValue(':line_id', $product['line_id']);
                          $lineStmt->execute();
                          $lineInfo = $lineStmt->fetch();
                          
                          if ($lineInfo) {
                            echo htmlspecialchars($lineInfo['line_name']);
                          } else {
                            echo '未设置';
                          }
                        } catch (PDOException $e) {
                          echo '未设置';
                        }
                      } else {
                        echo '未设置';
                      }
                    ?>
                </span>
            </div>
            <div class="spec-row">
                <span class="spec-label">内存:</span>
                <span><?php echo htmlspecialchars($product['memory'] ?? '未设置'); ?></span>
            </div>
        </div>
        <!-- 第三列：IP数/流量/价格/按钮 -->
        <div class="specs-column">
            <div class="spec-row">
                <span class="spec-label">IP数:</span>
                <span><?php echo htmlspecialchars($product['ip_count'] ?? '未设置'); ?>个</span>
            </div>
            <div class="spec-row">
                <span class="spec-label">流量:</span>
                <span>
                    <?php 
                      // 流量为空或null都显示"不限"
                      if (isset($product['traffic']) && !empty($product['traffic'])) {
                        echo htmlspecialchars($product['traffic']);
                      } else {
                        echo '不限';
                      }
                    ?>
                </span>
            </div>
            <div class="spec-row price-row">
                <?php if (!empty($product['original_price']) && $product['original_price'] > $product['price']): ?>
                <del class="original-price">$<?php echo number_format($product['original_price'] * getMultiplier(), 2); ?></del>
                <?php endif; ?>
                <span class="currency">$</span>
                <span class="price"><?php echo number_format(($product['price'] ?? 0) * getMultiplier(), 2); ?></span>
                <span class="unit">/月</span>
            </div>
            <div class="spec-row action-row">
                <a href="/product/<?php echo $product['id']; ?>.html" class="btn btn-primary">立即购买</a>
                <a href="<?php echo $GLOBALS['Telegram']; ?>" class="btn btn-outline" target="_blank">申请测机</a>
            </div>
        </div>
    </div>
</div>
<?php endforeach;
}

// 获取产品列表HTML
$productListHtml = ob_get_clean();

// 开始捕获分页输出
ob_start();

if ($totalPages > 1): ?>
<a href="javascript:void(0);" class="page-item <?php echo $currentPage == 1 ? 'disabled' : ''; ?>" data-page="<?php echo max(1, $currentPage - 1); ?>"><i class="material-icons">chevron_left</i></a>
<?php
// 计算显示的页码范围
$startPage = max(1, $currentPage - 2);
$endPage = min($totalPages, $startPage + 4);
if ($endPage - $startPage < 4 && $startPage > 1) {
    $startPage = max(1, $endPage - 4);
}

for ($i = $startPage; $i <= $endPage; $i++):
?>
<a href="javascript:void(0);" class="page-item <?php echo $i == $currentPage ? 'active' : ''; ?>" data-page="<?php echo $i; ?>"><?php echo $i; ?></a>
<?php endfor; ?>
<a href="javascript:void(0);" class="page-item <?php echo $currentPage == $totalPages ? 'disabled' : ''; ?>" data-page="<?php echo min($totalPages, $currentPage + 1); ?>"><i class="material-icons">chevron_right</i></a>
<?php endif;

// 获取分页HTML
$paginationHtml = ob_get_clean();

// 调试输出
if (!$isAjax) {
    echo "<!--查询SQL: $query -->";
    echo "<!--查询条件: " . implode(', ', $whereConditions) . "-->";
    echo "<!--参数: " . json_encode($params) . "-->";
    echo "<!--产品数量: " . count($products) . "-->";
}

// 根据调用模式返回不同格式的数据
if ($isAjax) {
    // 返回JSON响应
    echo json_encode([
        'productList' => $productListHtml,
        'pagination' => $paginationHtml,
        'totalItems' => $totalItems,
        'totalPages' => $totalPages,
        'currentPage' => $currentPage
    ]); 
} else {
    // 直接返回HTML用于include
    echo $productListHtml;
    echo '<div class="pagination">';
    echo $paginationHtml;
    echo '</div>';
} 
