<?php
// 引入辅助函数
require_once __DIR__ . '/product_helper.php';

// 获取必要的数据
$filters = getCurrentFilters();
$regionsData = getRegionsData($db);
$tagsData = getTagsData($db);
$priceRanges = getPriceRanges();
$areaNames = getAreaNames($db);
$allTags = getAllTags($db);
$tagClasses = getTagClasses();

// 提取必要的变量
$parentRegions = $regionsData['parentRegions'];
$allRegions = $regionsData['allRegions'];
$childRegionsByParent = $regionsData['childRegionsByParent'];
$parentTags = $tagsData['parentTags'];
$allTagsList = $tagsData['allTags'];
$childTagsByParent = $tagsData['childTagsByParent'];

// 获取当前选中的筛选条件
$selectedTag = $filters['tag'];
$selectedRegion = $filters['region'];
$selectedParent = $filters['parent_region'];
$selectedMinPrice = $filters['min_price'];
$selectedMaxPrice = $filters['max_price'];
$sortBy = $filters['sort'];
$sortOrder = $filters['order'];
$currentPage = $filters['page'];

// 为排序方向设置图标
$priceIcon = ($sortBy == 'price' && $sortOrder == 'desc') ? 'arrow_upward' : 'arrow_downward';
$createdIcon = ($sortBy == 'created' && $sortOrder == 'asc') ? 'arrow_upward' : 'arrow_downward';

// 如果没有选中任何父级地区，默认选中第一个
if ($selectedParent == 0 && !empty($parentRegions)) {
    $selectedParentForDisplay = $parentRegions[0]['id'];
} else {
    $selectedParentForDisplay = $selectedParent;
}

// 获取产品列表
$productsData = getProductsList($db, $filters);
$products = $productsData['products'];
$totalItems = $productsData['totalItems'];
$totalPages = $productsData['totalPages'];

// 预先获取所有产品所需的线路信息
$lineData = [];
try {
    // 获取所有产品使用的线路ID
    $lineIds = [];
    foreach ($products as $product) {
        if (!empty($product['line_id']) && !in_array($product['line_id'], $lineIds)) {
            $lineIds[] = $product['line_id'];
        }
    }
    
    // 如果有线路ID，一次性查询所有线路信息
    if (!empty($lineIds)) {
        $placeholders = implode(',', array_fill(0, count($lineIds), '?'));
        $lineQuery = "SELECT id, name FROM line WHERE id IN ($placeholders)";
        $lineStmt = $db->prepare($lineQuery);
        
        // 绑定参数
        foreach ($lineIds as $index => $id) {
            $lineStmt->bindValue($index + 1, $id);
        }
        
        $lineStmt->execute();
        while ($line = $lineStmt->fetch()) {
            $lineData[$line['id']] = $line['name'];
        }
    }
} catch (PDOException $e) {
    // 发生错误时不中断程序，只是不显示线路信息
    error_log("线路数据查询错误: " . $e->getMessage());
} 
 
