<?php
/**
 * 站群服务器页面数据处理文件
 * 提供不同地区站群服务器的数据获取函数
 */

// 确保文件被包含而非直接访问
defined('INCLUDED_FROM_VIEW') or define('INCLUDED_FROM_VIEW', true);

// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';
// 引入网站配置
require_once dirname(__FILE__) . '/../public/config.php';

/**
 * 获取香港站群服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getHongKongClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 香港站群服务器(region_id=2, 站群标签)
        $query = "SELECT * FROM products 
                 WHERE region_id = 2 
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取美国站群服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getUsaClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 美国站群服务器(region_id=1, 站群标签)
        $query = "SELECT * FROM products 
                 WHERE region_id = 1 
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取韩国站群服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getKoreaClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 韩国站群服务器(region_id=3, 站群标签)
        $query = "SELECT * FROM products 
                 WHERE region_id = 3 
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取日本站群服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getJapanClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 日本站群服务器(region_id=8, 站群标签)
        $query = "SELECT * FROM products 
                 WHERE region_id = 8
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取美国站群服务器产品数据（按区域划分）
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 包含美国各区域及其产品的数组
 */
function getUsClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 美国站群服务器(region_id in (5,6,16,20), 站群标签)
        $query = "SELECT * FROM products 
                 WHERE region_id IN (5, 6, 16, 20) 
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取美国各地区及其站群产品
 * 获取美国下的各个地区(洛杉矶、纽约等)及其对应的产品
 *
 * @param bool $debug 是否开启调试模式
 * @return array 地区及产品数据
 */
function getUsRegionsWithProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 1. 获取美国下面的所有子区域
        $query = "SELECT * FROM area WHERE parent_id = 4 AND status = 1 ORDER BY sort_order ASC";
        $stmt = $db->query($query);
        $regions = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 在调试模式下显示查询到的区域
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>美国子区域</h3>";
            echo "<p>找到 <strong>" . count($regions) . "</strong> 个子区域</p>";
            echo "<pre>";
            print_r($regions);
            echo "</pre>";
            echo "</div>";
        }
        
        // 2. 为每个区域添加slug属性用于前端显示
        foreach ($regions as &$region) {
            // 添加slug属性，用于前端区域标识
            switch ($region['id']) {
                case 5:
                    $region['slug'] = 'losangeles';
                    break;
                case 6:
                    $region['slug'] = 'newyork';
                    break;
                case 16:
                    $region['slug'] = 'siliconvalley';
                    break;
                case 20:
                    $region['slug'] = 'atlanta';
                    break;
                default:
                    $region['slug'] = 'other';
            }
            
            // 为每个区域获取相应的产品
            $productQuery = "SELECT * FROM products 
                           WHERE region_id = {$region['id']} 
                           AND FIND_IN_SET(23, tags) 
                           AND status = 1 
                           ORDER BY price ASC";
            
            $productStmt = $db->query($productQuery);
            $products = $productStmt->fetchAll(PDO::FETCH_ASSOC);
            
            // 处理产品数据
            foreach ($products as &$product) {
                // 计算显示价格（应用倍数）
                $product['display_price'] = $product['price'] * getMultiplier();
                
                // 格式化显示价格
                $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
                
                // 处理标签
                if (!empty($product['tags'])) {
                    $tagIds = explode(',', $product['tags']);
                    $product['tag_names'] = getTagNames($db, $tagIds);
                } else {
                    $product['tag_names'] = [];
                }
            }
            
            $region['products'] = $products;
            $region['product_count'] = count($products);
        }
        
        // 在调试模式下显示带产品的区域信息
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>带产品的美国子区域</h3>";
            foreach ($regions as $region) {
                echo "<h4>{$region['name']} ({$region['product_count']}个产品)</h4>";
                if ($region['product_count'] > 0) {
                    echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                    echo "<tr style='background:#eee;'>";
                    echo "<th>ID</th>";
                    echo "<th>产品名称</th>";
                    echo "<th>CPU</th>";
                    echo "<th>内存</th>";
                    echo "<th>硬盘</th>";
                    echo "<th>价格</th>";
                    echo "</tr>";
                    
                    foreach ($region['products'] as $product) {
                        echo "<tr>";
                        echo "<td>" . $product['id'] . "</td>";
                        echo "<td>" . $product['name'] . "</td>";
                        echo "<td>" . $product['cpu'] . "</td>";
                        echo "<td>" . $product['memory'] . "</td>";
                        echo "<td>" . $product['disk'] . "</td>";
                        echo "<td>$" . $product['formatted_price'] . "</td>";
                        echo "</tr>";
                    }
                    
                    echo "</table>";
                } else {
                    echo "<p>没有产品</p>";
                }
            }
            echo "</div>";
        }
        
        $result = $regions;
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取美国区域及产品错误: " . $e->getMessage());
        $result = [];
    }
    
    return $result;
}

/**
 * 处理产品数据
 *
 * @param PDO $db 数据库连接
 * @param array $products 产品数据
 * @param string $query SQL查询语句
 * @param bool $debug 是否开启调试模式
 * @return array 处理后的产品数据
 */
function processProductsData($db, $products, $query, $debug = false) {
    // 计算记录数量
    $count = count($products);
    
    // 如果开启调试模式，打印查询结果
    if ($debug) {
        echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
        echo "<h3>查询结果</h3>";
        echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
        
        if ($count > 0) {
            echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
            echo "<tr style='background:#eee;'>";
            echo "<th>ID</th>";
            echo "<th>产品名称</th>";
            echo "<th>CPU</th>";
            echo "<th>内存</th>";
            echo "<th>硬盘</th>";
            echo "<th>带宽</th>";
            echo "<th>IP数量</th>";
            echo "<th>原价</th>";
            echo "<th>显示价格</th>";
            echo "<th>标签</th>";
            echo "</tr>";
            
            foreach ($products as $product) {
                echo "<tr>";
                echo "<td>" . $product['id'] . "</td>";
                echo "<td>" . $product['name'] . "</td>";
                echo "<td>" . $product['cpu'] . "</td>";
                echo "<td>" . $product['memory'] . "</td>";
                echo "<td>" . $product['disk'] . "</td>";
                echo "<td>" . $product['bandwidth'] . "</td>";
                echo "<td>" . $product['ip_count'] . "</td>";
                echo "<td>$" . number_format($product['price'], 2) . "</td>";
                echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                echo "<td>" . $product['tags'] . "</td>";
                echo "</tr>";
            }
            
            echo "</table>";
        } else {
            echo "<p>没有找到匹配的记录</p>";
        }
        
        echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
        echo "</div>";
    }
    
    // 处理产品数据
    foreach ($products as &$product) {
        // 计算显示价格（应用倍数）
        $product['display_price'] = $product['price'] * getMultiplier();
        
        // 格式化显示价格
        $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
        
        // 处理标签
        if (!empty($product['tags'])) {
            $tagIds = explode(',', $product['tags']);
            $product['tag_names'] = getTagNames($db, $tagIds);
        } else {
            $product['tag_names'] = [];
        }
    }
    
    return $products;
}

/**
 * 处理数据库错误
 *
 * @param PDOException $e 异常对象
 * @param bool $debug 是否开启调试模式
 */
function handleDatabaseError($e, $debug = false) {
    // 错误处理
    if ($debug) {
        echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
        echo "<h3>数据库错误</h3>";
        echo "<p>" . $e->getMessage() . "</p>";
        echo "</div>";
    }
    error_log("获取站群服务器产品错误: " . $e->getMessage());
}

/**
 * 获取标签名称
 *
 * @param PDO $db 数据库连接
 * @param array $tagIds 标签ID数组
 * @return array 标签名称数组
 */
function getTagNames($db, $tagIds) {
    $tagNames = [];
    
    if (empty($tagIds)) {
        return $tagNames;
    }
    
    try {
        $placeholders = implode(',', array_fill(0, count($tagIds), '?'));
        $query = "SELECT id, name FROM tags WHERE id IN ($placeholders)";
        
        $stmt = $db->prepare($query);
        
        // 绑定参数
        foreach ($tagIds as $index => $id) {
            $stmt->bindValue($index + 1, $id);
        }
        
        $stmt->execute();
        
        while ($tag = $stmt->fetch()) {
            $tagNames[$tag['id']] = $tag['name'];
        }
    } catch (PDOException $e) {
        error_log("获取标签名称错误: " . $e->getMessage());
    }
    
    return $tagNames;
}

/**
 * 渲染产品卡片HTML
 *
 * @param array $product 产品数据
 * @param string $regionName 地区名称
 * @param int $index 产品索引，用于确定是否为特色产品
 * @return string 产品卡片HTML
 */
function renderProductCard($product, $regionName, $index = 0) {
    // 确定产品类别
    $category = "basic"; // 默认基础型
    if ($index == 1) {
        $category = "pro"; // 第二个产品为专业型
    } else if ($index >= 2) {
        $category = "enterprise"; // 第三个及以后产品为企业型
    }
    
    // 确定是否为推荐产品
    $cardClass = ($index == 0) ? 'product-card featured' : 'product-card';
    
    // 显示价格（美元）
    $priceUSD = $product['display_price'];
    
    // 产品编号
    $productId = $product['id'];
    $productCode = '8' . str_pad($productId, 4, '0', STR_PAD_LEFT);
    
    // 产品配置名称 - 改为地区站群服务器+阿拉伯数字序号
    $productName = "{$regionName}站群服务器 " . ($index + 1);
    
    // 根据地区确定线路描述
    $networkDesc = '优化多线BGP';
    if ($regionName == '香港') {
        $networkDesc = '大陆优化';
    } else if ($regionName == '韩国' || $regionName == '日本') {
        $networkDesc = '亚洲优化线路';
    }
    
    // 生成HTML
    $html = '
    <div class="'.$cardClass.'" data-category="'.$category.'">
        <div class="product-title">
            <a href="/product_detail.html?id='.$productId.'" target="_blank">
                '.$productName.'
            </a>
            <span class="tag">'.$regionName.'专区</span>
        </div>
        <div class="product-specs">
            <!-- 第一列：编号/硬盘/防御/地区 -->
            <div class="specs-column">
                <div class="spec-row">
                    <span class="spec-label">编号:</span>
                    <span>'.$productCode.'</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">硬盘:</span>
                    <span>'.$product['disk'].'</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">防御:</span>
                    <span>可选</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">地区:</span>
                    <span>'.$regionName.'</span>
                </div>
            </div>
            <!-- 第二列：CPU/宽带/线路/内存 -->
            <div class="specs-column">
                <div class="spec-row">
                    <span class="spec-label">CPU:</span>
                    <span>'.$product['cpu'].'</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">宽带:</span>
                    <span>'.$product['bandwidth'].'</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">线路:</span>
                    <span>'.$networkDesc.'</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">内存:</span>
                    <span>'.$product['memory'].'</span>
                </div>
            </div>
            <!-- 第三列：IP数/流量/价格/按钮 -->
            <div class="specs-column">
                <div class="spec-row">
                    <span class="spec-label">IP数:</span>
                    <span>'.$product['ip_count'].'个</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">流量:</span>
                    <span>不限</span>
                </div>
                <div class="spec-row">
                    <span class="spec-label">价格:</span>
                    <span class="unit">$'.number_format($priceUSD, 2).'/月</span>
                </div>
                <div class="spec-row action-row">
                    <a href="product_detail.html?id='.$productId.'" class="btn btn-primary">产品详情</a>
                    <a href="/contact.html" class="btn btn-outline" target="_blank">申请测机</a>
                </div>
            </div>
        </div>
    </div>';
    
    return $html;
}

/**
 * 渲染产品列表HTML
 *
 * @param array $products 产品数据数组
 * @param string $regionName 地区名称
 * @return string 产品列表HTML
 */
function renderProductList($products, $regionName) {
    $html = '<div class="product-list">';
    
    if (!empty($products)) {
        // 只显示前3个产品
        $products = array_slice($products, 0, 3);
        foreach ($products as $index => $product) {
            $html .= renderProductCard($product, $regionName, $index);
        }
    } else {
        $html .= '<div class="no-products">该地区暂无可用产品，请联系客服了解更多信息。</div>';
    }
    
    $html .= '</div>';
    
    return $html;
}

/**
 * 渲染美国区域选择器和产品内容
 *
 * @param array $regions 美国各地区及其产品数据
 * @return array 包含区域导航和区域内容HTML的数组
 */
function renderUsRegionContent($regions) {
    $result = [
        'region_nav' => '',
        'region_content' => ''
    ];
    
    // 区域导航HTML
    $regionNav = '<div class="filter-options region-nav" id="us-region-nav">';
    
    // 区域内容HTML
    $regionContent = '';
    
    // 筛选出有产品的地区
    $regionsWithProducts = [];
    foreach ($regions as $region) {
        if (!empty($region['products'])) {
            $regionsWithProducts[] = $region;
        }
    }
    
    if (!empty($regionsWithProducts)) {
        // 生成区域导航
        foreach ($regionsWithProducts as $index => $region) {
            $isActive = ($index === 0);
            $regionNav .= '<button type="button" class="region-nav-item '.($isActive ? 'active' : '').'" ';
            $regionNav .= 'data-region="'.$region['slug'].'">'.$region['name'].'</button>';
        }
        
        // 生成区域内容
        foreach ($regionsWithProducts as $index => $region) {
            $isActive = ($index === 0);
            
            $regionContent .= '<div class="region-content '.($isActive ? 'active' : '').'" id="region-'.$region['slug'].'">';
            $regionContent .= '<div class="region-header">';
            $regionContent .= '<div>';
            $regionContent .= '<h3><i class="fas fa-flag-usa"></i> '.$region['name'].'站群服务器</h3>';
            
            // 添加地区描述
            if ($region['slug'] == 'losangeles') {
                $regionContent .= '<div class="region-description">西海岸主要节点，连接亚太地区，延迟适中，适合面向亚洲用户的业务</div>';
            } elseif ($region['slug'] == 'newyork') {
                $regionContent .= '<div class="region-description">东海岸金融中心，连接欧洲，国际网络节点，适合全球业务</div>';
            } elseif ($region['slug'] == 'siliconvalley') {
                $regionContent .= '<div class="region-description">硅谷核心区域，高科技网络设施，稳定可靠，适合科技类网站</div>';
            } elseif ($region['slug'] == 'atlanta') {
                $regionContent .= '<div class="region-description">南部节点，网络覆盖广泛，稳定性高，适合多样化业务</div>';
            }
            
            $regionContent .= '</div></div>';
            
            // 渲染产品列表
            $regionContent .= renderProductList($region['products'], $region['name']);
            $regionContent .= '</div>';
        }
    } else {
        // 如果没有有效区域，显示默认全部按钮
        $regionNav .= '<button type="button" class="filter-btn active" data-filter="all">全部地区</button>';
    }
    
    $regionNav .= '</div>';
    
    $result['region_nav'] = $regionNav;
    $result['region_content'] = $regionContent;
    
    return $result;
}

/**
 * 初始化所有站群服务器数据
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 包含所有地区站群服务器数据的数组
 */
function initAllClusterData($debug = false) {
    return [
        'hongKongProducts' => getHongKongClusterProducts($debug),
        'usaProducts' => getUsaClusterProducts($debug),
        'koreaProducts' => getKoreaClusterProducts($debug),
        'japanProducts' => getJapanClusterProducts($debug),
        'usRegions' => getUsRegionsWithProducts($debug)
    ];
}
