<?php
// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 引入数据库配置文件
require_once ROOT_PATH . '/config/database.php';

// 获取视频分类和视频数据
function getVideoData() {
    $result = [
        'categories' => [],
        'categoryVideos' => []
    ];
    
    try {
        // 获取数据库连接
        $db = getDbConnection();
        // 获取视频分类数据
        $categoriesQuery = "SELECT * FROM video_categories WHERE status = 1 ORDER BY sort_order ASC";
        $categoriesStmt = $db->query($categoriesQuery);
        $result['categories'] = $categoriesStmt->fetchAll();
        
        // 获取每个分类下的视频数据
        foreach ($result['categories'] as $category) {
            $videosQuery = "SELECT * FROM videos WHERE category_id = :category_id AND status = 1 ORDER BY created_at DESC LIMIT 4";
            $videosStmt = $db->prepare($videosQuery);
            $videosStmt->execute(['category_id' => $category['id']]);
            $result['categoryVideos'][$category['id']] = $videosStmt->fetchAll();
        }
    } catch (PDOException $e) {
        // 错误处理
        error_log("数据库错误: " . $e->getMessage());
        // 如果出错，使用空数组防止页面报错
        $result['categories'] = [];
        $result['categoryVideos'] = [];
    }
    
    return $result;
}
?>
