<?php
// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 引入数据库配置文件
require_once ROOT_PATH . '/config/database.php';

// 获取分类ID
$category_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取分类信息
    $categoryQuery = "SELECT * FROM video_categories WHERE id = :id AND status = 1";
    $categoryStmt = $db->prepare($categoryQuery);
    $categoryStmt->execute(['id' => $category_id]);
    $category = $categoryStmt->fetch();
    
    // 如果分类不存在，重定向到视频首页
    if (!$category) {
        header('Location: /video');
        exit;
    }
    
    // 分页设置
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
    $limit = 12; // 每页显示12个视频
    $offset = ($page - 1) * $limit;
    
    // 获取分类下的视频总数
    $countQuery = "SELECT COUNT(*) FROM videos WHERE category_id = :category_id AND status = 1";
    $countStmt = $db->prepare($countQuery);
    $countStmt->execute(['category_id' => $category_id]);
    $totalVideos = $countStmt->fetchColumn();
    
    // 计算总页数
    $totalPages = ceil($totalVideos / $limit);
    
    // 获取分类下的视频
    $videosQuery = "SELECT * FROM videos WHERE category_id = :category_id AND status = 1 ORDER BY created_at DESC LIMIT :offset, :limit";
    $videosStmt = $db->prepare($videosQuery);
    $videosStmt->bindValue(':category_id', $category_id, PDO::PARAM_INT);
    $videosStmt->bindValue(':offset', $offset, PDO::PARAM_INT);
    $videosStmt->bindValue(':limit', $limit, PDO::PARAM_INT);
    $videosStmt->execute();
    $videos = $videosStmt->fetchAll();
    
} catch (PDOException $e) {
    // 错误处理
    error_log("数据库错误: " . $e->getMessage());
    // 如果出错，重定向到视频首页
    header('Location: /video');
    exit;
}
?>
