<?php
/**
 * 文档详情页面
 * 从数据库中读取指定ID的文档详细内容
 */
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <?php 
    include 'public/config.php'; 
    
    // 引入数据库配置文件
    require_once 'config/database.php';
    
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取文档ID
    $id = isset($_GET['id']) ? intval($_GET['id']) : 0;
    
    if ($id <= 0) {
        // 如果没有指定ID或ID无效，重定向到文档中心页面
        header('Location: repository.html');
        exit;
    }
    
    // 查询文档内容
    $document = null;
    $documentQuery = "SELECT i.*, c.name as category_name, c.slug as category_slug 
                     FROM repositor_item i 
                     JOIN repositor_category c ON i.category_id = c.id 
                     WHERE i.id = ? AND i.status = 1";
    $stmt = $db->prepare($documentQuery);
    $stmt->execute([$id]);
    $document = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$document) {
        // 如果文档不存在，重定向到文档中心页面
        header('Location: repository.html');
        exit;
    }
    
    // 查询相关文档（同一分类下的其他文档）
    $relatedDocs = [];
    $relatedQuery = "SELECT * FROM repositor_item 
                    WHERE category_id = ? AND id != ? AND status = 1 
                    ORDER BY sort_order ASC 
                    LIMIT 5";
    $stmt = $db->prepare($relatedQuery);
    $stmt->execute([$document['category_id'], $id]);
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $relatedDocs[] = $row;
    }
    
    // 页面标题
    $pageTitle = $document['question'] . ' - 文档中心';
    ?>
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title><?php echo $pageTitle; ?></title>
        <meta name="keywords" content="服务器文档,服务器教程,云服务器指南,服务器配置,技术文档">
        <meta name="description" content="<?php echo strip_tags(substr($document['answer'], 0, 200)); ?>">
        <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
        <link href="/public/css/style.css" rel="stylesheet">
        <link href="/public/css/breadcrumb.css" rel="stylesheet">
        <link href="/public/css/repository.css" rel="stylesheet">
        <link href="/public/css/document.css" rel="stylesheet">
        <style>
            /* 确保内容正确显示的内联样式 */
            .document-body ul {
                list-style-type: disc;
            }
            .document-body ol {
                list-style-type: decimal;
            }
            .document-body strong {
                font-weight: bold;
            }
            .document-body p {
                margin-bottom: 15px;
            }
            .btn-action {
                margin-right: 10px;
            }
            .document-meta span {
                margin-right: 15px;
            }
        </style>
    </head>
    <body>
        <!-- 顶部导航 -->
        <?php include 'public/header.php'; ?>
        <!-- Banner 区域 -->
        <?php include 'public/banner.php'; ?>
        <!-- 主内容区 -->
        <div class="main-content">
            <div class="document-wrapper">
                <!-- 面包屑导航 -->
                <div class="container">
                    <div class="breadcrumb">
                        <a href="/">首页</a>
                        <i class="material-icons">chevron_right</i>
                        <a href="repository.html">文档中心</a>
                        <i class="material-icons">chevron_right</i>
                        <a href="repository.html#<?php echo $document['category_slug']; ?>"><?php echo $document['category_name']; ?></a>
                        <i class="material-icons">chevron_right</i>
                        <span><?php echo $document['question']; ?></span>
                    </div>
                </div>
                
                <div class="document-container">
                    <div class="document-sidebar">
                        <div class="sidebar-section">
                            <h3>相关文档</h3>
                            <ul>
                                <?php foreach ($relatedDocs as $relatedDoc): ?>
                                <li><a href="document.html?id=<?php echo $relatedDoc['id']; ?>"><?php echo $relatedDoc['question']; ?></a></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                        <div class="sidebar-section">
                            <h3>更多资源</h3>
                            <ul>
                                <li><a href="#">技术支持</a></li>
                                <li><a href="#">视频教程</a></li>
                                <li><a href="#">常见问题</a></li>
                                <li><a href="#">联系我们</a></li>
                            </ul>
                        </div>
                    </div>
                    
                    <div class="document-content">
                        <div class="document-header">
                            <h1><?php echo $document['question']; ?></h1>
                            <div class="document-meta">
                                <span><i class="material-icons">access_time</i> 更新日期：<?php echo date('Y-m-d', strtotime($document['updated_at'] ? $document['updated_at'] : $document['created_at'])); ?></span>
                                <span><i class="material-icons">folder</i> 分类：<?php echo $document['category_name']; ?></span>
                            </div>
                        </div>
                        
                        <div class="document-body">
                            <?php echo $document['answer']; ?>
                        </div>
                        
                        <div class="document-footer">
                            <div class="document-actions">
                                <span>此文档对您有帮助吗？</span>
                                <button class="btn-action"><i class="material-icons">thumb_up</i> 有帮助</button>
                                <button class="btn-action"><i class="material-icons">thumb_down</i> 没帮助</button>
                            </div>
                            
                            <div class="document-share">
                                <span>分享这篇文档：</span>
                                <a href="#" class="share-link"><i class="material-icons">content_copy</i> 复制链接</a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- 页脚 -->
        <?php include 'public/kf.php'; ?>
        <?php include 'public/footer.php'; ?>
        <script src="/public/js/js.js"></script>
        <script>
            // 添加文档页面特有的JavaScript
            document.addEventListener('DOMContentLoaded', function() {
                // 复制链接按钮功能
                const copyLinkBtn = document.querySelector('.share-link');
                if (copyLinkBtn) {
                    copyLinkBtn.addEventListener('click', function(e) {
                        e.preventDefault();
                        const url = window.location.href;
                        
                        // 创建临时输入框
                        const tempInput = document.createElement('input');
                        tempInput.style.position = 'absolute';
                        tempInput.style.left = '-1000px';
                        tempInput.value = url;
                        document.body.appendChild(tempInput);
                        
                        // 选择并复制
                        tempInput.select();
                        document.execCommand('copy');
                        
                        // 移除临时输入框
                        document.body.removeChild(tempInput);
                        
                        // 显示提示
                        alert('链接已复制到剪贴板！');
                    });
                }
                
                // 文档有用/没用按钮功能
                const actionBtns = document.querySelectorAll('.btn-action');
                actionBtns.forEach(btn => {
                    btn.addEventListener('click', function() {
                        // 添加已点击样式
                        actionBtns.forEach(b => b.classList.remove('active'));
                        this.classList.add('active');
                        
                        // 这里可以添加AJAX请求记录用户反馈
                        alert('感谢您的反馈！');
                    });
                });
            });
        </script>
    </body>
</html> 