<?php
// 定义ROOT_PATH常量
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', __DIR__);
}

// 添加调试代码
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <?php include ROOT_PATH . '/public/config.php'; ?>
  <?php include ROOT_PATH . '/public/includes/faq_data.php'; ?>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>服务器常见问题解答 - 选型、维护与技术支持指南 | 专业IDC知识库</title>
    <meta name="keywords" content="服务器常见问题,服务器选择指南,CN2线路说明,服务器技术支持,云服务器vs物理服务器,高防服务器问题,服务器故障排查,服务器账单管理,网络安全常见问题,IDC技术知识库">
    <meta name="description" content="全面的服务器常见问题解答中心，涵盖服务器选型对比、技术支持、账户管理、付款账单和网络安全等核心问题。提供CN2/GIA线路详解、物理服务器与云服务器对比分析、服务器配置指南等专业IDC知识。">
    <?php echo getCommonCss(); ?>
    <link href="/public/css/faq.css" rel="stylesheet">

  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include ROOT_PATH . '/public/header.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <!-- Banner 区域 -->
      <?php include ROOT_PATH . '/public/banner.php'; ?>
      <!-- 内容区域 -->
      <div class="faq-content">
        <!-- 面包屑导航 -->
        <div class="breadcrumb">
          <a href="/">首页</a>
          <i class="material-icons">chevron_right</i>
          <span>常见问题</span>
        </div>
        <!-- 页面标题 -->
        <div class="page-header">
          <h1>常见问题</h1>
          <p>为您解答服务器选择、使用和维护过程中的常见问题</p>
        </div>
        <!-- 搜索框 -->
        <div class="faq-search">
          <div class="search-container">
            <i class="material-icons">search</i>
            <input type="text" placeholder="输入关键词搜索问题..." id="faq-search-input">
            <button class="search-btn">搜索</button>
          </div>
        </div>
        <?php
                // 获取数据库中的FAQ分类和问题数据
                $faqData = getAllFaqData();
                
                // 检查是否有数据被返回 - 调试
                if (empty($faqData)) {
                    echo '<div style="background-color: #ffeeee; padding: 15px; margin: 15px; border: 1px solid #ff0000;">
                        <strong>调试信息：</strong> 没有从数据库获取到FAQ数据，请检查数据库连接和表内容。
                    </div>';
                }
                
                // 如果搜索关键词存在，则执行搜索
                $keyword = isset($_GET['q']) ? trim($_GET['q']) : '';
                $searchResults = [];
                if (!empty($keyword)) {
                    $searchResults = searchFaqItems($keyword);
                }
                
                // 获取当前激活的分类（从URL中获取）
                $activeCategory = isset($_GET['category']) ? $_GET['category'] : 'server-selection';
                ?>
        <!-- 问题分类导航 -->
        <div class="faq-categories">
          <?php foreach ($faqData as $category): ?>
          <a href="#<?= $category['slug']; ?>" class="category-item <?= ($category['slug'] == $activeCategory) ? 'active' : ''; ?>">
            <i class="material-icons"><?= $category['icon']; ?></i>
            <span><?= $category['name']; ?></span>
          </a>
          <?php endforeach; ?>
        </div>
        <!-- 常见问题列表 -->
        <div class="faq-sections">
          <?php if (!empty($keyword) && !empty($searchResults)): ?>
          <!-- 搜索结果 -->
          <section id="search-results" class="faq-section active">
            <div class="section-header">
              <h2>搜索结果: "<?= htmlspecialchars($keyword); ?>"</h2>
              <p>找到 <?= count($searchResults); ?> 个匹配的问题</p>
            </div>
            <div class="faq-list">
              <?php foreach ($searchResults as $item): ?>
              <div class="faq-item">
                <div class="faq-question">
                  <i class="material-icons">help_outline</i>
                  <h3><?= $item['question']; ?></h3>
                  <i class="material-icons toggle-icon">expand_more</i>
                </div>
                <div class="faq-answer">
                  <?= $item['answer']; ?>
                </div>
              </div>
              <?php endforeach; ?>
            </div>
          </section>
          <?php elseif (!empty($keyword) && empty($searchResults)): ?>
          <!-- 无搜索结果 -->
          <section id="search-results" class="faq-section active">
            <div class="section-header">
              <h2>搜索结果: "<?= htmlspecialchars($keyword); ?>"</h2>
              <p>没有找到匹配的问题，请尝试其他关键词</p>
            </div>
          </section>
          <?php else: ?>
          <!-- 常规FAQ内容 -->
          <?php foreach ($faqData as $index => $category): ?>
          <section id="<?= $category['slug']; ?>" class="faq-section <?= ($category['slug'] == $activeCategory || ($index == 0 && $activeCategory == '')) ? 'active' : ''; ?>">
            <div class="section-header">
              <h2><?= $category['name']; ?></h2>
              <p><?= $category['description']; ?></p>
            </div>
            <div class="faq-list">
              <?php if (isset($category['items']) && !empty($category['items'])): ?>
              <?php foreach ($category['items'] as $item): ?>
              <div class="faq-item">
                <div class="faq-question">
                  <i class="material-icons">help_outline</i>
                  <h3><?= $item['question']; ?></h3>
                  <i class="material-icons toggle-icon">expand_more</i>
                </div>
                <div class="faq-answer">
                  <?= $item['answer']; ?>
                </div>
              </div>
              <?php endforeach; ?>
              <?php else: ?>
              <p>此分类下暂无常见问题。</p>
              <?php endif; ?>
            </div>
          </section>
          <?php endforeach; ?>
          <?php endif; ?>
        </div> <!-- close faq-sections -->
        <!-- 联系我们 -->
        <section class="contact-section">
          <div class="contact-content">
            <h2>没有找到您的问题？</h2>
            <p>我们的技术支持团队随时为您提供帮助</p>
            <div class="contact-buttons">
              <a href="<?= $Telegram ?>" class="btn btn-primary" target="_blank">在线咨询</a>
              <a href="#" class="btn btn-outline">提交工单</a>
            </div>
          </div>
        </section>
      </div> <!-- close faq-content -->
    </div> <!-- close main-content -->
    <?php include ROOT_PATH . '/public/footer.php'; ?>
    <script>
    $(document).ready(function() {
      // 分类切换
      $('.faq-categories .category-item').click(function(e) {
        e.preventDefault();
        var target = $(this).attr('href');
        // 更新URL但不刷新页面
        if (history.pushState) {
          var newUrl = window.location.protocol + "//" + window.location.host + window.location.pathname + '?category=' + target.substr(1);
          window.history.pushState({
            path: newUrl
          }, '', newUrl);
        }
        // 激活分类
        $('.faq-categories .category-item').removeClass('active');
        $(this).addClass('active');
        // 显示对应分类的内容
        $('.faq-section').removeClass('active');
        $(target).addClass('active');
      });
      // 展开/折叠问题 - 修改这部分代码
      $('.faq-question').click(function() {
        // 找到当前问题对应的答案元素
        var $answer = $(this).next('.faq-answer');
        // 直接设置内容显示状态，不使用复杂的动画
        if ($answer.is(':visible')) {
          $answer.hide();
          $(this).removeClass('active');
          $(this).find('.toggle-icon').text('expand_more');
        } else {
          $answer.show();
          $(this).addClass('active');
          $(this).find('.toggle-icon').text('expand_less');
        }
      });
      // 搜索功能
      $('.search-btn').click(function() {
        var keyword = $('#faq-search-input').val().trim();
        if (keyword) {
          window.location.href = '?q=' + encodeURIComponent(keyword);
        }
      });
      // 回车搜索
      $('#faq-search-input').keypress(function(e) {
        if (e.which == 13) {
          $('.search-btn').click();
        }
      });
      // 初始化时确保每个问题的答案都是隐藏的
      $('.faq-answer').hide();
    });
    </script>
  </body>
</html>
