<?php
// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 获取URL中的分类ID
$category_id = 0;
// 安全获取REQUEST_URI，避免警告
$request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';

// 添加调试信息
// echo "REQUEST_URI: " . $request_uri . "<br>";

// 处理新的URL格式： /news/2 或 /news/2/
if ($request_uri && preg_match('#/news/(\d+)/?$#', $request_uri, $matches)) {
    $category_id = intval($matches[1]);
    // echo "Matched category ID: " . $category_id . "<br>";
} 
// 处理旧的URL格式： index.php?category_id=2
elseif (isset($_GET['category_id'])) {
    $category_id = intval($_GET['category_id']);
    // echo "GET category ID: " . $category_id . "<br>";
}

// 将category_id设置到$_GET中，以便news_code.php能够正常工作
$_GET['category_id'] = $category_id;

// 引入新闻逻辑处理文件
require_once ROOT_PATH . '/code/news_code.php';

// 引入数据库配置
require_once ROOT_PATH . '/config/database.php';

// 获取数据库连接
$db = getDbConnection();

// 获取新闻数据
$newsData = getNewsData();
$newsList = $newsData['newsList'];
$categories = $newsData['categories'];
$pagination = $newsData['pagination'];

// 获取热门文章，指定获取10条
$hotNews = getHotNews(10);

// 引入公共配置
include ROOT_PATH . '/public/config.php';

// 引入产品数据相关文件
require_once ROOT_PATH . '/code/product_data.php';
require_once ROOT_PATH . '/code/product_helper.php';

// 获取推荐产品数据，限制5个
$recProducts = getRecommendedProducts($db, 5);

// 获取区域名称，用于产品展示
$areaNames = getAreaNames($db);
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>服务器行业资讯 - 云计算技术教程 | 全球服务器动态</title>
    <meta name="description" content="提供全球服务器行业最新资讯、云计算技术动态、服务器选购指南和实用技术教程。涵盖香港、美国、日本、韩国等地区服务器市场分析，DDoS防御技术解析，以及各类服务器运维管理实践经验分享。">
    <meta name="keywords" content="服务器资讯,云计算技术,服务器教程,服务器选购指南,香港服务器动态,美国服务器动态,高防服务器技术,服务器运维,云服务器资讯,技术博客">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="/public/css/style.css" rel="stylesheet">
    <link href="/public/css/breadcrumb.css" rel="stylesheet">
    <link href="/public/css/news.css" rel="stylesheet">
  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include ROOT_PATH . '/public/header.php'; ?>
    <div class="main-content">
      <!-- Banner 区域 -->
      <?php include ROOT_PATH . '/public/banner.php'; ?>
      <!-- 内容区域 -->
      <div class="news-wrapper">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/">
              首页
            </a>
            <i class="material-icons">chevron_right</i>
            <a href="/news">
              资讯中心
            </a>
            <i class="material-icons">chevron_right</i>
            <span>行业资讯</span>
          </div>
        </div>
        <!-- 页面标题区域 -->
        <div class="promo-section">
          <div class="promo-title">
            <svg class="" viewBox="0 0 24 24" width="35" height="30">
              <path fill="#ff6600" d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27z" />
            </svg>
            <span class="promo-title-text with-underline">行业资讯 技术洞察</span>
          </div>
          <div class="promo-desc" style="display:block;"> 持续关注云计算和服务器技术发展，分享最新行业动态和前沿知识
            <a href="/news" class="promo-rules">
              更多资讯 ›
            </a>
          </div>
        </div>
        <div class="news-container">
          <!-- 左侧分类导航 -->
          <div class="news-sidebar">
            <div class="category-list">
              <div class="category-list-title">新闻分类</div>
              <ul>
                <li>
                  <a href="/news" <?php echo $category_id == 0 ? 'class="active"' : ''; ?>>
                    全部新闻
                  </a>
                </li>
                <?php foreach ($categories as $category): ?>
                <li>
                  <a href="/news/<?php echo $category['id']; ?>" <?php echo $category_id == $category['id'] ? 'class="active"' : ''; ?>>
                    <?php echo $category['name']; ?>
                  </a>
                </li>
                <?php endforeach; ?>
              </ul>
            </div>
            <!-- 热门文章 -->
            <div class="sidebar-box hot-news">
              <div class="sidebar-title">
                <i class="material-icons">whatshot</i>
                <span>热门文章</span>
              </div>
              <ul class="hot-news-list">
                <?php 
                                $rank = 1;
                                foreach ($hotNews as $hot): 
                                ?>
                <li>
                  <a href="/news/<?php echo $hot['id']; ?>.html">
                    <span class="hot-news-rank"><?php echo $rank++; ?></span>
                    <span class="hot-news-title"><?php echo $hot['title']; ?></span>
                  </a>
                </li>
                <?php endforeach; ?>
              </ul>
            </div>
            <!-- 推荐产品 -->
            <div class="sidebar-box featured-products">
              <div class="sidebar-title">
                <i class="material-icons">star</i>
                <span>热门产品</span>
              </div>
              <?php if (empty($recProducts)): ?>
              <div class="product-card">
                <div class="product-title">暂无推荐产品</div>
              </div>
              <?php else: ?>
              <?php foreach ($recProducts as $product): ?>
              <div class="product-card">
                <div class="product-specs">
                  <div class="spec-row">
                    <div class="spec-item">
                      <span class="spec-label">编号:</span>
                      <span class="spec-value"><?php echo formatProductId($product['id']); ?></span>
                    </div>
                    <div class="spec-item">
                      <span class="spec-label">CPU:</span>
                      <span class="spec-value"><?php echo htmlspecialchars($product['upc'] ?? ''); ?></span>
                    </div>
                  </div>
                  <div class="spec-row">
                    <div class="spec-item">
                      <span class="spec-label">硬盘:</span>
                      <span class="spec-value"><?php echo htmlspecialchars($product['disk'] ?? ''); ?></span>
                    </div>
                    <div class="spec-item">
                      <span class="spec-label">宽带:</span>
                      <span class="spec-value"><?php echo htmlspecialchars($product['bandwidth'] ?? ''); ?></span>
                    </div>
                  </div>
                  <div class="spec-row">
                    <div class="spec-item">
                      <span class="spec-label">防御:</span>
                      <span class="spec-value"><?php echo getDefenseDisplay($product['defense'] ?? ''); ?></span>
                    </div>
                    <div class="spec-item">
                      <span class="spec-label">线路:</span>
                      <span class="spec-value"><?php echo htmlspecialchars($product['line_id'] ?? '优化带宽'); ?></span>
                    </div>
                  </div>
                  <div class="spec-row">
                    <div class="spec-item">
                      <span class="spec-label">地区:</span>
                      <span class="spec-value"><?php echo getRegionDisplay($product['region_id'] ?? 0, $areaNames); ?></span>
                    </div>
                    <div class="spec-item">
                      <span class="spec-label">内存:</span>
                      <span class="spec-value"><?php echo htmlspecialchars($product['memory'] ?? ''); ?></span>
                    </div>
                  </div>
                  <div class="spec-row">
                    <div class="spec-item">
                      <span class="spec-label">IP数:</span>
                      <span class="spec-value"><?php echo htmlspecialchars($product['ip_count'] ?? ''); ?>个</span>
                    </div>
                    <div class="spec-item">
                      <span class="spec-label">流量:</span>
                      <span class="spec-value"><?php echo getTrafficDisplay($product['traffic'] ?? ''); ?></span>
                    </div>
                  </div>
                  <div class="spec-row">
                    <div class="spec-item">
                      <span class="spec-label">价格:</span>
                      <span class="spec-value">$<?php echo getRecommendedProductPrice($product['price']); ?>/月</span>
                    </div>
                  </div>
                </div>
                <div class="product-buttons">
                  <a href="/cart.html?id=<?php echo $product['id']; ?>" class="product-btn-detail">
                    立即购买
                  </a>
                  <a href="<?= $Telegram ?>" class="product-btn-apply" target="_blank">
                    申请测机
                  </a>
                </div>
              </div>
              <?php endforeach; ?>
              <?php endif; ?>
            </div>
          </div>
          <!-- 右侧新闻列表 -->
          <div class="news-content">
            <div class="news-list">
              <h1 class="news-list-title"> 最新资讯 </h1>
              <?php
                            foreach ($newsList as $news) {
                                ?>
              <div class="news-item">
                <h2 class="news-item-title">
                  <a href="/news/<?php echo $news['id']; ?>.html">
                    <?php echo $news['title']; ?>
                  </a>
                </h2>
                <div class="news-item-meta">
                  <span>分类：<?php echo $news['category_name']; ?></span>
                  <span>发布时间：<?php echo date('Y-m-d', strtotime($news['created_at'])); ?></span>
                  <span>浏览：<?php echo $news['views']; ?>次</span>
                </div>
                <div class="news-item-summary"><?php echo $news['summary']; ?></div>
                <div class="news-item-more">
                  <a href="/news/<?php echo $news['id']; ?>.html">
                    阅读全文 &raquo;
                  </a>
                </div>
              </div>
              <?php
                            }
                            ?>
            </div>
            <!-- 分页控件 -->
            <div class="pagination">
              <?php echo generatePaginationHtml($pagination); ?>
            </div>
          </div>
        </div>
        <!-- 热门标签区域 -->
        <div class="tags-section">
          <div class="promo-section">
            <div class="promo-title">
              <svg class="" viewBox="0 0 24 24" width="35" height="30">
                <path fill="#ff6600" d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27z" />
              </svg>
              <span class="promo-title-text">热门标签</span>
            </div>
            <div class="tags-container">
              <a href="#" class="tag-item">
                服务器
              </a>
              <a href="#" class="tag-item">
                云计算
              </a>
              <a href="#" class="tag-item">
                高防服务器
              </a>
              <a href="#" class="tag-item">
                香港服务器
              </a>
              <a href="#" class="tag-item">
                美国服务器
              </a>
              <a href="#" class="tag-item">
                CN2线路
              </a>
              <a href="#" class="tag-item">
                DDoS防护
              </a>
              <a href="#" class="tag-item">
                Linux优化
              </a>
              <a href="#" class="tag-item">
                服务器安全
              </a>
              <a href="#" class="tag-item">
                性能调优
              </a>
              <a href="#" class="tag-item">
                网站加速
              </a>
              <a href="#" class="tag-item">
                服务器托管
              </a>
            </div>
          </div>
        </div>
      </div>
    </div>
    <!-- 页脚 -->
    <!-- 引入JavaScript文件 -->
    <?php include ROOT_PATH . '/public/kf.php'; ?>
    <?php include ROOT_PATH . '/public/footer.php'; ?>
    <script src="/public/js/js.js"></script>
  </body>
</html>
