<?php
// 定义ROOT_PATH常量
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 获取URL中的ID（支持新旧两种URL格式）
$news_id = 0;
// 安全获取REQUEST_URI，避免警告
$request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';

// 处理新的URL格式： /news/2.html
if ($request_uri && preg_match('/\/news\/(\d+)\.html/', $request_uri, $matches)) {
    $news_id = intval($matches[1]);
} 
// 处理旧的URL格式： sohw.php?id=2
elseif (isset($_GET['id'])) {
    $news_id = intval($_GET['id']);
}

// 将news_id设置到$_GET中，以便news_detail_code.php能够正常工作
$_GET['id'] = $news_id;

// 如果没有设置id参数，重定向到新闻列表页
if ($news_id <= 0) {
    header('Location: /news');
    exit;
}

// 定义标记，表示重定向已经在此文件中处理
define('REDIRECT_HANDLED', true);

include ROOT_PATH . '/code/news_detail_code.php';

// 引入数据库配置
require_once ROOT_PATH . '/config/database.php';

// 获取数据库连接
$db = getDbConnection();

// 引入产品数据相关文件
require_once ROOT_PATH . '/code/product_data.php';
require_once ROOT_PATH . '/code/product_helper.php';

// 获取推荐产品数据，限制3个
$recProducts = getRecommendedProducts($db, 3);

// 获取区域名称，用于产品展示
$areaNames = getAreaNames($db);
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $newsDetail['title']; ?> - 新闻中心</title>
    <meta name="description" content="<?php echo $newsDetail['summary']; ?>">
    <meta name="keywords" content="<?php echo $newsDetail['keywords']; ?>,服务器,云计算,技术文章,景天云">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="/public/css/style.css" rel="stylesheet">
    <link href="/public/css/news.css" rel="stylesheet">
    <link href="/public/css/breadcrumb.css" rel="stylesheet">
  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include ROOT_PATH . '/public/header.php'; ?>
    <!-- Banner 区域 -->
    <?php include ROOT_PATH . '/public/banner.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <div class="news-detail-wrapper">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/">首页</a>
            <i class="material-icons">chevron_right</i>
            <a href="/news">资讯中心</a>
            <i class="material-icons">chevron_right</i>
            <span><?php echo $newsDetail['title']; ?></span>
          </div>
        </div>
        <div class="news-wrapper">
          <!-- 页面标题区域 -->
          <div class="promo-section">
            <div class="promo-title">
              <svg class="" viewBox="0 0 24 24" width="35" height="30">
                <path fill="#ff6600" d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27z" />
              </svg>
              <span class="promo-title-text with-underline">文章详情</span>
            </div>
            <div class="promo-desc">
              查看完整的技术文章和行业资讯
              <a href="/news" class="promo-rules">返回列表 ›</a>
            </div>
          </div>
          <div class="news-container">
            <!-- 左侧分类导航 -->
            <div class="news-sidebar">
              <div class="category-list">
                <div class="category-list-title">新闻分类</div>
                <ul>
                  <li>
                    <a href="/news">
                      全部新闻
                    </a>
                  </li>
                  <?php foreach ($categories as $category): ?>
                  <li>
                    <a href="/news?category_id=<?php echo $category['id']; ?>" <?php echo $newsDetail['category_id'] == $category['id'] ? 'class="active"' : ''; ?>>
                      <?php echo $category['name']; ?>
                    </a>
                  </li>
                  <?php endforeach; ?>
                </ul>
              </div>
              <!-- 热门文章 -->
              <div class="sidebar-box hot-news">
                <div class="sidebar-title">
                  <i class="material-icons">whatshot</i>
                  <span>热门文章</span>
                </div>
                <ul class="hot-news-list">
                  <?php 
                                    $rank = 1;
                                    foreach ($hotNews as $hot): 
                                    ?>
                  <li>
                    <a href="/news/<?php echo $hot['id']; ?>.html">
                      <span class="hot-news-rank"><?php echo $rank++; ?></span>
                      <span class="hot-news-title"><?php echo $hot['title']; ?></span>
                    </a>
                  </li>
                  <?php endforeach; ?>
                </ul>
              </div>
              <!-- 推荐产品 -->
              <div class="sidebar-box featured-products">
                <div class="sidebar-title">
                  <i class="material-icons">star</i>
                  <span>热门产品</span>
                </div>
                <?php if (empty($recProducts)): ?>
                <div class="product-card">
                  <div class="product-title">暂无推荐产品</div>
                </div>
                <?php else: ?>
                <?php foreach ($recProducts as $product): ?>
                <div class="product-card">
                  <div class="product-specs">
                    <div class="spec-row">
                      <div class="spec-item">
                        <span class="spec-label">编号:</span>
                        <span class="spec-value"><?php echo formatProductId($product['id']); ?></span>
                      </div>
                      <div class="spec-item">
                        <span class="spec-label">CPU:</span>
                        <span class="spec-value"><?php echo htmlspecialchars($product['upc'] ?? ''); ?></span>
                      </div>
                    </div>
                    <div class="spec-row">
                      <div class="spec-item">
                        <span class="spec-label">硬盘:</span>
                        <span class="spec-value"><?php echo htmlspecialchars($product['disk'] ?? ''); ?></span>
                      </div>
                      <div class="spec-item">
                        <span class="spec-label">宽带:</span>
                        <span class="spec-value"><?php echo htmlspecialchars($product['bandwidth'] ?? ''); ?></span>
                      </div>
                    </div>
                    <div class="spec-row">
                      <div class="spec-item">
                        <span class="spec-label">防御:</span>
                        <span class="spec-value"><?php echo getDefenseDisplay($product['defense'] ?? ''); ?></span>
                      </div>
                      <div class="spec-item">
                        <span class="spec-label">线路:</span>
                        <span class="spec-value"><?php echo htmlspecialchars($product['line_id'] ?? '优化带宽'); ?></span>
                      </div>
                    </div>
                    <div class="spec-row">
                      <div class="spec-item">
                        <span class="spec-label">地区:</span>
                        <span class="spec-value"><?php echo getRegionDisplay($product['region_id'] ?? 0, $areaNames); ?></span>
                      </div>
                      <div class="spec-item">
                        <span class="spec-label">内存:</span>
                        <span class="spec-value"><?php echo htmlspecialchars($product['memory'] ?? ''); ?></span>
                      </div>
                    </div>
                    <div class="spec-row">
                      <div class="spec-item">
                        <span class="spec-label">IP数:</span>
                        <span class="spec-value"><?php echo htmlspecialchars($product['ip_count'] ?? ''); ?>个</span>
                      </div>
                      <div class="spec-item">
                        <span class="spec-label">流量:</span>
                        <span class="spec-value"><?php echo getTrafficDisplay($product['traffic'] ?? ''); ?></span>
                      </div>
                    </div>
                    <div class="spec-row">
                      <div class="spec-item">
                        <span class="spec-label">价格:</span>
                        <span class="spec-value">$<?php echo getRecommendedProductPrice($product['price']); ?>/月</span>
                      </div>
                    </div>
                  </div>
                  <div class="product-buttons">
                    <a href="/product/<?php echo $product['id']; ?>.html"" class="product-btn-detail">查看详情</a>
                    <a href="<?= $Telegram ?>" class="product-btn-apply" target="_blank">申请测试</a>
                  </div>
                </div>
                <?php endforeach; ?>
                <?php endif; ?>
              </div>
              <!-- 相关文章 -->
              <div class="sidebar-box related-news">
                <div class="sidebar-title">
                  <i class="material-icons">library_books</i>
                  <span>相关文章</span>
                </div>
                <ul>
                  <?php foreach ($relatedNews as $related): ?>
                  <li>
                    <a href="/news/<?php echo $related['id']; ?>.html"><?php echo $related['title']; ?></a>
                    <div class="news-date"><?php echo date('Y-m-d', strtotime($related['created_at'])); ?></div>
                  </li>
                  <?php endforeach; ?>
                </ul>
              </div>
              <!-- 客服联系 -->
            </div>
            <!-- 右侧文章内容 -->
            <div class="news-content">
              <div class="news-detail">
                <div class="news-detail-header">
                  <h1 class="news-detail-title"><?php echo $newsDetail['title']; ?></h1>
                  <div class="news-detail-meta">
                    <span><i class="material-icons" style="font-size: 16px; vertical-align: text-bottom;">category</i> 分类：<?php echo $newsDetail['category_name']; ?></span>
                    <span><i class="material-icons" style="font-size: 16px; vertical-align: text-bottom;">schedule</i> 发布时间：<?php echo date('Y-m-d', strtotime($newsDetail['created_at'])); ?></span>
                    <span><i class="material-icons" style="font-size: 16px; vertical-align: text-bottom;">visibility</i> 浏览：<?php echo $newsDetail['views']; ?>次</span>
                  </div>
                </div>
                <div class="news-detail-content">
                  <?php echo $newsDetail['content']; ?>
                </div>
                <div class="news-detail-footer">
                  <div class="prev-next-links">
                    <?php if($prevNews): ?>
                    <a href="/news/<?php echo $prevNews['id']; ?>.html" class="prev-link"><i class="material-icons" style="font-size: 16px; vertical-align: text-bottom;">arrow_back</i> 上一篇：<?php echo $prevNews['title']; ?></a>
                    <?php endif; ?>
                    <?php if($nextNews): ?>
                    <a href="/news/<?php echo $nextNews['id']; ?>.html" class="next-link">下一篇：<?php echo $nextNews['title']; ?> <i class="material-icons" style="font-size: 16px; vertical-align: text-bottom;">arrow_forward</i></a>
                    <?php endif; ?>
                  </div>
                </div>
              </div>
              <!-- 文章标签 -->
              <?php if(!empty($newsDetail['keywords'])): ?>
              <div class="tags-section" style="margin-top: 20px;">
                <div class="sidebar-title">
                  <i class="material-icons">local_offer</i>
                  <span>文章标签</span>
                </div>
                <div class="tags-container">
                  <?php 
                                    $keywords = explode(',', $newsDetail['keywords']);
                                    foreach($keywords as $keyword): 
                                    ?>
                  <a href="/news?tag=<?php echo urlencode(trim($keyword)); ?>" class="tag-item"><?php echo trim($keyword); ?></a>
                  <?php endforeach; ?>
                </div>
              </div>
              <?php endif; ?>
            </div>
          </div>
        </div>
      </div>
    </div>
    <!-- 页脚 -->
    <?php include ROOT_PATH . '/public/kf.php'; ?>
    <?php include ROOT_PATH . '/public/footer.php'; ?>
    <!-- 引入JavaScript文件 -->
    <script src="/public/js/js.js"></script>
  </body>
</html>
