<?php
// 确保已经包含必要的配置文件
if (!isset($GLOBALS['Telegram'])) {
    include_once __DIR__ . '/../../public/config.php';
}

// 包含数据库连接
require_once __DIR__ . '/../../code/use_functions.php';

// 提取产品数据的函数
function getProducts($filters = [], $sort = 'recommended', $order = 'asc', $page = 1, $limit = 10) {
    // 从数据库获取产品数据的逻辑
    // 这里是简化示例，实际应该根据filter查询数据库
    $products = [];
    
    // 实际项目中，应该使用数据库查询
    return $products;
}

// 获取地区数据
function getRegionData() {
    // 实际项目中，应该从数据库获取地区数据
    $parentRegions = [
        ['id' => 1, 'name' => '亚洲地区'],
        ['id' => 2, 'name' => '欧洲地区'],
        ['id' => 3, 'name' => '美洲地区']
    ];
    
    $childRegionsByParent = [
        1 => [
            ['id' => 101, 'name' => '香港'],
            ['id' => 102, 'name' => '日本'],
            ['id' => 103, 'name' => '韩国'],
            ['id' => 104, 'name' => '新加坡'],
            ['id' => 105, 'name' => '台湾']
        ],
        2 => [
            ['id' => 201, 'name' => '德国'],
            ['id' => 202, 'name' => '英国'],
            ['id' => 203, 'name' => '法国']
        ],
        3 => [
            ['id' => 301, 'name' => '美国']
        ]
    ];
    
    return ['parentRegions' => $parentRegions, 'childRegionsByParent' => $childRegionsByParent];
}

// 获取产品标签
function getTagData() {
    // 实际项目中，应该从数据库获取标签数据
    $parentTags = [
        ['id' => 1, 'name' => '产品类型'],
        ['id' => 2, 'name' => '服务器类型']
    ];
    
    $childTagsByParent = [
        1 => [
            ['id' => 101, 'name' => '云服务器'],
            ['id' => 102, 'name' => '独立服务器']
        ],
        2 => [
            ['id' => 201, 'name' => '高防服务器'],
            ['id' => 202, 'name' => '高带宽服务器'],
            ['id' => 203, 'name' => '游戏服务器']
        ]
    ];
    
    return ['parentTags' => $parentTags, 'childTagsByParent' => $childTagsByParent];
}

// 获取价格范围数据
function getPriceRangeData() {
    return [
        ['min' => null, 'max' => null, 'label' => '全部'],
        ['min' => 0, 'max' => 500, 'label' => '0-500元'],
        ['min' => 500, 'max' => 1000, 'label' => '500-1000元'],
        ['min' => 1000, 'max' => 2000, 'label' => '1000-2000元'],
        ['min' => 2000, 'max' => null, 'label' => '2000元以上']
    ];
}

// 获取线路数据
function getLineData() {
    // 实际项目中，应该从数据库获取线路数据
    return [
        1 => '电信',
        2 => '联通',
        3 => '移动',
        4 => 'CN2',
        5 => 'BGP'
    ];
}

// 辅助函数
function generateProductTitle($product, $areaNames, $allRegions, $parentRegions) {
    // 根据产品数据生成标题
    $region = isset($areaNames[$product['region_id']]) ? $areaNames[$product['region_id']] : '未知地区';
    return htmlspecialchars($region . ' ' . ($product['title'] ?? '服务器'));
}

function getRegionDisplay($regionId, $areaNames) {
    return isset($areaNames[$regionId]) ? $areaNames[$regionId] : '未知地区';
}

function getLineDisplay($lineId, $lineData) {
    return isset($lineData[$lineId]) ? $lineData[$lineId] : '未知线路';
}

function getDefenseDisplay($defense) {
    if (!$defense) return '无防御';
    return htmlspecialchars($defense);
}

function getTrafficDisplay($traffic) {
    if (!$traffic) return '无限制';
    return htmlspecialchars($traffic);
}

function getPriceDisplay($price, $originalPrice = null) {
    $priceText = number_format($price, 2) . '元/月';
    if ($originalPrice && $originalPrice > $price) {
        $priceText = '<span class="current-price">' . $priceText . '</span> <span class="original-price">' . number_format($originalPrice, 2) . '元/月</span>';
    }
    return $priceText;
}

function formatProductId($id) {
    return 'SKU-' . str_pad($id, 6, '0', STR_PAD_LEFT);
}

function generatePagination($currentPage, $totalPages, $urlPattern = '/product/?page=%d') {
    if ($totalPages <= 1) return '';
    
    $html = '<div class="pagination">';
    
    // 上一页按钮
    if ($currentPage > 1) {
        $html .= '<a href="' . sprintf($urlPattern, $currentPage - 1) . '" class="page-nav prev">上一页</a>';
    } else {
        $html .= '<span class="page-nav prev disabled">上一页</span>';
    }
    
    // 页码按钮
    $startPage = max(1, $currentPage - 2);
    $endPage = min($totalPages, $startPage + 4);
    
    if ($startPage > 1) {
        $html .= '<a href="' . sprintf($urlPattern, 1) . '" class="page-number">1</a>';
        if ($startPage > 2) {
            $html .= '<span class="page-ellipsis">...</span>';
        }
    }
    
    for ($i = $startPage; $i <= $endPage; $i++) {
        if ($i == $currentPage) {
            $html .= '<span class="page-number active">' . $i . '</span>';
        } else {
            $html .= '<a href="' . sprintf($urlPattern, $i) . '" class="page-number">' . $i . '</a>';
        }
    }
    
    if ($endPage < $totalPages) {
        if ($endPage < $totalPages - 1) {
            $html .= '<span class="page-ellipsis">...</span>';
        }
        $html .= '<a href="' . sprintf($urlPattern, $totalPages) . '" class="page-number">' . $totalPages . '</a>';
    }
    
    // 下一页按钮
    if ($currentPage < $totalPages) {
        $html .= '<a href="' . sprintf($urlPattern, $currentPage + 1) . '" class="page-nav next">下一页</a>';
    } else {
        $html .= '<span class="page-nav next disabled">下一页</span>';
    }
    
    $html .= '</div>';
    
    return $html;
} 