<?php
// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(dirname(__DIR__)));
}

// 引入配置文件
include ROOT_PATH . '/public/config.php';

// 定义常量，表示这是视图文件包含逻辑文件
define('INCLUDED_FROM_VIEW', true);

// 引入逻辑处理文件
require_once ROOT_PATH . '/code/product_detail_logic.php';

// 调试信息
$debug = [];
$debug['request_uri'] = $_SERVER['REQUEST_URI'];
$debug['get_params'] = $_GET;

// 获取产品ID - 处理URL中的id参数
$product_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 如果还没有ID，检查URL路径中是否包含ID（兼容新的URL格式）
if ($product_id == 0) {
    // 尝试多种可能的URL模式
    $patterns = [
        '/\\/product\/(\d+)\.html/', // /product/数字.html
        '/\/product\/(\d+)\.html/',     // /product/数字.html
        '/\/(\d+)\.html/'               // /数字.html (最宽松的匹配)
    ];
    
    foreach ($patterns as $index => $pattern) {
        $debug['pattern_'.$index] = $pattern;
        if (preg_match($pattern, $_SERVER['REQUEST_URI'], $matches)) {
            $product_id = intval($matches[1]);
            $debug['matches_'.$index] = $matches;
            break;
        }
    }
}

$debug['final_product_id'] = $product_id;

// 防止产品ID为0的情况
if ($product_id == 0) {
    // 不使用重定向，而是显示错误信息
    $showError = true;
    $errorMessage = "该机器不存在，请联系在线客服咨询";
    if (defined('DEBUG_MODE') && DEBUG_MODE) {
        $errorMessage .= "<br>调试信息: " . json_encode($debug, JSON_UNESCAPED_UNICODE);
    }
} else {
    // 处理产品详情
    $result = processProductDetail($product_id);
    
    // 如果处理成功，提取处理结果中的变量
    if ($result['success']) {
        $showError = false;
        $product = $result['product'];
        $productCode = $result['productCode'];
        $locationText = $result['locationText'];
        $lineName = $result['lineName'];
        $tags = $result['tags'];
        $prices = $result['prices'];
        $regionData = $result['regionData'];
        $networkTestData = $result['networkTestData'];
        $ispData = $result['ispData'];
        $features = $result['features'];
        $faqData = $result['faqData'];
        $reviews = $result['reviews'];
        $recommendedProducts = $result['recommendedProducts'];
        $seoMetadata = $result['seoMetadata'];
        $defaultDescription = $result['defaultDescription'];
        $serviceGuarantees = $result['serviceGuarantees'];
        
        // 提取区域数据中的变量，以便模板中使用
        extract($regionData);
    } else {
        // 产品不存在或其他错误
        $showError = true;
        $errorMessage = "该机器不存在，请联系在线客服咨询";
        if (defined('DEBUG_MODE') && DEBUG_MODE) {
            $errorMessage .= "<br>调试信息: " . json_encode($debug, JSON_UNESCAPED_UNICODE);
        }
    }
}

// 此处之前有定义DEBUG_MODE的代码，由于已经在public/config.php中定义，在这里不需要重复定义
// 使用时请确保引入了config.php

?>
