<?php
// 引入主配置文件
require_once __DIR__ . '/../config/config.php';

// 初始化数据库连接
global $db;
$db = getDbConnection();

// 确保所有配置都被正确加载
load_all_configs();

// 确保关键变量设置为全局变量（针对旧代码兼容）
global $Telegram, $SiteName, $Siteurl, $Multiplier, $ExchangeRate, $bot, $USDTQRcode, $USDTaddress, $Scriptaddress;

// 如果某些变量未设置，可以在这里设置默认值
if (!isset($Multiplier)) {
    $Multiplier = 1.5; // 默认倍数参数
}

// 为了让变量在其他文件中可用，我们需要确保它是全局的
if (!function_exists('getTelegram')) {
    function getTelegram() {
        global $Telegram;
        return $Telegram;
    }
}

if (!function_exists('getSiteName')) {
    function getSiteName() {
        global $SiteName;
        return $SiteName;
    }
}

if (!function_exists('getMultiplier')) {
    function getMultiplier() {
        global $Multiplier;
        return $Multiplier;
    }
}

// 添加获取新价格的函数
if (!function_exists('getNewPrice')) {
    function getNewPrice($price) {
        global $Multiplier;
        // 确保价格是浮点数
        $price = floatval($price);
        // 返回乘以倍数后的新价格
        return $price * $Multiplier;
    }
}

// 添加价格计算函数
if (!function_exists('calculatePrice')) {
    function calculatePrice($original_price) {
        global $Multiplier;
        
        // 确保价格是浮点数
        $original_price = floatval($original_price);
        
        // 应用倍数参数计算新价格
        $new_price = $original_price * $Multiplier;
        
        // 计算差额
        $difference = $new_price - $original_price;
        
        // 返回包含各价格信息的数组
        return array(
            'original' => $original_price,
            'new' => $new_price,
            'difference' => $difference,
            'original_formatted' => number_format($original_price, 2, '.', ','),
            'new_formatted' => number_format($new_price, 2, '.', ','),
            'difference_formatted' => number_format($difference, 2, '.', ',')
        );
    }
}

// 添加获取公共CSS文件引用的函数
if (!function_exists('getCommonCss')) {
    function getCommonCss() {
        $css = <<<EOT
<link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
<link href="/public/css/style.css" rel="stylesheet">
<link href="/public/css/breadcrumb.css" rel="stylesheet">

EOT;
        return $css;
    }
}

// 定义调试模式 (仅在未定义时定义)
if (!defined('DEBUG_MODE')) {
    define('DEBUG_MODE', false); // 设置为true开启调试信息
}
?>
