<?php
// 引入全局配置文件
require_once __DIR__ . '/config.php';

// 客服链接
$telegram_link = getTelegram();
$telegram_username = str_replace('https://t.me/', '@', $telegram_link);
?>

<!-- 客服组件 - 可在任何页面引入 -->
<div class="customer-service-component">
    <!-- 客服卡片 -->
    <div class="cs-card">
        <div class="cs-header">
            <h3><i class="fab fa-telegram-plane"></i> 在线客服</h3>
            <div class="cs-status online">在线</div>
        </div>
        
        <div class="cs-content">
            <!-- 客服信息 -->
            <div class="cs-info">
                <div class="cs-avatar">
                    <img src="/uploads/public/telegram_avatar.png" alt="客服头像" onerror="this.src='/public/images/default_avatar.png'">
                </div>
                <div class="cs-details">
                    <div class="cs-name">专属客服</div>
                    <div class="cs-id"><?php echo $telegram_username; ?></div>
                    <div class="cs-description">24小时在线为您服务</div>
                </div>
            </div>
            
            <!-- 联系方式 -->
            <div class="cs-contact">
                <a href="<?php echo $telegram_link; ?>" class="cs-button primary" target="_blank">
                    <i class="fab fa-telegram-plane"></i> 立即咨询
                </a>
                <a href="javascript:void(0);" class="cs-button secondary ticket-btn" id="ticketBtn">
                    <i class="far fa-comment-dots"></i> 提交工单
                </a>
            </div>
            
            <!-- 二维码 (可选) -->
            <div class="cs-qrcode">
                <img src="/uploads/public/telegram_qr.png" alt="Telegram二维码" onerror="this.src='/public/images/default_qr.png'">
                <div class="cs-qrcode-text">扫码添加客服</div>
            </div>
        </div>
    </div>
</div>

<!-- 客服组件样式 -->
<style>
.customer-service-component {
    margin: 20px 0;
    font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
}

.cs-card {
    background: #fff;
    border-radius: 12px;
    box-shadow: 0 4px 15px rgba(0, 0, 0, 0.1);
    overflow: hidden;
    max-width: 500px;
    transition: transform 0.3s ease, box-shadow 0.3s ease;
}

.cs-card:hover {
    transform: translateY(-3px);
    box-shadow: 0 8px 20px rgba(0, 0, 0, 0.15);
}

.cs-header {
    background: linear-gradient(135deg, #0088cc, #005f8f);
    color: white;
    padding: 15px 20px;
    display: flex;
    justify-content: space-between;
    align-items: center;
}

.cs-header h3 {
    margin: 0;
    font-size: 18px;
    font-weight: 600;
    display: flex;
    align-items: center;
}

.cs-header h3 i {
    margin-right: 8px;
    font-size: 20px;
}

.cs-status {
    font-size: 14px;
    padding: 4px 12px;
    border-radius: 50px;
    font-weight: 500;
}

.cs-status.online {
    background: rgba(0, 255, 0, 0.2);
    color: #00b300;
}

.cs-content {
    padding: 20px;
}

.cs-info {
    display: flex;
    margin-bottom: 20px;
}

.cs-avatar {
    width: 70px;
    height: 70px;
    border-radius: 50%;
    overflow: hidden;
    margin-right: 15px;
    border: 3px solid #f2f2f2;
}

.cs-avatar img {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.cs-details {
    display: flex;
    flex-direction: column;
    justify-content: center;
}

.cs-name {
    font-weight: 600;
    font-size: 16px;
    margin-bottom: 5px;
    color: #333;
}

.cs-id {
    font-size: 14px;
    color: #0088cc;
    margin-bottom: 5px;
}

.cs-description {
    font-size: 13px;
    color: #666;
    line-height: 1.4;
}

.cs-contact {
    display: flex;
    gap: 10px;
    margin-bottom: 20px;
}

.cs-button {
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 10px 16px;
    border-radius: 6px;
    font-weight: 500;
    font-size: 14px;
    text-decoration: none;
    transition: all 0.3s ease;
    flex: 1;
}

.cs-button i {
    margin-right: 6px;
    font-size: 16px;
}

.cs-button.primary {
    background: #0088cc;
    color: white;
}

.cs-button.primary:hover {
    background: #006699;
}

.cs-button.secondary {
    background: #f2f2f2;
    color: #333;
}

.cs-button.secondary:hover {
    background: #e6e6e6;
}

.cs-qrcode {
    text-align: center;
    padding-top: 15px;
    border-top: 1px dashed #eee;
}

.cs-qrcode img {
    width: 150px;
    height: 150px;
    object-fit: contain;
    margin-bottom: 8px;
}

.cs-qrcode-text {
    font-size: 13px;
    color: #666;
}

/* 响应式设计 */
@media (max-width: 576px) {
    .cs-card {
        max-width: 100%;
    }
    
    .cs-contact {
        flex-direction: column;
    }
    
    .cs-qrcode img {
        width: 120px;
        height: 120px;
    }
}
</style>

<!-- 可选: 引入Font Awesome图标库 (如果页面中还没有引入) -->
<!-- <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css"> --> 