<?php
// 引入全局配置文件
require_once __DIR__ . '/config.php';

// 客服链接
$telegram_link = getTelegram();
$telegram_username = str_replace('https://t.me/', '@', $telegram_link);
?>

<!-- 悬浮客服组件 -->
<div class="floating-cs-container">
  <!-- 悬浮按钮 -->
  <div class="floating-cs-button" id="floatingCSButton">
    <div class="cs-icon">
      <i class="fab fa-telegram-plane"></i>
    </div>
    <div class="cs-pulse"></div>
  </div>

  <!-- 客服卡片 (默认隐藏) -->
  <div class="floating-cs-card" id="floatingCSCard">
    <div class="cs-card-header">
      <h3>在线客服</h3>
      <button class="cs-close-btn" id="closeCSCard">
        <i class="fas fa-times"></i>
      </button>
    </div>

    <div class="cs-card-body">
      <div class="cs-profile">
        <div class="cs-avatar">
          <img src="/uploads/public/telegram_avatar.png" alt="客服头像" onerror="this.src='/public/images/default_avatar.png'">
        </div>
        <div class="cs-info">
          <div class="cs-name">专属客服</div>
          <div class="cs-username"><?php echo $telegram_username; ?></div>
          <div class="cs-status"><span class="online-dot"></span> 在线</div>
        </div>
      </div>

      <div class="cs-description">
        有任何问题随时联系我们，24小时在线为您提供支持。
      </div>

      <div class="cs-actions">
        <a href="<?php echo $telegram_link; ?>" class="cs-action-btn primary" target="_blank">
          <i class="fab fa-telegram-plane"></i> 立即咨询
        </a>
        <a href="javascript:void(0);" class="cs-action-btn secondary" id="showQRCode">
          <i class="fas fa-qrcode"></i> 查看二维码
        </a>
      </div>

      <!-- QR码部分 (默认隐藏) -->
      <div class="cs-qrcode" id="csQRCode" style="display: none;">
        <img src="/uploads/public/telegram_qr.png" alt="Telegram二维码" onerror="this.src='/public/images/default_qr.png'">
        <div class="cs-scan-text">扫码添加客服</div>
      </div>
    </div>
  </div>
</div>

<!-- 悬浮客服样式 -->
<style>
.floating-cs-container {
  position: fixed;
  right: 30px;
  bottom: 30px;
  z-index: 9999;
  font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
}

.floating-cs-button {
  width: 60px;
  height: 60px;
  border-radius: 50%;
  background: linear-gradient(135deg, #0088cc, #005f8f);
  display: flex;
  align-items: center;
  justify-content: center;
  color: white;
  cursor: pointer;
  box-shadow: 0 4px 15px rgba(0, 136, 204, 0.4);
  position: relative;
  transition: all 0.3s ease;
}

.floating-cs-button:hover {
  transform: scale(1.05);
  box-shadow: 0 6px 20px rgba(0, 136, 204, 0.5);
}

.cs-icon {
  font-size: 26px;
}

.cs-pulse {
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: 50%;
  background-color: rgba(0, 136, 204, 0.6);
  opacity: 0;
  animation: pulse 2s infinite;
}

@keyframes pulse {
  0% {
    transform: scale(0.95);
    opacity: 0.7;
  }

  70% {
    transform: scale(1.1);
    opacity: 0;
  }

  100% {
    transform: scale(0.95);
    opacity: 0;
  }
}

.floating-cs-card {
  position: absolute;
  bottom: 75px;
  right: 0;
  width: 320px;
  background: white;
  border-radius: 12px;
  box-shadow: 0 5px 25px rgba(0, 0, 0, 0.15);
  overflow: hidden;
  opacity: 0;
  transform: translateY(20px);
  pointer-events: none;
  transition: opacity 0.3s ease, transform 0.3s ease;
}

.floating-cs-card.active {
  opacity: 1;
  transform: translateY(0);
  pointer-events: auto;
}

.cs-card-header {
  background: linear-gradient(135deg, #0088cc, #005f8f);
  color: white;
  padding: 15px 20px;
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.cs-card-header h3 {
  margin: 0;
  font-size: 16px;
  font-weight: 600;
}

.cs-close-btn {
  background: none;
  border: none;
  color: white;
  font-size: 16px;
  cursor: pointer;
  padding: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  border-radius: 50%;
  transition: background 0.3s ease;
}

.cs-close-btn:hover {
  background: rgba(255, 255, 255, 0.2);
}

.cs-card-body {
  padding: 20px;
}

.cs-profile {
  display: flex;
  align-items: center;
  margin-bottom: 15px;
}

.cs-avatar {
  width: 50px;
  height: 50px;
  border-radius: 50%;
  overflow: hidden;
  margin-right: 15px;
  border: 2px solid #f0f0f0;
}

.cs-avatar img {
  width: 100%;
  height: 100%;
  object-fit: cover;
}

.cs-info {
  display: flex;
  flex-direction: column;
}

.cs-name {
  font-weight: 600;
  font-size: 16px;
  color: #333;
  margin-bottom: 3px;
}

.cs-username {
  font-size: 14px;
  color: #0088cc;
  margin-bottom: 3px;
}

.cs-status {
  font-size: 13px;
  color: #666;
  display: flex;
  align-items: center;
}

.online-dot {
  width: 8px;
  height: 8px;
  background-color: #00cc00;
  border-radius: 50%;
  margin-right: 5px;
  display: inline-block;
}

.cs-description {
  padding: 10px 0;
  margin-bottom: 15px;
  font-size: 14px;
  color: #555;
  line-height: 1.5;
  border-bottom: 1px dashed #eee;
}

.cs-actions {
  display: flex;
  gap: 10px;
  margin-bottom: 15px;
}

.cs-action-btn {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 10px 0;
  border-radius: 6px;
  font-size: 14px;
  font-weight: 500;
  text-decoration: none;
  flex: 1;
  transition: all 0.3s ease;
}

.cs-action-btn i {
  margin-right: 6px;
}

.cs-action-btn.primary {
  background: #0088cc;
  color: white;
}

.cs-action-btn.primary:hover {
  background: #006699;
}

.cs-action-btn.secondary {
  background: #f0f0f0;
  color: #333;
}

.cs-action-btn.secondary:hover {
  background: #e0e0e0;
}

.cs-qrcode {
  text-align: center;
  padding-top: 10px;
}

.cs-qrcode img {
  width: 180px;
  height: 180px;
  object-fit: contain;
  margin-bottom: 8px;
}

.cs-scan-text {
  font-size: 13px;
  color: #666;
}

/* 响应式设计 */
@media (max-width: 576px) {
  .floating-cs-container {
    right: 15px;
    bottom: 15px;
  }

  .floating-cs-button {
    width: 50px;
    height: 50px;
  }

  .cs-icon {
    font-size: 22px;
  }

  .floating-cs-card {
    width: 280px;
    right: 0;
  }
}

</style>

<!-- 悬浮客服JavaScript -->
<script>
document.addEventListener('DOMContentLoaded', function() {
  const floatingButton = document.getElementById('floatingCSButton');
  const floatingCard = document.getElementById('floatingCSCard');
  const closeCardBtn = document.getElementById('closeCSCard');
  const showQRCodeBtn = document.getElementById('showQRCode');
  const qrCodeSection = document.getElementById('csQRCode');
  // 打开客服卡片
  floatingButton.addEventListener('click', function() {
    floatingCard.classList.toggle('active');
  });
  // 关闭客服卡片
  closeCardBtn.addEventListener('click', function() {
    floatingCard.classList.remove('active');
  });
  // 显示/隐藏二维码
  showQRCodeBtn.addEventListener('click', function() {
    if (qrCodeSection.style.display === 'none') {
      qrCodeSection.style.display = 'block';
      showQRCodeBtn.innerHTML = '<i class="fas fa-eye-slash"></i> 隐藏二维码';
    } else {
      qrCodeSection.style.display = 'none';
      showQRCodeBtn.innerHTML = '<i class="fas fa-qrcode"></i> 查看二维码';
    }
  });
  // 点击页面其他位置关闭客服卡片
  document.addEventListener('click', function(event) {
    if (!floatingCard.contains(event.target) && !floatingButton.contains(event.target) && floatingCard.classList.contains('active')) {
      floatingCard.classList.remove('active');
    }
  });
});
</script>

<!-- 可选: 引入Font Awesome图标库 (如果页面中还没有引入) -->
<!-- <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css"> -->
