/**
 * 活动页面交互脚本
 */
document.addEventListener('DOMContentLoaded', function() {
    // 初始化组件
    initModals();
    initCountdown();
    initNavigation();
    initAnimations();
    initRippleEffect();
    
    // 检查倒计时紧急状态
    checkUrgentTimers();
});

/**
 * 初始化模态框功能
 */
function initModals() {
    // 显示模态框
    document.querySelectorAll('[data-toggle="modal"]').forEach(function(element) {
        element.addEventListener('click', function(e) {
            e.preventDefault();
            var target = document.querySelector(element.getAttribute('data-target'));
            if (target) {
                target.style.display = 'block';
                document.body.style.overflow = 'hidden';
                
                // 添加进入动画类
                setTimeout(function() {
                    var dialog = target.querySelector('.modal-dialog');
                    if (dialog) {
                        dialog.classList.add('animate');
                    }
                }, 10);
            }
        });
    });
    
    // 关闭模态框
    document.querySelectorAll('[data-dismiss="modal"]').forEach(function(element) {
        element.addEventListener('click', function() {
            var modal = element.closest('.modal');
            closeModal(modal);
        });
    });
    
    // 点击模态框外部关闭
    document.querySelectorAll('.modal').forEach(function(modal) {
        modal.addEventListener('click', function(e) {
            if (e.target === modal) {
                closeModal(modal);
            }
        });
    });
    
    // ESC键关闭模态框
    document.addEventListener('keydown', function(e) {
        if (e.key === 'Escape') {
            var openModals = document.querySelectorAll('.modal[style*="display: block"]');
            openModals.forEach(function(modal) {
                closeModal(modal);
            });
        }
    });
    
    // 关闭模态框的通用函数
    function closeModal(modal) {
        if (modal) {
            // 添加离开动画
            var dialog = modal.querySelector('.modal-dialog');
            if (dialog) {
                dialog.classList.add('fadeout');
                
                setTimeout(function() {
                    modal.style.display = 'none';
                    dialog.classList.remove('animate', 'fadeout');
                    document.body.style.overflow = '';
                }, 300);
            } else {
                modal.style.display = 'none';
                document.body.style.overflow = '';
            }
        }
    }
}

/**
 * 初始化倒计时功能
 */
function initCountdown() {
    document.querySelectorAll('.timer-countdown').forEach(function(element) {
        var endTime = new Date(element.getAttribute('data-end')).getTime();

        function updateTimer() {
            var now = new Date().getTime();
            var distance = endTime - now;
            
            if (distance < 0) {
                element.innerHTML = "活动已结束";
                var card = element.closest('.group-buy-card');
                if (card) {
                    card.classList.add('expired');
                    const btn = card.querySelector('.btn-primary');
                    if (btn) {
                        btn.innerHTML = "活动已结束";
                        btn.classList.add('disabled');
                    }
                }
                return;
            }
            
            var days = Math.floor(distance / (1000 * 60 * 60 * 24));
            var hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
            var minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
            var seconds = Math.floor((distance % (1000 * 60)) / 1000);
            
            var timeString = "";
            if (days > 0) timeString += days + "天 ";
            timeString += (hours < 10 ? "0" : "") + hours + ":";
            timeString += (minutes < 10 ? "0" : "") + minutes + ":";
            timeString += (seconds < 10 ? "0" : "") + seconds;
            
            element.innerHTML = timeString;
            
            // 如果倒计时小于24小时，添加紧急样式
            if (distance < 24 * 60 * 60 * 1000 && !element.classList.contains('urgent') && !element.classList.contains('ending')) {
                element.classList.add('urgent');
            }
        }
        
        updateTimer();
        setInterval(updateTimer, 1000);
    });
}

/**
 * 检查紧急倒计时状态
 */
function checkUrgentTimers() {
    document.querySelectorAll('.timer-countdown').forEach(function(element) {
        var endTime = new Date(element.getAttribute('data-end')).getTime();
        var now = new Date().getTime();
        var distance = endTime - now;
        
        // 如果倒计时小于12小时，添加ending状态
        if (distance < 12 * 60 * 60 * 1000 && distance > 0) {
            var card = element.closest('.group-buy-card');
            if (card && !card.querySelector('.group-buy-status.ending')) {
                // 如果没有ending状态标签，添加一个
                var statusBadge = document.createElement('div');
                statusBadge.className = 'group-buy-status ending';
                statusBadge.textContent = '即将结束';
                card.appendChild(statusBadge);
                
                element.classList.add('ending');
            }
        }
    });
}

/**
 * 初始化导航滚动效果
 */
function initNavigation() {
    document.querySelectorAll('.activity-nav-item a').forEach(function(anchor) {
        anchor.addEventListener('click', function(e) {
            e.preventDefault();
            
            document.querySelectorAll('.activity-nav-item').forEach(function(item) {
                item.classList.remove('active');
            });
            
            this.parentElement.classList.add('active');
            
            var targetId = this.getAttribute('href').substring(1);
            var targetElement = document.getElementById(targetId);
            
            window.scrollTo({
                top: targetElement.offsetTop - 100,
                behavior: 'smooth'
            });
        });
    });
    
    // 滚动时高亮当前导航项
    window.addEventListener('scroll', function() {
        var scrollPosition = window.scrollY;
        
        document.querySelectorAll('section[id]').forEach(function(section) {
            var sectionTop = section.offsetTop - 150;
            var sectionBottom = sectionTop + section.offsetHeight;
            
            if (scrollPosition >= sectionTop && scrollPosition < sectionBottom) {
                var currentId = section.getAttribute('id');
                
                document.querySelectorAll('.activity-nav-item').forEach(function(item) {
                    item.classList.remove('active');
                    
                    if (item.querySelector('a').getAttribute('href') === '#' + currentId) {
                        item.classList.add('active');
                    }
                });
            }
        });
    });
}

/**
 * 初始化动画效果
 */
function initAnimations() {
    var animateElements = document.querySelectorAll('.activity-section, .product-card, .coupon-card, .group-buy-card');

    function isInViewport(element) {
        var rect = element.getBoundingClientRect();
        return (
            rect.top <= (window.innerHeight || document.documentElement.clientHeight) * 0.85
        );
    }

    function checkVisibility() {
        animateElements.forEach(function(element) {
            if (isInViewport(element)) {
                element.classList.add('animate');
            }
        });
    }
    
    // 初始检查
    checkVisibility();
    
    // 滚动时检查
    window.addEventListener('scroll', checkVisibility);
}

/**
 * 添加按钮波纹效果
 */
function initRippleEffect() {
    const buttons = document.querySelectorAll('.btn, .coupon-btn');
    
    buttons.forEach(button => {
        button.addEventListener('click', function(e) {
            let x = e.clientX - e.target.getBoundingClientRect().left;
            let y = e.clientY - e.target.getBoundingClientRect().top;
            
            let ripple = document.createElement('span');
            ripple.className = 'ripple-effect';
            ripple.style.left = `${x}px`;
            ripple.style.top = `${y}px`;
            
            this.appendChild(ripple);
            
            setTimeout(() => {
                ripple.remove();
            }, 600);
        });
    });
}

// 添加兼容性处理
function addCompatibilitySupport() {
    // 检测浏览器功能支持
    var supportsPassive = false;
    try {
        var opts = Object.defineProperty({}, 'passive', {
            get: function() {
                supportsPassive = true;
                return true;
            }
        });
        window.addEventListener('test', null, opts);
    } catch (e) {}
    
    // 为旧浏览器添加平滑滚动的兼容性支持
    if (typeof window.scrollTo !== 'function' || !('scrollBehavior' in document.documentElement.style)) {
        // 平滑滚动的兼容性实现
        window.smoothScrollPolyfill = function(targetY, duration) {
            var startY = window.pageYOffset;
            var distance = targetY - startY;
            var startTime = null;
            
            function animation(currentTime) {
                if (startTime === null) startTime = currentTime;
                var timeElapsed = currentTime - startTime;
                var progress = Math.min(timeElapsed / duration, 1);
                
                // 缓动函数
                progress = easeInOutQuad(progress);
                
                window.scrollTo(0, startY + distance * progress);
                
                if (timeElapsed < duration) {
                    requestAnimationFrame(animation);
                }
            }
            
            function easeInOutQuad(t) {
                return t < 0.5 ? 2 * t * t : -1 + (4 - 2 * t) * t;
            }
            
            requestAnimationFrame(animation);
        };
    }
    
    // 应用动画类的兼容性支持
    if (!('IntersectionObserver' in window)) {
        // 如果不支持 IntersectionObserver，使用滚动事件来触发动画
        window.addEventListener('scroll', function() {
            checkVisibilityLegacy();
        }, supportsPassive ? { passive: true } : false);
        
        window.addEventListener('resize', function() {
            checkVisibilityLegacy();
        }, supportsPassive ? { passive: true } : false);
        
        function checkVisibilityLegacy() {
            var elements = document.querySelectorAll('.activity-section, .product-card, .coupon-card, .group-buy-card');
            elements.forEach(function(el) {
                var rect = el.getBoundingClientRect();
                var viewHeight = Math.max(document.documentElement.clientHeight, window.innerHeight);
                if (rect.top <= viewHeight * 0.85) {
                    el.classList.add('animate');
                }
            });
        }
        
        // 初始检查
        setTimeout(function() {
            checkVisibilityLegacy();
        }, 100);
    }
}

// 初始化兼容性支持
addCompatibilitySupport();

// 在CSS中添加相关的动画类
if (!document.getElementById('modal-animation-styles')) {
    var style = document.createElement('style');
    style.id = 'modal-animation-styles';
    style.textContent = `
        .modal-dialog {
            opacity: 0;
            transform: translateY(-25px);
            transition: all 0.3s ease;
        }
        .modal-dialog.animate {
            opacity: 1;
            transform: translateY(0);
        }
        .modal-dialog.fadeout {
            opacity: 0;
            transform: translateY(25px);
        }
    `;
    document.head.appendChild(style);
} 