/**
 * 抗投诉型服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化服务级别选择
    initServiceTiers();
});

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('open');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('open');
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('open');
            }
        });
    });
}

/**
 * 初始化服务级别选择
 */
function initServiceTiers() {
    const tierCards = document.querySelectorAll('.tier-card');
    
    // 为每个服务级别卡片添加点击事件
    tierCards.forEach(card => {
        card.addEventListener('click', function() {
            // 高亮显示选中的卡片
            tierCards.forEach(c => c.classList.remove('selected'));
            this.classList.add('selected');
            
            // 可以在这里添加其他交互，比如显示详细信息或更新价格等
        });
        
        // 添加鼠标悬停效果
        card.addEventListener('mouseenter', function() {
            this.classList.add('hover');
        });
        
        card.addEventListener('mouseleave', function() {
            this.classList.remove('hover');
        });
    });
    
    // 为特性项添加工具提示
    const featureItems = document.querySelectorAll('.tier-features li');
    featureItems.forEach(item => {
        if (item.textContent.includes('法务支持') || 
            item.textContent.includes('合规建议') ||
            item.textContent.includes('IP资源池')) {
            
            item.classList.add('has-tooltip');
            
            // 创建提示框
            const tooltip = document.createElement('div');
            tooltip.className = 'feature-tooltip';
            
            // 根据特性内容设置不同的提示信息
            if (item.textContent.includes('法务支持')) {
                tooltip.textContent = '提供基础法律咨询和应对投诉的专业建议';
            } else if (item.textContent.includes('合规建议')) {
                tooltip.textContent = '针对不同地区法规提供业务合规性建议';
            } else if (item.textContent.includes('IP资源池')) {
                tooltip.textContent = '提供干净的IP资源，遇到投诉可快速更换';
            }
            
            item.appendChild(tooltip);
            
            // 显示/隐藏提示框
            item.addEventListener('mouseenter', function() {
                tooltip.style.display = 'block';
            });
            
            item.addEventListener('mouseleave', function() {
                tooltip.style.display = 'none';
            });
        }
    });
} 