/**
 * 抗DDoS服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化产品筛选功能
    initProductFilter();
    
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化监控图表模拟
    initMonitorCharts();
});

/**
 * 初始化产品筛选功能
 */
function initProductFilter() {
    const filterBtns = document.querySelectorAll('.filter-btn');
    const productCards = document.querySelectorAll('.product-card');
    
    // 为每个筛选按钮添加点击事件
    filterBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            // 获取筛选类型
            const filterGroup = this.parentElement.parentElement;
            const filterValue = this.textContent.trim();
            
            // 移除同组其他按钮的active类
            filterGroup.querySelectorAll('.filter-btn').forEach(el => {
                el.classList.remove('active');
            });
            
            // 添加当前按钮的active类
            this.classList.add('active');
            
            // 筛选产品卡片
            filterProducts();
        });
    });

    /**
     * 根据当前选中的筛选条件过滤产品卡片
     */
    function filterProducts() {
        // 获取所有激活的筛选条件
        const activeLevel = document.querySelector('.filter-group:nth-child(1) .filter-btn.active').textContent.trim();
        const activeRegion = document.querySelector('.filter-group:nth-child(2) .filter-btn.active').textContent.trim();
        const activePrice = document.querySelector('.filter-group:nth-child(3) .filter-btn.active').textContent.trim();
        
        // 遍历所有产品卡片
        productCards.forEach(card => {
            // 获取产品属性
            const cardLocation = card.querySelector('.product-location span').textContent.trim();
            const cardPrice = parseInt(card.querySelector('.price-value').textContent.replace(/[^\d]/g, ''));
            const cardDefense = card.querySelector('.highlight .spec-value').textContent.trim();
            const defenseValue = parseInt(cardDefense);
            
            // 判断是否符合防护级别筛选条件
            let levelMatch = activeLevel === '全部';
            if (activeLevel === '100G以下') {
                levelMatch = defenseValue < 100;
            } else if (activeLevel === '100G-300G') {
                levelMatch = defenseValue >= 100 && defenseValue <= 300;
            } else if (activeLevel === '300G-500G') {
                levelMatch = defenseValue > 300 && defenseValue <= 500;
            } else if (activeLevel === '500G以上') {
                levelMatch = defenseValue > 500;
            }
            
            // 判断是否符合区域筛选条件
            let regionMatch = activeRegion === '全部';
            if (activeRegion === '亚太地区') {
                regionMatch = ['香港', '日本', '新加坡', '韩国'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '欧洲') {
                regionMatch = ['德国', '法国', '英国', '荷兰'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '北美') {
                regionMatch = ['美国', '加拿大'].some(region => cardLocation.includes(region));
            }
            
            // 判断是否符合价格筛选条件
            let priceMatch = activePrice === '全部';
            if (activePrice === '3000元以下') {
                priceMatch = cardPrice < 3000;
            } else if (activePrice === '3000-5000元') {
                priceMatch = cardPrice >= 3000 && cardPrice <= 5000;
            } else if (activePrice === '5000-8000元') {
                priceMatch = cardPrice > 5000 && cardPrice <= 8000;
            } else if (activePrice === '8000元以上') {
                priceMatch = cardPrice > 8000;
            }
            
            // 显示或隐藏产品卡片
            if (levelMatch && regionMatch && priceMatch) {
                card.style.display = 'flex';
            } else {
                card.style.display = 'none';
            }
        });
    }
}

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('open');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('open');
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('open');
            }
        });
    });
}

/**
 * 初始化监控图表模拟
 */
function initMonitorCharts() {
    // 这里只是模拟展示，实际项目中可以接入真实的图表库如ECharts或Chart.js
    const chartContainers = document.querySelectorAll('.monitor-chart');
    
    chartContainers.forEach(container => {
        // 添加简单的图表占位符样式
        container.style.background = 'linear-gradient(135deg, #f8f9fa 25%, #e9ecef 25%, #e9ecef 50%, #f8f9fa 50%, #f8f9fa 75%, #e9ecef 75%, #e9ecef 100%)';
        container.style.backgroundSize = '20px 20px';
        container.style.position = 'relative';
        
        // 添加图表标签
        const label = document.createElement('div');
        label.style.position = 'absolute';
        label.style.top = '50%';
        label.style.left = '50%';
        label.style.transform = 'translate(-50%, -50%)';
        label.style.padding = '8px 12px';
        label.style.background = 'rgba(255, 255, 255, 0.8)';
        label.style.borderRadius = '4px';
        label.style.fontSize = '14px';
        label.style.color = '#666';
        
        if (container.textContent.includes('流量统计')) {
            label.textContent = '流量统计图表 (实际使用中将显示实时数据)';
        } else if (container.textContent.includes('攻击类型')) {
            label.textContent = '攻击类型分析 (实际使用中将显示实时数据)';
        }
        
        container.textContent = '';
        container.appendChild(label);
    });
}

/**
 * 初始化防护套餐选择
 */
function initProtectionTiers() {
    const tierCards = document.querySelectorAll('.tier-card');
    
    // 为每个防护套餐卡片添加点击事件
    tierCards.forEach(card => {
        card.addEventListener('click', function() {
            // 高亮显示选中的卡片
            tierCards.forEach(c => c.classList.remove('selected'));
            this.classList.add('selected');
            
            // 这里可以添加套餐选择后的逻辑，如价格更新等
        });
    });
} 