document.addEventListener('DOMContentLoaded', function () {
  const slides = document.querySelectorAll('.banner-slide');
  const promoBoxes = document.querySelectorAll('.promo-box');
  const prevBtn = document.querySelector('.banner-nav.prev');
  const nextBtn = document.querySelector('.banner-nav.next');

  let currentSlide = 0;
  let autoSlideInterval;

  // 更新活动幻灯片和促销框
  function updateSlides(index) {
    // 移除所有活动类
    slides.forEach(slide => slide.classList.remove('active'));
    promoBoxes.forEach(box => box.classList.remove('active'));

    // 添加新的活动类
    slides[index].classList.add('active');
    promoBoxes[index].classList.add('active');

    currentSlide = index;
  }

  // 点击促销框切换幻灯片
  promoBoxes.forEach(box => {
    box.addEventListener('click', function () {
      const slideIndex = parseInt(this.getAttribute('data-slide'));
      updateSlides(slideIndex);
      resetAutoSlide(); // 重置自动滚动计时器
    });
  });

  // 上一张/下一张按钮
  prevBtn.addEventListener('click', function () {
    let newIndex = currentSlide - 1;
    if (newIndex < 0) newIndex = slides.length - 1;
    updateSlides(newIndex);
    resetAutoSlide(); // 重置自动滚动计时器
  });

  nextBtn.addEventListener('click', function () {
    let newIndex = currentSlide + 1;
    if (newIndex >= slides.length) newIndex = 0;
    updateSlides(newIndex);
    resetAutoSlide(); // 重置自动滚动计时器
  });

  // 自动滚动函数
  function startAutoSlide() {
    autoSlideInterval = setInterval(function () {
      let newIndex = currentSlide + 1;
      if (newIndex >= slides.length) newIndex = 0;
      updateSlides(newIndex);
    }, 5000); // 每5秒切换一次
  }

  // 重置自动滚动计时器
  function resetAutoSlide() {
    clearInterval(autoSlideInterval);
    startAutoSlide();
  }

  // 启动自动滚动
  startAutoSlide();
}); 