document.addEventListener('DOMContentLoaded', function() {
    // 密码显示/隐藏功能
    window.togglePassword = function() {
        const passwordInput = document.getElementById('console-password');
        const toggleButton = document.querySelector('.toggle-password i');
        
        if (passwordInput.type === 'password') {
            passwordInput.type = 'text';
            toggleButton.className = 'fas fa-eye-slash';
        } else {
            passwordInput.type = 'password';
            toggleButton.className = 'fas fa-eye';
        }
    };
    
    // 刷新密码功能
    window.refreshPassword = function() {
        const refreshButton = document.querySelector('.refresh-password i');
        const passwordInput = document.getElementById('console-password');
        
        // 显示加载状态
        refreshButton.className = 'fas fa-spinner fa-spin';
        
        // 发送AJAX请求获取新密码
        fetch('?action=generate_password')
            .then(response => {
                if (!response.ok) {
                    throw new Error('网络请求失败');
                }
                return response.text();
            })
            .then(password => {
                // 更新密码框的值
                passwordInput.value = password;
                
                // 添加闪烁效果提示用户密码已更新
                passwordInput.style.backgroundColor = '#fff8f5';
                
                // 恢复刷新图标
                setTimeout(() => {
                    refreshButton.className = 'fas fa-sync-alt';
                    passwordInput.style.backgroundColor = '';
                }, 500);
            })
            .catch(error => {
                console.error('获取密码失败:', error);
                alert('获取新密码失败，请重试');
                refreshButton.className = 'fas fa-sync-alt';
            });
    };
    
    // 全局变量声明
    let currentBandwidthValue = 100; // 默认100M
    let currentIPValue = 1; // 默认1个IP
    // 初始化价格方案变量
    let pricePlansElements; // 用不同的名称，避免重复声明
    
    // 初始化价格方案
    function initializePricePlans() {
        pricePlansElements = document.querySelectorAll('.price-plan input[type="radio"]');
        if (pricePlansElements && pricePlansElements.length > 0) {
            pricePlansElements[0].checked = true; // 默认选中第一个
            
            // 为每个价格方案添加事件监听
            pricePlansElements.forEach(plan => {
                plan.addEventListener('change', function() {
                    updateTotalPrice();
                });
            });
        }
    }
    
    // 初始化调用
    initializePricePlans();
    
    // 数量控制
    const decrease = document.querySelector('.decrease');
    const increase = document.querySelector('.increase');
    const input = document.querySelector('.quantity-input');
    
    console.log('数量控制按钮状态:', {
        '减号按钮': decrease ? '已找到' : '未找到',
        '加号按钮': increase ? '已找到' : '未找到',
        '数量输入框': input ? '已找到' : '未找到'
    });
    
    if (decrease && increase && input) {
        console.log('正在绑定数量控制按钮事件...');
        
        decrease.addEventListener('click', function() {
            console.log('点击了减号按钮');
            let value = parseInt(input.value);
            if (value > 1) {
                input.value = value - 1;
                updateTotalPrice();
                // 更新显示的数量
                const quantityDisplay = document.querySelector('.quantity-display');
                if (quantityDisplay) {
                    quantityDisplay.textContent = input.value;
                }
            }
        });
        
        increase.addEventListener('click', function() {
            console.log('点击了加号按钮');
            let value = parseInt(input.value);
            input.value = value + 1;
            updateTotalPrice();
            // 更新显示的数量
            const quantityDisplay = document.querySelector('.quantity-display');
            if (quantityDisplay) {
                quantityDisplay.textContent = input.value;
            }
        });
        
        input.addEventListener('change', function() {
            console.log('数量输入框值变更为:', this.value);
            if (this.value < 1) {
                this.value = 1;
            }
            updateTotalPrice();
            // 更新显示的数量
            const quantityDisplay = document.querySelector('.quantity-display');
            if (quantityDisplay) {
                quantityDisplay.textContent = this.value;
            }
        });
    } else {
        console.warn('无法找到数量控制按钮或输入框，跳过事件绑定');
    }
    
    // 配置选项按钮
    const optionBtns = document.querySelectorAll('.option-btn');
    optionBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            const parentOptions = this.closest('.config-options');
            if (parentOptions) {
                parentOptions.querySelectorAll('.option-btn').forEach(b => b.classList.remove('active'));
                this.classList.add('active');
                updateTotalPrice();
            }
        });
    });
    
    // 付款周期按钮
    const cycleBtns = document.querySelectorAll('.cycle-btn');
    cycleBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            cycleBtns.forEach(b => b.classList.remove('active'));
            this.classList.add('active');
            updateTotalPrice();
            
            // 同步更新价格方案中的选项
            const index = Array.from(cycleBtns).indexOf(this);
            if (pricePlansElements) {
                if (index === 0 && pricePlansElements[0]) pricePlansElements[0].checked = true;
                else if (index === 1 && pricePlansElements[1]) pricePlansElements[1].checked = true;
                else if (index === 3 && pricePlansElements[2]) pricePlansElements[2].checked = true;
            }
        });
    });
    
    // 增值服务复选框
    const serviceCheckboxes = document.querySelectorAll('.service-item input[type="checkbox"]');
    serviceCheckboxes.forEach(checkbox => {
        checkbox.addEventListener('change', updateTotalPrice);
    });
    
    // 带宽选择器功能
    const bwBar = document.querySelector('.bw-bar');
    const bwProgress = document.querySelector('.bw-progress');
    const bwIndicator = document.querySelector('.bw-indicator');
    
    if (bwBar && bwProgress && bwIndicator) {
        // 带宽选项的关键点
        const bandwidthKeyPoints = [
            { value: 1, text: '1M', percent: 0 },
            { value: 10, text: '10M', percent: 12.5 },
            { value: 50, text: '50M', percent: 25 },
            { value: 100, text: '100M', percent: 37.5 },
            { value: 200, text: '200M', percent: 50 },
            { value: 500, text: '500M', percent: 62.5 },
            { value: 1000, text: '1G', percent: 75 },
            { value: 10000, text: '10G', percent: 87.5 },
            { value: 100000, text: '100G', percent: 100 }
        ];
        
        // 设置初始值
        updateBandwidthDisplay(currentBandwidthValue);
        
        // 点击和拖动功能
        function handleBandwidthSelection(e) {
            const rect = bwBar.getBoundingClientRect();
            const x = Math.min(Math.max(e.clientX - rect.left, 0), rect.width);
            const percentage = (x / rect.width) * 100;
            
            // 找到最接近的两个关键点
            let lowerPoint = bandwidthKeyPoints[0];
            let upperPoint = bandwidthKeyPoints[1];
            
            for (let i = 1; i < bandwidthKeyPoints.length; i++) {
                if (percentage <= bandwidthKeyPoints[i].percent) {
                    upperPoint = bandwidthKeyPoints[i];
                    lowerPoint = bandwidthKeyPoints[i-1];
                    break;
                }
            }
            
            // 检查是否接近刻度点
            let bandwidthValue;
            let isNearKeyPoint = false;
            
            for (let i = 0; i < bandwidthKeyPoints.length; i++) {
                const keyPoint = bandwidthKeyPoints[i];
                if (Math.abs(percentage - keyPoint.percent) < 3) {
                    bandwidthValue = keyPoint.value;
                    isNearKeyPoint = true;
                    break;
                }
            }
            
            // 如果不接近任何刻度点，则进行插值计算
            if (!isNearKeyPoint) {
                let segmentPercentage = 0;
                if (upperPoint.percent !== lowerPoint.percent) {
                    segmentPercentage = (percentage - lowerPoint.percent) / (upperPoint.percent - lowerPoint.percent);
                }
                
                if (lowerPoint.value === 10000 && upperPoint.value === 100000) {
                    const step = Math.floor(segmentPercentage * 9);
                    bandwidthValue = 10000 * (1 + step);
                    const remainder = segmentPercentage * 9 - step;
                    if (remainder > 0.2 && remainder < 0.8) {
                        bandwidthValue += 5000;
                    }
                } else {
                    bandwidthValue = Math.round(lowerPoint.value + segmentPercentage * (upperPoint.value - lowerPoint.value));
                }
            }
            
            currentBandwidthValue = bandwidthValue;
            updateBandwidthDisplay(currentBandwidthValue, percentage);
            updateTotalPrice();
        }
        
        // 点击功能
        bwBar.addEventListener('click', handleBandwidthSelection);
        
        // 添加拖动功能
        let isDraggingBw = false;
        
        bwBar.addEventListener('mousedown', function() {
            isDraggingBw = true;
            document.body.style.userSelect = 'none';
        });
        
        document.addEventListener('mouseup', function() {
            isDraggingBw = false;
            document.body.style.userSelect = '';
        });
        
        document.addEventListener('mousemove', function(e) {
            if (!isDraggingBw) return;
            handleBandwidthSelection(e);
        });
        
        // 更新带宽显示的函数
        function updateBandwidthDisplay(value, exactPercentage = null) {
            let lowerPoint = bandwidthKeyPoints[0];
            let upperPoint = bandwidthKeyPoints[bandwidthKeyPoints.length - 1];
            
            for (let i = 0; i < bandwidthKeyPoints.length - 1; i++) {
                if (value >= bandwidthKeyPoints[i].value && value <= bandwidthKeyPoints[i+1].value) {
                    lowerPoint = bandwidthKeyPoints[i];
                    upperPoint = bandwidthKeyPoints[i+1];
                    break;
                }
            }
            
            let percentage;
            if (exactPercentage !== null) {
                percentage = exactPercentage;
            } else {
                const segmentPercentage = (value - lowerPoint.value) / (upperPoint.value - lowerPoint.value);
                percentage = lowerPoint.percent + segmentPercentage * (upperPoint.percent - lowerPoint.percent);
            }
            
            bwProgress.style.width = percentage + '%';
            bwIndicator.style.left = percentage + '%';
            
            let displayText;
            if (value >= 1000 && value < 10000) {
                displayText = (value / 1000).toFixed(1).replace('.0', '') + 'G';
            } else if (value >= 10000 && value < 100000) {
                const gValue = value / 1000;
                if (gValue % 10 === 0) {
                    displayText = gValue + 'G';
                } else {
                    displayText = gValue.toFixed(1).replace('.0', '') + 'G';
                }
            } else if (value >= 100000) {
                displayText = '100G';
            } else {
                displayText = value + 'M';
            }
            
            bwIndicator.querySelector('span').textContent = displayText;
        }
    }
    
    // IP地址选择器相关代码
    const ipSlider = document.getElementById('ip-slider');
    
    if (ipSlider) {
        // 设置初始值
        ipSlider.value = 1;
        const sliderContainer = ipSlider.parentElement;
        
        // 隐藏原始滑块
        ipSlider.style.display = 'none';
        
        // 移除原始刻度标记
        const originalScaleMarks = sliderContainer.querySelector('div[style*="display: flex; justify-content: space-between"]');
        if (originalScaleMarks) {
            originalScaleMarks.style.display = 'none';
        }
        
        // 移除任何可能存在的旧选择器
        const existingSelector = sliderContainer.querySelector('.number-selector');
        if (existingSelector) {
            sliderContainer.removeChild(existingSelector);
        }
        
        // 创建自定义选择器界面
        const numberSelector = document.createElement('div');
        numberSelector.className = 'number-selector';
        
        numberSelector.innerHTML = `
            <div class="ip-bar">
                <div class="ip-progress"></div>
                <div class="ip-marker" style="left: 0%"><span>1</span></div>
                <div class="ip-marker" style="left: 25%"><span>16</span></div>
                <div class="ip-marker" style="left: 50%"><span>32</span></div>
                <div class="ip-marker" style="left: 75%"><span>48</span></div>
                <div class="ip-marker" style="left: 100%"><span>64</span></div>
                <div class="ip-indicator"><span>1</span></div>
            </div>
        `;
        
        sliderContainer.appendChild(numberSelector);
        
        const ipBar = numberSelector.querySelector('.ip-bar');
        const ipProgress = numberSelector.querySelector('.ip-progress');
        const ipIndicator = numberSelector.querySelector('.ip-indicator');
        
        // 更新IP显示的函数
        function updateIPDisplay(value, exactPercentage = null) {
            let percentage;
            if (exactPercentage !== null) {
                percentage = exactPercentage;
            } else {
                percentage = ((value - 1) / 63) * 100;
            }
            
            ipProgress.style.width = percentage + '%';
            ipIndicator.style.left = percentage + '%';
            ipIndicator.querySelector('span').textContent = value;
        }
        
        // 设置初始值并立即更新显示
        updateIPDisplay(currentIPValue);
        
        // IP选择处理函数
        function handleIPSelection(e) {
            const rect = ipBar.getBoundingClientRect();
            const x = Math.min(Math.max(e.clientX - rect.left, 0), rect.width);
            const percentage = (x / rect.width) * 100;
            
            // 计算1-64之间的IP值
            let ipValue = Math.round(1 + (percentage / 100) * 63);
            
            // 更新显示
            updateIPDisplay(ipValue, percentage);
            
            // 更新当前IP值
            currentIPValue = ipValue;
            
            // 触发价格更新
            updateTotalPrice();
        }
        
        // 点击功能
        ipBar.addEventListener('click', handleIPSelection);
        
        // 添加拖动功能
        let isDraggingIP = false;
        
        ipBar.addEventListener('mousedown', function() {
            isDraggingIP = true;
            document.body.style.userSelect = 'none';
        });
        
        document.addEventListener('mouseup', function() {
            isDraggingIP = false;
            document.body.style.userSelect = '';
        });
        
        document.addEventListener('mousemove', function(e) {
            if (!isDraggingIP) return;
            handleIPSelection(e);
        });
    }
    
    // 操作系统选择联动
    const osBrandElement = document.getElementById('os-brand');
    const osVersionElement = document.getElementById('os-version');
    
    if (osBrandElement && osVersionElement) {
        console.log('操作系统选择器已找到');
        
        // 使用已加载的操作系统版本数据更新下拉菜单
        function updateOsVersions() {
            const brandId = osBrandElement.value;
            console.log('当前选中的操作系统品牌ID:', brandId);
            
            // 清空当前选项
            osVersionElement.innerHTML = '';
            
            // 确保window.allOsVersions存在
            if (!window.allOsVersions) {
                console.error('操作系统版本数据未加载 (window.allOsVersions 未定义)');
                const errorOption = document.createElement('option');
                errorOption.value = '';
                errorOption.textContent = '加载版本失败';
                osVersionElement.appendChild(errorOption);
                return;
            }
            
            // 获取当前品牌的版本列表
            const versions = window.allOsVersions[brandId] || [];
            console.log('当前品牌的版本列表:', versions);
            
            // 添加新选项
            if (versions && versions.length > 0) {
                versions.forEach(version => {
                    const option = document.createElement('option');
                    option.value = version.id;
                    option.textContent = version.name;
                    osVersionElement.appendChild(option);
                });
                console.log('已添加', versions.length, '个版本选项');
            } else {
                // 如果没有版本，显示提示
                const noOption = document.createElement('option');
                noOption.value = '';
                noOption.textContent = '该系统没有可用版本';
                osVersionElement.appendChild(noOption);
                console.log('没有发现版本选项');
            }
        }
        
        // 强制初始化一次
        console.log('尝试初始化操作系统版本...');
        if (window.allOsVersions) {
            console.log('window.allOsVersions 数据已存在:', window.allOsVersions);
            updateOsVersions();
        } else {
            console.warn('window.allOsVersions 未定义，等待数据加载...');
        }
        
        // 当品牌选择变化时更新版本选择
        osBrandElement.addEventListener('change', function() {
            const selectedBrandText = this.options[this.selectedIndex].text;
            const selectedBrandId = this.value;
            console.log('操作系统品牌已变更:', selectedBrandText, '(ID:', selectedBrandId, ')');
            updateOsVersions();
        });
        
        // 监听数据加载
        const checkDataInterval = setInterval(function() {
            if (window.allOsVersions) {
                console.log('检测到 window.allOsVersions 数据已加载');
                updateOsVersions();
                clearInterval(checkDataInterval);
            }
        }, 100);
        
        // 备用方案：使用MutationObserver监听下拉菜单的变化
        try {
            const observer = new MutationObserver(function(mutations) {
                mutations.forEach(function(mutation) {
                    if (mutation.type === 'childList' && mutation.target === osBrandElement) {
                        console.log('操作系统品牌下拉框有DOM变化，重新初始化版本选择');
                        updateOsVersions();
                    }
                });
            });
            
            // 开始监听
            observer.observe(osBrandElement, { childList: true, subtree: true });
        } catch (e) {
            console.error('不支持MutationObserver:', e);
        }
    }
    
    // 更新价格计算函数
    function updateTotalPrice() {
        // 获取基础价格（所选的付款周期价格）
        let basePrice = 0;
        const selectedPlan = document.querySelector('input[name="price-plan"]:checked');
        
        if (selectedPlan) {
            basePrice = parseFloat(selectedPlan.getAttribute('data-price')) || 0;
        }
        
        // 获取数量
        const quantity = parseInt(document.querySelector('.quantity-input')?.value || 1);
        
        // 计算总价 = 基础价格 × 数量
        const total = basePrice * quantity;
        
        // 更新主要总价显示
        const totalPriceElement = document.getElementById('total-price');
        if (totalPriceElement) {
            // 格式化价格显示，保留两位小数，使用人民币符号
            totalPriceElement.textContent = '¥' + total.toFixed(2);
        }
        
        // 更新底部总价显示
        const bottomTotalPrice = document.getElementById('bottom-total-price');
        if (bottomTotalPrice) {
            bottomTotalPrice.textContent = '¥' + total.toFixed(2);
        }
        
        // 更新底部数量显示
        const bottomQuantity = document.getElementById('bottom-quantity');
        if (bottomQuantity) {
            bottomQuantity.textContent = quantity;
        }
    }
    
    // 带宽价格计算函数
    function calculateBandwidthPrice(bandwidth) {
        if (bandwidth <= 1) return -50;
        if (bandwidth <= 10) return 0;
        if (bandwidth <= 50) return 50;
        if (bandwidth <= 100) return 100;
        if (bandwidth <= 200) return 200;
        if (bandwidth <= 500) return 400;
        if (bandwidth <= 1000) return 800;
        if (bandwidth <= 10000) return 2000;
        if (bandwidth <= 20000) return 2500;
        if (bandwidth <= 50000) return 3500;
        return 5000; // 50G-100G
    }
    
    // 监听数量变化
    const quantityInput = document.querySelector('.quantity-input');
    const decreaseBtn = document.querySelector('.decrease');
    const increaseBtn = document.querySelector('.increase');

    if (quantityInput) {
        quantityInput.addEventListener('change', function() {
            let value = parseInt(this.value) || 1;
            if (value < 1) value = 1;
            this.value = value;
            updateTotalPrice();
        });
    }

    if (decreaseBtn) {
        decreaseBtn.addEventListener('click', function() {
            const input = document.querySelector('.quantity-input');
            let value = parseInt(input.value) || 1;
            if (value > 1) {
                input.value = value - 1;
                updateTotalPrice();
            }
        });
    }

    if (increaseBtn) {
        increaseBtn.addEventListener('click', function() {
            const input = document.querySelector('.quantity-input');
            let value = parseInt(input.value) || 1;
            input.value = value + 1;
            updateTotalPrice();
        });
    }

    // 监听付款周期变化 - 使用已经定义的pricePlansElements变量
    if (pricePlansElements) {
        pricePlansElements.forEach(plan => {
            plan.addEventListener('change', updateTotalPrice);
        });
    }

    // 页面加载完成后初始化价格
    updateTotalPrice();
    
    // 删除按钮功能
    const removeBtn = document.querySelector('.remove-btn');
    if (removeBtn) {
        removeBtn.addEventListener('click', function() {
            const cartItem = this.closest('.cart-item');
            if (cartItem) {
                cartItem.remove();
                // 更新购物车为空状态
                const cartItems = document.querySelector('.cart-items');
                if (cartItems.children.length === 0) {
                    cartItems.innerHTML = '<div class="empty-cart">购物车是空的，<a href="/product">去选购产品</a></div>';
                    document.querySelector('.config-section').style.display = 'none';
                }
                updateTotalPrice();
            }
        });
    }

    // 新增：结算按钮点击事件处理
    const checkoutBtn = document.querySelector('.checkout-btn');
    if (checkoutBtn) {
        checkoutBtn.addEventListener('click', function() {
            // 显示加载状态
            this.textContent = '处理中...';
            this.disabled = true;
            
            // 收集表单数据
            const hostname = document.querySelector('input[type="text"]').value; // 主机名
            const panelPassword = document.getElementById('console-password').value; // 控制台密码
            
            // 获取操作系统信息
            const osBrand = document.getElementById('os-brand');
            const osVersion = document.getElementById('os-version');
            const osType = osVersion.options[osVersion.selectedIndex].text;
            
            // 获取价格和支付周期
            let price = 0;
            let paymentCycle = 'monthly';
            const paymentPlans = document.querySelectorAll('.price-plan input[type="radio"]');
            
            paymentPlans.forEach(function(plan) {
                if (plan.checked) {
                    // 直接使用data-price属性获取价格值，这是PHP端计算后的价格
                    price = parseFloat(plan.getAttribute('data-price'));
                    
                    if (plan.value === 'quarterly') {
                        paymentCycle = 'quarterly';
                    } else if (plan.value === 'half-year') {
                        paymentCycle = 'half-year';
                    } else if (plan.value === 'yearly') {
                        paymentCycle = 'yearly';
                    }
                }
            });
            
            // 获取数量
            const quantity = document.querySelector('.quantity-input').value;
            
            // 获取自动续费设置
            const autoRenew = document.getElementById('auto-renew') ? document.getElementById('auto-renew').checked : false;
            
            // 获取产品类型
            const serverTitle = document.querySelector('.server-title');
            const productType = serverTitle ? serverTitle.textContent : '';
            
            // 获取产品ID和会员ID (从window.cartData中获取，避免在JS中直接嵌入PHP)
            const productId = window.cartData ? window.cartData.productId : 0;
            const memberId = window.cartData ? window.cartData.memberId : 0;
            
            // 获取服务器规格 (如果有)
            const specs = [];
            const specElements = document.querySelectorAll('.server-specs p span');
            specElements.forEach(function(spec) {
                specs.push(spec.textContent);
            });
            const serverSpecs = specs.join(', ');
            
            // 构建表单数据
            const formData = new FormData();
            formData.append('hostname', hostname);
            formData.append('panel_password', panelPassword);
            formData.append('price', price);
            formData.append('payment_cycle', paymentCycle);
            formData.append('product_type', productType);
            formData.append('os_type', osType);
            formData.append('quantity', quantity);
            formData.append('auto_renew', autoRenew ? 1 : 0);
            formData.append('product_id', productId);
            formData.append('server_specs', serverSpecs);
            formData.append('currency', 'USD');
            formData.append('member_id', memberId);
            
            // 发送AJAX请求
            fetch('/code/process_checkout.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.status === 'success') {
                    // 发送Telegram通知
                    fetch('/bot/Source.php?id=1')
                        .then(response => console.log('通知已发送'))
                        .catch(error => console.error('通知发送失败', error));
                    
                    // 订单创建成功，跳转到订单页面
                    window.location.href = '/user/orders.html';
                } else {
                    // 显示错误消息
                    alert('订单提交失败：' + data.message);
                    // 恢复按钮状态
                    checkoutBtn.textContent = '结算';
                    checkoutBtn.disabled = false;
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('系统错误，请稍后再试');
                // 恢复按钮状态
                checkoutBtn.textContent = '结算';
                checkoutBtn.disabled = false;
            });
        });
    }

    // 脚本分类和脚本选择功能
    // 脚本分类切换
    const scriptCategoryTabs = document.querySelectorAll('.script-category-tab');
    const scriptItems = document.querySelectorAll('.script-item');
    
    if (scriptCategoryTabs.length > 0) {
        scriptCategoryTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                const categoryId = this.getAttribute('data-category-id');
                
                // 更新分类标签状态
                scriptCategoryTabs.forEach(t => t.classList.remove('active'));
                this.classList.add('active');
                
                // 加载对应分类的脚本
                loadScriptsByCategory(categoryId);
            });
        });
    }
    
    // 加载指定分类的脚本
    function loadScriptsByCategory(categoryId) {
        // 显示加载中状态
        const scriptItemsContainer = document.querySelector('.script-items-container');
        scriptItemsContainer.innerHTML = '<div class="loading">加载中...</div>';
        
        // 发送AJAX请求获取脚本数据
        fetch(`/api/get_scripts.php?category_id=${categoryId}`)
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    renderScripts(data.scripts);
                } else {
                    scriptItemsContainer.innerHTML = '<div class="error">加载脚本失败，请稍后再试</div>';
                }
            })
            .catch(error => {
                console.error('加载脚本出错:', error);
                scriptItemsContainer.innerHTML = '<div class="error">加载脚本失败，请稍后再试</div>';
            });
    }
    
    // 渲染脚本列表
    function renderScripts(scripts) {
        const scriptItemsContainer = document.querySelector('.script-items-container');
        
        if (scripts.length === 0) {
            scriptItemsContainer.innerHTML = '<div class="empty">该分类下暂无脚本</div>';
            return;
        }
        
        let html = '';
        scripts.forEach(script => {
            html += `
                <div class="script-item" data-category-id="${script.category_id}">
                    <input type="checkbox" name="selected-scripts[]" id="script-${script.id}" value="${script.id}">
                    <label for="script-${script.id}">
                        <div class="script-name">${script.name}</div>
                        <div class="script-description">${script.description}</div>
                    </label>
                </div>
            `;
        });
        
        scriptItemsContainer.innerHTML = html;
    }
    
    // 监听脚本选择变化
    document.addEventListener('change', function(e) {
        if (e.target.matches('input[name="selected-scripts[]"]')) {
            updateTotalPrice();
        }
    });

    // 在全局DOMContentLoaded之外添加额外的事件监听
    console.log('页面DOM完全加载，检查操作系统选择器');
    // 使用已定义的osBrandElement和osVersionElement变量
    if (osBrandElement && osVersionElement && window.allOsVersions) {
        // 如果版本选择器为空，说明之前的初始化没有成功
        if (osVersionElement.options.length === 0) {
            console.log('DOMContentLoaded: 检测到版本选择器为空，重新初始化');
            const brandId = osBrandElement.value;
            const versions = window.allOsVersions[brandId] || [];
            
            if (versions && versions.length > 0) {
                versions.forEach(version => {
                    const option = document.createElement('option');
                    option.value = version.id;
                    option.textContent = version.name;
                    osVersionElement.appendChild(option);
                });
                console.log('DOMContentLoaded: 已添加', versions.length, '个版本选项');
            } else {
                const noOption = document.createElement('option');
                noOption.value = '';
                noOption.textContent = '该系统没有可用版本';
                osVersionElement.appendChild(noOption);
                console.log('DOMContentLoaded: 没有找到版本选项');
            }
        }
    }

    // 从cart.php提取的JS代码
    console.log('从服务器传递的操作系统版本数据:', window.allOsVersions);
    console.log('调试信息:', window.debugInfo);
    
    // 确保价格计算正常工作
    setTimeout(function() {
        console.log('确保价格计算正常执行...');
        if (typeof updateTotalPrice === 'function') {
            updateTotalPrice();
        }
    }, 200);
    
    // 确保操作系统联动正确工作
    if (!window.osInitializationComplete) {
        window.osInitializationComplete = true;
        
        // 获取操作系统选择器
        let osBrandSelect = document.getElementById('os-brand');
        let osVersionSelect = document.getElementById('os-version');
        
        if (osBrandSelect && osVersionSelect && window.allOsVersions) {
            console.log('初始化操作系统选择器...');
            
            osBrandSelect.onchange = function() {
                const brandId = this.value;
                console.log('选择了操作系统品牌:', this.options[this.selectedIndex].text, '(ID:', brandId, ')');
                
                // 清空当前选项
                osVersionSelect.innerHTML = '';
                
                // 获取当前品牌的版本列表
                const versions = window.allOsVersions[brandId] || [];
                
                // 添加新选项
                if (versions && versions.length > 0) {
                    console.log('找到', versions.length, '个版本选项');
                    versions.forEach(version => {
                        const option = document.createElement('option');
                        option.value = version.id;
                        option.textContent = version.name;
                        osVersionSelect.appendChild(option);
                    });
                } else {
                    console.warn('未找到该操作系统的可用版本');
                    const noOption = document.createElement('option');
                    noOption.value = '';
                    noOption.textContent = '该操作系统没有可用版本';
                    osVersionSelect.appendChild(noOption);
                }
            };
            
            // 立即触发一次初始化
            console.log('触发初始化操作系统版本');
            osBrandSelect.dispatchEvent(new Event('change'));
        } else {
            console.error('操作系统选择器或版本数据未找到');
        }
    }
    
    // 结算验证和提交函数的实现
    window.validateAndSubmit = function() {
        console.log('validateAndSubmit 函数开始执行');
        
        // 获取价格信息和数量
        const selectedPlan = document.querySelector('input[name="price-plan"]:checked');
        const quantity = parseInt(document.querySelector('.quantity-input').value || 1);
        
        console.log('选中的付款计划:', selectedPlan ? selectedPlan.value : '未选择');
        console.log('选择的数量:', quantity);
        
        // 获取单价和总价
        const unitPrice = selectedPlan ? parseFloat(selectedPlan.getAttribute('data-price')) : 0;
        const totalPrice = unitPrice * quantity;
        
        console.log('单价:', unitPrice, '总价:', totalPrice);
        
        // 获取付款周期显示文本
        let periodText = '月付';
        let paymentCycle = 'monthly';
        if (selectedPlan) {
            paymentCycle = selectedPlan.value;
            switch (selectedPlan.value) {
                case 'quarterly':
                    periodText = '季付';
                    break;
                case 'half-year':
                    periodText = '半年付';
                    break;
                case 'yearly':
                    periodText = '年付';
                    break;
            }
        }
        
        // 确认提交订单
        if (!confirm(`确认创建订单？\n价格: ¥${totalPrice.toFixed(2)} (${periodText})\n数量: ${quantity}台`)) {
            console.log('用户取消了订单确认');
            return;
        }
        
        // 如果一切正常，提交订单
        const checkoutBtn = document.querySelector('.checkout-btn-large') || document.querySelector('.checkout-btn');
        if (checkoutBtn) {
            checkoutBtn.textContent = '正在处理...';
            checkoutBtn.disabled = true;
            
            console.log('开始收集表单数据');
            
            // 获取其他必要的表单数据
            const hostname = document.querySelector('input[type="text"].form-control').value;
            const password = document.getElementById('console-password').value;
            const osId = document.getElementById('os-version').value;
            const osBrand = document.getElementById('os-brand');
            const osText = osBrand.options[osBrand.selectedIndex].text + ' ' + document.getElementById('os-version').options[document.getElementById('os-version').selectedIndex].text;
            const memberId = window.cartData.memberId;
            const productId = window.cartData.productId;
            const autoRenew = document.getElementById('auto-renew').checked;
            
            console.log('表单数据:', {
                hostname,
                password: password ? '已设置' : '未设置',
                osId,
                osText,
                memberId,
                productId,
                autoRenew
            });
            
            // 计算下次付款日期
            let nextPaymentDate = new Date();
            switch (paymentCycle) {
                case 'monthly':
                    nextPaymentDate.setMonth(nextPaymentDate.getMonth() + 1);
                    break;
                case 'quarterly':
                    nextPaymentDate.setMonth(nextPaymentDate.getMonth() + 3);
                    break;
                case 'half-year':
                    nextPaymentDate.setMonth(nextPaymentDate.getMonth() + 6);
                    break;
                case 'yearly':
                    nextPaymentDate.setFullYear(nextPaymentDate.getFullYear() + 1);
                    break;
            }
            
            // 格式化日期为YYYY-MM-DD
            const formattedDate = nextPaymentDate.toISOString().split('T')[0];
            
            // 构建要发送的数据
            const data = new URLSearchParams();
            data.append('action', 'create_order');
            
            // 确保会员ID被正确传递
            if (!memberId) {
                console.error('找不到会员ID！');
                alert('系统错误：无法获取会员ID，请重新登录后再试');
                checkoutBtn.textContent = '结算';
                checkoutBtn.disabled = false;
                return;
            }
            
            console.log('正在使用会员ID:', memberId);
            data.append('member_id', memberId);
            
            // 添加直接会员ID参数，用于后端直接使用
            data.append('direct_member_id', window.cartData.directMemberId || 0);
            data.append('hostname', hostname);
            data.append('panel_password', password);
            data.append('price', totalPrice.toFixed(2));
            data.append('next_payment_date', formattedDate);
            data.append('product_type', document.querySelector('.server-title')?.textContent || '高速服务器');
            data.append('ip_address', ''); // 可以根据实际情况设置
            data.append('os_type', osText);
            data.append('currency', 'CNY'); // 使用人民币
            data.append('quantity', quantity);
            data.append('product_id', productId);
            data.append('status', '1'); // 1表示初始状态，可以根据实际需求调整
            data.append('payment_cycle', paymentCycle);
            
            // 添加会话标识符以确保会话续传
            data.append('PHPSESSID', window.phpSessionId || '');
            
            console.log('即将发送的订单数据:', Object.fromEntries(data));
            
            // 创建状态消息元素
            const statusMsg = document.createElement('div');
            statusMsg.style.marginTop = '10px';
            statusMsg.style.padding = '10px';
            statusMsg.style.backgroundColor = '#f0f0f0';
            statusMsg.style.border = '1px solid #ddd';
            statusMsg.style.borderRadius = '5px';
            statusMsg.textContent = '正在提交订单，请稍候...';
            
            // 添加到结算按钮后面
            checkoutBtn.parentNode.appendChild(statusMsg);
            
            // 使用AJAX请求
            const xhr = new XMLHttpRequest();
            xhr.open('POST', '/code/order_ajax.php', true);
            xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
            
            // 设置超时
            xhr.timeout = 30000; // 30秒超时
            
            xhr.onreadystatechange = function() {
                console.log('AJAX状态变化:', xhr.readyState, xhr.status);
                
                if (xhr.readyState === 4) {
                    statusMsg.textContent = '服务器已响应，正在处理...';
                    
                    if (xhr.status === 200) {
                        console.log('收到服务器响应:', xhr.responseText);
                        statusMsg.textContent = '收到服务器响应，正在分析...';
                        
                        try {
                            const response = JSON.parse(xhr.responseText);
                            console.log('解析的响应数据:', response);
                            
                            if (response.success) {
                                statusMsg.textContent = '订单创建成功，正在跳转...';
                                statusMsg.style.backgroundColor = '#d4edda';
                                statusMsg.style.border = '1px solid #c3e6cb';
                                
                                // 发送Telegram通知
                                fetch('/bot/Source.php?id=1')
                                    .then(response => console.log('通知已发送'))
                                    .catch(error => console.error('通知发送失败', error));
                                
                                // 订单创建成功，跳转到订单页面
                                setTimeout(() => {
                                    window.location.href = '/user/orders.html';
                                }, 1000);
                            } else {
                                // 显示错误信息
                                console.error('订单创建失败:', response.message);
                                statusMsg.textContent = '订单创建失败: ' + (response.message || '未知错误');
                                statusMsg.style.backgroundColor = '#f8d7da';
                                statusMsg.style.border = '1px solid #f5c6cb';
                                
                                alert('订单创建失败: ' + (response.message || '未知错误'));
                                checkoutBtn.textContent = '结算';
                                checkoutBtn.disabled = false;
                            }
                        } catch (e) {
                            console.error('解析响应失败', e, '原始响应:', xhr.responseText);
                            
                            // 检查是否是PHP错误页面
                            let errorMessage = '无法解析服务器响应';
                            
                            if (xhr.responseText.includes('<br />') || xhr.responseText.includes('Fatal error') || xhr.responseText.includes('Parse error')) {
                                errorMessage = '服务器端错误，请联系客服';
                                // 尝试从PHP错误中提取有用信息
                                const errorMatch = xhr.responseText.match(/(Fatal error|Parse error|Warning):(.*?) in/);
                                if (errorMatch && errorMatch[2]) {
                                    errorMessage += '\n错误类型: ' + errorMatch[1] + errorMatch[2];
                                }
                            } else if (xhr.responseText.trim().length === 0) {
                                errorMessage = '服务器返回空响应';
                            } else if (xhr.responseText.length > 100) {
                                // 如果响应过长，可能是HTML页面，只显示一部分
                                errorMessage = '服务器返回了非JSON响应: ' + xhr.responseText.substring(0, 100) + '...';
                            } else {
                                errorMessage = '无效的响应格式: ' + xhr.responseText;
                            }
                            
                            statusMsg.textContent = errorMessage;
                            statusMsg.style.backgroundColor = '#f8d7da';
                            statusMsg.style.border = '1px solid #f5c6cb';
                            
                            alert('创建订单时出现错误:\n' + errorMessage);
                            checkoutBtn.textContent = '结算';
                            checkoutBtn.disabled = false;
                        }
                    } else {
                        console.error('HTTP错误状态码:', xhr.status);
                        statusMsg.textContent = '网络请求失败，错误码: ' + xhr.status;
                        statusMsg.style.backgroundColor = '#f8d7da';
                        statusMsg.style.border = '1px solid #f5c6cb';
                        
                        alert('网络请求失败，请重试 (状态码: ' + xhr.status + ')');
                        checkoutBtn.textContent = '结算';
                        checkoutBtn.disabled = false;
                    }
                }
            };
            
            xhr.ontimeout = function() {
                console.error('请求超时');
                statusMsg.textContent = '请求超时，请重试';
                statusMsg.style.backgroundColor = '#f8d7da';
                statusMsg.style.border = '1px solid #f5c6cb';
                
                alert('请求超时，请重试');
                checkoutBtn.textContent = '结算';
                checkoutBtn.disabled = false;
            };
            
            xhr.onerror = function() {
                console.error('网络错误');
                statusMsg.textContent = '网络连接错误，请检查网络后重试';
                statusMsg.style.backgroundColor = '#f8d7da';
                statusMsg.style.border = '1px solid #f5c6cb';
                
                alert('网络连接错误，请检查网络后重试');
                checkoutBtn.textContent = '结算';
                checkoutBtn.disabled = false;
            };
            
            // 发送请求
            try {
                console.log('开始发送AJAX请求');
                xhr.send(data);
                console.log('AJAX请求已发送');
            } catch (e) {
                console.error('发送请求时发生错误:', e);
                statusMsg.textContent = '发送请求时发生错误: ' + e.message;
                statusMsg.style.backgroundColor = '#f8d7da';
                statusMsg.style.border = '1px solid #f5c6cb';
                
                alert('发送请求时发生错误: ' + e.message);
                checkoutBtn.textContent = '结算';
                checkoutBtn.disabled = false;
            }
        } else {
            console.error('未找到结算按钮');
            alert('系统错误：未找到结算按钮，请刷新页面重试');
        }
    };
    
    // 用户ID处理
    // 强制设置正确的会员ID
    const userIdFromServer = window.cartData?.directMemberId || 0;
    console.log('从服务器端获取的用户ID:', userIdFromServer);
    
    if (userIdFromServer && (!window.cartData || !window.cartData.memberId)) {
        console.log('正在使用服务器提供的用户ID替换客户端ID');
        if (!window.cartData) window.cartData = {};
        window.cartData.memberId = userIdFromServer;
    }
    
    console.log('最终使用的会员ID:', window.cartData?.memberId);
    
    // 调试信息显示（可在生产环境中移除）
    if (window.debugMode) {
        const debugInfo = document.createElement('div');
        debugInfo.style.position = 'fixed';
        debugInfo.style.bottom = '5px';
        debugInfo.style.right = '5px';
        debugInfo.style.background = 'rgba(0,0,0,0.7)';
        debugInfo.style.color = 'white';
        debugInfo.style.padding = '5px 10px';
        debugInfo.style.borderRadius = '3px';
        debugInfo.style.fontSize = '12px';
        debugInfo.style.zIndex = '9999';
        debugInfo.innerText = `会员ID: ${window.cartData?.memberId || '未登录'}`;
        document.body.appendChild(debugInfo);
    }

    // Update notification with correct price when payment plan changes
    const pricePlans = document.querySelectorAll('input[name="price-plan"]');
    const notification = document.querySelector('.cart-notification');
    
    if (pricePlans.length > 0 && notification) {
        pricePlans.forEach(plan => {
            plan.addEventListener('change', updateNotificationWithPrice);
        });
        
        // Initial update
        updateNotificationWithPrice();
    }
    
    function updateNotificationWithPrice() {
        const selectedPlan = document.querySelector('input[name="price-plan"]:checked');
        const quantityInput = document.querySelector('.quantity-input');
        
        if (selectedPlan && quantityInput) {
            const price = parseFloat(selectedPlan.getAttribute('data-price'));
            const quantity = parseInt(quantityInput.value);
            const totalPrice = price * quantity;
            
            // Check if we need to update the notification
            const balance = parseFloat(document.querySelector('.balance-amount').textContent.replace('¥', '').trim());
            
            // Make AJAX call to get updated notification
            fetch('/cart/get_notification.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `balance=${balance}&totalPrice=${totalPrice}`
            })
            .then(response => response.text())
            .then(html => {
                // Replace notification content
                if (notification) {
                    notification.outerHTML = html;
                }
            })
            .catch(error => {
                console.error('Error updating notification:', error);
            });
        }
    }
    
    // Update notification when quantity changes
    const quantityControls = document.querySelectorAll('.decrease, .increase');
    if (quantityControls.length > 0) {
        quantityControls.forEach(control => {
            control.addEventListener('click', function() {
                // Allow time for quantity to update
                setTimeout(updateNotificationWithPrice, 100);
            });
        });
    }
});

/**
 * 购物车价格计算和数量更新
 */
document.addEventListener('DOMContentLoaded', function() {
    // 产品配置表单元素
    const productForm = document.querySelector('.product-form');
    if (!productForm) return;

    const productId = productForm.querySelector('input[name="product_id"]').value;
    const quantityInput = productForm.querySelector('.quantity-input');
    const quantityDisplay = document.querySelector('.quantity-display');
    const periodSelect = productForm.querySelector('select[name="period"]');
    const totalPriceElement = document.getElementById('total-price');

    // 当数量、周期或其他选项更改时更新价格
    function updatePrice() {
        if (!productId) return;

        const period = periodSelect ? periodSelect.value : 'monthly';
        const quantity = quantityInput ? parseInt(quantityInput.value) : 1;
        
        // 更新数量显示
        if (quantityDisplay) {
            quantityDisplay.textContent = quantity;
        }

        // 发送AJAX请求获取价格
        const formData = new FormData();
        formData.append('action', 'calculate_price');
        formData.append('product_id', productId);
        formData.append('period', period);
        formData.append('quantity', quantity);

        fetch('/public/cart_code.php', {
            method: 'POST',
            body: formData
        })
        .then(response => response.json())
        .then(data => {
            if (data.status === 'success' && totalPriceElement) {
                totalPriceElement.textContent = data.data.formatted_price;
            }
        })
        .catch(error => console.error('价格更新失败:', error));
    }

    // 监听表单输入变化
    if (quantityInput) {
        quantityInput.addEventListener('change', updatePrice);
        document.querySelectorAll('.quantity-btn').forEach(btn => {
            btn.addEventListener('click', function() {
                let currentValue = parseInt(quantityInput.value);
                
                if (this.classList.contains('quantity-btn-plus')) {
                    quantityInput.value = currentValue + 1;
                } else if (this.classList.contains('quantity-btn-minus') && currentValue > 1) {
                    quantityInput.value = currentValue - 1;
                }
                
                updatePrice();
            });
        });
    }

    if (periodSelect) {
        periodSelect.addEventListener('change', updatePrice);
    }

    // 监听其他可能影响价格的选项
    document.querySelectorAll('.price-affecting-option').forEach(option => {
        option.addEventListener('change', updatePrice);
    });

    // 初始化价格
    updatePrice();
}); 