document.addEventListener('DOMContentLoaded', function() {
  console.log("Data center map initializing...");
  
  const mapContainer = document.getElementById('dataCentersMap');
  if (!mapContainer) {
    console.error("Map container not found!");
    return;
  }
  
  // 获取容器尺寸，用于坐标转换
  let containerWidth = mapContainer.offsetWidth;
  let containerHeight = mapContainer.offsetHeight;
  
  // 监听窗口大小变化，更新容器尺寸
  window.addEventListener('resize', function() {
    containerWidth = mapContainer.offsetWidth;
    containerHeight = mapContainer.offsetHeight;
  });
  
  // 检测是否为移动设备
  const isMobile = window.innerWidth < 768;
  
  // 数据中心位置数据 - 添加硅谷、越南、马来西亚和菲律宾节点，以及德国节点
  const dataCenters = [
    { id: 'hk', name: '香港', x: isMobile ? 75 : 75, y: isMobile ? 45 : 45, isMain: true },  // 橙色主节点
    { id: 'la', name: '洛杉矶', x: isMobile ? 18 : 18, y: isMobile ? 40 : 40 },
    { id: 'ny', name: '纽约', x: isMobile ? 25 : 25, y: isMobile ? 38 : 38 },
    { id: 'ln', name: '英国', x: isMobile ? 45 : 45, y: isMobile ? 30 : 30 },
    { id: 'fr', name: '法国', x: isMobile ? 48 : 48, y: isMobile ? 33 : 33 },
    { id: 'tk', name: '东京', x: isMobile ? 82 : 82, y: isMobile ? 40 : 40 },
    { id: 'sg', name: '新加坡', x: isMobile ? 72 : 72, y: isMobile ? 52 : 52, isMain: true },
    { id: 'tw', name: '台湾', x: 83, y: 42 },
    { id: 'kr', name: '首尔', x: 84, y: 35 },
    { id: 'sv', name: '硅谷', x: 15, y: 40 },
    { id: 'vn', name: '越南', x: 78, y: 50 },
    { id: 'my', name: '马来西亚', x: 76, y: 53 },
    { id: 'ph', name: '菲律宾', x: 82, y: 48 },
    { id: 'de', name: '德国', x: 52, y: 31 }  // 新增德国节点
  ];
  
  // 定义节点之间的连接 - 添加新节点的连接，以及香港到德国的连接
  const connections = [
    { from: 'hk', to: 'la' },
    { from: 'hk', to: 'ny' },
    { from: 'hk', to: 'ln' },
    { from: 'hk', to: 'fr' },
    { from: 'hk', to: 'tk' },
    { from: 'hk', to: 'sg' },
    { from: 'hk', to: 'tw' },
    { from: 'hk', to: 'kr' },
    { from: 'hk', to: 'sv' },
    { from: 'hk', to: 'vn' },
    { from: 'hk', to: 'my' },
    { from: 'hk', to: 'ph' },
    { from: 'hk', to: 'de' }  // 新增香港到德国的连接
  ];
  
  // 创建SVG容器
  const svgNS = "http://www.w3.org/2000/svg";
  const svg = document.createElementNS(svgNS, "svg");
  svg.setAttribute('width', '100%');
  svg.setAttribute('height', '100%');
  svg.style.position = 'absolute';
  svg.style.top = '0';
  svg.style.left = '0';
  mapContainer.appendChild(svg);
  
  // 先绘制连接线
  connections.forEach(connection => {
    const fromCenter = dataCenters.find(center => center.id === connection.from);
    const toCenter = dataCenters.find(center => center.id === connection.to);
    
    if (fromCenter && toCenter) {
      const line = document.createElementNS(svgNS, "line");
      line.setAttribute('x1', fromCenter.x + '%');
      line.setAttribute('y1', fromCenter.y + '%');
      line.setAttribute('x2', toCenter.x + '%');
      line.setAttribute('y2', toCenter.y + '%');
      line.setAttribute('stroke', '#33CCFF');
      line.setAttribute('stroke-width', '1');
      line.setAttribute('opacity', '0.6');
      svg.appendChild(line);
      
      // 添加动态效果 - 沿线移动的点
      const animatedDot = document.createElementNS(svgNS, "circle");
      animatedDot.setAttribute('r', '2');
      animatedDot.setAttribute('fill', '#33CCFF');
      
      // 创建动画
      const animate = document.createElementNS(svgNS, "animate");
      animate.setAttribute('attributeName', 'cx');
      animate.setAttribute('from', fromCenter.x + '%');
      animate.setAttribute('to', toCenter.x + '%');
      animate.setAttribute('dur', '3s');
      animate.setAttribute('repeatCount', 'indefinite');
      animatedDot.appendChild(animate);
      
      const animateY = document.createElementNS(svgNS, "animate");
      animateY.setAttribute('attributeName', 'cy');
      animateY.setAttribute('from', fromCenter.y + '%');
      animateY.setAttribute('to', toCenter.y + '%');
      animateY.setAttribute('dur', '3s');
      animateY.setAttribute('repeatCount', 'indefinite');
      animatedDot.appendChild(animateY);
      
      svg.appendChild(animatedDot);
    }
  });
  
  // 然后绘制数据中心节点
  dataCenters.forEach(center => {
    const dot = document.createElement('div');
    dot.className = 'data-center-node';
    dot.style.position = 'absolute';
    dot.style.left = center.x + '%';
    dot.style.top = center.y + '%';
    dot.style.width = center.isMain ? '20px' : '10px';
    dot.style.height = center.isMain ? '20px' : '10px';
    dot.style.borderRadius = '50%';
    dot.style.backgroundColor = center.isMain ? '#FF6600' : '#33CCFF';
    dot.style.boxShadow = center.isMain ? 
        '0 0 0 rgba(255, 102, 0, 0.4)' : 
        '0 0 0 rgba(51, 204, 255, 0.4)';
    dot.style.transform = 'translate(-50%, -50%)';
    dot.style.zIndex = '2';
    
    // 为主节点添加脉动效果
    if (center.isMain) {
      const pulse = document.createElement('div');
      pulse.className = 'pulse-effect';
      pulse.style.position = 'absolute';
      pulse.style.width = '100%';
      pulse.style.height = '100%';
      pulse.style.borderRadius = '50%';
      pulse.style.backgroundColor = 'rgba(255, 102, 0, 0.6)';
      pulse.style.animation = 'pulse 2s infinite';
      dot.appendChild(pulse);
    }
    
    // 添加节点标签
    const label = document.createElement('div');
    label.className = 'data-center-label';
    label.textContent = center.name;
    label.style.position = 'absolute';
    label.style.top = '100%';
    label.style.left = '50%';
    label.style.transform = 'translateX(-50%)';
    label.style.color = '#fff';
    label.style.fontSize = '10px';
    label.style.whiteSpace = 'nowrap';
    label.style.textShadow = '0 0 2px #000';
    dot.appendChild(label);
    
    mapContainer.appendChild(dot);
  });
  
  // 添加CSS动画
  const style = document.createElement('style');
  style.textContent = `
    @keyframes pulse {
      0% {
        transform: scale(1);
        opacity: 0.6;
      }
      70% {
        transform: scale(2);
        opacity: 0;
      }
      100% {
        transform: scale(1);
        opacity: 0;
      }
    }
  `;
  document.head.appendChild(style);
  
  // 创建数据中心点位
  const dataCenterPoints = [
    { name: '香港', x: isMobile ? 75 : 75, y: isMobile ? 45 : 45, type: 'self' },
    { name: '东京', x: isMobile ? 82 : 82, y: isMobile ? 40 : 40, type: 'partner' },
    { name: '新加坡', x: isMobile ? 72 : 72, y: isMobile ? 52 : 52, type: 'self' },
    { name: '洛杉矶', x: isMobile ? 18 : 18, y: isMobile ? 40 : 40, type: 'self' },
    { name: '纽约', x: isMobile ? 25 : 25, y: isMobile ? 38 : 38, type: 'partner' },
    { name: '伦敦', x: isMobile ? 45 : 45, y: isMobile ? 30 : 30, type: 'partner' },
    { name: '法兰克福', x: isMobile ? 48 : 48, y: isMobile ? 33 : 33, type: 'self' },
  ];
  
  // 创建数据中心点
  dataCenterPoints.forEach(point => {
    const pointElement = document.createElement('div');
    pointElement.className = `data-center-point ${point.type}`;
    pointElement.style.left = `${point.x}%`;
    pointElement.style.top = `${point.y}%`;
    
    // 添加脉冲动画效果
    const pulse = document.createElement('div');
    pulse.className = 'pulse';
    pointElement.appendChild(pulse);
    
    // 添加点位名称标签
    const label = document.createElement('div');
    label.className = 'point-label';
    label.textContent = point.name;
    pointElement.appendChild(label);
    
    mapContainer.appendChild(pointElement);
  });
  
  // 添加移动端的响应性调整
  function adjustForMobile() {
    const isNowMobile = window.innerWidth < 768;
    if (isNowMobile) {
      // 移动端点位样式调整
      const points = document.querySelectorAll('.data-center-point');
      points.forEach(point => {
        point.style.width = '6px';
        point.style.height = '6px';
      });
      
      // 移动端标签调整
      const labels = document.querySelectorAll('.point-label');
      labels.forEach(label => {
        label.style.fontSize = '8px';
        label.style.padding = '2px 4px';
      });
    }
  }
  
  // 初始调整
  adjustForMobile();
  
  // 窗口大小变化时调整
  window.addEventListener('resize', adjustForMobile);
  
  console.log("Data center map initialized successfully");
}); 