// FAQ页面交互功能
document.addEventListener('DOMContentLoaded', function() {
  console.log('FAQ页面脚本已加载');
  
  // 问题展开/收起功能
  const faqItems = document.querySelectorAll('.faq-item');
  console.log('找到FAQ项目数量:', faqItems.length);
  
  faqItems.forEach(item => {
    const question = item.querySelector('.faq-question');
    
    question.addEventListener('click', () => {
      console.log('FAQ问题被点击');
      // 关闭其他已打开的问题
      const currentlyActive = document.querySelector('.faq-item.active');
      if (currentlyActive && currentlyActive !== item) {
        currentlyActive.classList.remove('active');
      }
      
      // 切换当前问题的状态
      item.classList.toggle('active');
    });
  });
  
  // 分类导航功能
  const categoryLinks = document.querySelectorAll('.category-item');
  const faqSections = document.querySelectorAll('.faq-section');
  
  categoryLinks.forEach(link => {
    link.addEventListener('click', function(e) {
      e.preventDefault();
      
      // 移除所有分类的active类
      categoryLinks.forEach(item => item.classList.remove('active'));
      
      // 为当前点击的分类添加active类
      this.classList.add('active');
      
      // 获取目标section的id
      const targetId = this.getAttribute('href').substring(1);
      
      // 隐藏所有section
      faqSections.forEach(section => section.classList.remove('active'));
      
      // 显示目标section
      document.getElementById(targetId).classList.add('active');
      
      // 平滑滚动到section位置
      document.getElementById(targetId).scrollIntoView({
        behavior: 'smooth',
        block: 'start'
      });
    });
  });
  
  // 搜索功能
  const searchInput = document.getElementById('faq-search-input');
  const searchBtn = document.querySelector('.search-btn');
  
  function performSearch() {
    const searchTerm = searchInput.value.toLowerCase().trim();
    
    if (searchTerm.length < 2) return; // 至少输入2个字符才搜索
    
    let foundResults = false;
    
    // 隐藏所有FAQ项目
    faqItems.forEach(item => {
      item.style.display = 'none';
      item.classList.remove('active');
    });
    
    // 显示所有section以便搜索
    faqSections.forEach(section => section.classList.add('active'));
    
    // 搜索问题标题和内容
    faqItems.forEach(item => {
      const question = item.querySelector('h3').textContent.toLowerCase();
      const answer = item.querySelector('.faq-answer').textContent.toLowerCase();
      
      if (question.includes(searchTerm) || answer.includes(searchTerm)) {
        item.style.display = 'block';
        item.classList.add('active'); // 展开匹配的问题
        foundResults = true;
        
        // 确保该section可见
        const parentSection = item.closest('.faq-section');
        parentSection.classList.add('active');
        
        // 更新分类导航的active状态
        const sectionId = parentSection.id;
        categoryLinks.forEach(link => {
          if (link.getAttribute('href') === '#' + sectionId) {
            link.classList.add('active');
          } else {
            link.classList.remove('active');
          }
        });
      }
    });
    
    // 如果没有找到结果，显示提示
    if (!foundResults) {
      // 恢复默认视图
      faqItems.forEach(item => item.style.display = 'block');
      
      // 显示第一个分类
      faqSections.forEach((section, index) => {
        section.classList.toggle('active', index === 0);
      });
      
      // 更新分类导航
      categoryLinks.forEach((link, index) => {
        link.classList.toggle('active', index === 0);
      });
      
      // 显示提示
      alert('没有找到匹配的问题，请尝试其他关键词。');
    }
  }
  
  // 搜索按钮点击事件
  searchBtn.addEventListener('click', performSearch);
  
  // 回车键搜索
  searchInput.addEventListener('keypress', function(e) {
    if (e.key === 'Enter') {
      performSearch();
    }
  });
  
  // 重置搜索
  searchInput.addEventListener('input', function() {
    if (this.value === '') {
      // 恢复默认视图
      faqItems.forEach(item => {
        item.style.display = 'block';
        item.classList.remove('active');
      });
      
      // 只显示第一个分类
      faqSections.forEach((section, index) => {
        section.classList.toggle('active', index === 0);
      });
      
      // 更新分类导航
      categoryLinks.forEach((link, index) => {
        link.classList.toggle('active', index === 0);
      });
    }
  });
});