/**
 * GPU服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化产品筛选功能
    initProductFilter();
    
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化表格样式
    enhancePerformanceTable();
});

/**
 * 初始化产品筛选功能
 */
function initProductFilter() {
    const filterBtns = document.querySelectorAll('.filter-btn');
    const productCards = document.querySelectorAll('.product-card');
    
    // 为每个筛选按钮添加点击事件
    filterBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            // 获取筛选类型
            const filterGroup = this.parentElement.parentElement;
            const filterValue = this.textContent.trim();
            
            // 移除同组其他按钮的active类
            filterGroup.querySelectorAll('.filter-btn').forEach(el => {
                el.classList.remove('active');
            });
            
            // 添加当前按钮的active类
            this.classList.add('active');
            
            // 筛选产品卡片
            filterProducts();
        });
    });

    /**
     * 根据当前选中的筛选条件过滤产品卡片
     */
    function filterProducts() {
        // 获取所有激活的筛选条件
        const activeGpuType = document.querySelector('.filter-group:nth-child(1) .filter-btn.active').textContent.trim();
        const activeRegion = document.querySelector('.filter-group:nth-child(2) .filter-btn.active').textContent.trim();
        const activePrice = document.querySelector('.filter-group:nth-child(3) .filter-btn.active').textContent.trim();
        
        // 遍历所有产品卡片
        productCards.forEach(card => {
            // 获取产品属性
            const cardHeader = card.querySelector('.product-header h3').textContent.trim();
            const cardLocation = card.querySelector('.product-location span').textContent.trim();
            const cardPrice = parseInt(card.querySelector('.price-value').textContent.replace(/[^\d]/g, ''));
            const cardGpuType = card.querySelector('.highlight .spec-value').textContent.trim();
            
            // 判断是否符合GPU类型筛选条件
            let gpuTypeMatch = activeGpuType === '全部';
            if (activeGpuType === 'NVIDIA A100') {
                gpuTypeMatch = cardGpuType.includes('A100');
            } else if (activeGpuType === 'NVIDIA V100') {
                gpuTypeMatch = cardGpuType.includes('V100');
            } else if (activeGpuType === 'NVIDIA T4') {
                gpuTypeMatch = cardGpuType.includes('T4');
            } else if (activeGpuType === 'NVIDIA RTX系列') {
                gpuTypeMatch = cardGpuType.includes('RTX');
            }
            
            // 判断是否符合区域筛选条件
            let regionMatch = activeRegion === '全部';
            if (activeRegion === '亚太地区') {
                regionMatch = ['香港', '日本', '新加坡', '韩国'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '欧洲') {
                regionMatch = ['德国', '法国', '英国', '荷兰'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '北美') {
                regionMatch = ['美国', '加拿大'].some(region => cardLocation.includes(region));
            }
            
            // 判断是否符合价格筛选条件
            let priceMatch = activePrice === '全部';
            if (activePrice === '5000元以下') {
                priceMatch = cardPrice < 5000;
            } else if (activePrice === '5000-10000元') {
                priceMatch = cardPrice >= 5000 && cardPrice <= 10000;
            } else if (activePrice === '10000-20000元') {
                priceMatch = cardPrice > 10000 && cardPrice <= 20000;
            } else if (activePrice === '20000元以上') {
                priceMatch = cardPrice > 20000;
            }
            
            // 显示或隐藏产品卡片
            if (gpuTypeMatch && regionMatch && priceMatch) {
                card.style.display = 'flex';
            } else {
                card.style.display = 'none';
            }
        });
    }
}

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('open');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('open');
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('open');
            }
        });
    });
}

/**
 * 增强性能对比表格交互体验
 */
function enhancePerformanceTable() {
    const performanceTable = document.querySelector('.performance-table');
    
    if (!performanceTable) return;
    
    // 添加表格行悬停效果
    const tableRows = performanceTable.querySelectorAll('tbody tr');
    tableRows.forEach(row => {
        row.addEventListener('mouseenter', function() {
            this.style.backgroundColor = '#f8f8f8';
        });
        
        row.addEventListener('mouseleave', function() {
            this.style.backgroundColor = '';
        });
    });
    
    // 添加表格列高亮效果
    const tableCells = performanceTable.querySelectorAll('td, th');
    tableCells.forEach(cell => {
        cell.addEventListener('mouseenter', function() {
            const cellIndex = Array.from(this.parentNode.children).indexOf(this);
            
            // 高亮当前列
            tableRows.forEach(row => {
                const targetCell = row.children[cellIndex];
                if (targetCell) {
                    targetCell.style.backgroundColor = '#f0f0f0';
                }
            });
            
            // 高亮表头
            const headerCell = performanceTable.querySelector(`thead th:nth-child(${cellIndex + 1})`);
            if (headerCell) {
                headerCell.style.backgroundColor = '#e9e9e9';
            }
        });
        
        cell.addEventListener('mouseleave', function() {
            const cellIndex = Array.from(this.parentNode.children).indexOf(this);
            
            // 恢复当前列
            tableRows.forEach(row => {
                const targetCell = row.children[cellIndex];
                if (targetCell) {
                    targetCell.style.backgroundColor = '';
                }
            });
            
            // 恢复表头
            const headerCell = performanceTable.querySelector(`thead th:nth-child(${cellIndex + 1})`);
            if (headerCell) {
                headerCell.style.backgroundColor = '#f7f7f7';
            }
        });
    });
} 