document.addEventListener('DOMContentLoaded', function() {
  const mobileMenuToggle = document.querySelector('.mobile-menu-toggle');
  const nav = document.querySelector('.nav');
  const navItems = document.querySelectorAll('.nav-item');
  
  // 点击汉堡菜单按钮，显示/隐藏整个菜单
  mobileMenuToggle.addEventListener('click', function(e) {
    e.preventDefault();
    e.stopPropagation();
    this.classList.toggle('active');
    nav.classList.toggle('active');
    document.body.classList.toggle('menu-open');
  });

  // 点击页面其他地方关闭菜单
  document.addEventListener('click', function(event) {
    if (!nav.contains(event.target) && !mobileMenuToggle.contains(event.target)) {
      mobileMenuToggle.classList.remove('active');
      nav.classList.remove('active');
      document.body.classList.remove('menu-open');
      // 同时关闭所有子菜单
      document.querySelectorAll('.nav-item').forEach(item => {
        item.classList.remove('open');
        const dropdown = item.querySelector('.dropdown, .mega-dropdown');
        if (dropdown) dropdown.style.display = 'none';
      });
    }
  });

  // 初始化菜单
  function setupMenu() {
    const isMobile = window.innerWidth <= 992;
    
    if (isMobile) {
      // 移动端菜单处理
      
      // 确保所有子菜单初始隐藏
      document.querySelectorAll('.dropdown, .mega-dropdown').forEach(dropdown => {
        dropdown.style.display = 'none';
      });
      
      // 为主菜单项添加点击事件
      navItems.forEach(item => {
        const link = item.querySelector('.nav-link');
        const dropdown = item.querySelector('.dropdown, .mega-dropdown');
        
        if (dropdown && link) {
          link.addEventListener('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            
            console.log('点击了菜单：', link.textContent.trim());
            
            // 首先关闭所有其他菜单
            navItems.forEach(otherItem => {
              if (otherItem !== item) {
                otherItem.classList.remove('open');
                const otherDropdown = otherItem.querySelector('.dropdown, .mega-dropdown');
                if (otherDropdown) {
                  otherDropdown.style.display = 'none';
                }
              }
            });
            
            // 切换当前菜单
            if (item.classList.contains('open')) {
              // 如果已经打开，则关闭
              item.classList.remove('open');
              dropdown.style.display = 'none';
              console.log('关闭菜单');
            } else {
              // 如果关闭，则打开
              item.classList.add('open');
              dropdown.style.display = dropdown.classList.contains('mega-dropdown') ? 'grid' : 'block';
              console.log('打开菜单', dropdown);
            }
          });
        }
      });
      
      // 阻止子菜单项的点击冒泡，允许链接跳转
      document.querySelectorAll('.dropdown-list-t li a, .mega-item a').forEach(link => {
        link.addEventListener('click', function(e) {
          e.stopPropagation();
        });
      });
    } else {
      // 桌面模式 - 重置所有菜单样式
      document.querySelectorAll('.dropdown, .mega-dropdown').forEach(dropdown => {
        dropdown.style.display = '';
      });
      
      document.querySelectorAll('.nav-item').forEach(item => {
        item.classList.remove('open');
      });
    }
  }
  
  // 初始化菜单
  setupMenu();
  
  // 窗口大小变化时重新初始化
  window.addEventListener('resize', function() {
    if (window.innerWidth > 992) {
      // 桌面视图下重置菜单状态
      if (mobileMenuToggle) mobileMenuToggle.classList.remove('active');
      if (nav) nav.classList.remove('active');
      document.body.classList.remove('menu-open');
      
      // 重置子菜单显示
      navItems.forEach(item => {
        item.classList.remove('open');
        
        const dropdown = item.querySelector('.dropdown');
        if (dropdown) dropdown.style.display = '';
        
        const megaDropdown = item.querySelector('.mega-dropdown');
        if (megaDropdown) megaDropdown.style.display = '';
      });
      
      // 重置mega菜单列表显示
      const megaLists = document.querySelectorAll('.mega-list, .dropdown-list');
      megaLists.forEach(list => {
        list.style.display = '';
      });
    }
  });

  // 处理一级菜单项的子菜单展开/收起
  navItems.forEach(item => {
    const navLink = item.querySelector('.nav-link');
    const dropdown = item.querySelector('.dropdown');
    const megaDropdown = item.querySelector('.mega-dropdown');
    
    // 仅在移动视图下处理点击事件
    if (window.innerWidth <= 992 && navLink) {
      navLink.addEventListener('click', function(e) {
        // 防止链接立即导航
        e.preventDefault();
        
        // 移动视图下关闭其他已打开的菜单项
        navItems.forEach(otherItem => {
          if (otherItem !== item && otherItem.classList.contains('open')) {
            otherItem.classList.remove('open');
            
            const otherDropdown = otherItem.querySelector('.dropdown');
            if (otherDropdown) otherDropdown.style.display = 'none';
            
            const otherMegaDropdown = otherItem.querySelector('.mega-dropdown');
            if (otherMegaDropdown) otherMegaDropdown.style.display = 'none';
          }
        });
        
        // 切换当前项的展开/收起状态
        item.classList.toggle('open');
        
        // 处理普通下拉菜单
        if (dropdown) {
          dropdown.style.display = item.classList.contains('open') ? 'block' : 'none';
        }
        
        // 处理mega下拉菜单
        if (megaDropdown) {
          megaDropdown.style.display = item.classList.contains('open') ? 'grid' : 'none';
        }
      });
    }
  });
  
  // 处理二级菜单 (megaDropdown中的列)
  const megaTitles = document.querySelectorAll('.mega-title');
  
  megaTitles.forEach(title => {
    // 在小屏幕上为mega菜单标题添加点击展开/收起功能
    if (window.innerWidth <= 992) {
      title.addEventListener('click', function(e) {
        if (window.innerWidth <= 992) {
          const parentColumn = this.closest('.mega-column');
          if (parentColumn) {
            const siblingsList = parentColumn.querySelector('.mega-list, .dropdown-list');
            if (siblingsList) {
              // 切换显示/隐藏状态
              if (siblingsList.style.display === 'none') {
                siblingsList.style.display = 'block';
                this.classList.add('open');
              } else {
                siblingsList.style.display = 'none';
                this.classList.remove('open');
              }
            }
          }
        }
      });
    }
  });

  // 增加触摸滑动手势支持
  let touchStartX = 0;
  let touchEndX = 0;
  
  document.addEventListener('touchstart', e => {
    touchStartX = e.changedTouches[0].screenX;
  }, { passive: true });
  
  document.addEventListener('touchend', e => {
    touchEndX = e.changedTouches[0].screenX;
    handleSwipe();
  }, { passive: true });
  
  function handleSwipe() {
    if (nav && nav.classList.contains('active') && touchEndX - touchStartX > 100) {
      // 向右滑动关闭菜单
      if (mobileMenuToggle) mobileMenuToggle.classList.remove('active');
      nav.classList.remove('active');
      document.body.classList.remove('menu-open');
    }
  }

  // 添加辅助样式
  const headerStyles = document.createElement('style');
  headerStyles.textContent = `
    /* 移动菜单状态样式 */
    body.menu-open {
      overflow: hidden;
    }
    
    /* 标题栏动画 */
    @media (max-width: 992px) {
      .nav-item .dropdown,
      .nav-item .mega-dropdown {
        display: none;
      }
      
      .nav-item.open .nav-link {
        color: #ff6600;
      }
      
      .nav-item.open .nav-link i {
        color: #ff6600;
      }
      
      .mega-title.open {
        color: #ff6600;
      }
      
      .mega-title.open i {
        transform: rotate(90deg);
      }
      
      /* 增强触摸体验 */
      .nav-link, .dropdown-list-t li a, .mega-item a {
        padding: 15px 20px !important;
      }
    }
  `;
  document.head.appendChild(headerStyles);
}); 