/**
 * 高带宽服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // Banner轮播初始化
    initHighBandwidthBanner();
    
    // 导航菜单初始化
    initHighBandwidthNavMenu();
    
    // 产品筛选功能初始化
    initProductFilter();
    
    // FAQ交互初始化
    initFaqInteraction();
});

/**
 * 初始化banner轮播
 */
function initHighBandwidthBanner() {
    if (typeof initBannerSlider === 'function') {
        // 使用js.js中的banner初始化函数
        initBannerSlider();
    } else {
        // 备用banner初始化
        new Swiper('.banner-swiper', {
            loop: true,
            autoplay: {
                delay: 5000,
                disableOnInteraction: false
            },
            pagination: {
                el: '.swiper-pagination',
                clickable: true
            },
            navigation: {
                nextEl: '.swiper-button-next',
                prevEl: '.swiper-button-prev'
            },
            effect: 'fade',
            fadeEffect: {
                crossFade: true
            }
        });
    }
}

/**
 * 初始化导航菜单
 */
function initHighBandwidthNavMenu() {
    if (typeof initNavMenu === 'function') {
        initNavMenu();
    } else {
        // 备用菜单初始化
        $('.nav-item.dropdown').hover(
            function() {
                $(this).find('.dropdown-menu').addClass('show');
            },
            function() {
                $(this).find('.dropdown-menu').removeClass('show');
            }
        );
    }
}

/**
 * 初始化产品筛选功能
 */
function initProductFilter() {
    const filterBtns = document.querySelectorAll('.filter-btn');
    const productCards = document.querySelectorAll('.product-card');
    
    filterBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            const filterType = this.parentElement.parentElement.querySelector('label').textContent.includes('带宽') ? 'bandwidth' : 'location';
            const filterValue = this.getAttribute('data-filter');
            
            // 移除同组其他按钮的active类
            this.parentElement.querySelectorAll('.filter-btn').forEach(el => {
                el.classList.remove('active');
            });
            
            // 添加当前按钮的active类
            this.classList.add('active');
            
            // 筛选产品卡片
            filterProducts();
        });
    });

    /**
     * 根据选中的筛选条件过滤产品卡片
     */
    function filterProducts() {
        const activeBandwidthFilter = document.querySelector('.filter-group:nth-child(1) .filter-btn.active').getAttribute('data-filter');
        const activeLocationFilter = document.querySelector('.filter-group:nth-child(2) .filter-btn.active').getAttribute('data-filter');
        
        productCards.forEach(card => {
            const cardBandwidth = card.getAttribute('data-bandwidth');
            const cardLocation = card.getAttribute('data-location');
            
            const bandwidthMatch = activeBandwidthFilter === 'all' || cardBandwidth === activeBandwidthFilter;
            const locationMatch = activeLocationFilter === 'all' || cardLocation === activeLocationFilter;
            
            if (bandwidthMatch && locationMatch) {
                card.style.display = 'flex';
            } else {
                card.style.display = 'none';
            }
        });
    }
}

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        const answer = item.querySelector('.faq-answer');
        
        question.addEventListener('click', function() {
            // 切换当前FAQ项的激活状态
            item.classList.toggle('active');
            
            // 展开/收起回答
            if (item.classList.contains('active')) {
                answer.style.maxHeight = answer.scrollHeight + 'px';
            } else {
                answer.style.maxHeight = '0';
            }
        });
    });
} 