/**
 * 服务器托管页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化托管方案卡片交互
    initPlanCards();
    
    // 初始化服务保障项交互
    initGuaranteeItems();
});

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('active');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('active');
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('active');
                
                // 展开答案内容
                const answer = item.querySelector('.faq-answer');
                answer.style.maxHeight = answer.scrollHeight + 'px';
            }
        });
    });
}

/**
 * 初始化托管方案卡片交互效果
 */
function initPlanCards() {
    const planCards = document.querySelectorAll('.plan-card');
    
    planCards.forEach(card => {
        // 添加鼠标悬停增强效果
        card.addEventListener('mouseenter', function() {
            if (!this.classList.contains('featured')) {
                this.style.transform = 'translateY(-10px)';
                this.style.boxShadow = '0 15px 30px rgba(0, 0, 0, 0.1)';
            } else {
                this.style.transform = 'scale(1.05) translateY(-10px)';
                this.style.boxShadow = '0 20px 40px rgba(0, 0, 0, 0.15)';
            }
            
            // 突出显示按钮
            const btn = this.querySelector('.btn');
            if (btn) {
                if (btn.classList.contains('btn-outline')) {
                    btn.style.backgroundColor = 'rgba(255, 102, 0, 0.1)';
                } else if (btn.classList.contains('btn-primary')) {
                    btn.style.backgroundColor = '#e55c00';
                }
            }
        });
        
        // 恢复默认状态
        card.addEventListener('mouseleave', function() {
            if (!this.classList.contains('featured')) {
                this.style.transform = '';
                this.style.boxShadow = '';
            } else {
                this.style.transform = 'scale(1.05)';
                this.style.boxShadow = '';
            }
            
            // 恢复按钮样式
            const btn = this.querySelector('.btn');
            if (btn) {
                if (btn.classList.contains('btn-outline')) {
                    btn.style.backgroundColor = '';
                } else if (btn.classList.contains('btn-primary')) {
                    btn.style.backgroundColor = '';
                }
            }
        });
    });
    
    // 添加特色卡片标记
    const featuredCard = document.querySelector('.plan-card.featured');
    if (featuredCard) {
        const badge = document.createElement('div');
        badge.className = 'featured-badge';
        badge.textContent = '推荐';
        badge.style.position = 'absolute';
        badge.style.top = '0';
        badge.style.right = '20px';
        badge.style.backgroundColor = '#ff6600';
        badge.style.color = 'white';
        badge.style.padding = '5px 10px';
        badge.style.fontSize = '12px';
        badge.style.fontWeight = 'bold';
        badge.style.borderRadius = '0 0 5px 5px';
        
        featuredCard.style.position = 'relative';
        featuredCard.appendChild(badge);
    }
}

/**
 * 初始化服务保障项交互效果
 */
function initGuaranteeItems() {
    const guaranteeItems = document.querySelectorAll('.guarantee-item');
    
    guaranteeItems.forEach(item => {
        // 添加点击效果
        item.addEventListener('click', function() {
            // 移除所有项的激活状态
            guaranteeItems.forEach(i => {
                i.style.backgroundColor = '#f9f9f9';
                i.style.transform = '';
                
                const icon = i.querySelector('.guarantee-icon i');
                if (icon) {
                    icon.style.transform = '';
                    icon.style.color = '#ff6600';
                }
            });
            
            // 激活当前项
            this.style.backgroundColor = '#fff3eb';
            this.style.transform = 'translateY(-5px)';
            
            // 强调图标
            const icon = this.querySelector('.guarantee-icon i');
            if (icon) {
                icon.style.transform = 'scale(1.2)';
                icon.style.transition = 'transform 0.3s ease, color 0.3s ease';
                icon.style.color = '#ff6600';
            }
        });
        
        // 添加悬停效果
        item.addEventListener('mouseenter', function() {
            if (this.style.backgroundColor !== 'rgb(255, 243, 235)') { // 如果不是激活状态
                this.style.backgroundColor = '#f5f5f5';
                this.style.transform = 'translateY(-5px)';
            }
        });
        
        item.addEventListener('mouseleave', function() {
            if (this.style.backgroundColor !== 'rgb(255, 243, 235)') { // 如果不是激活状态
                this.style.backgroundColor = '#f9f9f9';
                this.style.transform = '';
            }
        });
    });
    
    // 默认激活第一个项目
    if (guaranteeItems.length > 0) {
        guaranteeItems[0].click();
    }
}

/**
 * 添加平滑滚动效果
 */
function initSmoothScroll() {
    // 获取所有内部链接
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function(e) {
            e.preventDefault();
            
            const targetId = this.getAttribute('href');
            if (targetId === '#') return;
            
            const targetElement = document.querySelector(targetId);
            if (targetElement) {
                // 平滑滚动到目标元素
                targetElement.scrollIntoView({
                    behavior: 'smooth',
                    block: 'start'
                });
            }
        });
    });
} 