/**
 * 热销服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化产品筛选功能
    initProductFilter();
    
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化评价轮播
    initReviewsSlider();
});

/**
 * 初始化产品筛选功能
 */
function initProductFilter() {
    const filterBtns = document.querySelectorAll('.filter-btn');
    const productCards = document.querySelectorAll('.product-card');
    
    // 为每个筛选按钮添加点击事件
    filterBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            // 获取筛选类型
            const filterGroup = this.parentElement.parentElement;
            const filterType = filterGroup.querySelector('label').textContent.trim();
            const filterValue = this.textContent.trim();
            
            // 移除同组其他按钮的active类
            filterGroup.querySelectorAll('.filter-btn').forEach(el => {
                el.classList.remove('active');
            });
            
            // 添加当前按钮的active类
            this.classList.add('active');
            
            // 筛选产品卡片
            filterProducts();
        });
    });

    /**
     * 根据当前选中的筛选条件过滤产品卡片
     */
    function filterProducts() {
        // 获取所有激活的筛选条件
        const activeRegion = document.querySelector('.filter-group:nth-child(1) .filter-btn.active').textContent.trim();
        const activeCPU = document.querySelector('.filter-group:nth-child(2) .filter-btn.active').textContent.trim();
        const activePrice = document.querySelector('.filter-group:nth-child(3) .filter-btn.active').textContent.trim();
        
        // 遍历所有产品卡片
        productCards.forEach(card => {
            // 获取产品属性
            const cardLocation = card.querySelector('.product-location span').textContent.trim();
            const cardCPU = card.querySelector('.spec-item:nth-child(1) .spec-value').textContent.trim();
            const cardPrice = parseInt(card.querySelector('.price-value').textContent.replace(/[^\d]/g, ''));
            
            // 判断是否符合区域筛选条件
            let regionMatch = activeRegion === '全部';
            if (activeRegion === '亚太地区') {
                regionMatch = ['香港', '日本', '新加坡', '韩国'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '欧洲') {
                regionMatch = ['德国', '法国', '英国', '荷兰'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '北美') {
                regionMatch = ['美国', '加拿大'].some(region => cardLocation.includes(region));
            }
            
            // 判断是否符合CPU筛选条件
            let cpuMatch = activeCPU === '全部';
            if (activeCPU === 'Intel') {
                cpuMatch = cardCPU.includes('Intel');
            } else if (activeCPU === 'AMD') {
                cpuMatch = cardCPU.includes('AMD');
            }
            
            // 判断是否符合价格筛选条件
            let priceMatch = activePrice === '全部';
            if (activePrice === '500元以下') {
                priceMatch = cardPrice < 500;
            } else if (activePrice === '500-1000元') {
                priceMatch = cardPrice >= 500 && cardPrice <= 1000;
            } else if (activePrice === '1000-2000元') {
                priceMatch = cardPrice > 1000 && cardPrice <= 2000;
            } else if (activePrice === '2000元以上') {
                priceMatch = cardPrice > 2000;
            }
            
            // 显示或隐藏产品卡片
            if (regionMatch && cpuMatch && priceMatch) {
                card.style.display = 'flex';
            } else {
                card.style.display = 'none';
            }
        });
    }
}

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        const answer = item.querySelector('.faq-answer');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('open');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('open');
                i.querySelector('.faq-answer').style.maxHeight = '0';
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('open');
                answer.style.maxHeight = answer.scrollHeight + 'px';
            }
        });
    });
}

/**
 * 初始化评价轮播
 */
function initReviewsSlider() {
    // 检查是否存在移动端设备
    const isMobile = window.innerWidth < 768;
    
    // 仅在移动端激活真正的轮播效果
    if (isMobile) {
        const reviewsContainer = document.querySelector('.reviews-slider');
        const reviewCards = document.querySelectorAll('.review-card');
        
        // 如果有多个评价
        if (reviewCards.length > 1) {
            let currentReview = 0;
            
            // 创建指示器
            const indicators = document.createElement('div');
            indicators.className = 'review-indicators';
            
            reviewCards.forEach((_, index) => {
                const dot = document.createElement('span');
                dot.className = 'review-dot';
                if (index === 0) dot.classList.add('active');
                
                dot.addEventListener('click', () => {
                    showReview(index);
                });
                
                indicators.appendChild(dot);
            });
            
            // 将指示器添加到容器后面
            reviewsContainer.parentNode.insertBefore(indicators, reviewsContainer.nextSibling);
            
            // 显示特定评价
            function showReview(index) {
                // 隐藏所有评价
                reviewCards.forEach(card => {
                    card.style.display = 'none';
                });
                
                // 显示当前评价
                reviewCards[index].style.display = 'block';
                
                // 更新指示器
                document.querySelectorAll('.review-dot').forEach((dot, i) => {
                    dot.classList.toggle('active', i === index);
                });
                
                currentReview = index;
            }
            
            // 自动轮播
            setInterval(() => {
                currentReview = (currentReview + 1) % reviewCards.length;
                showReview(currentReview);
            }, 5000);
            
            // 初始显示第一个评价
            showReview(0);
        }
    }
} 