/**
 * 景天云网站通用 JavaScript 文件
 */

// 页面加载完成后执行
document.addEventListener('DOMContentLoaded', function() {
  // 添加页面过渡效果
  document.body.classList.add('page-transition');
  
  // 根据当前页面路径执行不同的初始化函数
  const currentPath = window.location.pathname;
  
  // 初始化所有页面通用的功能
  initCommonFeatures();
  
  // 根据页面路径初始化特定页面的功能
  if (currentPath.includes('index.php') || currentPath.endsWith('/') || currentPath.endsWith('/')) {
    initHomePage();
  } else if (currentPath.includes('product.html')) {
    initProductListPage();
  } else if (currentPath.includes('product_detail.html')) {
    initProductDetailPage();
  } else if (currentPath.includes('news.php')) {
    initNewsListPage();
  } else if (currentPath.includes('news_detail.html')) {
    initNewsDetailPage();
  }
  
  // 轮播广告功能
  initBannerSlider();
  
  // 特色区域动画
  const featureBoxes = document.querySelectorAll('.feature-box');
  featureBoxes.forEach((box, index) => {
    box.style.animation = 'fadeIn 0.5s ease-out forwards ' + (index * 0.2) + 's';
    box.style.opacity = '0';
  });
  
  // 标签页切换功能
  const tabs = document.querySelectorAll('.server-tab');
  tabs.forEach(tab => {
    tab.addEventListener('click', function(e) {
      e.preventDefault();
      // 移除所有active类
      tabs.forEach(t => t.classList.remove('active'));
      // 为当前标签添加active类
      this.classList.add('active');
    });
  });
  
  // 移除加载动画
  setTimeout(function() {
    const loader = document.querySelector('.loading-corner');
    if (loader) {
      loader.style.opacity = '0';
      setTimeout(function() {
        loader.style.display = 'none';
      }, 500);
    }
  }, 800);

  // FAQ交互效果
  const faqItems = document.querySelectorAll('.faq-item');
  
  faqItems.forEach(item => {
    const question = item.querySelector('.faq-question');
    
    if (question) {
      question.addEventListener('click', () => {
        // 关闭其他所有已打开的FAQ项
        faqItems.forEach(otherItem => {
          if (otherItem !== item && otherItem.classList.contains('open')) {
            otherItem.classList.remove('open');
          }
        });
        
        // 切换当前项的状态
        item.classList.toggle('open');
      });
    }
  });

  // 表单提交处理
  const contactForms = document.querySelectorAll('.contact-form form');
  
  contactForms.forEach(form => {
    form.addEventListener('submit', function(e) {
      e.preventDefault();
      
      // 获取表单数据
      const formData = new FormData(form);
      const formValues = {};
      
      for (let [key, value] of formData.entries()) {
        formValues[key] = value;
      }
      
      // 验证表单
      let isValid = true;
      const requiredFields = form.querySelectorAll('[required]');
      
      requiredFields.forEach(field => {
        if (!field.value.trim()) {
          isValid = false;
          field.classList.add('error');
        } else {
          field.classList.remove('error');
        }
      });
      
      if (!isValid) {
        showMessage('请填写所有必填字段', 'error');
        return;
      }
      
      // 模拟表单提交
      const submitButton = form.querySelector('.submit-button');
      if (submitButton) {
        const originalText = submitButton.textContent;
        submitButton.textContent = '提交中...';
        submitButton.disabled = true;
        
        // 模拟AJAX请求
        setTimeout(() => {
          showMessage('您的咨询已提交，我们将尽快与您联系！', 'success');
          form.reset();
          submitButton.textContent = originalText;
          submitButton.disabled = false;
        }, 1500);
      }
    });
  });
  
  // 消息提示功能
  function showMessage(text, type = 'info') {
    // 检查是否已有消息元素
    let messageEl = document.querySelector('.message-notification');
    
    if (!messageEl) {
      messageEl = document.createElement('div');
      messageEl.className = 'message-notification';
      document.body.appendChild(messageEl);
    }
    
    // 设置消息类型和内容
    messageEl.textContent = text;
    messageEl.className = `message-notification ${type}`;
    messageEl.style.display = 'block';
    
    // 自动隐藏消息
    setTimeout(() => {
      messageEl.style.opacity = '0';
      setTimeout(() => {
        messageEl.style.display = 'none';
        messageEl.style.opacity = '1';
      }, 500);
    }, 3000);
  }
  
  // 添加消息样式
  if (!document.querySelector('#message-styles')) {
    const styles = document.createElement('style');
    styles.id = 'message-styles';
    styles.textContent = `
      .message-notification {
        position: fixed;
        top: 20px;
        right: 20px;
        padding: 15px 25px;
        background-color: #f8f9fa;
        border-left: 4px solid #6c757d;
        box-shadow: 0 4px 15px rgba(0,0,0,0.1);
        z-index: 9999;
        border-radius: 4px;
        opacity: 1;
        transition: opacity 0.3s ease;
      }
      .message-notification.success {
        background-color: #e8f5e9;
        border-left-color: #4caf50;
        color: #2e7d32;
      }
      .message-notification.error {
        background-color: #fdf2f2;
        border-left-color: #f44336;
        color: #d32f2f;
      }
      .message-notification.info {
        background-color: #e3f2fd;
        border-left-color: #2196f3;
        color: #1976d2;
      }
      .contact-form .error {
        border-color: #f44336 !important;
        box-shadow: 0 0 0 3px rgba(244, 67, 54, 0.1) !important;
      }
    `;
    document.head.appendChild(styles);
  }

  // 创建返回顶部按钮
  initBackToTopButton();

  // 初始化移动端菜单增强
  initMobileMenuEnhancement();

  // 服务器类型选项卡切换功能
  const planTabs = document.querySelectorAll('.plan-tab');
  
  if (planTabs.length > 0) {
    planTabs.forEach(tab => {
      tab.addEventListener('click', function() {
        // 移除所有选项卡的active类
        planTabs.forEach(t => t.classList.remove('active'));
        
        // 为当前点击的选项卡添加active类
        this.classList.add('active');
        
        // 获取当前选项卡对应的内容ID
        const planType = this.getAttribute('data-plan');
        
        // 隐藏所有内容
        document.querySelectorAll('.plans-content').forEach(content => {
          content.classList.remove('active');
        });
        
        // 显示当前选项卡对应的内容
        document.getElementById(planType + '-plans').classList.add('active');
      });
    });
  }
});

/**
 * 初始化所有页面通用的功能
 */
function initCommonFeatures() {
  // 添加平滑滚动
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const targetId = this.getAttribute('href');
      if (targetId === '#') return;
      
      const targetElement = document.querySelector(targetId);
      if (targetElement) {
        window.scrollTo({
          top: targetElement.offsetTop - 100,
          behavior: 'smooth'
        });
      }
    });
  });
  
  // 替换全屏加载动画为更小的角落提示
  const loadingDiv = document.createElement('div');
  loadingDiv.className = 'loading-corner';
  loadingDiv.innerHTML = '<div class="loading-spinner-small"></div><span>加载中...</span>';
  document.body.appendChild(loadingDiv);
  
  // 导航菜单动画
  const navItems = document.querySelectorAll('.nav-item');
  navItems.forEach((item, index) => {
    item.style.animation = `fadeIn 0.3s ease-out forwards ${index * 0.1}s`;
    item.style.opacity = '0';
  });
  
  // 监听滚动事件，添加元素进入视图时的动画
  const animateOnScroll = function() {
    const elements = document.querySelectorAll('.feature-box, .news-item, .detail-section');
    
    elements.forEach(element => {
      const elementPosition = element.getBoundingClientRect().top;
      const windowHeight = window.innerHeight;
      
      if (elementPosition < windowHeight - 100) {
        element.classList.add('animated');
      }
    });
  };
  
  window.addEventListener('scroll', animateOnScroll);
  // 初始调用一次，处理页面加载时已在视图中的元素
  setTimeout(animateOnScroll, 500);
  
  // 为所有页面的 banner 添加动画
  const banners = document.querySelectorAll('.banner');
  banners.forEach(banner => {
    banner.style.animation = 'fadeIn 1s ease-out forwards';
    banner.style.opacity = '0';
  });
  
  // 添加横幅按钮悬停效果
  const bannerBtn = document.querySelector('.banner .btn');
  if (bannerBtn) {
    bannerBtn.addEventListener('mouseover', function() {
      this.style.animation = 'pulse 0.5s ease-in-out';
    });
    
    bannerBtn.addEventListener('animationend', function() {
      this.style.animation = '';
    });
  }
}

/**
 * 初始化首页特定功能
 */
function initHomePage() {
  // 导航箭头功能
  const prevButton = document.querySelector('.server-nav.prev');
  const nextButton = document.querySelector('.server-nav.next');
  const dots = document.querySelectorAll('.server-dot');
  let currentDot = 2; // 当前第3个点被激活
  
  if (prevButton && nextButton && dots.length > 0) {
    prevButton.addEventListener('click', function() {
      if (currentDot > 0) {
        dots[currentDot].classList.remove('active');
        currentDot--;
        dots[currentDot].classList.add('active');
      }
    });
    
    nextButton.addEventListener('click', function() {
      if (currentDot < dots.length - 1) {
        dots[currentDot].classList.remove('active');
        currentDot++;
        dots[currentDot].classList.add('active');
      }
    });
    
    // 点击分页点
    dots.forEach((dot, index) => {
      dot.addEventListener('click', function() {
        dots[currentDot].classList.remove('active');
        currentDot = index;
        dots[currentDot].classList.add('active');
      });
    });
  }
}

/**
 * 初始化轮播广告功能
 */
function initBannerSlider() {
  // 获取所有幻灯片
  const slides = document.querySelectorAll('.banner-slide');
  
  // 如果没有轮播元素，则退出
  if (!slides.length) {
    console.log('没有找到轮播元素');
    return;
  }
  
  console.log('找到轮播元素:', slides.length, '张幻灯片');
  
  let currentSlide = 0;
  let slideTimer = null;
  const slideInterval = 5000; // 5秒切换一次
  
  // 初始化指示器
  const indicators = document.querySelectorAll('.indicator');
  
  // 显示指定幻灯片
  function showSlide(index) {
    console.log('显示幻灯片', index);
    
    // 隐藏所有幻灯片
    slides.forEach(slide => {
      slide.classList.remove('active');
    });
    
    // 显示当前幻灯片
    slides[index].classList.add('active');
    
    // 更新指示器
    if (indicators.length > 0) {
      indicators.forEach((indicator, i) => {
        if (i === index) {
          indicator.classList.add('active');
        } else {
          indicator.classList.remove('active');
        }
      });
    }
    
    // 更新促销框状态
    const promoBoxes = document.querySelectorAll('.promo-box');
    if (promoBoxes.length > 0) {
      promoBoxes.forEach((box, i) => {
        if (i === index) {
          box.classList.add('active');
        } else {
          box.classList.remove('active');
        }
      });
    }
    
    currentSlide = index;
  }
  
  // 自动轮播
  function nextSlide() {
    console.log('切换到下一张幻灯片');
    let next = currentSlide + 1;
    if (next >= slides.length) {
      next = 0;
    }
    showSlide(next);
  }
  
  // 启动轮播
  function startSlideshow() {
    if (slideTimer) {
      clearInterval(slideTimer);
    }
    slideTimer = setInterval(nextSlide, slideInterval);
    console.log('轮播已启动');
  }
  
  // 鼠标悬停在轮播区域时暂停自动轮播
  const bannerSlider = document.querySelector('.banner-slider');
  if (bannerSlider) {
    bannerSlider.addEventListener('mouseenter', function() {
      console.log('鼠标进入轮播区域，暂停轮播');
      if (slideTimer) {
        clearInterval(slideTimer);
        slideTimer = null;
      }
    });
    
    bannerSlider.addEventListener('mouseleave', function() {
      console.log('鼠标离开轮播区域，继续轮播');
      startSlideshow();
    });
  }
  
  // 初始化幻灯片状态
  slides.forEach((slide, index) => {
    if (index !== 0) {
      slide.classList.remove('active');
    } else {
      slide.classList.add('active');
    }
  });
  
  // 添加导航按钮事件
  const prevBtn = document.querySelector('.banner-nav.prev');
  const nextBtn = document.querySelector('.banner-nav.next');

  if (prevBtn && nextBtn) {
    prevBtn.addEventListener('click', () => {
      let prev = currentSlide - 1;
      if (prev < 0) {
        prev = slides.length - 1;
      }
      showSlide(prev);
      if (slideTimer) {
        clearInterval(slideTimer);
      }
      startSlideshow();
    });
    
    nextBtn.addEventListener('click', () => {
      let next = currentSlide + 1;
      if (next >= slides.length) {
        next = 0;
      }
      showSlide(next);
      if (slideTimer) {
        clearInterval(slideTimer);
      }
      startSlideshow();
    });
  }
  
  // 添加促销框点击事件
  const promoBoxes = document.querySelectorAll('.promo-box');
  if (promoBoxes.length > 0) {
    promoBoxes.forEach((box, index) => {
      box.addEventListener('click', () => {
        showSlide(index);
        if (slideTimer) {
          clearInterval(slideTimer);
        }
        startSlideshow();
      });
    });
  }
  
  // 启动轮播
  startSlideshow();
  
  // 确保页面离开时清除定时器
  window.addEventListener('beforeunload', function() {
    if (slideTimer) {
      clearInterval(slideTimer);
    }
  });
}

/**
 * 初始化返回顶部按钮
 */
function initBackToTopButton() {
  // 此功能已被禁用 - 不再需要返回顶部按钮
  /*
  const backToTopButton = document.createElement('div');
  backToTopButton.className = 'back-to-top';
  backToTopButton.innerHTML = '<i class="fas fa-arrow-up"></i>';
  document.body.appendChild(backToTopButton);

  // 监听滚动事件
  window.addEventListener('scroll', function() {
    if (window.pageYOffset > 300) {
      backToTopButton.classList.add('visible');
    } else {
      backToTopButton.classList.remove('visible');
    }
  });

  // 点击返回顶部
  backToTopButton.addEventListener('click', function() {
    window.scrollTo({
      top: 0,
      behavior: 'smooth'
    });
  });
  */
}

/**
 * 初始化移动端菜单增强
 */
function initMobileMenuEnhancement() {
  // 获取菜单相关元素
  const mobileMenuToggle = document.querySelector('.mobile-menu-toggle');
  const nav = document.querySelector('.nav');
  const navItems = document.querySelectorAll('.nav-item');

  if (!mobileMenuToggle || !nav) return;

  // 为移动菜单切换按钮添加事件
  mobileMenuToggle.addEventListener('click', function() {
    this.classList.toggle('active');
    nav.classList.toggle('active');
    document.body.classList.toggle('menu-open');
  });

  // 为每个导航项添加点击事件，以展开/折叠子菜单
  navItems.forEach(item => {
    // 查找子菜单
    const dropdown = item.querySelector('.dropdown') || item.querySelector('.mega-dropdown');
    if (!dropdown) return;

    // 为拥有子菜单的项添加展开/折叠功能
    const link = item.querySelector('.nav-link');
    
    if (window.innerWidth <= 992 && link) { // 仅在移动视图下启用
      link.addEventListener('click', function(e) {
        // 检查是否点击了链接本身，而不是展开指示器
        if (e.target === this || e.target.parentNode === this) {
          e.preventDefault();
          
          // 关闭其他打开的项
          navItems.forEach(otherItem => {
            if (otherItem !== item && otherItem.classList.contains('open')) {
              otherItem.classList.remove('open');
              const otherDropdown = otherItem.querySelector('.dropdown') || otherItem.querySelector('.mega-dropdown');
              if (otherDropdown) {
                otherDropdown.style.display = 'none';
              }
            }
          });
          
          // 切换当前项
          item.classList.toggle('open');
          
          if (item.classList.contains('open')) {
            dropdown.style.display = 'block';
          } else {
            dropdown.style.display = 'none';
          }
        }
      });
    }
  });

  // 点击页面其他区域关闭菜单
  document.addEventListener('click', function(e) {
    if (nav.classList.contains('active') && 
        !e.target.closest('.nav') && 
        !e.target.closest('.mobile-menu-toggle')) {
      mobileMenuToggle.classList.remove('active');
      nav.classList.remove('active');
      document.body.classList.remove('menu-open');
    }
  });

  // 添加菜单状态样式
  const menuStyles = document.createElement('style');
  menuStyles.textContent = `
    body.menu-open {
      overflow: hidden;
    }
    
    @media (max-width: 992px) {
      .nav-item .dropdown,
      .nav-item .mega-dropdown {
        display: none;
      }
      
      .nav-item.open .dropdown,
      .nav-item.open .mega-dropdown {
        display: block;
      }
    }
  `;
  document.head.appendChild(menuStyles);

  // 处理窗口大小变化
  window.addEventListener('resize', function() {
    if (window.innerWidth > 992) {
      // 恢复桌面状态
      mobileMenuToggle.classList.remove('active');
      nav.classList.remove('active');
      document.body.classList.remove('menu-open');
      
      // 恢复下拉菜单显示样式
      navItems.forEach(item => {
        item.classList.remove('open');
        const dropdown = item.querySelector('.dropdown') || item.querySelector('.mega-dropdown');
        if (dropdown) {
          dropdown.style.display = '';
        }
      });
    }
  });

  // 添加触摸滑动手势支持
  let touchStartX = 0;
  let touchEndX = 0;
  
  document.addEventListener('touchstart', e => {
    touchStartX = e.changedTouches[0].screenX;
  }, false);
  
  document.addEventListener('touchend', e => {
    touchEndX = e.changedTouches[0].screenX;
    handleSwipe();
  }, false);
  
  function handleSwipe() {
    if (nav.classList.contains('active') && touchEndX - touchStartX > 100) {
      // 向右滑动关闭菜单
      mobileMenuToggle.classList.remove('active');
      nav.classList.remove('active');
      document.body.classList.remove('menu-open');
    }
  }
}