/**
 * 移动端菜单简洁脚本
 */
// JavaScript Document
(function() {
  // 在DOM加载完成后执行
  document.addEventListener('DOMContentLoaded', function() {
    // 获取菜单按钮和侧边栏元素
    const menuToggle = document.querySelector('.mobile-menu-toggle');
    const mobileSide = document.querySelector('.mobileSide');
    const menuItems = document.querySelectorAll('.mobileSide > div > li');
    const menuTitles = document.querySelectorAll('.mobileSide > div > li > div');
    const menuArrows = document.querySelectorAll('.mobileSide .menu-arrow');
    
    if (!menuToggle || !mobileSide) {
      console.error('菜单元素未找到');
      return;
    }

    // 切换菜单显示/隐藏
    menuToggle.addEventListener('click', function(e) {
      e.preventDefault();
      e.stopPropagation();
      
      this.classList.toggle('active');
      mobileSide.classList.toggle('active');
      
      // 切换body的class，防止菜单打开时页面滚动
      if (mobileSide.classList.contains('active')) {
        document.body.classList.add('menu-open');
      } else {
        document.body.classList.remove('menu-open');
      }
    });

    // 点击页面其他区域关闭菜单
    document.addEventListener('click', function(e) {
      if (mobileSide.classList.contains('active') && 
          !mobileSide.contains(e.target) && 
          !menuToggle.contains(e.target)) {
        mobileSide.classList.remove('active');
        menuToggle.classList.remove('active');
        document.body.classList.remove('menu-open');
      }
    });

    // 添加滑动关闭功能
    let touchStartX = 0;
    mobileSide.addEventListener('touchstart', function(e) {
      touchStartX = e.touches[0].clientX;
    }, { passive: true });

    mobileSide.addEventListener('touchmove', function(e) {
      if (!mobileSide.classList.contains('active')) return;
      
      const touchX = e.touches[0].clientX;
      const diff = touchStartX - touchX;
      
      // 向左滑动超过50px时关闭菜单
      if (diff > 50) {
        mobileSide.classList.remove('active');
        menuToggle.classList.remove('active');
        document.body.classList.remove('menu-open');
      }
    }, { passive: true });

    // 点击菜单标题展开/收起子菜单
    menuTitles.forEach(title => {
      // 找到父级li和箭头
      const parentLi = title.parentElement;
      const arrow = title.querySelector('.menu-arrow i');
      
      title.addEventListener('click', function(e) {
        // 阻止事件冒泡
        e.stopPropagation();
        
        // 关闭其他打开的子菜单
        menuItems.forEach(item => {
          if (item !== parentLi && item.classList.contains('active')) {
            item.classList.remove('active');
            // 重置其他菜单项的箭头
            const otherArrow = item.querySelector('.menu-arrow i');
            if (otherArrow) {
              otherArrow.classList.remove('fa-chevron-up');
              otherArrow.classList.add('fa-chevron-down');
            }
          }
        });
        
        // 切换当前子菜单显示状态
        parentLi.classList.toggle('active');
        
        // 更新箭头方向
        if (arrow) {
          if (parentLi.classList.contains('active')) {
            arrow.classList.remove('fa-chevron-down');
            arrow.classList.add('fa-chevron-up');
          } else {
            arrow.classList.remove('fa-chevron-up');
            arrow.classList.add('fa-chevron-down');
          }
        }
      });
    });

    // 点击子菜单链接时阻止事件冒泡
    const subMenuLinks = document.querySelectorAll('.mobileSide > div > li > ul > li > a');
    subMenuLinks.forEach(link => {
      link.addEventListener('click', function(e) {
        e.stopPropagation();
      });
    });

    // 点击子菜单项时阻止事件冒泡
    const subMenuItems = document.querySelectorAll('.mobileSide > div > li > ul > li');
    subMenuItems.forEach(item => {
      item.addEventListener('click', function(e) {
        e.stopPropagation();
      });
    });

    // 页面加载时初始化菜单状态
    mobileSide.classList.remove('active');
    menuToggle.classList.remove('active');
    document.body.classList.remove('menu-open');
    
    // 确保所有箭头初始化为向下图标
    menuArrows.forEach(arrow => {
      const iconElement = arrow.querySelector('i');
      if (iconElement) {
        iconElement.classList.remove('fa-chevron-up');
        iconElement.classList.add('fa-chevron-down');
      }
    });
    
    // 复位所有子菜单状态
    menuItems.forEach(item => {
      item.classList.remove('active');
    });
    
    // 桌面端导航菜单箭头处理
    const navItems = document.querySelectorAll('.nav-item');
    navItems.forEach(item => {
      const arrow = item.querySelector('.menu-arrow i');
      if (!arrow) return;
      
      item.addEventListener('mouseenter', function() {
        arrow.classList.remove('fa-chevron-down');
        arrow.classList.add('fa-chevron-up');
      });
      
      item.addEventListener('mouseleave', function() {
        arrow.classList.remove('fa-chevron-up');
        arrow.classList.add('fa-chevron-down');
      });
    });
    
    // 检查当前URL是否与菜单项匹配，如果匹配则高亮显示
    const currentUrl = window.location.pathname;
    const allLinks = document.querySelectorAll('.mobileSide a');
    
    allLinks.forEach(link => {
      const linkUrl = link.getAttribute('href');
      if (linkUrl && currentUrl.includes(linkUrl) && linkUrl !== '/') {
        // 找到父级li元素
        let parentLi = link.closest('li');
        if (parentLi) {
          // 如果是子菜单项，则也要展开父菜单
          const parentMenu = parentLi.closest('.mobileSide > div > li');
          if (parentMenu) {
            parentMenu.classList.add('active');
            const parentArrow = parentMenu.querySelector('.menu-arrow i');
            if (parentArrow) {
              parentArrow.classList.remove('fa-chevron-down');
              parentArrow.classList.add('fa-chevron-up');
            }
          }
          
          // 高亮当前菜单项
          parentLi.classList.add('active');
        }
      }
    });
  });
})(); 