/**
 * 多IP型服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化产品筛选功能
    initProductFilter();
    
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化解决方案卡片交互
    initSolutionCards();
});

/**
 * 初始化产品筛选功能
 */
function initProductFilter() {
    const filterBtns = document.querySelectorAll('.filter-btn');
    const productCards = document.querySelectorAll('.product-card');
    
    // 为每个筛选按钮添加点击事件
    filterBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            // 获取筛选类型
            const filterGroup = this.parentElement.parentElement;
            const filterValue = this.textContent.trim();
            
            // 移除同组其他按钮的active类
            filterGroup.querySelectorAll('.filter-btn').forEach(el => {
                el.classList.remove('active');
            });
            
            // 添加当前按钮的active类
            this.classList.add('active');
            
            // 筛选产品卡片
            filterProducts();
        });
    });

    /**
     * 根据当前选中的筛选条件过滤产品卡片
     */
    function filterProducts() {
        // 获取所有激活的筛选条件
        const activeIpCount = document.querySelector('.filter-group:nth-child(1) .filter-btn.active').textContent.trim();
        const activeRegion = document.querySelector('.filter-group:nth-child(2) .filter-btn.active').textContent.trim();
        const activePrice = document.querySelector('.filter-group:nth-child(3) .filter-btn.active').textContent.trim();
        
        // 遍历所有产品卡片
        productCards.forEach(card => {
            // 获取产品属性
            const cardLocation = card.querySelector('.product-location span').textContent.trim();
            const cardPrice = parseInt(card.querySelector('.price-value').textContent.replace(/[^\d]/g, ''));
            const cardIpCount = card.querySelector('.highlight .spec-value').textContent.trim();
            const ipCount = parseInt(cardIpCount);
            
            // 判断是否符合IP数量筛选条件
            let ipCountMatch = activeIpCount === '全部';
            if (activeIpCount === '10-50个') {
                ipCountMatch = ipCount >= 10 && ipCount <= 50;
            } else if (activeIpCount === '50-100个') {
                ipCountMatch = ipCount > 50 && ipCount <= 100;
            } else if (activeIpCount === '100-200个') {
                ipCountMatch = ipCount > 100 && ipCount <= 200;
            } else if (activeIpCount === '200个以上') {
                ipCountMatch = ipCount > 200;
            }
            
            // 判断是否符合区域筛选条件
            let regionMatch = activeRegion === '全部';
            if (activeRegion === '亚太地区') {
                regionMatch = ['香港', '日本', '新加坡', '韩国'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '欧洲') {
                regionMatch = ['德国', '法国', '英国', '荷兰', '阿姆斯特丹'].some(region => cardLocation.includes(region));
            } else if (activeRegion === '北美') {
                regionMatch = ['美国', '加拿大', '洛杉矶', '温哥华'].some(region => cardLocation.includes(region));
            }
            
            // 判断是否符合价格筛选条件
            let priceMatch = activePrice === '全部';
            if (activePrice === '2000元以下') {
                priceMatch = cardPrice < 2000;
            } else if (activePrice === '2000-4000元') {
                priceMatch = cardPrice >= 2000 && cardPrice <= 4000;
            } else if (activePrice === '4000-6000元') {
                priceMatch = cardPrice > 4000 && cardPrice <= 6000;
            } else if (activePrice === '6000元以上') {
                priceMatch = cardPrice > 6000;
            }
            
            // 显示或隐藏产品卡片
            if (ipCountMatch && regionMatch && priceMatch) {
                card.style.display = 'flex';
            } else {
                card.style.display = 'none';
            }
        });
    }
}

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('open');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('open');
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('open');
            }
        });
    });
}

/**
 * 初始化解决方案卡片交互效果
 */
function initSolutionCards() {
    const solutionCards = document.querySelectorAll('.solution-card');
    
    solutionCards.forEach(card => {
        // 添加鼠标悬停效果
        card.addEventListener('mouseenter', function() {
            // 增强卡片悬停效果
            this.style.transform = 'translateY(-8px)';
            this.style.boxShadow = '0 12px 25px rgba(0, 0, 0, 0.2)';
            
            // 改变图标颜色
            const icon = this.querySelector('.solution-icon i');
            if (icon) {
                icon.style.transform = 'scale(1.1)';
                icon.style.transition = 'transform 0.3s ease';
            }
        });
        
        card.addEventListener('mouseleave', function() {
            // 恢复默认状态
            this.style.transform = '';
            this.style.boxShadow = '';
            
            // 恢复图标颜色
            const icon = this.querySelector('.solution-icon i');
            if (icon) {
                icon.style.transform = '';
            }
        });
    });
} 