/**
 * 产品详情页面JavaScript功能
 * 包含选项卡切换、Banner轮播和FAQ手风琴效果
 */
document.addEventListener('DOMContentLoaded', function() {
    // 初始化各功能模块
    initBannerCarousel();
    initTabSwitching();
    initFaqAccordion();
});

/**
 * 初始化Banner轮播功能
 */
function initBannerCarousel() {
    const slides = document.querySelectorAll('.banner-slide');
    const indicators = document.querySelectorAll('.indicator');
    const prevBtn = document.querySelector('.banner-nav.prev');
    const nextBtn = document.querySelector('.banner-nav.next');
    
    // 如果没有轮播元素，直接返回
    if (slides.length === 0) return;
    
    let currentSlide = 0;
    const slideCount = slides.length;
    let slideInterval;

    // 显示指定幻灯片的函数
    function showSlide(index) {
        // 隐藏所有幻灯片
        slides.forEach(slide => slide.classList.remove('active'));
        indicators.forEach(indicator => indicator.classList.remove('active'));
        
        // 显示指定幻灯片
        slides[index].classList.add('active');
        indicators[index].classList.add('active');
        currentSlide = index;
    }

    // 启动自动轮播
    function startAutoCarousel() {
        // 清除现有定时器
        if (slideInterval) {
            clearInterval(slideInterval);
        }
        
        // 设置新的定时器
        slideInterval = setInterval(() => {
            let nextSlide = (currentSlide + 1) % slideCount;
            showSlide(nextSlide);
        }, 5000);
    }

    // 初始启动自动轮播
    startAutoCarousel();

    // 点击指示器切换幻灯片
    indicators.forEach((indicator, index) => {
        indicator.addEventListener('click', () => {
            showSlide(index);
            startAutoCarousel();
        });
    });

    // 上一张/下一张按钮事件
    if (prevBtn && nextBtn) {
        prevBtn.addEventListener('click', () => {
            let prevSlide = (currentSlide - 1 + slideCount) % slideCount;
            showSlide(prevSlide);
            startAutoCarousel();
        });

        nextBtn.addEventListener('click', () => {
            let nextSlide = (currentSlide + 1) % slideCount;
            showSlide(nextSlide);
            startAutoCarousel();
        });
    }
}

/**
 * 初始化选项卡切换功能
 */
function initTabSwitching() {
    const tabs = document.querySelectorAll('.tabs-header .tab');
    const tabContents = document.querySelectorAll('.tab-content');
    
    // 如果没有选项卡元素，直接返回
    if (tabs.length === 0 || tabContents.length === 0) return;

    // 确保初始状态正确
    tabContents.forEach(content => {
        content.classList.remove('active');
    });
    
    // 默认显示第一个选项卡
    const defaultTabId = tabs[0].getAttribute('data-tab');
    const defaultTabContent = document.getElementById(defaultTabId);
    
    if (defaultTabContent) {
        defaultTabContent.classList.add('active');
    } else {
        // 如果找不到默认选项卡内容，尝试显示"tab-specs"
        const specTab = document.getElementById('tab-specs');
        if (specTab) {
            specTab.classList.add('active');
        }
    }

    // 为每个选项卡添加点击事件
    tabs.forEach(tab => {
        tab.addEventListener('click', function() {
            // 移除所有激活状态
            tabs.forEach(t => t.classList.remove('active'));
            tabContents.forEach(c => c.classList.remove('active'));
            
            // 添加当前激活状态
            this.classList.add('active');
            const tabId = this.getAttribute('data-tab');
            
            // 确保元素存在
            const tabContent = document.getElementById(tabId);
            if (tabContent) {
                tabContent.classList.add('active');
            } else {
                console.error('找不到ID为 ' + tabId + ' 的选项卡内容');
            }
        });
    });
}

/**
 * 初始化FAQ手风琴效果
 */
function initFaqAccordion() {
    const faqQuestions = document.querySelectorAll('.faq-question');
    
    // 如果没有FAQ元素，直接返回
    if (faqQuestions.length === 0) return;

    faqQuestions.forEach(question => {
        question.addEventListener('click', function() {
            const parent = this.parentElement;
            
            // 如果当前项已打开，则关闭它
            if (parent.classList.contains('open')) {
                parent.classList.remove('open');
            } else {
                // 可选：关闭其他打开的FAQ项
                // document.querySelectorAll('.faq-item.open').forEach(item => {
                //     item.classList.remove('open');
                // });
                
                // 打开当前项
                parent.classList.add('open');
            }
        });
    });
} 