/**
 * 站群服务器页面专用JavaScript
 */

// 文档就绪后执行
$(function() {
    // 初始化FAQ交互功能
    initFaqInteraction();
    
    // 初始化站群服务器区域卡片交互
    initClusterCards();
    
    // 初始化平滑滚动
    initSmoothScroll();
    
    // 初始化站群详情区域交互
    initClusterDetails();
});

/**
 * 初始化FAQ交互功能
 */
function initFaqInteraction() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        
        question.addEventListener('click', function() {
            // 检查当前项是否已激活
            const isActive = item.classList.contains('open');
            
            // 关闭所有FAQ项
            faqItems.forEach(i => {
                i.classList.remove('open');
            });
            
            // 如果点击的项未激活，则激活它
            if (!isActive) {
                item.classList.add('open');
            }
        });
    });
}

/**
 * 初始化站群区域卡片交互效果
 */
function initClusterCards() {
    const clusterCards = document.querySelectorAll('.cluster-card');
    
    clusterCards.forEach(card => {
        // 添加鼠标悬停效果
        card.addEventListener('mouseenter', function() {
            // 增强卡片悬停效果
            this.style.transform = 'translateY(-8px)';
            this.style.boxShadow = '0 12px 25px rgba(0, 0, 0, 0.2)';
            
            // 改变SVG图标效果
            const icon = this.querySelector('.svg-icon');
            if (icon) {
                icon.style.transform = 'scale(1.2)';
                icon.style.transition = 'transform 0.3s ease';
            }
            
            // 改变按钮样式
            const btn = this.querySelector('.btn-outline');
            if (btn) {
                btn.style.backgroundColor = 'rgba(255, 102, 0, 0.1)';
            }
        });
        
        card.addEventListener('mouseleave', function() {
            // 恢复默认状态
            this.style.transform = '';
            this.style.boxShadow = '';
            
            // 恢复SVG图标效果
            const icon = this.querySelector('.svg-icon');
            if (icon) {
                icon.style.transform = '';
            }
            
            // 恢复按钮样式
            const btn = this.querySelector('.btn-outline');
            if (btn) {
                btn.style.backgroundColor = '';
            }
        });
    });
    
    // 增强特性项交互
    const featureItems = document.querySelectorAll('.feature-item');
    featureItems.forEach(item => {
        item.addEventListener('mouseenter', function() {
            const icon = this.querySelector('.svg-icon');
            if (icon) {
                icon.style.transform = 'scale(1.2)';
                icon.style.transition = 'transform 0.3s ease';
            }
        });
        
        item.addEventListener('mouseleave', function() {
            const icon = this.querySelector('.svg-icon');
            if (icon) {
                icon.style.transform = '';
            }
        });
    });
}

/**
 * 初始化平滑滚动效果
 */
function initSmoothScroll() {
    const links = document.querySelectorAll('a[href^="#"]');
    
    links.forEach(link => {
        link.addEventListener('click', function(e) {
            const targetId = this.getAttribute('href').substring(1);
            const targetElement = document.getElementById(targetId);
            
            if (targetElement) {
                e.preventDefault();
                
                // 平滑滚动到目标元素
                window.scrollTo({
                    top: targetElement.offsetTop - 80, // 80px的偏移量，以避免被导航栏遮挡
                    behavior: 'smooth'
                });
                
                // 更新URL
                history.pushState(null, null, `#${targetId}`);
            }
        });
    });
    
    // 检查URL中是否有锚点，如果有则滚动到相应位置
    if (window.location.hash) {
        const targetId = window.location.hash.substring(1);
        const targetElement = document.getElementById(targetId);
        
        if (targetElement) {
            // 页面加载后稍微延迟滚动，确保所有内容都已加载
            setTimeout(() => {
                window.scrollTo({
                    top: targetElement.offsetTop - 80,
                    behavior: 'smooth'
                });
                
                // 激活相应的选项卡
                const tabItems = document.querySelectorAll('.tab-item');
                tabItems.forEach(tab => {
                    if (tab.getAttribute('data-target') === targetId) {
                        // 移除其他选项卡的激活状态
                        document.querySelectorAll('.tab-item.active').forEach(activeTab => {
                            activeTab.classList.remove('active');
                        });
                        
                        // 设置当前选项卡为激活状态
                        tab.classList.add('active');
                    }
                });
            }, 300);
        }
    }
}

/**
 * 初始化站群详情区域交互
 */
function initClusterDetails() {
    // 添加配置项目交互效果
    const configItems = document.querySelectorAll('.config-item');
    configItems.forEach(item => {
        item.addEventListener('mouseenter', function() {
            this.style.backgroundColor = '#f5f5f5';
            this.style.transition = 'background-color 0.3s ease';
            this.style.borderRadius = '4px';
            this.style.padding = '5px';
        });
        
        item.addEventListener('mouseleave', function() {
            this.style.backgroundColor = 'transparent';
            this.style.padding = '0';
        });
    });
    
    // 添加特性列表项目交互效果
    const featureListItems = document.querySelectorAll('.feature-list li');
    featureListItems.forEach(item => {
        item.addEventListener('mouseenter', function() {
            const icon = this.querySelector('.svg-icon');
            if (icon) {
                icon.style.transform = 'scale(1.2)';
                icon.style.transition = 'transform 0.3s ease';
                icon.style.fill = '#e55c00';
            }
            this.style.color = '#333';
        });
        
        item.addEventListener('mouseleave', function() {
            const icon = this.querySelector('.svg-icon');
            if (icon) {
                icon.style.transform = '';
                icon.style.fill = '#ff6600';
            }
            this.style.color = '';
        });
    });
}

// 站群服务器页面JS功能

document.addEventListener('DOMContentLoaded', function() {
  // 初始化产品卡片动画效果
  initCardAnimations();
  
  // 初始化选项卡切换
  initTabSwitching();
  
  // 初始化过滤器功能
  initFilterNavigation();
  
  // 添加平滑滚动效果
  initSmoothScroll();
  
  // 初始化图像悬停效果
  initImageHoverEffects();
});

// 产品卡片入场动画
function initCardAnimations() {
  const cards = document.querySelectorAll('.cluster-card, .plan-card');
  
  // 检查IntersectionObserver API是否可用
  if ('IntersectionObserver' in window) {
    const observer = new IntersectionObserver((entries) => {
      entries.forEach(entry => {
        if (entry.isIntersecting) {
          entry.target.classList.add('animated');
          observer.unobserve(entry.target);
        }
      });
    }, {
      threshold: 0.1
    });
    
    cards.forEach(card => {
      card.classList.add('fade-in');
      observer.observe(card);
    });
  } else {
    // 如果不支持IntersectionObserver，直接显示所有卡片
    cards.forEach(card => card.classList.add('animated'));
  }
  
  // 为每张卡片添加hover效果的延迟
  cards.forEach((card, index) => {
    card.style.transitionDelay = `${index * 50}ms`;
  });
}

// 选项卡切换功能
function initTabSwitching() {
  const tabItems = document.querySelectorAll('.tab-item');
  
  tabItems.forEach(tab => {
    tab.addEventListener('click', function() {
      // 获取当前活动的选项卡
      const currentActive = document.querySelector('.tab-item.active');
      if (currentActive) {
        currentActive.classList.remove('active');
      }
      
      // 将当前点击的选项卡设为活动状态
      this.classList.add('active');
      
      // 如果有链接，执行跳转
      const targetId = this.getAttribute('data-target');
      if (targetId) {
        const targetElement = document.getElementById(targetId);
        if (targetElement) {
          window.scrollTo({
            top: targetElement.offsetTop - 80,
            behavior: 'smooth'
          });
        }
      }
    });
  });
}

// 过滤器导航功能
function initFilterNavigation() {
  // 为每个区域分别设置过滤器
  const sections = document.querySelectorAll('.cluster-detail-section');
  
  sections.forEach(section => {
    const filterButtons = section.querySelectorAll('.filter-btn');
    const planCards = section.querySelectorAll('.plan-card');
    
    filterButtons.forEach(button => {
      button.addEventListener('click', function() {
        // 移除当前区域内其他按钮的活动状态
        filterButtons.forEach(btn => {
          btn.classList.remove('active');
        });
        
        // 设置当前按钮为活动状态
        this.classList.add('active');
        
        // 获取过滤器值
        const filterValue = this.getAttribute('data-filter');
        
        // 根据过滤器值显示或隐藏卡片
        planCards.forEach(card => {
          const cardCategory = card.getAttribute('data-category');
          
          if (filterValue === 'all' || cardCategory === filterValue) {
            card.style.display = 'flex';
            setTimeout(() => {
              card.style.opacity = '1';
              card.style.transform = card.classList.contains('featured') 
                ? 'scale(1.05)' 
                : 'translateY(0)';
            }, 10);
          } else {
            card.style.opacity = '0';
            card.style.transform = 'translateY(20px)';
            setTimeout(() => {
              card.style.display = 'none';
            }, 300);
          }
        });
      });
    });
  });
}

// 图像悬停效果
function initImageHoverEffects() {
  const images = document.querySelectorAll('.cluster-image img');
  
  images.forEach(img => {
    img.addEventListener('mouseenter', function() {
      this.style.transform = 'scale(1.03)';
    });
    
    img.addEventListener('mouseleave', function() {
      this.style.transform = 'scale(1)';
    });
  });
  
  // 添加视差效果
  window.addEventListener('mousemove', function(e) {
    const cards = document.querySelectorAll('.cluster-card');
    const mouseX = e.clientX / window.innerWidth;
    const mouseY = e.clientY / window.innerHeight;
    
    cards.forEach(card => {
      const rect = card.getBoundingClientRect();
      const cardCenterX = rect.left + rect.width / 2;
      const cardCenterY = rect.top + rect.height / 2;
      
      // 计算鼠标与卡片中心的距离
      const offsetX = (mouseX - cardCenterX / window.innerWidth) * 15;
      const offsetY = (mouseY - cardCenterY / window.innerHeight) * 15;
      
      // 应用微妙的视差效果
      card.style.transform = `translateY(-5px) rotateX(${offsetY}deg) rotateY(${offsetX}deg)`;
    });
  });
}

// 添加额外的CSS类到head
function addDynamicStyles() {
  const style = document.createElement('style');
  style.textContent = `
    .fade-in {
      opacity: 0;
      transform: translateY(30px);
      transition: opacity 0.6s ease, transform 0.6s ease;
    }
    
    .animated {
      opacity: 1;
      transform: translateY(0);
    }
    
    @keyframes pulse {
      0% { transform: scale(1); }
      50% { transform: scale(1.05); }
      100% { transform: scale(1); }
    }
    
    .pulse {
      animation: pulse 2s infinite;
    }
    
    .cluster-card:hover .cluster-icon {
      animation: pulse 1.5s infinite;
    }
  `;
  
  document.head.appendChild(style);
}

// 在页面加载后执行添加样式
window.addEventListener('load', addDynamicStyles); 