/**
 * 服务器专题页面的脚本功能
 */

// 每个楼层的标签切换
document.addEventListener('DOMContentLoaded', function() {
  document.querySelectorAll('.floor-section').forEach(floor => {
    const tabs = floor.querySelectorAll('.tab-item');
    const containers = floor.querySelectorAll('.product-container');
    
    tabs.forEach(tab => {
      tab.addEventListener('click', function() {
        // 移除当前楼层所有标签的active类
        floor.querySelectorAll('.tab-item').forEach(t => t.classList.remove('active'));
        this.classList.add('active');
        
        // 切换产品显示
        const targetId = this.dataset.target;
        floor.querySelectorAll('.product-container').forEach(container => {
          container.classList.remove('active');
        });
        floor.querySelector(`#${targetId}`).classList.add('active');
      });
    });
  });

  // 获取所有楼层
  const floors = document.querySelectorAll('.floor-section');

  // 为每个楼层设置服务器类型切换
  floors.forEach(floor => {
    const typeItems = floor.querySelectorAll('.server-type-item');
    const typeContents = floor.querySelectorAll('.server-type-content');
    
    typeItems.forEach(item => {
      item.addEventListener('click', function() {
        // 添加点击动画效果
        this.classList.add('clicked');
        setTimeout(() => {
          this.classList.remove('clicked');
        }, 300);
        
        // 移除当前楼层内所有active类
        typeItems.forEach(i => i.classList.remove('active'));
        typeContents.forEach(c => {
          c.classList.remove('active');
          c.style.display = 'none';
        });
        
        // 添加active类到当前点击的项目
        this.classList.add('active');
        const targetId = this.getAttribute('data-target');
        const targetContent = floor.querySelector('#' + targetId);
        
        // 使用淡入效果显示内容
        setTimeout(() => {
          targetContent.classList.add('active');
          targetContent.style.display = 'block';
        }, 50);
      });
    });
  });

  // 为楼层添加滚动动画
  const floorSections = document.querySelectorAll('.floor-section');
  
  function checkVisibility() {
    floorSections.forEach(section => {
      const rect = section.getBoundingClientRect();
      const isVisible = (
        rect.top < window.innerHeight - 100 && 
        rect.bottom >= 0
      );
      
      if (isVisible && !section.classList.contains('animated')) {
        section.classList.add('animated');
        section.style.opacity = '1';
        section.style.transform = 'translateY(0)';
      }
    });
  }
  
  // 初始设置
  floorSections.forEach(section => {
    section.style.opacity = '0';
    section.style.transform = 'translateY(20px)';
    section.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
  });
  
  // 检查可见性
  checkVisibility();
  window.addEventListener('scroll', checkVisibility);
  
  // 产品卡片悬停效果增强
  const productCards = document.querySelectorAll('.product-card');
  
  productCards.forEach(card => {
    card.addEventListener('mouseenter', function() {
      this.style.transform = 'translateY(-8px)';
      this.style.boxShadow = '0 8px 25px rgba(0, 0, 0, 0.15)';
    });
    
    card.addEventListener('mouseleave', function() {
      this.style.transform = '';
      this.style.boxShadow = '';
    });
  });
}); 