/**
 * 服务器标签页切换功能
 */
document.addEventListener('DOMContentLoaded', function() {
  // 获取所有标签按钮和内容面板
  const tabButtons = document.querySelectorAll('.tab-btn');
  const tabPanes = document.querySelectorAll('.tab-pane');
  
  // 如果没有找到标签元素，则退出
  if (!tabButtons.length || !tabPanes.length) {
    console.log('未找到标签页元素');
    return;
  }
  
  console.log('找到标签页元素:', tabButtons.length, '个按钮,', tabPanes.length, '个内容面板');
  
  // 为每个标签按钮添加点击事件
  tabButtons.forEach(button => {
    button.addEventListener('click', function() {
      console.log('点击标签按钮:', this.textContent.trim());
      
      // 移除所有标签按钮的活动状态
      tabButtons.forEach(btn => btn.classList.remove('active'));
      
      // 移除所有内容面板的活动状态
      tabPanes.forEach(pane => pane.classList.remove('active'));
      
      // 添加当前按钮的活动状态
      this.classList.add('active');
      
      // 获取目标内容面板的ID
      const targetId = this.getAttribute('data-target');
      console.log('目标面板ID:', targetId);
      
      // 显示目标内容面板
      const targetPane = document.getElementById(targetId);
      if (targetPane) {
        targetPane.classList.add('active');
        console.log('已显示目标面板');
      } else {
        console.log('未找到目标面板:', targetId);
      }
    });
  });
  
  // 初始化标签页状态 - 确保有一个标签处于活动状态
  let hasActiveTab = false;
  tabButtons.forEach(btn => {
    if (btn.classList.contains('active')) {
      hasActiveTab = true;
    }
  });
  
  // 如果没有活动标签，则激活第一个标签
  if (!hasActiveTab && tabButtons.length > 0) {
    tabButtons[0].classList.add('active');
    const targetId = tabButtons[0].getAttribute('data-target');
    const targetPane = document.getElementById(targetId);
    if (targetPane) {
      targetPane.classList.add('active');
    }
  }
});
