// 页面加载完成后执行
document.addEventListener('DOMContentLoaded', function() {
  // FAQ 交互初始化
  initFaqInteraction();
  
  // 产品卡片悬停效果
  initProductCardHover();
  
  // 平滑滚动
  initSmoothScroll();
});

// 初始化 FAQ 交互功能
function initFaqInteraction() {
  const faqItems = document.querySelectorAll('.faq-item');
  
  // 默认打开第一个FAQ
  if (faqItems.length > 0) {
    faqItems[0].classList.add('active');
  }
  
  // 为每个FAQ项添加点击事件
  faqItems.forEach(item => {
    const question = item.querySelector('.faq-question');
    
    question.addEventListener('click', () => {
      // 如果当前项已激活，则关闭它
      if (item.classList.contains('active')) {
        item.classList.remove('active');
      } else {
        // 关闭所有已激活的项
        faqItems.forEach(faq => {
          faq.classList.remove('active');
        });
        
        // 激活当前点击的项
        item.classList.add('active');
      }
    });
  });
}

// 初始化产品卡片悬停效果
function initProductCardHover() {
  const productCards = document.querySelectorAll('.product-card');
  
  productCards.forEach(card => {
    card.addEventListener('mouseenter', () => {
      card.querySelector('.btn-primary').style.transform = 'scale(1.05)';
    });
    
    card.addEventListener('mouseleave', () => {
      card.querySelector('.btn-primary').style.transform = 'scale(1)';
    });
  });
}

// 初始化平滑滚动
function initSmoothScroll() {
  // 获取所有锚点链接
  const anchorLinks = document.querySelectorAll('a[href^="#"]');
  
  anchorLinks.forEach(link => {
    link.addEventListener('click', function(e) {
      const targetId = this.getAttribute('href');
      
      // 如果是有效的锚点
      if (targetId !== '#') {
        e.preventDefault();
        
        const targetElement = document.querySelector(targetId);
        
        if (targetElement) {
          // 平滑滚动到目标元素
          window.scrollTo({
            top: targetElement.offsetTop - 100, // 偏移量，避免被导航栏遮挡
            behavior: 'smooth'
          });
        }
      }
    });
  });
}

// 监听滚动事件，实现滚动动画
window.addEventListener('scroll', function() {
  // 获取所有需要动画的元素
  const animElements = document.querySelectorAll('.feature-card, .product-card, .tech-card, .use-case-card');
  
  animElements.forEach(element => {
    // 检查元素是否在视口中
    const elementTop = element.getBoundingClientRect().top;
    const elementVisible = 150; // 元素可见的阈值
    
    if (elementTop < window.innerHeight - elementVisible) {
      element.classList.add('visible');
    }
  });
}); 