<?php


// 设置详细错误报告
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 记录访问和会话信息
$log_prefix = "[KF聊天组件] - " . date('Y-m-d H:i:s') . ": ";
error_log($log_prefix . "组件访问开始");

// 确保欢迎消息和Telegram链接变量存在（设置默认值）
if (!isset($GLOBALS['welcome'])) {
  $GLOBALS['welcome'] = '欢迎咨询我们的在线客服！';
}
if (!isset($GLOBALS['Telegram'])) {
  $GLOBALS['Telegram'] = 'https://t.me/Ammkiss';
}
$welcome = $GLOBALS['welcome'];
$Telegram = $GLOBALS['Telegram'];

// 获取数据库连接
$db_ok = false;
$messages = [];
$user_id = 0;

try {
  if (function_exists('getDbConnection')) {
    $db = getDbConnection();
    $db_ok = true;
    error_log($log_prefix . "数据库连接成功");
  }
} catch (Exception $e) {
  $db_ok = false;
  error_log($log_prefix . "数据库连接失败: " . $e->getMessage());
}

// 获取用户ID
$user_id = isset($_SESSION['user_id']) ? intval($_SESSION['user_id']) : 0;
error_log($log_prefix . "当前用户ID: " . $user_id);

// 用户是否已登录标志
$is_logged_in = ($user_id > 0);
error_log($log_prefix . "用户登录状态: " . ($is_logged_in ? '已登录' : '未登录'));

// 如果用户已登录并且数据库连接成功，尝试获取历史消息
if ($is_logged_in && $db_ok) {
  try {
    // 基于user_id获取聊天消息
    $sql = "SELECT * FROM chat_messages WHERE user_id = $user_id ORDER BY created_at ASC";
    error_log($log_prefix . "执行SQL: " . $sql);
    
    // 尝试直接查询而不是使用预处理语句
    $result = $db->query($sql);
    if ($result) {
      $messages = $result->fetchAll(PDO::FETCH_ASSOC);
      
      // 调试信息：记录消息数量
      error_log($log_prefix . "当前用户ID: " . $user_id . ", 加载消息数量: " . count($messages));
      
      // 直接执行更新语句，将管理员发送的未读消息标记为已读
      $update_sql = "UPDATE chat_messages SET is_read = 1 WHERE user_id = $user_id AND admin_id IS NOT NULL AND is_read = 0";
      error_log($log_prefix . "执行SQL: " . $update_sql);
      $db->exec($update_sql);
    } else {
      error_log($log_prefix . "查询消息失败: " . print_r($db->errorInfo(), true));
    }
  } catch (Exception $e) {
    error_log($log_prefix . "获取消息失败: " . $e->getMessage());
  }
}

// 处理消息发送请求 (通过AJAX方式)
if ($is_logged_in && $db_ok && isset($_POST['action']) && $_POST['action'] == 'send_message' && !empty($_POST['message'])) {
  $message = $_POST['message'];
  error_log($log_prefix . "收到消息发送请求: " . $message);
  
  try {
    // 执行SQL插入
    $safe_message = $db->quote($message);
    $insert_sql = "INSERT INTO chat_messages (user_id, admin_id, message, is_read, created_at) VALUES ($user_id, NULL, $safe_message, 1, NOW())";
    
    error_log($log_prefix . "插入SQL: " . $insert_sql);
    $result = $db->exec($insert_sql);
    
    if ($result !== false) {
      error_log($log_prefix . "发送成功：消息ID: " . $db->lastInsertId());
      
      // 客服自动回复
      $reply = "您好！我已收到您的消息，会尽快为您解答，请稍候片刻~";
      $safe_reply = $db->quote($reply);
      
      $reply_sql = "INSERT INTO chat_messages (user_id, admin_id, message, is_read, created_at) VALUES ($user_id, 1, $safe_reply, 0, NOW())";
      error_log($log_prefix . "执行SQL: " . $reply_sql);
      
      $db->exec($reply_sql);
      
      // 返回JSON响应
      header('Content-Type: application/json');
      echo json_encode(['success' => true, 'message' => '消息已发送']);
      exit;
    } else {
      error_log($log_prefix . "发送失败：" . print_r($db->errorInfo(), true));
      // 返回JSON响应
      header('Content-Type: application/json');
      echo json_encode(['success' => false, 'error' => '消息发送失败']);
      exit;
    }
  } catch (Exception $e) {
    error_log($log_prefix . "发送异常：" . $e->getMessage());
    // 返回JSON响应
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    exit;
  }
}

// 无论是否登录，都显示客服组件
?>

<!-- 用于调试的隐藏信息 -->
<!-- 登录状态: <?php echo $is_logged_in ? '已登录' : '未登录'; ?> | 用户ID: <?php echo $user_id; ?> -->

<!-- 在线客服组件样式 -->
<style>
/* 在线客服容器 */
.online-service-container {
  position: fixed;
  right: 20px;
  bottom: 100px;
  z-index: 9999;
  display: flex !important;
  flex-direction: column;
  align-items: center;
}

/* 客服按钮样式 */
.service-btns {
  display: flex;
  flex-direction: column;
  align-items: center;
}

.service-btn {
  width: 50px;
  height: 50px;
  border-radius: 50%;
  background: linear-gradient(145deg, #ff7a10, #ff6000);
  color: white;
  display: flex;
  justify-content: center;
  align-items: center;
  margin-bottom: 10px;
  text-decoration: none;
  box-shadow: 0 4px 15px rgba(255, 106, 0, 0.3);
  transition: all 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275);
  border: 2px solid rgba(255, 255, 255, 0.1);
}

.service-btn:hover {
  transform: translateY(-5px) scale(1.05);
  box-shadow: 0 6px 20px rgba(255, 106, 0, 0.4);
}

.service-btn:active {
  transform: translateY(0) scale(0.95);
}

.service-icon {
  font-size: 22px;
  filter: drop-shadow(0 2px 3px rgba(0, 0, 0, 0.2));
}

/* 聊天窗口样式 */
.chat-container {
  position: fixed;
  bottom: 20px;
  right: 20px;
  width: 360px;
  height: 500px;
  background-color: #fff;
  border-radius: 15px;
  box-shadow: 0 10px 40px rgba(0, 0, 0, 0.2);
  display: flex !important;
  flex-direction: column;
  overflow: hidden;
  z-index: 99999;
  opacity: 0;
  visibility: hidden;
  transform: translateY(30px) scale(0.95);
  transition: all 0.4s cubic-bezier(0.19, 1, 0.22, 1);
  border: 1px solid rgba(0, 0, 0, 0.08);
}

/* 激活状态 - 显示聊天窗口 */
.chat-container.active {
  opacity: 1;
  visibility: visible;
  transform: translateY(0) scale(1);
}

/* 最大化状态 */
.chat-container.maximized {
  width: 450px;
  height: 650px;
}

/* 聊天头部 */
.chat-header {
  background: linear-gradient(145deg, #ff7a10, #ff6000);
  color: white;
  padding: 16px 20px;
  display: flex;
  justify-content: space-between;
  align-items: center;
  border-bottom: 1px solid rgba(0, 0, 0, 0.05);
}

.chat-header h3 {
  margin: 0;
  font-size: 18px;
  font-weight: 600;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
  letter-spacing: 0.3px;
}

.header-buttons a {
  color: white;
  margin-left: 15px;
  text-decoration: none;
  font-size: 15px;
  opacity: 0.9;
  transition: all 0.2s;
}

.header-buttons a:hover {
  opacity: 1;
  transform: scale(1.1);
}

/* 聊天主体 */
.chat-body {
  flex: 1;
  display: flex;
  flex-direction: column;
  overflow: hidden;
  background-color: #f8f9fb;
}

/* 消息区域 */
.chat-messages {
  flex: 1;
  padding: 20px;
  overflow-y: auto;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.95), rgba(255, 255, 255, 0.85)),
    url("data:image/svg+xml,%3Csvg width='120' height='120' viewBox='0 0 120 120' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M9 0h2v20H9V0zm25.134.84l1.732 1-10 17.32-1.732-1 10-17.32zm-20 20l1.732 1-10 17.32-1.732-1 10-17.32zM58.16 4.134l1 1.732-17.32 10-1-1.732 17.32-10zm-40 40l1 1.732-17.32 10-1-1.732 17.32-10zM80 9v2H60V9h20zM20 69v2H0v-2h20zm79.32-55l-1 1.732-17.32-10L82 4l17.32 10zm-80 80l-1 1.732-17.32-10L2 84l17.32 10zm96.546-75.84l-1.732 1-10-17.32 1.732-1 10 17.32zm-100 100l-1.732 1-10-17.32 1.732-1 10 17.32zM38.16 24.134l1 1.732-17.32 10-1-1.732 17.32-10zM60 29v2H40v-2h20zm19.32 5l-1 1.732-17.32-10L62 24l17.32 10zm16.546 4.16l-1.732 1-10-17.32 1.732-1 10 17.32zM111 40h-2V20h2v20zm3.134.84l1.732 1-10 17.32-1.732-1 10-17.32zM40 49v2H20v-2h20zm19.32 5l-1 1.732-17.32-10L42 44l17.32 10zm16.546 4.16l-1.732 1-10-17.32 1.732-1 10 17.32zM91 60h-2V40h2v20zm3.134.84l1.732 1-10 17.32-1.732-1 10-17.32zm24.026 3.294l1 1.732-17.32 10-1-1.732 17.32-10zM39.32 74l-1 1.732-17.32-10L22 64l17.32 10zm16.546 4.16l-1.732 1-10-17.32 1.732-1 10 17.32zM71 80h-2V60h2v20zm3.134.84l1.732 1-10 17.32-1.732-1 10-17.32zm24.026 3.294l1 1.732-17.32 10-1-1.732 17.32-10zM120 89v2h-20v-2h20zm-84.134 9.16l-1.732 1-10-17.32 1.732-1 10 17.32zM51 100h-2V80h2v20zm3.134.84l1.732 1-10 17.32-1.732-1 10-17.32zm24.026 3.294l1 1.732-17.32 10-1-1.732 17.32-10zM100 109v2H80v-2h20zm19.32 5l-1 1.732-17.32-10 1-1.732 17.32 10zM31 120h-2v-20h2v20z' fill='%23f0f0f0' fill-opacity='0.4' fill-rule='evenodd'/%3E%3C/svg%3E");
  background-attachment: fixed;
  scrollbar-width: thin;
  scrollbar-color: rgba(0, 0, 0, 0.2) transparent;
}

.chat-messages::-webkit-scrollbar {
  width: 6px;
}

.chat-messages::-webkit-scrollbar-track {
  background: transparent;
}

.chat-messages::-webkit-scrollbar-thumb {
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 10px;
}

/* 消息样式 */
.message {
  margin-bottom: 18px;
  max-width: 85%;
  clear: both;
  position: relative;
  animation: fadeInUp 0.3s ease-out;
}

@keyframes fadeInUp {
  from {
    opacity: 0;
    transform: translateY(10px);
  }

  to {
    opacity: 1;
    transform: translateY(0);
  }
}

.message.user {
  float: right;
}

.message.service {
  float: left;
}

.message-content {
  padding: 12px 16px;
  border-radius: 18px;
  position: relative;
  box-shadow: 0 2px 10px rgba(0, 0, 0, 0.06);
}

.message.user .message-content {
  background: linear-gradient(135deg, #e3f3ff 0%, #e6f7ff 100%);
  color: #333;
  border-bottom-right-radius: 4px;
  margin-right: 5px;
}

.message.user .message-content:after {
  content: '';
  position: absolute;
  bottom: 0;
  right: -10px;
  width: 15px;
  height: 15px;
  background: radial-gradient(circle at top right, transparent 12px, #e6f7ff 0);
}

.message.service .message-content {
  background: linear-gradient(135deg, #f5f5f5 0%, #f0f0f0 100%);
  color: #333;
  border-bottom-left-radius: 4px;
  margin-left: 5px;
}

.message.service .message-content:after {
  content: '';
  position: absolute;
  bottom: 0;
  left: -10px;
  width: 15px;
  height: 15px;
  background: radial-gradient(circle at top left, transparent 12px, #f0f0f0 0);
}

.message-content p {
  margin: 0 0 8px 0;
  word-wrap: break-word;
  line-height: 1.5;
  font-size: 14px;
}

.message-content p:last-child {
  margin-bottom: 0;
}

.message-time {
  display: block;
  font-size: 11px;
  color: #888;
  margin-top: 4px;
  text-align: right;
}

/* 输入区域 */
.chat-input-area {
  padding: 15px;
  background: #fff;
  border-top: 1px solid #eaeaea;
  display: flex;
  align-items: center;
  box-shadow: 0 -2px 10px rgba(0, 0, 0, 0.03);
}

.message-input {
  flex: 1;
  padding: 12px 15px;
  border: 1px solid #e0e0e0;
  border-radius: 24px;
  resize: none;
  outline: none;
  transition: all 0.3s;
  font-size: 14px;
  line-height: 1.4;
  max-height: 120px;
  min-height: 24px;
  box-shadow: inset 0 1px 3px rgba(0, 0, 0, 0.05);
}

.message-input:focus {
  border-color: #ff6a00;
  box-shadow: 0 0 0 2px rgba(255, 106, 0, 0.1);
}

.message-input:disabled {
  background-color: #f5f5f5;
  cursor: not-allowed;
  color: #999;
}

.send-btn {
  width: 44px;
  height: 44px;
  border-radius: 50%;
  background: linear-gradient(145deg, #ff7a10, #ff6000);
  color: white;
  border: none;
  margin-left: 10px;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  transition: all 0.3s;
  box-shadow: 0 3px 10px rgba(255, 106, 0, 0.2);
}

.send-btn:hover {
  transform: scale(1.1);
  box-shadow: 0 5px 15px rgba(255, 106, 0, 0.3);
}

.send-btn:active {
  transform: scale(0.95);
}

.send-btn:disabled {
  background: linear-gradient(145deg, #d0d0d0, #b0b0b0);
  box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  cursor: not-allowed;
}

.send-btn i {
  font-size: 18px;
  margin-left: 2px;
}

/* 链接样式 */
.message-content a {
  color: #0078d7;
  text-decoration: none;
  transition: all 0.2s;
  border-bottom: 1px solid transparent;
}

.message-content a:hover {
  color: #ff6a00;
  border-bottom: 1px solid #ff6a00;
}

/* 清除浮动 */
.chat-messages::after {
  content: "";
  display: table;
  clear: both;
}

/* 手机响应式 */
@media (max-width: 480px) {
  .chat-container {
    width: 100%;
    height: 100%;
    right: 0;
    bottom: 0;
    border-radius: 0;
  }

  .chat-container.active {
    transform: translateY(0) scale(1);
  }

  .chat-container.maximized {
    width: 100%;
    height: 100%;
  }

  .message {
    max-width: 90%;
  }

  .online-service-container {
    bottom: 70px;
  }
}

.back-to-top {
  opacity: 0;
  visibility: hidden;
  transition: opacity 0.3s ease, visibility 0.3s ease;
}

.back-to-top.visible {
  opacity: 1;
  visibility: visible;
}

/* 未登录时的欢迎消息样式 */
.message.welcome-message {
  max-width: 100%;
}

</style>

<!-- 在线客服组件 -->
<div class="online-service-container" style="display:flex !important; visibility:visible !important; opacity:1 !important;">
  <!-- 客服按钮组 -->
  <div class="service-btns">
    <!-- Telegram在线咨询 -->
    <a href="<?php echo $Telegram; ?>" target="_blank" class="service-btn telegram-btn">
      <div class="service-icon">
        <i class="fab fa-telegram-plane"></i>
      </div>
    </a>
    <!-- 在线客服 -->
    <a href="javascript:void(0);" class="service-btn chat-btn" id="ticketBtn">
      <div class="service-icon">
        <i class="far fa-comment-dots"></i>
      </div>
    </a>
    <!-- 返回顶部按钮 -->
    <a href="javascript:void(0);" class="service-btn back-to-top">
      <div class="service-icon">
        <i class="fas fa-chevron-up"></i>
      </div>
    </a>
  </div>
  <!-- 聊天窗口 -->
  <div class="chat-container" id="ticketFormContainer">
    <div class="chat-header">
      <h3><i class="fas fa-headset" style="margin-right: 8px;"></i>在线客服</h3>
      <div class="header-buttons">
        <a href="javascript:void(0);" class="maximize-btn" id="maximizeChat">
          <i class="fas fa-expand-alt"></i>
        </a>
        <a href="javascript:void(0);" class="close-btn" id="closeTicketForm">
          <i class="fas fa-times"></i>
        </a>
      </div>
    </div>
    <div class="chat-body">
      <div class="chat-messages" id="chatMessages">
        <?php if (!empty($messages) && $is_logged_in): ?>
        <!-- 显示历史消息 -->
        <?php foreach ($messages as $message): ?>
        <?php 
          $messageClass = '';
          // 根据消息的发送者类型来判断样式类名
          if ($message['admin_id'] === null) {
            // 用户发送的消息
            $messageClass = 'user';
          } else {
            // 管理员回复的消息
            $messageClass = 'service';
          }
        ?>
        <div class="message <?php echo $messageClass; ?>">
          <div class="message-content">
            <p><?php echo htmlspecialchars($message['message']); ?></p>
            <small class="message-time"><?php echo date('H:i', strtotime($message['created_at'])); ?></small>
          </div>
        </div>
        <?php endforeach; ?>
        <?php else: ?>
        <!-- 默认欢迎消息 -->
        <div class="message service welcome-message">
          <div class="message-content">
            <p><strong>嗨，欢迎来到我们！</strong> 所有产品均可先试用后付费，不满意完全不收费！</p>
            <?php if (!$is_logged_in): ?>
            <p>为了给您提供更好的服务，请先 <a href="/user/log.html" target="_blank"><i class="fas fa-sign-in-alt"></i> 注册/登录</a> 与我们交流</p>
            <?php endif; ?>
            <p>您也可以直接联系专属客服经理：</p>
            <p>
              <a href="<?= $Telegram ?>" target="_blank"><i class="fab fa-telegram"></i> <?= $Telegram ?></a>
            </p>
          </div>
        </div>
        <?php endif; ?>
      </div>
      <div class="chat-input-area">
        <textarea id="messageInput" class="message-input" placeholder="<?php echo $is_logged_in ? '请输入您想咨询的问题...' : '请先登录后再发送消息...'; ?>" rows="1" <?php echo $is_logged_in ? '' : 'disabled'; ?>></textarea>
        <button id="sendMessage" class="send-btn" <?php echo $is_logged_in ? '' : 'disabled'; ?>>
          <i class="fas fa-paper-plane"></i>
        </button>
      </div>
    </div>
  </div>
</div>
<!-- 引入Font Awesome图标库 -->
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
<!-- 引入客服脚本 -->
<script>
// 立即执行函数避免变量污染全局作用域
(function() {
  // 在控制台输出调试信息
  console.log('客服组件开始加载');
  // 页面加载完成后执行
  document.addEventListener('DOMContentLoaded', function() {
    console.log('DOM加载完成，开始初始化客服组件');
    // 获取DOM元素
    const ticketBtn = document.getElementById('ticketBtn');
    const closeTicketBtn = document.getElementById('closeTicketForm');
    const maximizeChatBtn = document.getElementById('maximizeChat');
    const ticketFormContainer = document.getElementById('ticketFormContainer');
    const messageInput = document.getElementById('messageInput');
    const sendMessageBtn = document.getElementById('sendMessage');
    const chatMessages = document.getElementById('chatMessages');
    const backToTopBtn = document.querySelector('.back-to-top');
    // 调试信息：打印DOM元素，确保获取正确
    console.log('客服按钮存在:', ticketBtn ? '是' : '否');
    console.log('聊天窗口存在:', ticketFormContainer ? '是' : '否');
    // 是否已登录
    const isLoggedIn = <?php echo $is_logged_in ? 'true' : 'false'; ?>;
    console.log('用户登录状态:', isLoggedIn ? '已登录' : '未登录');
    // 确保所有必要的DOM元素都存在
    if (!ticketBtn || !ticketFormContainer) {
      console.error('客服组件初始化失败：缺少必要DOM元素');
      return; // 如果重要元素不存在，退出初始化
    }
    // 定义函数：滚动到聊天窗口底部
    function scrollToBottom() {
      if (chatMessages) {
        setTimeout(() => {
          chatMessages.scrollTop = chatMessages.scrollHeight;
          console.log('已滚动到底部');
        }, 100); // 延迟执行确保内容已渲染
      }
    }
    // 定义函数：显示聊天窗口
    function showChatWindow() {
      console.log('准备显示聊天窗口');
      ticketFormContainer.classList.add('active');
      scrollToBottom();
      console.log('聊天窗口已显示');
    }
    // 定义函数：隐藏聊天窗口
    function hideChatWindow() {
      console.log('准备隐藏聊天窗口');
      ticketFormContainer.classList.remove('active');
      ticketFormContainer.classList.remove('maximized');
      console.log('聊天窗口已隐藏');
    }
    // 直接简化绑定点击事件 - 不使用条件判断
    // 1. 客服按钮点击事件 - 打开聊天窗口
    ticketBtn.onclick = function(e) {
      e.preventDefault();
      e.stopPropagation();
      console.log('客服按钮被点击');
      showChatWindow();
    };
    // 2. 关闭按钮点击事件
    if (closeTicketBtn) {
      closeTicketBtn.onclick = function(e) {
        e.preventDefault();
        e.stopPropagation();
        console.log('关闭按钮被点击');
        hideChatWindow();
      };
    }
    // 3. 最大化按钮点击事件
    if (maximizeChatBtn) {
      maximizeChatBtn.onclick = function(e) {
        e.preventDefault();
        e.stopPropagation();
        console.log('最大化按钮被点击');
        ticketFormContainer.classList.toggle('maximized');
        // 更改图标
        const icon = maximizeChatBtn.querySelector('i');
        if (icon) {
          if (ticketFormContainer.classList.contains('maximized')) {
            icon.className = 'fas fa-compress-alt';
          } else {
            icon.className = 'fas fa-expand-alt';
          }
        }
      };
    }
    // 4. 返回顶部按钮点击事件
    if (backToTopBtn) {
      backToTopBtn.onclick = function(e) {
        e.preventDefault();
        console.log('返回顶部按钮被点击');
        window.scrollTo({
          top: 0,
          behavior: 'smooth'
        });
      };
    }
    // 5. 阻止聊天窗口内点击事件冒泡
    ticketFormContainer.onclick = function(e) {
      e.stopPropagation();
    };
    // 6. 点击窗口外部关闭聊天窗口
    document.addEventListener('click', function(e) {
      if (ticketFormContainer.classList.contains('active')) {
        // 检查点击的不是聊天窗口内部元素和客服按钮
        if (!ticketFormContainer.contains(e.target) && e.target !== ticketBtn && !ticketBtn.contains(e.target)) {
          console.log('检测到窗口外点击，关闭聊天窗口');
          hideChatWindow();
        }
      }
    });
    // 仅当用户已登录时启用发送功能
    if (isLoggedIn && messageInput && sendMessageBtn) {
      // 监听发送按钮点击
      sendMessageBtn.onclick = sendMessage;
      // 监听输入框按键事件（回车发送）
      messageInput.onkeypress = function(e) {
        if (e.key === 'Enter' && !e.shiftKey) {
          e.preventDefault();
          sendMessage();
        }
      };
      // 自动调整文本区域高度
      messageInput.oninput = function() {
        this.style.height = 'auto';
        this.style.height = (this.scrollHeight) + 'px';
      };
    }
    // 发送消息函数
    function sendMessage() {
      if (!messageInput) return;
      const message = messageInput.value.trim();
      if (message === '') return;
      console.log('发送消息:', message);
      // 添加用户消息到聊天窗口
      const userMessageElement = document.createElement('div');
      userMessageElement.className = 'message user';
      userMessageElement.innerHTML = `
        <div class="message-content">
          <p>${escapeHtml(message)}</p>
          <small class="message-time">${getCurrentTime()}</small>
        </div>
      `;
      chatMessages.appendChild(userMessageElement);
      // 清空输入框并重置高度
      messageInput.value = '';
      messageInput.style.height = 'auto';
      // 滚动到底部
      scrollToBottom();
      // 发送消息到服务器
      fetch(window.location.href, {
          method: 'POST',
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
          },
          body: `action=send_message&message=${encodeURIComponent(message)}`
        })
        .then(response => response.json())
        .then(data => {
          console.log('服务器响应:', data);
          if (data.success) {
            // 添加自动回复消息
            setTimeout(() => {
              const autoReplyElement = document.createElement('div');
              autoReplyElement.className = 'message service';
              autoReplyElement.innerHTML = `
              <div class="message-content">
                <p>您好！我已收到您的消息，会尽快为您解答，请稍候片刻~</p>
                <small class="message-time">${getCurrentTime()}</small>
              </div>
            `;
              chatMessages.appendChild(autoReplyElement);
              scrollToBottom();
            }, 1000);
          } else {
            console.error('消息发送失败:', data.error);
          }
        })
        .catch(error => {
          console.error('发送请求出错:', error);
        });
    }
    // 获取当前时间
    function getCurrentTime() {
      const now = new Date();
      const hours = now.getHours().toString().padStart(2, '0');
      const minutes = now.getMinutes().toString().padStart(2, '0');
      return `${hours}:${minutes}`;
    }
    // HTML转义函数
    function escapeHtml(text) {
      const div = document.createElement('div');
      div.textContent = text;
      return div.innerHTML;
    }
    // 手动触发一次点击测试（仅开发模式），模拟点击客服按钮
    const debugTest = false; // 设置为true开启测试模式
    if (debugTest) {
      console.log('调试模式：模拟点击客服按钮');
      setTimeout(() => {
        ticketBtn.click();
      }, 2000);
    }
    // 初始化完成
    console.log('客服组件初始化完成');
    // 强制显示客服组件，无论登录状态如何
    const onlineServiceContainer = document.querySelector('.online-service-container');
    if (onlineServiceContainer) {
      // 确保客服组件显示
      onlineServiceContainer.style.display = 'flex';
      onlineServiceContainer.style.visibility = 'visible';
      onlineServiceContainer.style.opacity = '1';
      console.log('已强制显示客服组件');
    }
  });
})();
</script>
