<?php
/**
 * 客服组件助手函数
 * 使用这些函数可以轻松在任何页面中引入客服相关组件
 */

/**
 * 引入客服卡片组件
 * 在页面中调用此函数即可显示客服卡片
 * 
 * @param string $position 卡片位置 (left, center, right)
 * @param bool $show_qrcode 是否显示二维码
 */
function include_customer_service_card($position = 'center', $show_qrcode = true) {
    // 设置卡片位置的样式
    $style = '';
    switch ($position) {
        case 'left':
            $style = 'margin-right: auto; margin-left: 0;';
            break;
        case 'right':
            $style = 'margin-left: auto; margin-right: 0;';
            break;
        case 'center':
        default:
            $style = 'margin-left: auto; margin-right: auto;';
            break;
    }
    
    // 设置是否显示二维码
    $qrcode_style = $show_qrcode ? '' : 'display: none;';
    
    // 输出自定义样式
    echo '<style>.cs-card { ' . $style . ' } .cs-qrcode { ' . $qrcode_style . ' }</style>';
    
    // 引入客服卡片组件
    include_once __DIR__ . '/customer_service.php';
}

/**
 * 引入悬浮客服组件
 * 在页面中调用此函数即可显示悬浮客服按钮和卡片
 * 
 * @param string $position 悬浮位置 (bottom-right, bottom-left, top-right, top-left)
 */
function include_floating_service($position = 'bottom-right') {
    // 设置悬浮位置的样式
    $style = '';
    switch ($position) {
        case 'bottom-left':
            $style = 'left: 30px; bottom: 30px; right: auto;';
            break;
        case 'top-right':
            $style = 'right: 30px; top: 30px; bottom: auto;';
            break;
        case 'top-left':
            $style = 'left: 30px; top: 30px; bottom: auto; right: auto;';
            break;
        case 'bottom-right':
        default:
            $style = 'right: 30px; bottom: 30px;';
            break;
    }
    
    // 输出自定义样式
    echo '<style>.floating-cs-container { ' . $style . ' }</style>';
    
    // 引入悬浮客服组件
    include_once __DIR__ . '/floating_service.php';
}

/**
 * 在当前页面中添加Telegram客服链接按钮
 * 
 * @param string $text 按钮文字
 * @param string $class 按钮CSS类名
 * @param bool $with_icon 是否显示Telegram图标
 * @return string HTML按钮代码
 */
function telegram_button($text = '联系客服', $class = 'btn btn-primary', $with_icon = true) {
    // 引入配置文件获取Telegram链接
    require_once __DIR__ . '/config.php';
    $telegram_link = getTelegram();
    
    // 构建图标HTML
    $icon = $with_icon ? '<i class="fab fa-telegram-plane"></i> ' : '';
    
    // 返回按钮HTML
    return '<a href="' . $telegram_link . '" class="' . $class . '" target="_blank">' . $icon . $text . '</a>';
}

/**
 * 在页面中添加Telegram联系信息
 * 
 * @param bool $with_username 是否显示用户名
 * @param bool $with_qrcode 是否显示二维码
 * @return string HTML代码
 */
function telegram_contact_info($with_username = true, $with_qrcode = true) {
    // 引入配置文件获取Telegram链接
    require_once __DIR__ . '/config.php';
    $telegram_link = getTelegram();
    $telegram_username = str_replace('https://t.me/', '@', $telegram_link);
    
    // 构建HTML
    $html = '<div class="telegram-contact-info">';
    
    if ($with_username) {
        $html .= '<div class="telegram-username"><i class="fab fa-telegram-plane"></i> ' . $telegram_username . '</div>';
    }
    
    if ($with_qrcode) {
        $html .= '<div class="telegram-qrcode">
            <img src="/uploads/public/telegram_qr.png" alt="Telegram二维码" onerror="this.src=\'/public/images/default_qr.png\'">
            <div class="qrcode-caption">扫码添加客服</div>
        </div>';
    }
    
    $html .= '</div>';
    
    // 返回HTML
    return $html;
}
?> 