<?php
/**
 * 文档中心页面
 * 从数据库中读取文档分类和文档数据
 */

// 定义ROOT_PATH常量
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', __DIR__);
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <?php 
    include 'public/config.php'; 
    
    // 引入数据库配置文件
    require_once ROOT_PATH . '/config/database.php';
    
    // 获取数据库连接
    $db = getDbConnection();
    
    // 查询所有分类
    $categories = [];
    $categoriesQuery = "SELECT * FROM repositor_category WHERE status = 1 ORDER BY sort_order ASC";
    $categoryResults = $db->query($categoriesQuery);
    while ($row = $categoryResults->fetch(PDO::FETCH_ASSOC)) {
        $categories[$row['id']] = $row;
    }
    
    // 查询热门文档（将featured改为按照view_count排序，取前3条）
    $featuredDocs = [];
    $featuredDocsQuery = "SELECT * FROM repositor_item WHERE status = 1 ORDER BY sort_order ASC LIMIT 3";
    $featuredResults = $db->query($featuredDocsQuery);
    while ($row = $featuredResults->fetch(PDO::FETCH_ASSOC)) {
        $featuredDocs[] = $row;
    }
    
    // 根据分类获取文档
    $docsByCategory = [];
    $categoryDocs = "SELECT * FROM repositor_item WHERE status = 1 ORDER BY category_id ASC, sort_order ASC";
    $docsResults = $db->query($categoryDocs);
    while ($row = $docsResults->fetch(PDO::FETCH_ASSOC)) {
        if (!isset($docsByCategory[$row['category_id']])) {
            $docsByCategory[$row['category_id']] = [];
        }
        $docsByCategory[$row['category_id']][] = $row;
    }
    ?>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>文档中心 - 知识库文档，更详细的了解全线产品</title>
    <meta name="keywords" content="服务器文档,服务器教程,云服务器指南,服务器配置,技术文档,Linux教程,Windows Server教程,服务器监控,服务器安全,数据备份,服务器性能优化">
    <meta name="description" content="全面的服务器知识库与技术文档中心，提供服务器初始化配置、安全加固、性能优化、数据备份等详细指南和教程。覆盖Linux、Windows各类服务器系统，帮助用户更好地管理和优化他们的服务器资源。">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="/public/css/style.css" rel="stylesheet">
    <link href="/public/css/breadcrumb.css" rel="stylesheet">
    <link href="/public/css/repository.css" rel="stylesheet">
  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include 'public/header.php'; ?>
    <!-- Banner 区域 -->
    <?php include 'public/banner.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <div class="repository-wrapper">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/">首页</a>
            <i class="material-icons">chevron_right</i>
            <span>文档中心</span>
          </div>
        </div>
        <!-- 页面标题区域 -->
        <div class="promo-section">
          <div class="promo-title">
            <svg class="" viewBox="0 0 24 24" width="35" height="30">
              <path fill="#ff6600" d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27z" />
            </svg>
            <span class="promo-title-text with-underline">文档中心</span>
            <div class="promo-desc">
              知识库文档，更详细的了解全线产品
            </div>
          </div>
          <a href="./product" class="promo-rules">立即选购</a>
        </div>
        <!-- 文档分类导航 -->
        <div class="repo-nav">
          <ul class="category-nav">
            <li class="active"><a href="#all">全部</a></li>
            <?php foreach ($categories as $category): ?>
            <li><a href="#<?php echo $category['slug']; ?>"><?php echo $category['name']; ?></a></li>
            <?php endforeach; ?>
          </ul>
        </div>
        <!-- 侧边栏分类 -->
        <div class="repo-container">
          <div class="repo-sidebar">
            <div class="sidebar-section">
              <h3>产品</h3>
              <ul>
                <li><a href="#">裸机云</a></li>
                <li><a href="#">独立服务器</a></li>
                <li><a href="#">大带宽服务器</a></li>
                <li><a href="#">定制服务器</a></li>
              </ul>
            </div>
            <div class="sidebar-section">
              <h3>服务器</h3>
              <ul>
                <li><a href="#">服务器托管</a></li>
                <li><a href="#">一站式解决方案</a></li>
              </ul>
            </div>
            <div class="sidebar-section">
              <h3>云集成服务器</h3>
              <ul>
                <li><a href="#">公有云</a></li>
                <li><a href="#">VPS</a></li>
                <li><a href="#">私有云</a></li>
                <li><a href="#">混合云互联</a></li>
              </ul>
            </div>
            <div class="sidebar-section">
              <h3>解决方案</h3>
              <ul>
                <li><a href="#">IP Transit</a></li>
                <li><a href="#">Network Peering</a></li>
                <li><a href="#">全球网络</a></li>
                <li><a href="#">SD-WAN</a></li>
              </ul>
            </div>
            <div class="sidebar-section">
              <h3>合作与代理</h3>
              <ul>
                <li><a href="#">代理商</a></li>
                <li><a href="#">佣金体系</a></li>
              </ul>
            </div>
          </div>
          <!-- 文档内容区 -->
          <div class="repo-content">
            <!-- 文档搜索框 -->
            <div class="search-box">
              <input type="text" placeholder="搜索文档...">
              <button><i class="material-icons">search</i></button>
            </div>
            <!-- 热门文档 -->
            <div class="featured-docs">
              <h2>热门文档</h2>
              <div class="docs-grid">
                <?php foreach ($featuredDocs as $doc): ?>
                <div class="doc-card">
                  <div class="doc-icon"><i class="material-icons">description</i></div>
                  <div class="doc-content">
                    <h3><?php echo $doc['question']; ?></h3>
                    <p><?php echo strip_tags(substr($doc['answer'], 0, 100)) . '...'; ?></p>
                    <div class="doc-meta">
                      <span><i class="material-icons">access_time</i> <?php echo date('Y-m-d', strtotime($doc['created_at'])); ?></span>
                    </div>
                  </div>
                </div>
                <?php endforeach; ?>
              </div>
            </div>
            <!-- 文档列表 -->
            <?php foreach ($categories as $categoryId => $category): ?>
            <?php if (isset($docsByCategory[$categoryId])): ?>
            <div class="doc-category" id="<?php echo $category['slug']; ?>">
              <h2><?php echo $category['name']; ?></h2>
              <div class="docs-list">
                <?php foreach ($docsByCategory[$categoryId] as $doc): ?>
                <div class="doc-item">
                  <div class="doc-type"><i class="material-icons">article</i></div>
                  <div class="doc-info">
                    <h3><a href="document.html?id=<?php echo $doc['id']; ?>"><?php echo $doc['question']; ?></a></h3>
                    <p><?php echo strip_tags(substr($doc['answer'], 0, 150)) . '...'; ?></p>
                  </div>
                </div>
                <?php endforeach; ?>
              </div>
            </div>
            <?php endif; ?>
            <?php endforeach; ?>
            <!-- 分页 -->

          </div>
        </div>
        <!-- 文档订阅 -->
      </div>
    </div>
    <!-- 页脚 -->
    <?php include 'public/kf.php'; ?>
    <?php include 'public/footer.php'; ?>
    <script src="/public/js/js.js"></script>
  </body>
</html>
