<!DOCTYPE html>
<html lang="zh-CN"> <?php 
include 'public/config.php'; 
// 定义常量，表示这是视图文件包含逻辑文件
define('INCLUDED_FROM_VIEW', true);
// 引入逻辑处理文件
require_once 'code/tag_products.php';
require_once 'code/product_helper.php';

// 获取标签ID
$tag_id = isset($_GET['tag']) ? intval($_GET['tag']) : 0;

if ($tag_id <= 0) {
    header("Location: /product");
    exit;
}

// 处理标签产品
$result = getProductsByTag($tag_id);

// 如果处理失败，重定向到产品列表页
if (!$result['success']) {
    header("Location: " . $result['redirect']);
    exit;
}

// 提取处理结果中的变量
$products = $result['products'];
$totalItems = $result['totalItems'];
$totalPages = $result['totalPages'];
$currentPage = $result['currentPage'];
$tagInfo = $result['tagInfo'];
$regionsData = $result['regionsData'];
$tagsData = $result['tagsData'];
$areaNames = $result['areaNames'];
$lineData = $result['lineData'];
$filters = $result['filters'];

// 为排序方向设置图标
$sortBy = $filters['sort'];
$sortOrder = $filters['order'];
$priceIcon = ($sortBy == 'price' && $sortOrder == 'desc') ? 'arrow_upward' : 'arrow_downward';
$createdIcon = ($sortBy == 'created' && $sortOrder == 'asc') ? 'arrow_upward' : 'arrow_downward';

// 生成标题
$pageTitle = $tagInfo['name'] . '服务器 - 高品质专业稳定安全';
?> <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - <?php echo $GLOBALS['SiteName']; ?></title>
    <meta name="description" content="<?php echo $tagInfo['name']; ?>服务器，品质保障，安全稳定，多线路选择，立即购买体验优质服务">
    <meta name="keywords" content="<?php echo $tagInfo['name']; ?>服务器,服务器租用,服务器托管,高速服务器,专业服务器"> <?php echo getCommonCss(); ?>
    <link href="/public/css/product.css" rel="stylesheet">
    <link href="/public/css/product-enhanced.css" rel="stylesheet">
    <link href="/public/css/server_card.css" rel="stylesheet">
    <script src="/public/js/product.js" defer></script>
    <script src="/public/js/product-filter.js" defer></script>
  </head>
  <body>
    <!-- 顶部导航 --> <?php include 'public/header.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <!-- Banner 区域（全宽） --> <?php include 'public/banner.php'; ?>
      <!-- 内容区域（固定宽度） -->
      <div class="product-content">
        <!-- 面包屑导航 -->
        <div class="breadcrumb">
          <a href="/">首页</a>
          <i class="material-icons">chevron_right</i>
          <a href="/product">服务器产品</a>
          <i class="material-icons">chevron_right</i>
          <span><?php echo $tagInfo['name']; ?>服务器</span>
        </div>
        
        <!-- 产品标题区 -->
        <div class="section-title">
          <h1><?php echo $tagInfo['name']; ?>服务器</h1>
          <p>专业稳定的<?php echo $tagInfo['name']; ?>服务器，满足您的各种业务需求</p>
        </div>
        
        <!-- 排序选项 -->
        <div class="product-sort">
          <span class="sort-label">排序方式：</span>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'recommended' ? 'active' : ''; ?>" data-sort="recommended">默认</a>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'price' ? 'active' : ''; ?>" data-sort="price" data-current-order="<?php echo $sortOrder; ?>">价格 <i class="material-icons"><?php echo $priceIcon; ?></i></a>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'created' ? 'active' : ''; ?>" data-sort="created" data-current-order="<?php echo $sortOrder; ?>">上架时间 <i class="material-icons"><?php echo $createdIcon; ?></i></a>
          <div class="view-mode">
            <a href="#" class="view-mode-btn active" title="网格视图">
              <i class="material-icons">grid_view</i>
            </a>
            <a href="#" class="view-mode-btn" title="列表视图">
              <i class="material-icons">view_list</i>
            </a>
          </div>
        </div>
        
        <!-- 产品列表 -->
        <div class="product-list"> <?php if (empty($products)): ?> <div class="no-products" style="text-align:center; padding:30px; font-size:18px;">暂无<?php echo $tagInfo['name']; ?>服务器产品，请联系客服咨询。</div> <?php else: ?> <?php foreach ($products as $product): ?> <div class="server-card">
              <div class="server-card-header">
                <h2 class="server-title"><?php echo generateProductTitle($product, $areaNames, $regionsData['allRegions'], $regionsData['parentRegions']); ?></h2>
              </div>
              <div class="server-specs">
                <div class="spec-row">
                  <div class="spec-item">
                    <span class="spec-label">编号:</span>
                    <span class="spec-value"><?php echo formatProductId($product['id']); ?></span>
                  </div>
                  <div class="spec-item">
                    <span class="spec-label">CPU:</span>
                    <span class="spec-value"><?php echo htmlspecialchars($product['upc'] ?? 'E3-1230'); ?></span>
                  </div>
                </div>
                <div class="spec-row">
                  <div class="spec-item">
                    <span class="spec-label">硬盘:</span>
                    <span class="spec-value"><?php echo htmlspecialchars($product['disk'] ?? '240G SSD'); ?></span>
                  </div>
                  <div class="spec-item">
                    <span class="spec-label">带宽:</span>
                    <span class="spec-value"><?php echo htmlspecialchars($product['bandwidth'] ?? '15M'); ?></span>
                  </div>
                </div>
                <div class="spec-row">
                  <div class="spec-item">
                    <span class="spec-label">防御:</span>
                    <span class="spec-value"><?php echo getDefenseDisplay($product['defense']); ?></span>
                  </div>
                  <div class="spec-item">
                    <span class="spec-label">线路:</span>
                    <span class="spec-value"><?php echo getLineDisplay($product['line_id'], $lineData); ?></span>
                  </div>
                </div>
                <div class="spec-row">
                  <div class="spec-item">
                    <span class="spec-label">地区:</span>
                    <span class="spec-value"><?php echo getRegionDisplay($product['region_id'], $areaNames); ?></span>
                  </div>
                  <div class="spec-item">
                    <span class="spec-label">内存:</span>
                    <span class="spec-value"><?php echo htmlspecialchars($product['memory'] ?? '8G'); ?></span>
                  </div>
                </div>
                <div class="spec-row">
                  <div class="spec-item">
                    <span class="spec-label">IP数:</span>
                    <span class="spec-value"><?php echo htmlspecialchars($product['ip_count'] ?? '1'); ?>个</span>
                  </div>
                  <div class="spec-item">
                    <span class="spec-label">流量:</span>
                    <span class="spec-value"><?php echo getTrafficDisplay($product['traffic']); ?></span>
                  </div>
                </div>
              </div>
              <div class="server-price-container">
                <div class="server-price">
                  <span class="price-currency">¥</span>
                  <span class="price-amount"><?php echo getFormattedPrice($product['price']); ?></span>
                  <span class="price-period">/月</span>
                </div>
              </div>
              <div class="server-actions">
                <a href="cart.html?id=<?php echo $product['id']; ?>" class="server-btn server-btn-primary">立即购买</a>
                <a href="<?php echo $GLOBALS['Telegram']; ?>" class="server-btn server-btn-secondary">申请测机</a>
              </div>
            </div> <?php endforeach; ?> <?php endif; ?> </div>
        
        <!-- 分页 --> <?php 
        // 分页函数
        function generatePagination($currentPage, $totalPages) {
            if ($totalPages <= 1) return '';
            
            $tag = isset($_GET['tag']) ? '&tag=' . intval($_GET['tag']) : '';
            $sort = isset($_GET['sort']) ? '&sort=' . $_GET['sort'] : '';
            $order = isset($_GET['order']) ? '&order=' . $_GET['order'] : '';
            
            $output = '<div class="pagination">';
            
            // 上一页
            if ($currentPage > 1) {
                $output .= '<a href="?page=' . ($currentPage - 1) . $tag . $sort . $order . '" class="page-item"><i class="material-icons">chevron_left</i></a>';
            } else {
                $output .= '<span class="page-item disabled"><i class="material-icons">chevron_left</i></span>';
            }
            
            // 页码
            $range = 2; // 当前页前后显示的页码数
            for ($i = max(1, $currentPage - $range); $i <= min($totalPages, $currentPage + $range); $i++) {
                if ($i == $currentPage) {
                    $output .= '<span class="page-item active">' . $i . '</span>';
                } else {
                    $output .= '<a href="?page=' . $i . $tag . $sort . $order . '" class="page-item">' . $i . '</a>';
                }
            }
            
            // 下一页
            if ($currentPage < $totalPages) {
                $output .= '<a href="?page=' . ($currentPage + 1) . $tag . $sort . $order . '" class="page-item"><i class="material-icons">chevron_right</i></a>';
            } else {
                $output .= '<span class="page-item disabled"><i class="material-icons">chevron_right</i></span>';
            }
            
            $output .= '</div>';
            return $output;
        }
        
        echo generatePagination($currentPage, $totalPages);
        ?>
        
      </div>
    </div>
    
    <!-- 客服和页脚 --> <?php include 'public/kf.php'; ?> <?php include 'public/footer.php'; ?> 
    <script src="/public/js/js.js"></script>
    <script>
    // 在这里添加页面php变量到js的桥接代码
    document.addEventListener('DOMContentLoaded', function() {
        // 为排序选项添加点击事件
        document.querySelectorAll('.sort-option').forEach(function(option) {
            option.addEventListener('click', function() {
                const sortType = this.getAttribute('data-sort');
                let orderType = 'asc';
                
                // 如果点击已激活的选项，切换排序方向
                if (this.classList.contains('active')) {
                    orderType = this.getAttribute('data-current-order') === 'asc' ? 'desc' : 'asc';
                } else if (sortType === 'price') {
                    orderType = 'asc'; // 价格默认从低到高
                } else {
                    orderType = 'desc'; // 其他默认从高到低
                }
                
                // 构建URL
                let url = window.location.pathname + '?tag=<?php echo $tag_id; ?>&sort=' + sortType + '&order=' + orderType;
                if (<?php echo $currentPage; ?> > 1) {
                    url += '&page=<?php echo $currentPage; ?>';
                }
                
                window.location.href = url;
            });
        });
    });
    </script>
  </body>
</html> 