<?php
/**
 * 更新服务器备注API
 * 接收POST请求，更新指定服务器的备注信息
 */

// 引入必要的文件
require_once '../code/auth.php';
require_once '../../config/database.php';

// 设置响应类型为JSON
header('Content-Type: application/json');

// 验证用户是否已登录
if (!isLoggedIn()) {
    echo json_encode([
        'success' => false,
        'message' => '用户未登录'
    ]);
    exit;
}

// 获取当前用户ID
$userId = getCurrentUserId();

// 验证请求参数
if (!isset($_POST['server_id']) || !isset($_POST['note'])) {
    echo json_encode([
        'success' => false,
        'message' => '参数不完整'
    ]);
    exit;
}

$serverId = intval($_POST['server_id']);
$note = trim($_POST['note']);

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 验证服务器所有权（确保当前用户拥有该服务器）
    $checkStmt = $db->prepare("SELECT id FROM orders WHERE id = ? AND MemberID = ?");
    $checkStmt->execute([$serverId, $userId]);
    
    if (!$checkStmt->fetch()) {
        echo json_encode([
            'success' => false,
            'message' => '无权限修改此服务器'
        ]);
        exit;
    }
    
    // 更新备注信息
    $updateStmt = $db->prepare("UPDATE orders SET notes = ? WHERE id = ?");
    $result = $updateStmt->execute([$note, $serverId]);
    
    // 返回结果
    if ($result) {
        echo json_encode([
            'success' => true,
            'message' => '备注已更新'
        ]);
    } else {
        echo json_encode([
            'success' => false,
            'message' => '备注更新失败'
        ]);
    }
} catch (PDOException $e) {
    // 记录错误日志
    error_log("Error updating server note: " . $e->getMessage());
    
    echo json_encode([
        'success' => false,
        'message' => '服务器错误，请稍后重试'
    ]);
}
?> 