<?php
/**
 * 财务记录处理文件
 * 用于获取并处理当前会员的财务数据
 */

require_once __DIR__ . '/auth.php';
require_once __DIR__ . '/../../config/database.php';
require_once __DIR__ . '/../../config/config.php';

// 确保用户已登录
requireLogin();
$userId = getCurrentUserId();

// 初始化变量
$financeRecords = [];
$totalRecords = 0;
$currentPage = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$recordsPerPage = isset($_GET['perPage']) ? (int)$_GET['perPage'] : 10;
$offset = ($currentPage - 1) * $recordsPerPage;

// 计算用户余额 - 使用config.php中定义的余额计算函数
$balance = calculateUserBalance($userId);

// 获取财务记录总数
try {
    $db = getDbConnection();
    $stmt = $db->prepare("
        SELECT COUNT(*) as total 
        FROM finance 
        WHERE member_id = ?
    ");
    $stmt->execute([$userId]);
    $result = $stmt->fetch();
    $totalRecords = $result['total'];
} catch (PDOException $e) {
    error_log("Error counting finance records: " . $e->getMessage());
}

// 计算总页数
$totalPages = ceil($totalRecords / $recordsPerPage);

// 获取财务记录
try {
    $db = getDbConnection();
    $stmt = $db->prepare("
        SELECT f.*, u.username as operator_name 
        FROM finance f
        LEFT JOIN user u ON f.operator_id = u.id
        WHERE f.member_id = ?
        ORDER BY f.created_at DESC
        LIMIT ?, ?
    ");
    $stmt->bindParam(1, $userId, PDO::PARAM_INT);
    $stmt->bindParam(2, $offset, PDO::PARAM_INT);
    $stmt->bindParam(3, $recordsPerPage, PDO::PARAM_INT);
    $stmt->execute();
    $financeRecords = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log("Error fetching finance records: " . $e->getMessage());
}

/**
 * 获取支付状态文本
 * @param int $status 状态码
 * @return string 状态文本
 */
function getPaymentStatusText($status) {
    switch ($status) {
        case 0:
            return '未支付';
        case 1:
            return '已支付';
        default:
            return '未知状态';
    }
}

/**
 * 获取交易类型文本
 * @param int $type 类型码
 * @return string 类型文本
 */
function getTransactionTypeText($type) {
    switch ($type) {
        case 1:
            return '充值';
        case 2:
            return '管理员操作';
        case 3:
            return '系统扣款';
        default:
            return '其他类型';
    }
}

/**
 * 格式化金额显示
 * @param float $amount 金额
 * @return string 格式化后的金额
 */
function formatAmount($amount) {
    return '$' . number_format($amount, 2);
}
?>
