<?php
require_once 'auth.php';
require_once 'publi.php';
require_once '../config/config.php';
require_once 'finance_code.php';
require_once '../config/database.php';

// 获取当前用户ID并计算余额
$userId = getCurrentUserId();
$balance = calculateUserBalance($userId);

// 获取news表前10条记录
$db = getDbConnection();
$stmt = $db->query("SELECT id, category_id, title, summary, keywords, content, status, views, sort_order FROM news ORDER BY id DESC LIMIT 5");
$newsList = $stmt->fetchAll();

// 获取orders表的最新5条记录
$stmt = $db->prepare("SELECT id, MemberID, product_type, price, status, created_at FROM orders WHERE MemberID = ? ORDER BY created_at DESC LIMIT 5");
$stmt->execute([$userId]);
$recentOrders = $stmt->fetchAll();

// 获取tickets表的最新5条工单记录
$ticketsQuery = "SELECT t.id, t.subject, t.status, t.priority, 
                DATE_FORMAT(t.created_at, '%Y-%m-%d %H:%i:%s') as formatted_created_at,
                DATE_FORMAT(t.last_reply, '%Y-%m-%d %H:%i:%s') as formatted_last_reply
                FROM tickets t 
                WHERE t.user_id = ?
                ORDER BY t.last_reply DESC, t.created_at DESC
                LIMIT 5";
$stmt = $db->prepare($ticketsQuery);
$stmt->execute([$userId]);
$recentTickets = $stmt->fetchAll();

// 根据status字段值定义显示的文本
function getStatusText($status) {
    switch ($status) {
        case 1:
            return '有效';
        case 2:
            return '审核中';
        case 3:
            return '已管理';
        case 4:
            return '已终止';
        case 5:
            return '已取消';
        default:
            return '未知状态';
    }
}

// 状态映射
$statusMap = [
    'open' => '未处理',
    'pending' => '处理中',
    'answered' => '已回复',
    'replied' => '已回复',
    'closed' => '已关闭'
];

// 状态图标映射
$statusIconMap = [
    'open' => 'exclamation-circle',
    'pending' => 'clock',
    'answered' => 'check-circle',
    'replied' => 'check-circle',
    'closed' => 'check'
];

// 优先级图标映射
$priorityIconMap = [
    'low' => 'arrow-down',
    'medium' => 'minus',
    'high' => 'arrow-up',
    'urgent' => 'exclamation-triangle'
];

// 优先级颜色映射
$priorityColorMap = [
    'low' => 'low',
    'medium' => 'medium',
    'high' => 'high',
    'urgent' => 'warning'
];

/**
 * 获取最新的5条产品记录
 */
function getLatestProducts() {
    // 使用通用的数据库连接函数
    $db = getDbConnection();
    
    try {
        // 简化查询，直接获取表中所有记录
        $sql = "SELECT * FROM products LIMIT 5";
        
        $stmt = $db->query($sql);
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 调试输出
        error_log("Products count: " . count($products));
        
        return $products;
    } catch (Exception $e) {
        // 出错时记录错误信息并返回空数组
        error_log("获取产品数据出错: " . $e->getMessage());
        return [];
    }
}

// 获取最新产品
$latestProducts = getLatestProducts();

/**
 * 获取地区数据和对应的图标
 */
function getAreaData() {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 修改SQL，先按父级排序，再按子级排序
        $sql = "SELECT a.*, p.name as parent_name, p.sort_order as parent_sort_order
                FROM area a 
                LEFT JOIN area p ON a.parent_id = p.id 
                WHERE a.parent_id IS NOT NULL 
                AND a.status = 1 
                ORDER BY p.sort_order ASC, p.id ASC, a.sort_order ASC";
                
        $areas = $db->query($sql)->fetchAll(PDO::FETCH_ASSOC);
        
        foreach($areas as $area) {
            // 设置默认图标
            $icon = 'fas fa-server';
            
            // 根据地区名称设置特定图标
            if(stripos($area['parent_name'], '美国') !== false || stripos($area['name'], '美国') !== false) {
                $icon = 'fas fa-flag-usa';
            } elseif(stripos($area['parent_name'], '日本') !== false || stripos($area['name'], '日本') !== false) {
                $icon = 'fas fa-torii-gate';
            } elseif(stripos($area['parent_name'], '欧洲') !== false || stripos($area['name'], '德国') !== false) {
                $icon = 'fas fa-globe-europe';
            } elseif(stripos($area['parent_name'], '中国') !== false || stripos($area['name'], '中国') !== false) {
                $icon = 'fas fa-globe-asia';
            } elseif(stripos($area['parent_name'], '亚洲') !== false || stripos($area['name'], '新加坡') !== false) {
                $icon = 'fas fa-globe-asia';
            }
            
            $area['icon'] = $icon;
            // 组合显示名称：城市/国家
            $area['display_name'] = $area['name'] . '/' . $area['parent_name'];
            $result[] = $area;
        }
        
        return $result;
    } catch (Exception $e) {
        error_log("获取地区数据出错: " . $e->getMessage());
        return [];
    }
}

// 获取地区数据
$areaData = getAreaData();

// 其他可能需要的全局变量和函数
// 这些变量和函数都会在包含此文件的页面中可用
?>
