<?php
/**
 * 基本PHP逻辑函数文件
 * 提供常用功能供其他文件引用
 */

// 格式化日期时间
function formatDateTime($timestamp = null, $format = 'Y-m-d H:i:s') {
    if ($timestamp === null) {
        $timestamp = time();
    }
    return date($format, $timestamp);
}

// 计算两个数字的和
function addNumbers($a, $b) {
    return $a + $b;
}

// 检查字符串是否为空
function isEmptyString($str) {
    return empty(trim($str));
}

// 获取安全的GET参数
function getSafeGet($key, $default = '') {
    return isset($_GET[$key]) ? htmlspecialchars($_GET[$key], ENT_QUOTES, 'UTF-8') : $default;
}

// 获取安全的POST参数
function getSafePost($key, $default = '') {
    return isset($_POST[$key]) ? htmlspecialchars($_POST[$key], ENT_QUOTES, 'UTF-8') : $default;
}

// 生成随机字符串
function generateRandomString($length = 10) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, strlen($characters) - 1)];
    }
    return $randomString;
}

// 获取最新视频数据
function getLatestVideos($limit = 5) {
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 获取视频数据，限制最新的记录
        $videosQuery = "SELECT * FROM videos WHERE status = 1 ORDER BY created_at DESC LIMIT " . intval($limit);
        $videosStmt = $db->query($videosQuery);
        $videos = $videosStmt->fetchAll();
        
        return $videos;
    } catch (PDOException $e) {
        // 错误处理
        error_log("数据库错误: " . $e->getMessage());
        // 如果出错，使用空数组防止页面报错
        return [];
    }
}

// 获取最新新闻数据
function getLatestNews($limit = 5) {
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 查询新闻数据，限制为指定条数
        $query = "SELECT * FROM news WHERE status = 1 ORDER BY created_at DESC LIMIT " . intval($limit);
        $stmt = $db->query($query);
        if ($stmt) {
            $news = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $news;
        }
        
        return [];
    } catch (PDOException $e) {
        // 错误处理
        error_log("数据库错误: " . $e->getMessage());
        // 如果出错，使用空数组防止页面报错
        return [];
    }
}
?>
