<?php
// 确保没有之前的输出
ob_start();

session_start();
require_once __DIR__ . '/../../config/database.php';
require_once __DIR__ . '/../../config/config.php';

// 如果是AJAX请求，不输出HTML
if (!empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest') {
    // 只处理AJAX请求，不输出HTML
    // 后续代码会继续执行，但主页面会提前退出
    define('IS_AJAX', true);
} else {
    define('IS_AJAX', false);
}

// 开启错误显示
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// 设置错误处理函数
function handleError($response) {
    ob_clean(); // 清除之前的所有输出
    header('Content-Type: application/json');
    error_log("Response sent: " . json_encode($response));
    echo json_encode($response);
    exit;
}

// 检查是否有register参数
$isRegister = isset($_GET['action']) && $_GET['action'] === 'register';

// 处理注册请求
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $response = ['success' => false, 'message' => ''];
    
    // 记录接收到的数据
    error_log("Received POST data: " . print_r($_POST, true));
    
    if (isset($_POST['action']) && $_POST['action'] === 'register') {
        try {
            if (!isset($_POST['username']) || !isset($_POST['password']) || !isset($_POST['confirm_password'])) {
                throw new Exception('请填写所有必填字段');
            }
            
            $username = trim($_POST['username']);
            $password = $_POST['password'];
            $confirm_password = $_POST['confirm_password'];
            $telegram_id = !empty($_POST['telegram_id']) ? trim($_POST['telegram_id']) : null;
            
            if (empty($username) || empty($password)) {
                throw new Exception('用户名和密码不能为空');
            }
            
            if ($password !== $confirm_password) {
                throw new Exception('两次输入的密码不一致');
            }
            
            $db = getDbConnection();
            error_log("Database connection established");
            
            // 验证用户名是否已存在
            $stmt = $db->prepare("SELECT id FROM user WHERE username = ?");
            $stmt->execute([$username]);
            if ($stmt->fetch()) {
                throw new Exception('用户名已存在');
            }
            
            // 密码加密
            $hashed_password = password_hash($password, PASSWORD_DEFAULT);
            
            // 插入新用户
            $stmt = $db->prepare("INSERT INTO user (username, password, telegram_id, status, created_at, updated_at) VALUES (?, ?, ?, 1, NOW(), NOW())");
            $result = $stmt->execute([$username, $hashed_password, $telegram_id]);
            
            if ($result) {
                $response['success'] = true;
                $response['message'] = '注册成功';
                error_log("User registered successfully: " . $username);
            } else {
                throw new Exception('注册失败，请稍后重试');
            }
            
        } catch (Exception $e) {
            error_log("Registration error: " . $e->getMessage());
            $response['message'] = $e->getMessage();
        }
        
        handleError($response);
    }
    
    // 处理登录请求
    if (isset($_POST['action']) && $_POST['action'] === 'login') {
        error_log("Received login data: " . print_r($_POST, true));
        
        $username = trim($_POST['username']);
        $password = $_POST['password'];
        $remember = isset($_POST['remember']) ? true : false;
        
        $response = ['success' => false, 'message' => ''];
        
        try {
            $db = getDbConnection();
            error_log("Database connection established for login");
            
            // 查询用户
            $stmt = $db->prepare("SELECT id, username, password, status FROM user WHERE username = ?");
            $stmt->execute([$username]);
            $user = $stmt->fetch();
            
            if ($user && password_verify($password, $user['password'])) {
                if ($user['status'] == 1) {
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['username'] = $user['username'];
                    
                    if ($remember) {
                        // 设置30天的记住我cookie
                        $token = bin2hex(random_bytes(32));
                        setcookie('remember_token', $token, time() + 30 * 24 * 3600, '/', '', true, true);
                        
                        // 存储token到数据库
                        $stmt = $db->prepare("UPDATE user SET remember_token = ? WHERE id = ?");
                        $stmt->execute([$token, $user['id']]);
                    }
                    
                    $response['success'] = true;
                    $response['message'] = '登录成功';
                    $response['redirect'] = true;
                    $response['redirect_url'] = '/user/index.html';
                    error_log("User logged in successfully: " . $username);
                } else {
                    $response['message'] = '账号已被禁用';
                    error_log("Account disabled: " . $username);
                }
            } else {
                $response['message'] = '用户名或密码错误';
                error_log("Login failed - invalid credentials for: " . $username);
            }
        } catch (PDOException $e) {
            $response['message'] = '系统错误：' . $e->getMessage();
            error_log("Login error: " . $e->getMessage());
        }
        
        handleError($response);
    }
}

// 检查是否已登录
$isLoggedIn = isset($_SESSION['user_id']);

// 如果已登录且不是AJAX请求，直接跳转到会员中心
if ($isLoggedIn && empty($_SERVER['HTTP_X_REQUESTED_WITH'])) {
    header('Location: /user/index.html');
    exit;
}

// 允许正常输出页面内容
ob_end_flush();

// 如果是AJAX请求，停止继续执行，不输出HTML
if (defined('IS_AJAX') && IS_AJAX) {
    return;
}
?>
