<?php
// 设置详细错误报告
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 记录访问和会话信息
$log_prefix = "[OCS聊天系统] - " . date('Y-m-d H:i:s') . ": ";
error_log($log_prefix . "页面访问开始");

// 获取数据库连接
try {
  $db = getDbConnection();
  $db_ok = true;
  error_log($log_prefix . "数据库连接成功");
  
  // 如果是测试模式，直接尝试插入一条测试消息
  if (isset($_GET['test_insert']) && $_GET['test_insert'] == '1' && $db_ok) {
    try {
      $test_message = "这是一条测试消息 - " . date('Y-m-d H:i:s');
      $test_user_id = 4; // 使用演示数据中的用户ID 4
      
      // 关闭预处理语句，直接执行SQL
      $test_sql = "INSERT INTO chat_messages (user_id, admin_id, message, is_read, created_at) 
                  VALUES ($test_user_id, NULL, '$test_message', 1, NOW())";
      
      $db->exec($test_sql);
      // 重定向回页面
      header('Location: ' . $_SERVER['PHP_SELF']);
      exit;
    } catch (Exception $e) {
      error_log($log_prefix . "测试异常：" . $e->getMessage());
    }
  }
} catch (Exception $e) {
  $db_ok = false;
  error_log($log_prefix . "数据库连接失败: " . $e->getMessage());
}

// 获取用户ID
$user_id = isset($_SESSION['user_id']) ? intval($_SESSION['user_id']) : 0;
error_log($log_prefix . "当前用户ID: " . $user_id);

// 判断用户是否已登录
if ($user_id <= 0) {
  // 未登录用户重定向到登录页
  error_log($log_prefix . "用户未登录，重定向到登录页");
  header('Location: login.php?redirect=' . urlencode($_SERVER['REQUEST_URI']));
  exit;
}

// 处理直接消息发送
if (isset($_GET['direct_send']) && !empty($_GET['msg'])) {
  $direct_message = $_GET['msg'];
  error_log($log_prefix . "收到直接发送请求: " . $direct_message);
  
  try {
    // 直接执行SQL插入
    $safe_message = $db->quote($direct_message);
    $insert_sql = "INSERT INTO chat_messages (user_id, admin_id, message, is_read, created_at) VALUES ($user_id, NULL, $safe_message, 1, NOW())";
    
    error_log($log_prefix . "直接插入SQL: " . $insert_sql);
    $direct_result = $db->exec($insert_sql);
    
    if ($direct_result !== false) {
      error_log($log_prefix . "直接发送成功：消息ID: " . $db->lastInsertId());
      
      // 客服回复（直接执行SQL）
      $reply = "感谢您的咨询，我会尽快处理您的问题。";
      $safe_reply = $db->quote($reply);
      
      $reply_sql = "INSERT INTO chat_messages (user_id, admin_id, message, is_read, created_at) VALUES ($user_id, 1, $safe_reply, 0, NOW())";
      error_log($log_prefix . "执行SQL: " . $reply_sql);
      
      $db->exec($reply_sql);
    } else {
      error_log($log_prefix . "直接发送失败：" . print_r($db->errorInfo(), true));
    }
    
    // 重定向回页面
    header('Location: ' . $_SERVER['PHP_SELF']);
    exit;
  } catch (Exception $e) {
    error_log($log_prefix . "直接发送异常：" . $e->getMessage());
  }
}

// 获取历史消息
$messages = []; 
if ($db_ok) {
  try {
    // 基于user_id获取聊天消息
    $sql = "SELECT * FROM chat_messages WHERE user_id = $user_id ORDER BY created_at ASC";
    error_log($log_prefix . "执行SQL: " . $sql);
    
    // 尝试直接查询而不是使用预处理语句
    $result = $db->query($sql);
    if ($result) {
      $messages = $result->fetchAll(PDO::FETCH_ASSOC);
      
      // 调试信息：记录消息数量
      error_log($log_prefix . "当前用户ID: " . $user_id . ", 加载消息数量: " . count($messages));
      
      // 直接执行更新语句
      $update_sql = "UPDATE chat_messages SET is_read = 1 WHERE user_id = $user_id AND admin_id IS NOT NULL AND is_read = 0";
      error_log($log_prefix . "执行SQL: " . $update_sql);
      $db->exec($update_sql);
    } else {
      error_log($log_prefix . "查询消息失败: " . print_r($db->errorInfo(), true));
    }
  } catch (Exception $e) {
    error_log($log_prefix . "获取消息失败: " . $e->getMessage());
  }
}
?>
