<?php
require_once '../../config/database.php'; // 注意路径已更改，因为文件现在在user/code目录下
require_once 'auth.php'; // 现在在同一目录下

// 记录完整的请求信息，便于调试
error_log("Payment process started. POST data: " . print_r($_POST, true));
error_log("Session data: " . print_r($_SESSION, true));

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    error_log("Payment failed: User not logged in");
    echo json_encode(['status' => 'error', 'message' => '用户未登录']);
    exit;
}

// 获取提交的数据并记录日志用于调试
$amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
$orderNumber = isset($_POST['orderNumber']) ? $_POST['orderNumber'] : ''; // 接收字符串格式的订单号

// 记录调试信息
error_log("Payment details: amount = $amount, orderNumber = $orderNumber, user_id = " . $_SESSION['user_id']);

// 验证数据
if ($amount <= 0) {
    error_log("Payment failed: Invalid amount: $amount");
    echo json_encode(['status' => 'error', 'message' => '无效的支付金额']);
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    error_log("Database connection established");
    
    // 准备插入数据
    $memberId = $_SESSION['user_id'];
    $type = 1; // 1:会员费用
    $description = ""; // 描述字段留空，由管理员填写
    $paymentStatus = 0; // 0:未支付 (因为这时用户只是点击了支付按钮，实际上还未支付完成)
    $operatorId = 0; // 系统操作，无人工操作员
    $currentTime = date("Y-m-d H:i:s");
    
    // 记录要插入的数据用于调试
    error_log("Inserting payment data: member_id=$memberId, amount=$amount, type=$type, status=$paymentStatus, description=$description");
    
    // 插入数据到finance表
    $sql = "INSERT INTO finance (type, amount, member_id, description, payment_status, operator_id, created_at, updated_at) 
            VALUES (:type, :amount, :member_id, :description, :payment_status, :operator_id, :created_at, :updated_at)";
    
    try {
        $stmt = $db->prepare($sql);
        
        if (!$stmt) {
            error_log("SQL prepare failed: " . print_r($db->errorInfo(), true));
            throw new PDOException("SQL prepare failed");
        }
        
        $stmt->bindParam(':type', $type, PDO::PARAM_INT);
        $stmt->bindParam(':amount', $amount, PDO::PARAM_STR);
        $stmt->bindParam(':member_id', $memberId, PDO::PARAM_INT);
        $stmt->bindParam(':description', $description, PDO::PARAM_STR);
        $stmt->bindParam(':payment_status', $paymentStatus, PDO::PARAM_INT);
        $stmt->bindParam(':operator_id', $operatorId, PDO::PARAM_INT);
        $stmt->bindParam(':created_at', $currentTime);
        $stmt->bindParam(':updated_at', $currentTime);
        
        // 记录最终SQL
        $debug_sql = "INSERT INTO finance (type, amount, member_id, description, payment_status, operator_id, created_at, updated_at) 
                VALUES ($type, '$amount', $memberId, '$description', $paymentStatus, $operatorId, '$currentTime', '$currentTime')";
        error_log("Debug SQL: $debug_sql");
        
        $result = $stmt->execute();
        
        if ($result) {
            // 获取新插入记录的ID
            $financeId = $db->lastInsertId();
            error_log("Payment record created successfully with ID: $financeId");
            
            // 发送Telegram通知
            $notifyUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://" . $_SERVER['HTTP_HOST'] . "/bot/Source.php?id=2";
            error_log("正在发送Telegram通知: $notifyUrl");
            
            // 使用file_get_contents发送通知请求
            $notifyResult = @file_get_contents($notifyUrl);
            error_log("Telegram通知结果: " . ($notifyResult !== false ? $notifyResult : '发送失败'));
            
            echo json_encode(['status' => 'success', 'message' => '支付请求已提交', 'finance_id' => $financeId]);
        } else {
            error_log("Failed to insert payment record: " . print_r($stmt->errorInfo(), true));
            echo json_encode(['status' => 'error', 'message' => '支付记录失败']);
        }
    } catch (PDOException $ex) {
        error_log("PDO statement error: " . $ex->getMessage());
        throw $ex; // 重新抛出异常以便外部捕获
    }
    
} catch (PDOException $e) {
    // 记录详细错误信息
    error_log("支付处理错误: " . $e->getMessage() . "\n" . $e->getTraceAsString());
    echo json_encode(['status' => 'error', 'message' => '支付处理失败，请稍后重试: ' . $e->getMessage()]);
}
?>
