<?php
// 产品页面的逻辑处理代码
require_once '../config/database.php'; // 添加数据库连接文件

// 处理产品相关的所有逻辑
function getProductData() {
    // 获取请求参数
    $serverType = isset($_GET['server_type']) ? intval($_GET['server_type']) : 0;
    $region = isset($_GET['region']) ? intval($_GET['region']) : 0;
    $parentRegion = isset($_GET['parent_region']) ? intval($_GET['parent_region']) : 0;
    $price = isset($_GET['price']) ? intval($_GET['price']) : 0;
    $sort = isset($_GET['sort']) ? intval($_GET['sort']) : 0;
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
    
    // 如果设置了地区但没有设置父地区，尝试查找父地区
    if ($region > 0 && $parentRegion == 0) {
        // 查询数据库获取该地区的父区域ID
        // 这里使用示例代码，实际应该从数据库查询
        $parentRegion = getRegionParentId($region);
    }
    
    // 构建查询条件
    $conditions = [];
    
    // 添加服务器类型条件
    if ($serverType > 0) {
        $conditions[] = "server_type = $serverType";
    }
    
    // 添加地区条件
    if ($region > 0) {
        $conditions[] = "region_id = $region";
    } elseif ($parentRegion > 0) {
        // 如果只选择了父地区，没有选择具体地区，则查询该父地区下的所有地区
        $conditions[] = "region_parent_id = $parentRegion";
    }
    
    // 添加价格条件
    if ($price > 0) {
        switch ($price) {
            case 1:
                $conditions[] = "price BETWEEN 0 AND 50";
                break;
            case 2:
                $conditions[] = "price BETWEEN 50 AND 100";
                break;
            case 3:
                $conditions[] = "price BETWEEN 100 AND 200";
                break;
            case 4:
                $conditions[] = "price > 200";
                break;
        }
    }
    
    // 构建WHERE子句
    $whereClause = count($conditions) > 0 ? "WHERE " . implode(" AND ", $conditions) : "";
    
    // 构建ORDER BY子句
    $orderClause = "ORDER BY id DESC"; // 默认排序
    if ($sort > 0) {
        switch ($sort) {
            case 1:
                $orderClause = "ORDER BY price ASC"; // 价格从低到高
                break;
            case 2:
                $orderClause = "ORDER BY price DESC"; // 价格从高到低
                break;
            case 3:
                $orderClause = "ORDER BY created_at DESC"; // 新品优先
                break;
        }
    }
    
    // 构建分页
    $limit = 9; // 每页显示9个产品
    $offset = ($page - 1) * $limit;
    $limitClause = "LIMIT $limit OFFSET $offset";
    
    // 构建完整SQL
    // 注意：这里假设您已经有一个数据库连接
    global $db;
    $sql = "SELECT * FROM products $whereClause $orderClause $limitClause";
    
    // 这里使用示例数据替代实际SQL查询
    // 实际应用中，请使用以下代码从数据库获取数据
    // $products = [];
    // $result = $db->query($sql);
    // while ($row = $result->fetch_assoc()) {
    //     $products[] = $row;
    // }
    
    // 获取地区列表（示例数据）
    $regions = getRegions();
    $parentRegions = getParentRegions();
    
    // 获取服务器类型（示例数据）
    $serverTypes = getServerTypes();
    
    // 获取标签数据（示例数据）
    $allTags = getAllTags();
    
    // 获取总记录数并计算总页数（示例数据）
    $totalCount = 50; // 实际应该查询数据库获得
    $totalPages = ceil($totalCount / $limit);
    
    // 获取选中地区的名称
    $selectedRegionName = "全部";
    if ($region > 0) {
        foreach ($regions as $r) {
            if ($r['id'] == $region) {
                $selectedRegionName = $r['name'];
                break;
            }
        }
    } elseif ($parentRegion > 0) {
        foreach ($parentRegions as $pr) {
            if ($pr['id'] == $parentRegion) {
                $selectedRegionName = $pr['name'];
                break;
            }
        }
    }
    
    // 模拟产品数据
    $products = getExampleProducts($serverType, $region, $parentRegion, $price, $sort, $page, $limit);
    
    // 返回所有数据
    return [
        'selectedServerType' => $serverType,
        'selectedRegion' => $region,
        'selectedParent' => $parentRegion,
        'selectedRegionName' => $selectedRegionName,
        'currentPage' => $page,
        'totalPages' => $totalPages,
        'products' => $products,
        'regions' => $regions,
        'serverTypes' => $serverTypes,
        'allTags' => $allTags,
        'parentRegions' => $parentRegions,
    ];
}

// 辅助函数：获取地区列表（示例数据）
function getRegions() {
    // 实际应该从数据库查询
    return [
        ['id' => 1, 'name' => '香港区域1', 'parent_id' => 1],
        ['id' => 2, 'name' => '香港区域2', 'parent_id' => 1],
        ['id' => 3, 'name' => '香港区域3', 'parent_id' => 1],
        ['id' => 4, 'name' => '台湾区域1', 'parent_id' => 2],
        ['id' => 5, 'name' => '台湾区域2', 'parent_id' => 2],
        ['id' => 6, 'name' => '日本区域1', 'parent_id' => 3],
        ['id' => 7, 'name' => '日本区域2', 'parent_id' => 3],
        ['id' => 8, 'name' => '新加坡区域', 'parent_id' => 4],
        ['id' => 9, 'name' => '韩国区域', 'parent_id' => 5],
        ['id' => 10, 'name' => '美国西部', 'parent_id' => 6],
        ['id' => 11, 'name' => '美国东部', 'parent_id' => 6],
    ];
}

// 辅助函数：获取父地区列表（示例数据）
function getParentRegions() {
    // 实际应该从数据库查询
    return [
        ['id' => 1, 'name' => '香港'],
        ['id' => 2, 'name' => '台湾'],
        ['id' => 3, 'name' => '日本'],
        ['id' => 4, 'name' => '新加坡'],
        ['id' => 5, 'name' => '韩国'],
        ['id' => 6, 'name' => '美国'],
    ];
}

// 辅助函数：获取服务器类型（示例数据）
function getServerTypes() {
    // 实际应该从数据库查询
    return [
        ['id' => 1, 'name' => '高防服务器'],
        ['id' => 2, 'name' => '云服务器'],
        ['id' => 3, 'name' => '站群服务器'],
        ['id' => 4, 'name' => '游戏服务器'],
        ['id' => 5, 'name' => '独立服务器'],
    ];
}

// 辅助函数：获取所有标签（示例数据）
function getAllTags() {
    // 实际应该从数据库查询
    return [
        1 => '高性能',
        2 => '高防护',
        3 => '低延迟',
        4 => '大带宽',
        5 => '独享资源',
        6 => '企业级',
        7 => '特惠',
        8 => '新品',
    ];
}

// 辅助函数：根据地区ID获取父地区ID（示例数据）
function getRegionParentId($regionId) {
    $regions = getRegions();
    foreach ($regions as $region) {
        if ($region['id'] == $regionId && isset($region['parent_id'])) {
            return $region['parent_id'];
        }
    }
    return 0;
}

// 辅助函数：获取示例产品数据
function getExampleProducts($serverType, $region, $parentRegion, $price, $sort, $page, $limit) {
    // 实际应该从数据库查询
    $products = [];
    
    // 生成示例产品
    for ($i = 1; $i <= $limit; $i++) {
        $productId = ($page - 1) * $limit + $i;
        
        // 为不同地区设置不同的名称
        $regionId = $region > 0 ? $region : rand(1, 11);
        $regionName = '未知地区';
        $regions = getRegions();
        foreach ($regions as $r) {
            if ($r['id'] == $regionId) {
                $regionName = $r['name'];
                break;
            }
        }
        
        // 随机生成线路名称
        $lineNames = ['BGP优化', 'CN2 GIA', '三网直连', 'IPLC专线', '双向CN2', '阿里云专线'];
        $lineId = rand(0, count($lineNames) - 1);
        $lineName = $lineNames[$lineId];
        
        // 随机生成价格，根据价格条件筛选
        $price = rand(30, 300);
        if ($price == 1 && $price > 50) continue;
        if ($price == 2 && ($price < 50 || $price > 100)) continue;
        if ($price == 3 && ($price < 100 || $price > 200)) continue;
        if ($price == 4 && $price <= 200) continue;
        
        // 随机生成标签
        $tagCount = rand(1, 3);
        $tags = [];
        for ($j = 0; $j < $tagCount; $j++) {
            $tags[] = rand(1, 8);
        }
        $tagString = implode(',', array_unique($tags));
        
        // 添加产品数据
        $products[] = [
            'id' => $productId,
            'product_code' => 'SV' . str_pad($productId, 5, '0', STR_PAD_LEFT),
            'product_type' => $serverType > 0 ? getServerTypes()[$serverType - 1]['name'] : '高防服务器',
            'region_id' => $regionId,
            'region_name' => $regionName,
            'line_id' => $lineId,
            'line_name' => $lineName,
            'cpu' => 'Intel Xeon ' . rand(4, 16) . ' 核',
            'memory' => rand(8, 64) . 'GB',
            'disk' => rand(200, 1000) . 'GB SSD',
            'bandwidth' => rand(10, 100) . 'Mbps',
            'traffic' => rand(0, 1) ? '不限流量' : rand(500, 5000) . 'GB/月',
            'ip_count' => rand(1, 8),
            'price' => $price,
            'original_price' => rand(0, 1) ? $price + rand(10, 50) : null,
            'tags' => $tagString,
            'defence' => rand(0, 1) ? rand(10, 100) . 'Gbps' : '可选',
            'line_type' => $lineName,
        ];
    }
    
    // 根据排序参数对产品进行排序
    if ($sort > 0) {
        usort($products, function($a, $b) use ($sort) {
            switch ($sort) {
                case 1:
                    return $a['price'] - $b['price']; // 价格从低到高
                case 2:
                    return $b['price'] - $a['price']; // 价格从高到低
                case 3:
                    return rand(-1, 1); // 模拟新品排序
                default:
                    return 0;
            }
        });
    }
    
    return $products;
}
