<?php
require_once __DIR__ . '/../code/auth.php';
requireLogin();

$username = getCurrentUsername();
$userInfo = getCurrentUserInfo() ?? [
    'id' => 0,
    'username' => '未知用户',
    'avatar' => 'https://placehold.co/80x80'
];

// 初始化统计数据默认值
$ticketCount = 0;
$billCount = 0;
$expiringCount = 0;
$serverCounts = [
    'cloud_count' => 0,
    'dedicated_count' => 0,
    'cluster_count' => 0,
    'protected_count' => 0
];

// 获取用户统计数据
require_once __DIR__ . '/../../config/database.php';
try {
    $db = getDbConnection();
    
    // 获取工单数量
    $stmt = $db->prepare("SELECT COUNT(*) FROM tickets WHERE user_id = ? AND status = 'pending'");
    if ($stmt->execute([getCurrentUserId()])) {
        $ticketCount = $stmt->fetchColumn() ?: 0;
    }
    
    // 获取消费明细数量
    $stmt = $db->prepare("SELECT COUNT(*) FROM bills WHERE user_id = ?");
    if ($stmt->execute([getCurrentUserId()])) {
        $billCount = $stmt->fetchColumn() ?: 0;
    }
    
    // 获取7天内到期的服务器数量
    $stmt = $db->prepare("
        SELECT COUNT(*) 
        FROM servers 
        WHERE user_id = ? 
        AND status = 1 
        AND expiry_date BETWEEN NOW() AND DATE_ADD(NOW(), INTERVAL 7 DAY)
    ");
    if ($stmt->execute([getCurrentUserId()])) {
        $expiringCount = $stmt->fetchColumn() ?: 0;
    }
    
    // 获取各类型服务器数量
    $stmt = $db->prepare("
        SELECT type, COUNT(*) as count 
        FROM servers 
        WHERE user_id = ? AND status = 1 
        GROUP BY type
    ");
    if ($stmt->execute([getCurrentUserId()])) {
        $servers = $stmt->fetchAll(PDO::FETCH_ASSOC);
        foreach ($servers as $server) {
            switch ($server['type']) {
                case 'cloud':
                    $serverCounts['cloud_count'] = $server['count'];
                    break;
                case 'dedicated':
                    $serverCounts['dedicated_count'] = $server['count'];
                    break;
                case 'cluster':
                    $serverCounts['cluster_count'] = $server['count'];
                    break;
                case 'protected':
                    $serverCounts['protected_count'] = $server['count'];
                    break;
            }
        }
    }
} catch (PDOException $e) {
    error_log("Error fetching user stats: " . $e->getMessage());
}
?>
