<?php
require_once 'auth.php';
require_once 'publi.php';
require_once '../config/database.php'; // 引入数据库配置文件

// 检查用户是否已登录
if (!isset($_SESSION['user_id']) || empty($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

// 获取当前用户信息
$userId = $_SESSION['user_id'];
$userName = isset($_SESSION['user_name']) ? $_SESSION['user_name'] : '';
$userEmail = isset($_SESSION['user_email']) ? $_SESSION['user_email'] : '';

// 处理表单提交
$message = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 验证和获取表单数据
        $subject = trim($_POST['subject'] ?? '');
        $priority = $_POST['priority'] ?? 'medium';
        $message = trim($_POST['message'] ?? '');
        
        // 验证数据
        if (empty($subject)) {
            $error = '请输入工单主题';
        } elseif (empty($message)) {
            $error = '请输入工单内容';
        } else {
            // 开始事务
            $db->beginTransaction();
            
            // 插入工单记录到tickets表，确保包含user_id，不要包含message字段
            $insertTicketQuery = "INSERT INTO tickets (user_id, subject, priority, status, created_at, updated_at, last_reply) 
                                 VALUES (:user_id, :subject, :priority, 'open', NOW(), NOW(), NOW())";
            $stmt = $db->prepare($insertTicketQuery);
            $stmt->bindParam(':user_id', $userId, PDO::PARAM_INT);
            $stmt->bindParam(':subject', $subject, PDO::PARAM_STR);
            $stmt->bindParam(':priority', $priority, PDO::PARAM_STR);
            $stmt->execute();
            
            // 获取新插入的工单ID
            $ticketId = $db->lastInsertId();
            
            // 生成会话ID
            $conversationId = 'TKT' . date('YmdHis') . rand(1000, 9999);
            
            // 更新工单的conversation_id
            $updateTicketQuery = "UPDATE tickets SET conversation_id = :conversation_id WHERE id = :ticket_id";
            $stmt = $db->prepare($updateTicketQuery);
            $stmt->bindParam(':conversation_id', $conversationId, PDO::PARAM_STR);
            $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
            $stmt->execute();
            
            // 插入第一条回复消息到ticket_replies表
            $insertReplyQuery = "INSERT INTO ticket_replies (ticket_id, user_id, conversation_id, message, created_at) 
                               VALUES (:ticket_id, :user_id, :conversation_id, :message, NOW())";
            $stmt = $db->prepare($insertReplyQuery);
            $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
            $stmt->bindParam(':user_id', $userId, PDO::PARAM_INT);
            $stmt->bindParam(':conversation_id', $conversationId, PDO::PARAM_STR);
            $stmt->bindParam(':message', $message, PDO::PARAM_STR);
            $stmt->execute();
            
            // 处理附件上传
            if (!empty($_FILES['attachments']['name'][0])) {
                // 使用相对路径，更简单可靠
                $uploadDir = '../uploads/tickets/';
                $absoluteUploadDir = realpath(dirname(__FILE__) . '/../../') . '/uploads/tickets/';
                
                // 输出调试信息
                error_log("上传目录相对路径：" . $uploadDir);
                error_log("上传目录绝对路径：" . $absoluteUploadDir);
                
                // 如果目录不存在则创建
                if (!file_exists($absoluteUploadDir)) {
                    if (!mkdir($absoluteUploadDir, 0777, true)) {
                        throw new Exception('无法创建上传目录：' . $absoluteUploadDir);
                    }
                    // 确保创建后的目录具有正确的权限
                    chmod($absoluteUploadDir, 0777);
                }
                
                // 检查目录是否可写
                if (!is_writable($absoluteUploadDir)) {
                    error_log("目录不可写，尝试修改权限：" . $absoluteUploadDir);
                    chmod($absoluteUploadDir, 0777);
                    if (!is_writable($absoluteUploadDir)) {
                        throw new Exception('上传目录没有写入权限：' . $absoluteUploadDir);
                    }
                }
                
                // 允许的文件类型
                $allowedTypes = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif', 'application/pdf', 'application/zip'];
                $maxFileSize = 1024 * 1024; // 1MB
                
                $attachmentsData = [];
                
                // 循环处理每个上传的文件
                foreach ($_FILES['attachments']['name'] as $key => $filename) {
                    if (empty($filename)) continue;
                    
                    $tmpName = $_FILES['attachments']['tmp_name'][$key];
                    $fileSize = $_FILES['attachments']['size'][$key];
                    $fileType = $_FILES['attachments']['type'][$key];
                    
                    // 检查文件类型
                    if (!in_array($fileType, $allowedTypes)) {
                        throw new Exception('文件类型不允许：' . $filename);
                    }
                    
                    // 检查文件大小
                    if ($fileSize > $maxFileSize) {
                        throw new Exception('文件大小超过限制：' . $filename);
                    }
                    
                    // 生成唯一的文件名
                    $newFilename = uniqid() . '_' . preg_replace('/[^a-zA-Z0-9\.]/', '_', $filename);
                    $destinationRelative = $uploadDir . $newFilename;
                    $destinationAbsolute = $absoluteUploadDir . $newFilename;
                    
                    error_log("尝试上传文件：" . $tmpName . " 到 " . $destinationRelative);
                    
                    // 尝试使用相对路径
                    if (move_uploaded_file($tmpName, $destinationRelative)) {
                        error_log("文件上传成功（相对路径）");
                        $filePathToSave = '/uploads/tickets/' . $newFilename;
                    } else {
                        error_log("相对路径上传失败，尝试使用绝对路径");
                        // 如果相对路径失败，尝试使用绝对路径
                        if (move_uploaded_file($tmpName, $destinationAbsolute)) {
                            error_log("文件上传成功（绝对路径）");
                            $filePathToSave = '/uploads/tickets/' . $newFilename;
                        } else {
                            // 获取详细错误信息
                            $error_message = '文件上传失败：' . $filename;
                            $error_message .= '，临时文件路径：' . $tmpName;
                            $error_message .= '，相对目标路径：' . $destinationRelative;
                            $error_message .= '，绝对目标路径：' . $destinationAbsolute;
                            $error_message .= '，错误代码：' . (isset($_FILES['attachments']['error'][$key]) ? $_FILES['attachments']['error'][$key] : 'unknown');
                            
                            // 检查临时文件是否存在
                            if (!file_exists($tmpName)) {
                                $error_message .= '，临时文件不存在';
                            }
                            
                            // 检查PHP进程的用户
                            if (function_exists('posix_getpwuid') && function_exists('posix_geteuid')) {
                                $processUser = posix_getpwuid(posix_geteuid());
                                $error_message .= '，PHP进程用户：' . ($processUser['name'] ?? 'unknown');
                            }
                            
                            // 尝试获取更详细的错误信息
                            if (function_exists('error_get_last')) {
                                $last_error = error_get_last();
                                if ($last_error) {
                                    $error_message .= '，PHP错误：' . print_r($last_error, true);
                                }
                            }
                            
                            throw new Exception($error_message);
                        }
                    }
                    
                    // 保存附件信息到数据库，关联到工单
                    $insertAttachmentQuery = "INSERT INTO ticket_attachments (ticket_id, reply_id, file_name, file_path, file_type, file_size, created_at) 
                                            VALUES (:ticket_id, NULL, :file_name, :file_path, :file_type, :file_size, NOW())";
                    $stmt = $db->prepare($insertAttachmentQuery);
                    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
                    $stmt->bindParam(':file_name', $filename, PDO::PARAM_STR);
                    $stmt->bindParam(':file_path', $filePathToSave, PDO::PARAM_STR);
                    $stmt->bindParam(':file_type', $fileType, PDO::PARAM_STR);
                    $stmt->bindParam(':file_size', $fileSize, PDO::PARAM_INT);
                    $stmt->execute();
                    
                    // 保存附件信息到数组，用于JSON存储
                    $attachmentsData[] = [
                        'name' => $filename,
                        'path' => $filePathToSave,
                        'type' => $fileType,
                        'size' => $fileSize
                    ];
                }
                
                // 如果有附件，更新ticket_replies表中的attachments字段
                if (!empty($attachmentsData)) {
                    $attachmentsJson = json_encode($attachmentsData);
                    
                    // 获取刚刚插入的回复ID
                    $replyId = $db->lastInsertId();
                    
                    $updateReplyQuery = "UPDATE ticket_replies SET attachments = :attachments WHERE ticket_id = :ticket_id AND user_id = :user_id ORDER BY created_at DESC LIMIT 1";
                    $stmt = $db->prepare($updateReplyQuery);
                    $stmt->bindParam(':attachments', $attachmentsJson, PDO::PARAM_STR);
                    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
                    $stmt->bindParam(':user_id', $userId, PDO::PARAM_INT);
                    $stmt->execute();
                }
            }
            
            // 提交事务
            $db->commit();
            
            // 设置成功消息并重定向
            $_SESSION['success_message'] = '工单提交成功！';
            header("Location: ticket_detail.php?id=$ticketId");
            exit;
        }
    } catch (Exception $e) {
        // 回滚事务
        if (isset($db) && $db->inTransaction()) {
            $db->rollBack();
        }
        
        // 记录错误日志
        error_log("工单提交错误: " . $e->getMessage());
        $error = "提交工单时出错：" . $e->getMessage();
    }
}
?>
