<!DOCTYPE html>
<html lang="zh-CN">
  <?php
require_once 'code/auth.php';
require_once 'code/publi.php';
require_once 'code/finance_code.php';
?>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员中心 - 财务记录</title>
    <?php include 'public/head.php'; ?>
    <link rel="stylesheet" href="css/style.css">
    <link rel="stylesheet" href="css/finance.css">
    <!-- 添加 Font Awesome 引用 -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
  </head>
  <body>
    <div class="container">
      <?php include 'public/left.php'; ?>
      <div class="main">
        <!-- 将汉堡菜单按钮移到这里 -->
        <button class="menu-toggle" id="menuToggle">
          <i class="fas fa-bars"></i>
        </button>
        <?php include 'public/header.php'; ?>
        <!-- 面包屑导航 -->
        <div class="breadcrumb-container">
          <div class="breadcrumb">
            <a href="index.php" class="breadcrumb-link">
              <i class="fas fa-home"></i>
              会员中心
            </a>
            <span class="breadcrumb-separator"><i class="fas fa-angle-right"></i></span>
            <span class="breadcrumb-current">
              财务记录
            </span>
          </div>
        </div>

        <div class="content-wrapper">
          <div class="bill-container">
            <div class="account-balance">
              <span class="balance-label">当前余额：</span>
              <span class="balance-amount"><?php echo formatAmount($balance); ?></span>
            </div>
            <div class="recharge-section">
              <a href="recharge.php" class="recharge-btn">
                <i class="fas fa-money-bill-wave" style="margin-right: 5px;"></i> 我要充值
              </a>
            </div>
            <table class="bill-table">
              <thead>
                <tr>
                  <th>交易ID</th>
                  <th>交易类型</th>
                  <th>金额</th>
                  <th>说明</th>
                  <th>操作员</th>
                  <th>支付状态</th>
                  <th>创建时间</th>
                  <th>更新时间</th>
                </tr>
              </thead>
              <tbody>
                <?php if (empty($financeRecords)): ?>
                <tr>
                  <td colspan="8" class="no-records">暂无财务记录</td>
                </tr>
                <?php else: ?>
                <?php foreach ($financeRecords as $record): ?>
                <tr>
                  <td><?php echo htmlspecialchars((string)$record['id']); ?></td>
                  <td><?php echo getTransactionTypeText($record['type']); ?></td>
                  <td class="<?php echo $record['amount'] >= 0 ? 'amount-positive' : 'amount-negative'; ?>">
                    <?php echo formatAmount($record['amount']); ?>
                  </td>
                  <td><?php echo htmlspecialchars((string)($record['description'] ?? '')); ?></td>
                  <td><?php echo htmlspecialchars((string)($record['operator_name'] ?? '系统')); ?></td>
                  <td class="status-<?php echo $record['payment_status'] == 1 ? 'paid' : 'unpaid'; ?>">
                    <?php echo getPaymentStatusText($record['payment_status']); ?>
                  </td>
                  <td><?php echo isset($record['created_at']) && $record['created_at'] ? date('Y-m-d H:i:s', strtotime($record['created_at'])) : ''; ?></td>
                  <td><?php echo isset($record['updated_at']) && $record['updated_at'] ? date('Y-m-d H:i:s', strtotime($record['updated_at'])) : ''; ?></td>
                </tr>
                <?php endforeach; ?>
                <?php endif; ?>
              </tbody>
            </table>
            <!-- 底部控制区域 -->
            <div class="bill-footer">
              <div class="bill-actions">
                <span class="page-info">每页显示:</span>
                <form id="perPageForm" method="get" action="">
                  <select name="perPage" onchange="document.getElementById('perPageForm').submit()">
                    <option value="10" <?php echo $recordsPerPage == 10 ? 'selected' : ''; ?>>10</option>
                    <option value="20" <?php echo $recordsPerPage == 20 ? 'selected' : ''; ?>>20</option>
                    <option value="50" <?php echo $recordsPerPage == 50 ? 'selected' : ''; ?>>50</option>
                  </select>
                  <input type="hidden" name="page" value="<?php echo $currentPage; ?>">
                </form>
                <span>条</span>
              </div>
              <?php if ($totalPages > 1): ?>
              <div class="pagination">
                <?php if ($currentPage > 1): ?>
                <a href="?page=<?php echo $currentPage - 1; ?>&perPage=<?php echo $recordsPerPage; ?>">上一页</a>
                <?php endif; ?>

                <?php
                // 确定要显示的页码范围
                $startPage = max(1, $currentPage - 2);
                $endPage = min($totalPages, $startPage + 4);
                
                // 如果页码范围不足5个，则调整起始页
                if ($endPage - $startPage < 4) {
                    $startPage = max(1, $endPage - 4);
                }
                
                // 输出页码
                for ($i = $startPage; $i <= $endPage; $i++):
                ?>
                <a href="?page=<?php echo $i; ?>&perPage=<?php echo $recordsPerPage; ?>"
                   class="<?php echo $i == $currentPage ? 'active' : ''; ?>">
                  <?php echo $i; ?>
                </a>
                <?php endfor; ?>

                <?php if ($endPage < $totalPages): ?>
                <span>...</span>
                <a href="?page=<?php echo $totalPages; ?>&perPage=<?php echo $recordsPerPage; ?>">
                  <?php echo $totalPages; ?>
                </a>
                <?php endif; ?>

                <?php if ($currentPage < $totalPages): ?>
                <a href="?page=<?php echo $currentPage + 1; ?>&perPage=<?php echo $recordsPerPage; ?>">下一页</a>
                <?php endif; ?>
              </div>
              <?php endif; ?>
            </div>
          </div>
        </div>
      </div>
    </div>
    <!-- 基础脚本 -->
    <script src="js/main.js"></script>
    <script src="js/js.js"></script>
    <script src="js/finance.js"></script>
  </body>
</html>
