/**
 * chat-scroll-helper.js
 * 帮助确保聊天容器始终滚动到最新消息
 */

(function() {
    // 全局滚动函数
    window.scrollChatToBottom = function() {
        const chatMessages = document.querySelector('.chat-messages');
        if (chatMessages) {
            chatMessages.scrollTop = chatMessages.scrollHeight;
        }
    };

    // 初始化函数
    function initChatScroll() {
        const chatMessages = document.querySelector('.chat-messages');
        if (!chatMessages) return;

        // 初始滚动到底部
        scrollChatToBottom();

        // 监听窗口大小变化
        window.addEventListener('resize', scrollChatToBottom);

        // 监听消息变化
        if (window.MutationObserver) {
            const observer = new MutationObserver(function(mutations) {
                scrollChatToBottom();
            });

            observer.observe(chatMessages, {
                childList: true,
                subtree: true
            });
        }

        // 图片加载后滚动
        document.addEventListener('load', function(e) {
            if (e.target.tagName === 'IMG') {
                scrollChatToBottom();
            }
        }, true);
    }

    // 页面加载完成后初始化
    if (document.readyState === 'loading') {
        document.addEventListener('DOMContentLoaded', initChatScroll);
    } else {
        initChatScroll();
    }
})(); 