/**
 * 产品卡片轮播功能
 * 实现每5秒自动切换一次产品卡片
 */
document.addEventListener('DOMContentLoaded', function() {
  // 获取轮播容器和所有产品卡片
  const carousel = document.querySelector('.product-carousel');
  if (!carousel) return;

  const productCards = carousel.querySelectorAll('.product-card');
  if (!productCards.length) return;

  let currentIndex = 0;
  const totalCards = productCards.length;

  // 延迟初始化，确保DOM完全加载
  setTimeout(initCarousel, 100);

  // 设置定时器，每5秒轮播一次
  let interval = setInterval(rotateProducts, 5000);

  // 初始化轮播样式
  function initCarousel() {
    // 先重置所有卡片样式以便正确计算高度
    productCards.forEach(card => {
      card.style.position = 'static';
      card.style.opacity = '1';
      card.style.display = 'flex';
      card.style.flexDirection = 'column';
    });
    
    // 计算最佳高度
    let maxHeight = 0;
    productCards.forEach(card => {
      const cardHeight = card.offsetHeight;
      if (cardHeight > maxHeight) {
        maxHeight = cardHeight;
      }
    });
    
    // 设置容器样式
    carousel.style.position = 'relative';
    carousel.style.overflow = 'hidden';
    carousel.style.width = '100%';
    carousel.style.height = maxHeight + 'px';

    // 设置所有卡片的样式
    productCards.forEach((card, index) => {
      card.style.position = 'absolute';
      card.style.top = '0';
      card.style.left = '0';
      card.style.width = '100%';
      card.style.height = maxHeight + 'px';
      card.style.transition = 'opacity 0.5s ease-in-out';
      
      // 让产品按钮容器和按钮宽度设置为100%确保布局正确
      const buttonContainer = card.querySelector('.product-buttons');
      if (buttonContainer) {
        buttonContainer.style.width = '100%';
        buttonContainer.style.display = 'flex';
        const buttons = buttonContainer.querySelectorAll('.product-btn');
        buttons.forEach(btn => {
          btn.style.flex = '1';
        });
      }
      
      // 只显示第一个卡片
      if (index === 0) {
        card.style.opacity = '1';
        card.style.zIndex = '1';
      } else {
        card.style.opacity = '0';
        card.style.zIndex = '0';
      }
    });
  }

  // 轮播函数
  function rotateProducts() {
    // 当前显示的卡片
    const currentCard = productCards[currentIndex];
    
    // 计算下一个卡片的索引
    const nextIndex = (currentIndex + 1) % totalCards;
    const nextCard = productCards[nextIndex];
    
    // 淡出当前卡片
    currentCard.style.opacity = '0';
    currentCard.style.zIndex = '0';
    
    // 淡入下一个卡片
    nextCard.style.opacity = '1';
    nextCard.style.zIndex = '1';
    
    // 更新当前索引
    currentIndex = nextIndex;
  }

  // 鼠标悬停时暂停轮播，移开时继续
  carousel.addEventListener('mouseenter', () => {
    clearInterval(interval);
  });
  
  carousel.addEventListener('mouseleave', () => {
    clearInterval(interval);
    interval = setInterval(rotateProducts, 5000);
  });
  
  // 窗口大小变化时重新计算高度
  window.addEventListener('resize', () => {
    // 延迟执行以确保DOM更新完成
    setTimeout(initCarousel, 100);
  });
});
