document.addEventListener('DOMContentLoaded', function() {
  // 获取所有按钮元素
  const telegramBtn = document.querySelector('.telegram-btn');
  const ticketBtn = document.querySelector('.chat-btn');
  const backToTopBtn = document.querySelector('.back-to-top');
  const chatContainer = document.getElementById('ticketFormContainer');
  const closeChat = document.getElementById('closeTicketForm');
  const maximizeChat = document.getElementById('maximizeChat');
  const messageInput = document.getElementById('messageInput');
  const sendButton = document.getElementById('sendMessage');
  const chatMessages = document.getElementById('chatMessages');
  console.log('Telegram按钮:', telegramBtn);
  console.log('在线客服按钮:', ticketBtn);
  console.log('聊天窗口:', chatContainer);
  console.log('最大化按钮:', maximizeChat);
  // 窗口最大化/还原功能
  let isMaximized = false;
  if (maximizeChat) {
    // 强制更新初始图标
    maximizeChat.innerHTML = '<i class="fas fa-expand-alt"></i>';
    maximizeChat.addEventListener('click', function(e) {
      e.preventDefault();
      e.stopPropagation();
      console.log('最大化按钮被点击');
      isMaximized = !isMaximized;
      if (isMaximized) {
        chatContainer.classList.add('maximized');
        maximizeChat.innerHTML = '<i class="fas fa-compress-alt"></i>';
        console.log('窗口已最大化');
      } else {
        chatContainer.classList.remove('maximized');
        maximizeChat.innerHTML = '<i class="fas fa-expand-alt"></i>';
        console.log('窗口已还原');
      }
      // 滚动到最新消息
      if (chatMessages) {
        chatMessages.scrollTop = chatMessages.scrollHeight;
      }
    });
  }
  // Telegram按钮点击事件
  if (telegramBtn) {
    telegramBtn.addEventListener('click', function(e) {
      console.log('Telegram按钮被点击');
      const telegramUrl = telegramBtn.getAttribute('href');
      console.log('Telegram URL:', telegramUrl);
      window.open(telegramUrl, '_blank');
    });
  }
  // 在线客服按钮点击事件
  if (ticketBtn) {
    ticketBtn.onclick = function(e) {
      e.preventDefault();
      if (chatContainer) {
        chatContainer.style.display = 'flex';
        chatContainer.classList.add('active');
        // 确保窗口初始状态正确
        if (isMaximized) {
          chatContainer.classList.add('maximized');
          if (maximizeChat) {
            maximizeChat.innerHTML = '<i class="fas fa-compress-alt"></i>';
          }
        } else {
          chatContainer.classList.remove('maximized');
          if (maximizeChat) {
            maximizeChat.innerHTML = '<i class="fas fa-expand-alt"></i>';
          }
        }
        if (chatMessages) {
          chatMessages.scrollTop = chatMessages.scrollHeight;
        }
      }
    };
  }
  // 返回顶部按钮事件
  if (backToTopBtn) {
    window.addEventListener('scroll', function() {
      if (window.pageYOffset > 300) {
        backToTopBtn.classList.add('visible');
      } else {
        backToTopBtn.classList.remove('visible');
      }
    });
    backToTopBtn.onclick = function(e) {
      e.preventDefault();
      window.scrollTo({
        top: 0,
        behavior: 'smooth'
      });
    };
  }
  // 创建输入中提示元素
  const typingIndicator = document.createElement('div');
  typingIndicator.className = 'typing-indicator message service';
  typingIndicator.innerHTML = `
    <div class="message-content">
      <span></span>
      <span></span>
      <span></span>
    </div>
  `;
  // 自动调整文本框高度
  if (messageInput) {
    messageInput.addEventListener('input', function() {
      this.style.height = 'auto';
      this.style.height = Math.min(this.scrollHeight, 120) + 'px';
    });
  }
  // 关闭聊天窗口
  if (closeChat) {
    closeChat.addEventListener('click', function() {
      chatContainer.classList.remove('active');
      setTimeout(() => {
        chatContainer.style.display = 'none';
      }, 300);
    });
  }
  // 发送消息
  function sendMessage() {
    const message = messageInput.value.trim();
    if (message) {
      // 添加用户消息
      addMessage(message, 'user');
      messageInput.value = '';
      messageInput.style.height = 'auto';
      // 显示输入中提示
      chatMessages.appendChild(typingIndicator);
      scrollToBottom();
      // 模拟客服回复
      setTimeout(() => {
        // 移除输入中提示
        typingIndicator.remove();
        const replies = ['好的，让我为您详细介绍一下这个问题。', '这个问题我很清楚，您看是这样的...', '您说得对，关于这一点，我建议您可以...', '好的，我明白您的需求，让我来帮您处理。', '这个情况比较特殊，需要我们技术团队进一步评估，您方便留下联系方式吗？', '感谢您的咨询，针对这个问题，我们有以下解决方案...'];
        const randomReply = replies[Math.floor(Math.random() * replies.length)];
        addMessage(randomReply, 'service');
      }, 2000);
    }
  }
  // 添加消息到聊天界面
  function addMessage(text, type) {
    const messageDiv = document.createElement('div');
    messageDiv.className = `message ${type}`;
    messageDiv.innerHTML = `
      <div class="message-content">
        ${text}
      </div>
    `;
    chatMessages.appendChild(messageDiv);
    scrollToBottom();
  }
  // 滚动到底部
  function scrollToBottom() {
    requestAnimationFrame(() => {
      chatMessages.scrollTop = chatMessages.scrollHeight;
    });
  }
  // 发送按钮点击事件
  if (sendButton) {
    sendButton.addEventListener('click', sendMessage);
  }
  // 回车发送消息
  if (messageInput) {
    messageInput.addEventListener('keypress', function(e) {
      if (e.key === 'Enter' && !e.shiftKey) {
        e.preventDefault();
        sendMessage();
      }
    });
  }
  // 监听聊天区域内容变化
  if (chatMessages) {
    const chatObserver = new MutationObserver(scrollToBottom);
    chatObserver.observe(chatMessages, {
      childList: true,
      subtree: true
    });
  }
});
