// 确保页面加载后表单状态与URL参数一致
document.addEventListener('DOMContentLoaded', function() {
    // 已经通过PHP设置了初始状态，这里只需确保JS切换功能正常工作
    const loginSwitch = document.querySelector('.switch-login');
    const registerSwitch = document.querySelector('.switch-register');
    const loginForm = document.querySelector('.login-form');
    const registerForm = document.querySelector('.register-form');
    
    // 为每个表单添加消息容器
    [loginForm, registerForm].forEach(form => {
        const messageContainer = document.createElement('div');
        messageContainer.className = 'message-container';
        form.insertBefore(messageContainer, form.firstChild);
    });
    
    // 显示消息的函数
    function showMessage(form, message, isError = false) {
        const container = form.querySelector('.message-container');
        if (container) {
            container.innerHTML = `
                <div class="message ${isError ? 'error-message' : 'success-message'}">
                    ${message}
                </div>
            `;
            setTimeout(() => {
                container.innerHTML = '';
            }, 5000);
        }
    }

    // 提交表单
    async function submitForm(form, action) {
        const button = form.querySelector('button[type="submit"]');
        if (button) {
            button.disabled = true;
            button.textContent = action === 'login' ? '登录中...' : '注册中...';
        }
        
        try {
            const formData = new FormData(form);
            formData.append('action', action);
            
            const response = await fetch(window.location.href, {
                method: 'POST',
                headers: {
                    'X-Requested-With': 'XMLHttpRequest'
                },
                body: formData
            });
            
            const data = await response.json();
            console.log('Server response:', data);
            
            if (data.success) {
                showMessage(form, data.message, false);
                if (action === 'register') {
                    setTimeout(() => loginSwitch.click(), 1500);
                } else if (data.redirect) {
                    // 使用服务器返回的URL进行跳转
                    setTimeout(() => {
                        if (data.redirect_url) {
                            window.location.href = data.redirect_url;
                        } else {
                            window.location.reload();
                        }
                    }, 1500);
                }
            } else {
                showMessage(form, data.message, true);
            }
        } catch (error) {
            console.error('Error:', error);
            showMessage(form, '操作失败，请稍后重试', true);
        }
        
        if (button) {
            button.disabled = false;
            button.textContent = action === 'login' ? '登录' : '注册';
        }
    }

    // 切换到登录表单
    loginSwitch.addEventListener('click', () => {
        loginSwitch.classList.add('active');
        registerSwitch.classList.remove('active');
        loginForm.classList.remove('hidden');
        registerForm.classList.add('hidden');
        document.querySelector('.auth-title').textContent = '欢迎回来';
        // 更新URL，移除参数
        history.replaceState(null, '', window.location.pathname);
    });
    
    // 切换到注册表单
    registerSwitch.addEventListener('click', () => {
        registerSwitch.classList.add('active');
        loginSwitch.classList.remove('active');
        registerForm.classList.remove('hidden');
        loginForm.classList.add('hidden');
        document.querySelector('.auth-title').textContent = '创建账号';
        // 更新URL为注册状态
        history.replaceState(null, '', '?action=register');
    });

    // 处理登录表单提交
    loginForm.addEventListener('submit', function(e) {
        e.preventDefault();
        submitForm(this, 'login');
    });

    // 处理注册表单提交
    registerForm.addEventListener('submit', function(e) {
        e.preventDefault();
        submitForm(this, 'register');
    });
}); 