/**
 * 产品页面JavaScript功能
 */
document.addEventListener('DOMContentLoaded', function() {
  console.log('DOM完全加载，开始初始化下拉菜单');
  // 获取所有下拉菜单元素
  const dropdowns = document.querySelectorAll('.dropdown');
  if (!dropdowns.length) {
    console.error('找不到下拉菜单元素！');
    return;
  }
  console.log(`找到 ${dropdowns.length} 个下拉菜单`);
  // 为每个下拉菜单添加点击事件
  dropdowns.forEach(dropdown => {
    const btn = dropdown.querySelector('.dropdown-btn');
    const content = dropdown.querySelector('.dropdown-content');
    if (!btn || !content) {
      console.error('下拉菜单结构不完整', dropdown);
      return;
    }
    // 按钮点击事件处理
    btn.addEventListener('click', function(e) {
      e.stopPropagation();
      console.log('下拉按钮被点击');
      const isActive = dropdown.classList.contains('active');
      // 关闭所有其他下拉菜单
      document.querySelectorAll('.dropdown.active').forEach(activeDropdown => {
        if (activeDropdown !== dropdown) {
          activeDropdown.classList.remove('active');
          console.log('关闭其他下拉菜单');
        }
      });
      // 切换当前下拉菜单状态
      dropdown.classList.toggle('active');
      console.log(`下拉菜单状态: ${dropdown.classList.contains('active') ? '显示' : '隐藏'}`);
    });
    // 下拉选项点击事件处理
    const items = content.querySelectorAll('.dropdown-item');
    items.forEach(item => {
      item.addEventListener('click', function(e) {
        e.preventDefault();
        e.stopPropagation();
        console.log('选项被点击:', item.textContent.trim());
        // 获取选项数据
        const selectedValue = item.getAttribute('data-value');
        const selectedText = item.textContent.trim();
        // 更新按钮文本
        const btnText = btn.querySelector('span') || btn;
        btnText.textContent = selectedText;
        // 标记选中的选项
        items.forEach(i => i.classList.remove('active'));
        item.classList.add('active');
        // 更新过滤参数并跳转
        updateFilter(item.getAttribute('data-filter-type'), selectedValue);
        // 关闭下拉菜单
        dropdown.classList.remove('active');
      });
    });
  });
  // 处理服务器类型筛选器
  const serverTypeFilters = document.querySelectorAll('.filter-option');
  serverTypeFilters.forEach(filter => {
    filter.addEventListener('click', function() {
      const filterType = filter.getAttribute('data-filter');
      const value = filter.getAttribute('data-type');
      updateFilter(filterType, value);
    });
  });
  // 点击页面其他地方关闭下拉菜单
  document.addEventListener('click', function(e) {
    dropdowns.forEach(dropdown => {
      if (!dropdown.contains(e.target) && dropdown.classList.contains('active')) {
        dropdown.classList.remove('active');
        console.log('通过页面点击关闭下拉菜单');
      }
    });
  });
  // 处理URL参数更新和跳转
  function updateFilter(filterType, value) {
    if (!filterType) return;
    console.log(`更新过滤器: ${filterType} = ${value}`);
    const url = new URL(window.location.href);
    const params = url.searchParams;
    // 更新参数
    if (value) {
      params.set(filterType, value);
    } else {
      params.delete(filterType);
    }
    // 重置页码
    params.delete('page');
    // 跳转
    window.location.href = url.toString();
  }
  // 初始化选中状态
  function initSelectedItems() {
    const url = new URL(window.location.href);
    const params = url.searchParams;
    // 为服务器类型过滤器设置当前选中项
    const serverTypeParam = params.get('server_type');
    if (serverTypeParam) {
      document.querySelectorAll('.filter-option').forEach(option => {
        if (option.getAttribute('data-type') === serverTypeParam) {
          option.classList.add('active');
        } else {
          option.classList.remove('active');
        }
      });
    }
    // 为其他过滤类型设置当前选中项
    document.querySelectorAll('[data-filter-type]').forEach(item => {
      const filterType = item.getAttribute('data-filter-type');
      const value = item.getAttribute('data-value');
      const paramValue = params.get(filterType);
      if (value === paramValue) {
        // 设置按钮文本
        const dropdown = item.closest('.dropdown');
        if (dropdown) {
          const btn = dropdown.querySelector('.dropdown-btn span') || dropdown.querySelector('.dropdown-btn');
          const selectedText = item.textContent.trim();
          btn.textContent = selectedText;
          // 设置选中状态
          item.classList.add('active');
        }
      }
    });
  }
  // 初始化选中状态
  initSelectedItems();
  // 商品卡片动画效果
  const productCards = document.querySelectorAll('.product-card');
  if (productCards.length) {
    productCards.forEach((card, index) => {
      // 添加延迟动画效果
      card.style.animationDelay = `${index * 0.05}s`;
      card.classList.add('fade-in');
    });
  }
});

/**
 * 产品页面筛选功能前端交互脚本
 */

document.addEventListener('DOMContentLoaded', function() {
    // 处理地区二级联动
    initRegionSelector();
    
    // 获取所有筛选选项
    const filterOptions = document.querySelectorAll('.filter-option:not(.parent-region)');
    
    // 为每个筛选选项添加点击事件（仅用于视觉效果，实际筛选已通过链接实现）
    filterOptions.forEach(option => {
        option.addEventListener('click', function(e) {
            // 因为链接已经设置了href，这里只处理视觉效果
            const parent = this.closest('.filter-options');
            if (parent) {
                // 移除同组中所有选项的active类
                parent.querySelectorAll('.filter-option').forEach(opt => {
                    opt.classList.remove('active');
                });
                
                // 为当前选项添加active类
                this.classList.add('active');
            }
        });
    });
    
    // 清空筛选按钮
    const clearFilterBtn = document.querySelector('.clear-filter');
    if (clearFilterBtn) {
        clearFilterBtn.addEventListener('click', function(e) {
            // 链接已经设置了href，会跳转到产品页面
            // 这里可以添加点击反馈效果
            this.style.opacity = '0.7';
            setTimeout(() => {
                this.style.opacity = '1';
            }, 200);
        });
    }
    
    // 初始化地区选择器
    function initRegionSelector() {
        // 获取所有父地区选项
        const parentRegionOptions = document.querySelectorAll('.parent-region');
        
        // 处理父地区点击事件
        parentRegionOptions.forEach(option => {
            option.addEventListener('click', function(e) {
                e.preventDefault();
                
                // 获取父地区ID
                const parentId = this.getAttribute('data-parent-id');
                
                // 设置样式
                parentRegionOptions.forEach(opt => opt.classList.remove('active'));
                this.classList.add('active');
                
                // 隐藏所有子区域，然后显示当前选中的父区域的子区域
                const subRegions = document.querySelectorAll('.sub-regions');
                subRegions.forEach(subRegion => {
                    subRegion.style.display = 'none';
                });
                
                // 如果选择的是"全部"，则不显示子区域
                if (parentId !== '0') {
                    const targetSubRegions = document.getElementById(`sub-region-${parentId}`);
                    if (targetSubRegions) {
                        targetSubRegions.style.display = 'flex';
                    }
                }
                
                // 如果是"全部"选项，直接跳转
                if (parentId === '0') {
                    window.location.href = `?server_type=${getUrlParam('server_type') || '0'}&region=0`;
                }
            });
        });
        
        // 初始化时，如果已有选中的父区域，则显示其对应的子区域
        const url = new URL(window.location.href);
        const parentRegion = url.searchParams.get('parent_region');
        
        if (parentRegion && parentRegion !== '0') {
            const subRegionContainer = document.getElementById(`sub-region-${parentRegion}`);
            if (subRegionContainer) {
                subRegionContainer.style.display = 'flex';
            }
            
            // 设置父区域为激活状态
            const parentOption = document.querySelector(`.parent-region[data-parent-id="${parentRegion}"]`);
            if (parentOption) {
                parentRegionOptions.forEach(opt => opt.classList.remove('active'));
                parentOption.classList.add('active');
            }
        }
    }
    
    // 辅助函数：获取URL参数
    function getUrlParam(name) {
        const url = new URL(window.location.href);
        return url.searchParams.get(name);
    }
    
    // 更新筛选结果数量显示
    function updateFilterCount() {
        const productCount = document.querySelectorAll('.product-card').length;
        const countElement = document.querySelector('.filter-summary strong');
        if (countElement) {
            countElement.textContent = productCount;
        }
    }
    
    // 检查URL参数，决定是否显示筛选结果统计
    function checkFilterParams() {
        const url = new URL(window.location.href);
        const params = url.searchParams;
        const filterSummary = document.getElementById('filter-summary');
        
        // 检查是否有筛选参数（region, server_type, price, sort等）
        const hasFilter = (params.has('region') && params.get('region') !== '0') || 
                          params.has('parent_region') ||
                          (params.has('server_type') && params.get('server_type') !== '0') || 
                          (params.has('price') && params.get('price') !== '0') || 
                          (params.has('sort') && params.get('sort') !== '0');
        
        // 如果有筛选参数，显示统计信息，否则隐藏
        if (hasFilter && filterSummary) {
            filterSummary.style.display = 'flex';
        } else if (filterSummary) {
            filterSummary.style.display = 'none';
        }
    }
    
    // 初始更新一次筛选结果数量
    updateFilterCount();
    
    // 检查是否应该显示筛选结果统计
    checkFilterParams();
});
