<?php
require_once 'code/auth.php';
require_once 'code/publi.php';
require_once '../config/config.php';
require_once 'code/finance_code.php';

// 检查用户是否登录
requireLogin();

// 获取数据库连接
$pdo = getDbConnection();

// 获取当前用户ID
$user_id = $_SESSION['user_id'] ?? 0;

// 初始化消息变量
$message = '';
$message_type = '';

// 如果表单被提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 获取表单数据
    $group_id = isset($_POST['group_id']) ? trim($_POST['group_id']) : '';
    $group_link = isset($_POST['group_link']) ? trim($_POST['group_link']) : '';
    $telegram_id = isset($_POST['telegram_id']) ? trim($_POST['telegram_id']) : '';
    
    // 数据验证 - 不再检查username
    try {
        // 准备更新语句 - 包含 telegram_id
        $stmt = $pdo->prepare("UPDATE user SET group_id = ?, group_link = ?, telegram_id = ?, updated_at = NOW() WHERE id = ?");
        $result = $stmt->execute([$group_id, $group_link, $telegram_id, $user_id]);
        
        // 处理头像上传
        if (isset($_FILES['avatar']) && $_FILES['avatar']['error'] == 0) {
            $avatar = $_FILES['avatar'];
            $allowed_types = ['image/jpeg', 'image/png'];
            $max_size = 2 * 1024 * 1024; // 2MB
            
            // 检查文件类型和大小
            if (in_array($avatar['type'], $allowed_types) && $avatar['size'] <= $max_size) {
                $file_ext = pathinfo($avatar['name'], PATHINFO_EXTENSION);
                $new_filename = 'avatar_' . $user_id . '_' . time() . '.' . $file_ext;
                $upload_path = 'uploads/avatars/' . $new_filename;
                
                // 确保上传目录存在
                if (!file_exists('uploads/avatars/')) {
                    mkdir('uploads/avatars/', 0777, true);
                }
                
                // 移动上传的文件
                if (move_uploaded_file($avatar['tmp_name'], $upload_path)) {
                    // 更新数据库中的头像路径
                    $stmt = $pdo->prepare("UPDATE user SET avatar = ? WHERE id = ?");
                    $stmt->execute([$upload_path, $user_id]);
                }
            }
        }
        
        if ($result) {
            $message = '会员资料更新成功！';
            $message_type = 'success';
        } else {
            $message = '更新失败，请稍后再试';
            $message_type = 'error';
        }
    } catch (PDOException $e) {
        $message = '系统错误，请联系管理员';
        $message_type = 'error';
    }
}

// 获取用户数据
try {
    $stmt = $pdo->prepare("SELECT * FROM user WHERE id = ?");
    $stmt->execute([$user_id]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$user) {
        die('获取用户信息失败');
    }
} catch (PDOException $e) {
    die('数据库错误: ' . $e->getMessage());
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员资料修改</title>
    <link rel="stylesheet" href="css/style.css">
    <link rel="stylesheet" href="css/modify.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
  </head>
  <body>
    <div class="container">
      <!-- 侧边栏 --> <?php include 'public/left.php'; ?>
      <!-- 主要内容区 -->
	  <?php include 'public/header.php'; ?>	
      <div class="main">
 <div style="padding-top:50px !important;">111</div>
        <div class="content-wrapper">
          <div class="profile-form">
            <?php if (!empty($message)): ?>
            <div class="alert alert-<?php echo $message_type === 'success' ? 'success' : 'danger'; ?>">
              <i class="fas fa-<?php echo $message_type === 'success' ? 'check-circle' : 'exclamation-circle'; ?>" style="margin-right: 10px;"></i>
              <?php echo $message; ?>
            </div>
            <?php endif; ?>
            <form id="profile-form" action="" method="post" enctype="multipart/form-data">
              <div class="avatar-container">
                <div class="avatar-wrapper">
                  <img src="<?php echo !empty($user['avatar']) ? htmlspecialchars($user['avatar']) : 'img/default-avatar.png'; ?>" alt="头像预览" class="avatar-preview" id="avatar-preview">
                  <?php if (isset($user['status'])): ?>
                  <div class="avatar-status <?php echo $user['status'] == 1 ? 'active' : 'inactive'; ?>">
                    <i class="fas fa-<?php echo $user['status'] == 1 ? 'check' : 'times'; ?>"></i>
                  </div>
                  <?php endif; ?>
                </div>
                <div class="avatar-upload">
                  <div style="display:flex;align-items:center;gap:10px;flex-wrap:wrap;">
                    <input type="file" id="avatar" name="avatar" accept="image/*" style="display: none;">
                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('avatar').click();">
                      <i class="fas fa-upload"></i> 选择头像
                    </button>
                  </div>
                  <small class="file-hint"><i class="fas fa-info-circle"></i> 支持 JPG, PNG 格式，最大 2MB</small>
                </div>
              </div>
              <div class="form-row">
                <div class="form-col">
                  <div class="form-group">
                    <label for="username"><i class="fas fa-user"></i> 会员名</label>
                    <div class="form-control-static">
                      <?php echo htmlspecialchars($user['username'] ?? ''); ?>
                    </div>
                  </div>
                </div>
                <div class="form-col">
                  <div class="form-group">
                    <label for="telegram_id"><i class="fab fa-telegram"></i> Telegram ID</label>
                    <input type="text" class="form-control" id="telegram_id" name="telegram_id" placeholder="请输入Telegram ID" value="<?php echo htmlspecialchars($user['telegram_id'] ?? ''); ?>">
                  </div>
                </div>
              </div>
              <div class="form-row">
                <div class="form-col">
                  <div class="form-group">
                    <label for="group_id"><i class="fas fa-users"></i> 群组ID</label>
                    <input type="text" class="form-control" id="group_id" name="group_id" placeholder="请输入群组ID" value="<?php echo htmlspecialchars($user['group_id'] ?? ''); ?>">
                  </div>
                </div>
                <div class="form-col">
                  <div class="form-group">
                    <label for="group_link"><i class="fas fa-link"></i> 群组链接</label>
                    <input type="text" class="form-control" id="group_link" name="group_link" placeholder="请输入群组链接" value="<?php echo htmlspecialchars($user['group_link'] ?? ''); ?>">
                  </div>
                </div>
              </div>
              <div class="form-row">
                <div class="form-col">
                  <div class="time-info">
                    <div><i class="fas fa-calendar-alt"></i> 创建时间: <?php echo isset($user['created_at']) ? date('Y-m-d H:i:s', strtotime($user['created_at'])) : '未知'; ?></div>
                    <div><i class="fas fa-clock"></i> 更新时间: <?php echo isset($user['updated_at']) ? date('Y-m-d H:i:s', strtotime($user['updated_at'])) : '未知'; ?></div>
                  </div>
                </div>
              </div>
              <div class="form-actions">
                <button type="button" class="btn btn-secondary" onclick="resetForm()">
                  <i class="fas fa-undo"></i> 重置
                </button>
                <button type="submit" class="btn btn-primary">
                  <i class="fas fa-save"></i> 保存修改
                </button>
              </div>
            </form>
          </div>
        </div>
      </div>
    </div>
    <!-- 脚本区域 -->
    <script src="js/main.js"></script>
    <script src="js/js.js"></script>
    <script>
    // 页面加载完成后执行
    document.addEventListener('DOMContentLoaded', function() {
      // 初始聚焦第一个输入框
      setTimeout(() => {
        const firstInput = document.querySelector('.form-control');
        if (firstInput) firstInput.focus();
      }, 500);

      // 为所有表单控件添加动态效果
      addFormEffects();
    });

    // 头像预览功能
    document.getElementById('avatar').addEventListener('change', function(e) {
      const file = e.target.files[0];
      if (file) {
        // 验证文件类型和大小
        const validTypes = ['image/jpeg', 'image/png', 'image/jpg'];
        const maxSize = 2 * 1024 * 1024; // 2MB

        if (!validTypes.includes(file.type)) {
          showMessage('请选择JPG或PNG格式的图片', 'danger');
          return;
        }

        if (file.size > maxSize) {
          showMessage('图片大小不能超过2MB', 'danger');
          return;
        }

        const reader = new FileReader();
        reader.onload = function(e) {
          const previewImg = document.getElementById('avatar-preview');
          previewImg.src = e.target.result;
          previewImg.classList.add('preview-animate');

          // 添加闪烁动画后移除
          setTimeout(() => {
            previewImg.classList.remove('preview-animate');
          }, 1000);

          showMessage('头像已选择，点击保存修改按钮完成上传', 'success');
        }
        reader.readAsDataURL(file);
      }
    });

    // 表单重置功能
    function resetForm() {
      if (confirm('确定要重置表单吗？所有未保存的修改将丢失。')) {
        document.getElementById('profile-form').reset();
        document.getElementById('avatar-preview').src = '<?php echo !empty($user['avatar']) ? htmlspecialchars($user['avatar']) : 'img/default-avatar.png'; ?>';
        showMessage('表单已重置', 'success');
      }
    }

    // 添加表单提交确认
    document.getElementById('profile-form').addEventListener('submit', function(e) {
      if (!confirm('确定要保存这些修改吗？')) {
        e.preventDefault();
      }
    });

    // 为表单元素添加动态效果
    function addFormEffects() {
      // 为输入框添加焦点效果
      const inputs = document.querySelectorAll('.form-control');
      inputs.forEach(input => {
        // 焦点效果
        input.addEventListener('focus', function() {
          this.parentElement.classList.add('input-focused');
        });

        input.addEventListener('blur', function() {
          this.parentElement.classList.remove('input-focused');
        });

        // 输入效果
        input.addEventListener('input', function() {
          if (this.value.trim()) {
            this.classList.add('has-value');
          } else {
            this.classList.remove('has-value');
          }
        });

        // 初始化已有值的状态
        if (input.value.trim()) {
          input.classList.add('has-value');
        }
      });
    }

    // 显示消息函数
    function showMessage(message, type) {
      const alertContainer = document.createElement('div');
      alertContainer.className = `alert alert-${type}`;
      alertContainer.style.position = 'fixed';
      alertContainer.style.top = '20px';
      alertContainer.style.right = '20px';
      alertContainer.style.zIndex = '9999';
      alertContainer.style.animation = 'fadeInUp 0.3s forwards';

      const icon = document.createElement('i');
      icon.className = `fas fa-${type === 'success' ? 'check-circle' : 'exclamation-circle'}`;
      icon.style.marginRight = '10px';

      alertContainer.appendChild(icon);
      alertContainer.appendChild(document.createTextNode(message));

      document.body.appendChild(alertContainer);

      setTimeout(function() {
        alertContainer.style.animation = 'fadeOut 0.5s forwards';
        setTimeout(function() {
          alertContainer.remove();
        }, 500);
      }, 3000);
    }

    <?php if (!empty($message)): ?>
    // 如果有消息，3秒后隐藏
    setTimeout(function() {
      const alertElement = document.querySelector('.alert');
      if (alertElement) {
        alertElement.style.animation = 'fadeOut 0.5s forwards';
        setTimeout(function() {
          alertElement.style.display = 'none';
        }, 500);
      }
    }, 3000);
    <?php endif; ?>
    </script>
    <style>
    /* 头像预览动画 */
    .preview-animate {
      transform: scale(1.05);
      border-color: var(--primary-color);
      box-shadow: 0 0 0 4px rgba(74, 144, 226, 0.3);
    }

    /* 表单字段焦点样式 */
    .input-focused label {
      color: var(--primary-color);
      font-weight: 600;
    }

    /* 表单已有值的样式 */
    .has-value {
      background-color: #fff !important;
      border-color: #aaa !important;
    }

    /* 时间信息样式优化 */
    .time-info div {
      margin-bottom: 5px;
    }

    </style>
  </body>
</html>
