    <?php
// 显示所有PHP错误
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'code/auth.php';
require_once 'code/publi.php';
require_once 'code/product_data.php'; // 引入产品数据处理
require_once 'code/product_init.php'; // 引入产品初始化
require_once 'code/product_helper.php'; // 引入产品辅助函数
?>
    <!DOCTYPE html>
    <html lang="zh-CN">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>服务器产品</title>
            <?php include 'public/theme.php'; ?>
            <link rel="stylesheet" href="css/product.css">
            <script src="js/js.js"></script>
            <script src="js/product-filter.js" defer></script>
        </head>
        <body class="theme-orange">
            <div class="container">
                <?php include 'public/left.php'; ?>
                <?php // include '../config/config.php'; // 已在product_data.php中引入，不需要重复引入 ?>
                <div class="main">
                    <?php include 'public/header.php'; ?>
                    <!-- 面包屑导航 -->
                    <div class="breadcrumb-container">
                        <div class="breadcrumb">
                            <a href="index.php" class="breadcrumb-link">
                                <i class="fas fa-home"></i> 会员中心
                            </a>
                            <span class="breadcrumb-separator"><i class="fas fa-angle-right"></i></span>
                            <span class="breadcrumb-current"> 产品购买 </span>
                        </div>
                    </div>
                    <div class="content-wrapper">
                        <!-- 调试信息 -->
                        <?php if (isset($db) && $db): ?>
                        <div style="padding: 10px; margin-bottom: 10px; background: #d4edda; color: #155724; border-radius: 4px; display: none;">
                            数据库连接正常
                        </div>
                        <?php else: ?>
                        <div style="padding: 10px; margin-bottom: 10px; background: #f8d7da; color: #721c24; border-radius: 4px;">
                            数据库连接异常，请检查配置
                        </div>
                        <?php endif; ?>
                        <div class="content" id="mainContent">
                            <!-- 产品过滤区 -->
                            <div class="product-filter">
                                <div class="filter-section">
                                    <div class="filter-title">地域分布</div>
                                    <div class="filter-options">
                                        <!-- 国家选项 -->
                                        <?php foreach ($parentRegions as $parent): ?>
                                        <a href="javascript:void(0);"
                                           class="filter-option country-option <?php echo $selectedParentForDisplay == $parent['id'] ? 'active' : ''; ?>"
                                           data-parent="<?php echo $parent['id']; ?>"
                                           data-filter="parent_region"
                                           data-value="<?php echo $parent['id']; ?>">
                                            <?php echo $parent['name']; ?>
                                        </a>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                                <div class="filter-section" id="region-filter-section"
                                     style="<?php echo empty($childRegionsByParent[$selectedParentForDisplay]) ? 'display:none;' : ''; ?>">
                                    <div class="filter-title">城市/区域</div>
                                    <div class="filter-options">
                                        <?php foreach ($parentRegions as $parent): ?>
                                        <div class="region-group <?php echo $selectedParentForDisplay == $parent['id'] ? 'active' : ''; ?>"
                                             style="display: <?php echo $selectedParentForDisplay == $parent['id'] ? 'flex' : 'none'; ?>;"
                                             data-parent="<?php echo $parent['id']; ?>">
                                            <?php if (isset($childRegionsByParent[$parent['id']])): ?>
                                            <?php foreach ($childRegionsByParent[$parent['id']] as $child): ?>
                                            <a href="javascript:void(0);"
                                               class="filter-option <?php echo $selectedRegion == $child['id'] ? 'active' : ''; ?>"
                                               data-filter="region" data-value="<?php echo $child['id']; ?>">
                                                <?php echo $child['name']; ?>
                                            </a>
                                            <?php endforeach; ?>
                                            <?php else: ?>
                                            <!-- 如果没有子地区，不显示任何地区选项 -->
                                            <?php endif; ?>
                                        </div>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                                <!-- 为每个一级标签创建一个筛选区块 -->
                                <?php foreach ($parentTags as $parent): ?>
                                <div class="filter-section">
                                    <div class="filter-title"><?php echo htmlspecialchars($parent['name']); ?></div>
                                    <div class="filter-options">
                                        <?php if (isset($childTagsByParent[$parent['id']])): ?>
                                        <?php foreach ($childTagsByParent[$parent['id']] as $child): ?>
                                        <a href="javascript:void(0);"
                                           class="filter-option <?php echo $selectedTag == $child['id'] ? 'active' : ''; ?>"
                                           data-filter="tag" data-value="<?php echo $child['id']; ?>">
                                            <?php echo htmlspecialchars($child['name']); ?>
                                        </a>
                                        <?php endforeach; ?>
                                        <?php else: ?>
                                        <!-- 如果没有子类型，显示"全部"选项 -->
                                        <a href="javascript:void(0);" class="filter-option active" data-filter="tag" data-value="0">全部</a>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <?php endforeach; ?>
                                <div class="filter-section">
                                    <div class="filter-title">价格</div>
                                    <div class="filter-options">
                                        <?php foreach ($priceRanges as $range): ?>
                                        <a href="javascript:void(0);"
                                           class="filter-option <?php echo ($selectedMinPrice == $range['min'] && $selectedMaxPrice == $range['max']) ? 'active' : ''; ?>"
                                           data-filter="price" data-min="<?php echo $range['min']; ?>" data-max="<?php echo $range['max']; ?>">
                                            <?php echo $range['label']; ?>
                                        </a>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                                <!-- 筛选结果统计 -->
                                <div id="filter-summary" class="filter-summary" style="display: none;">
                                    <div class="filter-count">符合您选择共计 <span id="product-count">0</span> 款产品</div>
                                    <a href="javascript:void(0);" id="clear-filters" class="clear-filters">
                                        <i class="fas fa-times" style="font-size: 16px; vertical-align: middle; margin-right: 4px;"></i>清除重选
                                    </a>
                                </div>
                            </div>
                            <!-- 排序选项 -->
                            <div class="product-sort">
                                <span class="sort-label">排序方式：</span>
                                <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'recommended' ? 'active' : ''; ?>" data-sort="recommended">默认</a>
                                <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'price' ? 'active' : ''; ?>" data-sort="price" data-current-order="<?php echo $sortOrder; ?>">价格
                                    <i class="fas <?php echo ($sortBy == 'price' && $sortOrder == 'desc') ? 'fa-arrow-up' : 'fa-arrow-down'; ?>"></i>
                                </a>
                                <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'created' ? 'active' : ''; ?>" data-sort="created" data-current-order="<?php echo $sortOrder; ?>">上架时间
                                    <i class="fas <?php echo ($sortBy == 'created' && $sortOrder == 'asc') ? 'fa-arrow-up' : 'fa-arrow-down'; ?>"></i>
                                </a>
                            </div>
                            <!-- 产品列表 -->
                            <div class="product-list list-view">
                                <?php if (empty($products)): ?>
                                <div class="no-products">
                                    <i class="fas fa-search"></i>
                                    <p>没有找到符合条件的产品</p>
                                    <p class="no-products-subtext">您可以尝试更换筛选条件或联系客服获取帮助</p>
                                </div>
                                <?php else: ?>
                                <!-- 表格头部 -->
                                <table class="server-table">
                                    <thead>
                                        <tr>
                                            <th>CPU</th>
                                            <th>内存</th>
                                            <th>硬盘</th>
                                            <th>宽带</th>
                                            <th>流量</th>
                                            <th>IP</th>
                                            <th>DDOS防御</th>
                                            <th>金额</th>
                                            <th>操作</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($products as $product): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($product['upc'] ?? '未设置'); ?></td>
                                            <td><?php echo htmlspecialchars($product['memory'] ?? '未设置'); ?></td>
                                            <td><?php echo htmlspecialchars($product['disk'] ?? '未设置'); ?></td>
                                            <td><?php echo htmlspecialchars($product['bandwidth'] ?? '未设置'); ?></td>
                                            <td><?php echo getTrafficDisplay($product['traffic']); ?></td>
                                            <td><?php echo htmlspecialchars($product['ip_count'] ?? '未设置'); ?>个</td>
                                            <td><?php echo getDefenseDisplay($product['defense']); ?></td>
                                            <td class="price"><?php echo getPriceDisplay($product['price'], $product['original_price'] ?? null, false); ?></td>
                                            <td>
                                                <a href="/cn/cart.php?id=<?php echo $product['id']; ?>" class="buy-btn">现在订购</a>
                                                <a href="<?= $Telegram ?>" class="buy-btn" target="_blank">申请试用</a>
                                            </td>
                                        </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                                <?php endif; ?>
                            </div>
                            <!-- 分页 -->
                            <?php echo generatePagination($currentPage, $totalPages); ?>
                        </div>
                    </div>
                </div>
            </div>
            <script>
            // 在这里添加产品页面php变量到js的桥接代码
            // 这些变量会被product-filter.js使用
            const selectedTag = <?php echo $selectedTag ?: 0; ?>;
            const selectedRegion = <?php echo $selectedRegion ?: 0; ?>;
            const selectedParent = <?php echo $selectedParent ?: 0; ?>;
            const selectedMinPrice = <?php echo $selectedMinPrice ? "'" . $selectedMinPrice . "'" : 'null'; ?>;
            const selectedMaxPrice = <?php echo $selectedMaxPrice ? "'" . $selectedMaxPrice . "'" : 'null'; ?>;
            const sortBy = '<?php echo $sortBy ?: 'recommended'; ?>';
            const sortOrder = '<?php echo $sortOrder ?: ''; ?>';
            const currentPage = <?php echo $currentPage ?: 1; ?>;
            </script>
        </body>
    </html>
