<?php
// 设置显示所有错误
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

echo "<h1>产品页面诊断工具</h1>";

// 1. 检查必要文件是否存在
echo "<h2>1. 文件存在性检查</h2>";
$requiredFiles = [
    '../config/database.php',
    'code/auth.php',
    'code/publi.php',
    'code/product_data.php',
    'code/product_init.php',
    'code/product_helper.php',
    'js/product-filter.js',
    'css/product.css'
];

foreach ($requiredFiles as $file) {
    $filePath = $file;
    $fileExists = file_exists($filePath);
    echo "文件 <code>$file</code>: " . ($fileExists ? '<span style="color:green">存在</span>' : '<span style="color:red">不存在</span>') . "<br>";
}

// 2. 尝试包含必要的PHP文件
echo "<h2>2. 包含文件测试</h2>";
try {
    echo "尝试加载 database.php... ";
    require_once '../config/database.php';
    echo '<span style="color:green">成功</span><br>';
    
    echo "尝试加载 auth.php... ";
    require_once 'code/auth.php';
    echo '<span style="color:green">成功</span><br>';
    
    echo "尝试加载 publi.php... ";
    require_once 'code/publi.php';
    echo '<span style="color:green">成功</span><br>';
    
    echo "尝试加载 product_data.php... ";
    require_once 'code/product_data.php';
    echo '<span style="color:green">成功</span><br>';
    
    echo "尝试加载 product_init.php... ";
    require_once 'code/product_init.php';
    echo '<span style="color:green">成功</span><br>';
    
    echo "尝试加载 product_helper.php... ";
    require_once 'code/product_helper.php';
    echo '<span style="color:green">成功</span><br>';
} catch (Exception $e) {
    echo '<span style="color:red">错误: ' . $e->getMessage() . '</span><br>';
}

// 3. 检查数据库连接
echo "<h2>3. 数据库连接测试</h2>";
if (function_exists('getDbConnection')) {
    try {
        $db = getDbConnection();
        if ($db) {
            echo '<span style="color:green">数据库连接成功!</span><br>';
            
            // 测试简单查询
            echo "测试简单查询... ";
            $stmt = $db->query("SELECT 1");
            $result = $stmt->fetchAll();
            if ($result) {
                echo '<span style="color:green">成功</span><br>';
            } else {
                echo '<span style="color:red">失败</span><br>';
            }
            
            // 测试区域表
            echo "测试查询 area 表... ";
            try {
                $stmt = $db->query("SELECT COUNT(*) as count FROM area");
                $result = $stmt->fetch();
                echo '<span style="color:green">成功 (共' . $result['count'] . '条记录)</span><br>';
            } catch (PDOException $e) {
                echo '<span style="color:red">失败 (' . $e->getMessage() . ')</span><br>';
            }
            
            // 测试产品表
            echo "测试查询 products 表... ";
            try {
                $stmt = $db->query("SELECT COUNT(*) as count FROM products");
                $result = $stmt->fetch();
                echo '<span style="color:green">成功 (共' . $result['count'] . '条记录)</span><br>';
            } catch (PDOException $e) {
                echo '<span style="color:red">失败 (' . $e->getMessage() . ')</span><br>';
            }
            
            // 测试标签表
            echo "测试查询 tags 表... ";
            try {
                $stmt = $db->query("SELECT COUNT(*) as count FROM tags");
                $result = $stmt->fetch();
                echo '<span style="color:green">成功 (共' . $result['count'] . '条记录)</span><br>';
            } catch (PDOException $e) {
                echo '<span style="color:red">失败 (' . $e->getMessage() . ')</span><br>';
            }
        } else {
            echo '<span style="color:red">数据库连接失败!</span><br>';
        }
    } catch (PDOException $e) {
        echo '<span style="color:red">数据库连接错误: ' . $e->getMessage() . '</span><br>';
    }
} else {
    echo '<span style="color:red">getDbConnection 函数不存在!</span><br>';
}

// 4. 测试产品筛选功能
echo "<h2>4. 产品数据获取测试</h2>";
if (function_exists('getProductsList') && isset($db) && $db) {
    try {
        $filters = getCurrentFilters();
        echo "当前筛选条件: <pre>" . print_r($filters, true) . "</pre>";
        
        $productsData = getProductsList($db, $filters);
        echo "获取产品列表... ";
        if (isset($productsData['products'])) {
            echo '<span style="color:green">成功 (共' . count($productsData['products']) . '条产品)</span><br>';
            
            if (count($productsData['products']) > 0) {
                echo "第一个产品信息: <pre>" . print_r($productsData['products'][0], true) . "</pre>";
            } else {
                echo '<span style="color:orange">警告: 没有找到产品</span><br>';
            }
        } else {
            echo '<span style="color:red">失败</span><br>';
        }
    } catch (Exception $e) {
        echo '<span style="color:red">产品数据获取错误: ' . $e->getMessage() . '</span><br>';
    }
}

// 5. 检查变量初始化
echo "<h2>5. 变量初始化测试</h2>";
$requiredVars = [
    'selectedTag',
    'selectedParent',
    'selectedRegion', 
    'selectedParentForDisplay',
    'selectedMinPrice',
    'selectedMaxPrice',
    'sortBy',
    'sortOrder',
    'currentPage',
    'totalPages',
    'products',
    'parentRegions',
    'parentTags'
];

foreach ($requiredVars as $var) {
    echo "变量 \$$var: " . (isset($$var) ? '<span style="color:green">已定义</span>' : '<span style="color:red">未定义</span>') . '<br>';
}

echo "<h2>结论</h2>";
echo "如果您看到任何红色错误消息，请修复相应问题。绿色消息表示该项测试通过。";
?> 