<!DOCTYPE html>
<html lang="zh-CN">
  <?php
  // 先定义ROOT_PATH（如果不存在）
  if (!defined('ROOT_PATH')) {
      define('ROOT_PATH', dirname(__DIR__));
  }
  
  // 引入配置文件
  include ROOT_PATH . '/public/config.php';
  
  // 引入视频列表代码
  require_once ROOT_PATH . '/code/video_list_code.php';
  ?>
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title><?php echo htmlspecialchars($category['name']); ?> - 视频教程</title>
    <?php echo getCommonCss(); ?>
    <link href="/public/css/video_list.css" rel="stylesheet" />
  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include ROOT_PATH . '/public/header.php'; ?>
    <div class="main-content">
      <?php include ROOT_PATH . '/public/banner.php'; ?>
      <div class="ip-matrix-content">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/"> 首页 </a>
            <i class="material-icons">chevron_right</i>
            <a href="/video"> 视频教程 </a>
            <i class="material-icons">chevron_right</i>
            <span><?php echo htmlspecialchars($category['name']); ?></span>
          </div>
        </div>
        <div class="container">
          <div class="category-header">
            <h1><?php echo htmlspecialchars($category['name']); ?></h1>
            <p><?php echo htmlspecialchars($category['description']); ?></p>
          </div>
          <?php if (!empty($videos)): ?>
          <div class="script-grid">
            <?php foreach ($videos as $video): ?>
            <a href="/video/<?php echo $video['id']; ?>.html" class="script-card">
              <div class="script-card-image">
                <img src="<?php echo !empty($video['thumbnail']) ? htmlspecialchars($video['thumbnail']) : 'http://temp.im/320x180'; ?>" alt="<?php echo htmlspecialchars($video['title']); ?>">
                <span class="duration-tag"><?php echo htmlspecialchars($video['duration']); ?></span>
                <div class="play-icon"></div>
              </div>
              <div class="script-card-content">
                <h3><?php echo htmlspecialchars($video['title']); ?></h3>
              </div>
            </a>
            <?php endforeach; ?>
          </div>
          <!-- 分页 -->
          <?php if ($totalPages > 1): ?>
          <div class="pagination">
            <?php if ($page > 1): ?>
            <a href="/video/list/<?php echo $category_id; ?>?page=1">首页</a>
            <a href="/video/list/<?php echo $category_id; ?>?page=<?php echo $page - 1; ?>">上一页</a>
            <?php else: ?>
            <span class="disabled">首页</span>
            <span class="disabled">上一页</span>
            <?php endif; ?>
            <?php
                        // 显示页码，最多显示5个页码
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $startPage + 4);
                        
                        if ($endPage - $startPage < 4) {
                            $startPage = max(1, $endPage - 4);
                        }
                        
                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
            <?php if ($i == $page): ?>
            <span class="current"><?php echo $i; ?></span>
            <?php else: ?>
            <a href="/video/list/<?php echo $category_id; ?>?page=<?php echo $i; ?>"><?php echo $i; ?></a>
            <?php endif; ?>
            <?php endfor; ?>
            <?php if ($page < $totalPages): ?>
            <a href="/video/list/<?php echo $category_id; ?>?page=<?php echo $page + 1; ?>">下一页</a>
            <a href="/video/list/<?php echo $category_id; ?>?page=<?php echo $totalPages; ?>">末页</a>
            <?php else: ?>
            <span class="disabled">下一页</span>
            <span class="disabled">末页</span>
            <?php endif; ?>
          </div>
          <?php endif; ?>
          <?php else: ?>
          <div class="no-results">
            <p>该分类下暂无视频内容，请稍后再来查看。</p>
          </div>
          <?php endif; ?>
        </div>
      </div>
    </div>
    <!-- 页脚 -->
    <?php include ROOT_PATH . '/public/kf.php'; ?>
    <?php include ROOT_PATH . '/public/footer.php'; ?>
    <script src="/public/js/js.js"></script>
  </body>
</html>
