<!DOCTYPE html>
<html lang="zh-CN">
  <?php
  // 先定义ROOT_PATH（如果不存在）
  if (!defined('ROOT_PATH')) {
      define('ROOT_PATH', dirname(__DIR__));
  }
  
  // 引入配置文件
  include ROOT_PATH . '/public/config.php';
  
  // 引入视频详情代码
  include ROOT_PATH . '/code/video_detail_code.php';
  ?>
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title><?php echo $currentVideo['title']; ?> - <?= $SiteName ?></title>
    <?php echo getCommonCss(); ?>
    <link href="/public/css/video-detail.css" rel="stylesheet" />
  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include ROOT_PATH . '/public/header.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <?php include ROOT_PATH . '/public/banner.php'; ?>
      <div class="ip-matrix-content">
        <!-- 面包屑导航 -->
        <div class="container">
          <div class="breadcrumb">
            <a href="/"> 首页 </a>
            <i class="material-icons">chevron_right</i>
            <a href="/video"> 视频教程 </a>
            <i class="material-icons">chevron_right</i>
            <?php if (!empty($currentVideo['category_id']) && !empty($currentVideo['category_name'])): ?>
            <a href="/video/list/<?php echo $currentVideo['category_id']; ?>"> <?php echo $currentVideo['category_name']; ?> </a>
            <i class="material-icons">chevron_right</i>
            <?php endif; ?>
            <span>视频详情</span>
          </div>
        </div>
        <!-- 视频播放区域 -->
        <section class="video-detail-section">
          <div class="container">
            <div class="video-detail-container">
              <!-- 左侧视频和内容 -->
              <div class="video-main-content">
                <!-- 视频播放器 -->
                <div class="video-player-container">
                  <div class="video-player">
                    <?php 
                                        // 检查视频URL并输出调试信息
                                        $video_url = $currentVideo['video_url'] ?? '';
                                        $embed_url = '';
                                        
                                        if(!empty($video_url)) {
                                            $embed_url = getYoutubeEmbedUrl($video_url);
                                            // 输出注释形式的调试信息
                                            echo "<!-- 原始视频URL: " . htmlspecialchars($video_url) . " -->\n";
                                            echo "<!-- 嵌入URL: " . htmlspecialchars($embed_url) . " -->\n";
                                        
                                            // 直接嵌入YouTube iframe
                                            ?>
                    <iframe id="youtubePlayer"
                            src="<?php echo $embed_url; ?>"
                            data-id="<?php echo $videoId; ?>"
                            width="100%"
                            height="100%"
                            frameborder="0"
                            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                            allowfullscreen>
                    </iframe>
                    <?php } else { ?>
                    <div class="video-placeholder">
                      <img src="<?php echo $currentVideo['thumbnail'] ?: 'http://temp.im/1280x720'; ?>" alt="<?php echo $currentVideo['title']; ?>">
                      <div class="placeholder-text">视频内容准备中...</div>
                    </div>
                    <?php } ?>
                  </div>
                </div>
                <!-- 视频信息 -->
                <div class="video-info">
                  <h1 class="video-title"><?php echo $currentVideo['title']; ?></h1>
                  <div class="video-meta">
                    <span class="video-views"><i class="material-icons">visibility</i> <?php echo $currentVideo['views_formatted']; ?>次观看</span>
                    <span class="video-date"><i class="material-icons">access_time</i> <?php echo date('Y-m-d', strtotime($currentVideo['created_at'])); ?></span>
                    <span class="video-duration"><i class="material-icons">timer</i> <?php echo $currentVideo['duration']; ?></span>
                    <?php if (!empty($currentVideo['category_name'])): ?>
                    <span class="video-category"><i class="material-icons">category</i> <?php echo $currentVideo['category_name']; ?></span>
                    <?php endif; ?>
                  </div>
                  <div class="video-actions">
                    <button class="action-btn like-btn" data-id="<?php echo $videoId; ?>">
                      <i class="material-icons">thumb_up</i> 赞(<?php echo $currentVideo['likes']; ?>)
                    </button>
                    <button class="action-btn share-btn">
                      <i class="material-icons">share</i> 分享
                    </button>
                    <button class="action-btn save-btn" data-id="<?php echo $videoId; ?>">
                      <i class="material-icons">bookmark</i> 收藏
                    </button>
                  </div>
                  <?php if (!empty($tags)): ?>
                  <div class="video-tags">
                    <?php foreach ($tags as $tag): ?>
                    <span class="tag"><?php echo $tag['name']; ?></span>
                    <?php endforeach; ?>
                  </div>
                  <?php endif; ?>
                </div>
                <!-- 视频描述 -->
                <div class="video-description">
                  <h3>视频简介</h3>
                  <div class="description-content">
                    <?php 
                                        // 如果描述为空，显示默认提示信息
                                        if (empty(trim($currentVideo['description']))) {
                                            echo '<p class="no-description">暂无视频简介内容...</p>';
                                        } else {
                                            // 输出经过安全处理的内容，但保留HTML格式
                                            echo $currentVideo['description']; 
                                        }
                                        ?>
                  </div>
                </div>
                <!-- 评论区 -->
                <div class="video-comments">
                  <h3>评论 (<?php echo $commentCount; ?>)</h3>
                  <div class="comment-form">
                    <form id="commentForm">
                      <input type="hidden" name="video_id" value="<?php echo $videoId; ?>">
                      <textarea placeholder="写下您的评论..."></textarea>
                      <button type="submit" class="comment-submit">发表评论</button>
                    </form>
                  </div>
                  <div class="comments-list">
                    <?php foreach ($comments as $comment): ?>
                    <div class="comment-item" data-id="comment-<?php echo $comment['id']; ?>">
                      <div class="comment-avatar">
                        <img src="http://temp.im/40x40" alt="用户头像">
                      </div>
                      <div class="comment-content">
                        <div class="comment-header">
                          <span class="comment-author"><?php echo !empty($comment['author_name']) ? $comment['author_name'] : ($comment['username'] ?: '匿名用户'); ?></span>
                          <span class="comment-time"><?php echo date('Y-m-d', strtotime($comment['created_at'])); ?></span>
                        </div>
                        <div class="comment-text">
                          <?php echo htmlspecialchars($comment['content']); ?>
                        </div>
                        <div class="comment-actions">
                          <a href="#" class="comment-like" data-id="<?php echo $comment['id']; ?>">
                            <i class="material-icons">thumb_up_off_alt</i> <span><?php echo $comment['likes']; ?></span>
                          </a>
                          <a href="#" class="comment-reply" data-id="<?php echo $comment['id']; ?>">回复</a>
                        </div>
                      </div>
                    </div>
                    <?php endforeach; ?>
                    <?php if (empty($comments)): ?>
                    <div class="no-comments">
                      <p>暂无评论，快来发表第一条评论吧！</p>
                    </div>
                    <?php endif; ?>
                  </div>
                  <?php if (count($comments) < $commentCount): ?>
                  <div class="view-more-comments">
                    <button data-video-id="<?php echo $videoId; ?>">查看更多评论</button>
                  </div>
                  <?php endif; ?>
                </div>
              </div>
              <!-- 右侧推荐视频 -->
              <div class="video-sidebar">
                <div class="sidebar-header">
                  <h3>推荐视频</h3>
                </div>
                <div class="recommended-videos">
                  <?php
                  // 获取推荐视频（页面级别操作，确保无论如何都有内容显示）
                  $page_related_videos = [];
                  $target_count = 10; // 目标推荐视频数量，从5增加到10
                  
                  try {
                      require_once ROOT_PATH . '/config/database.php';
                      $db = getDbConnection();
                      
                      // 1. 尝试获取同分类视频
                      $sql = "SELECT * FROM videos WHERE category_id = :category_id AND id != :video_id AND status = 1 ORDER BY views DESC LIMIT :limit";
                      $stmt = $db->prepare($sql);
                      $stmt->bindValue(':category_id', $currentVideo['category_id'], PDO::PARAM_INT);
                      $stmt->bindValue(':video_id', $videoId, PDO::PARAM_INT);
                      $stmt->bindValue(':limit', $target_count, PDO::PARAM_INT);
                      $stmt->execute();
                      $page_related_videos = $stmt->fetchAll(PDO::FETCH_ASSOC);
                      
                      // 2. 如果同分类视频不足目标数量，获取其他分类的热门视频
                      if (count($page_related_videos) < $target_count) {
                          $remaining = $target_count - count($page_related_videos);
                          
                          // 已有视频的ID，用于排除
                          $existing_ids = array_column($page_related_videos, 'id');
                          $existing_ids[] = $videoId; // 加上当前视频
                          $ids_to_exclude = implode(',', $existing_ids);
                          
                          // 如果有排除的ID，添加到查询条件
                          $exclude_condition = !empty($ids_to_exclude) ? "AND id NOT IN ($ids_to_exclude)" : "AND id != $videoId";
                          
                          // 获取其他分类的热门视频（按观看量排序）
                          $random_sql = "SELECT * FROM videos 
                                         WHERE status = 1 
                                         $exclude_condition
                                         AND category_id != :category_id
                                         ORDER BY views DESC, RAND() 
                                         LIMIT :limit";
                          
                          $random_stmt = $db->prepare($random_sql);
                          $random_stmt->bindValue(':category_id', $currentVideo['category_id'], PDO::PARAM_INT);
                          $random_stmt->bindValue(':limit', $remaining, PDO::PARAM_INT);
                          $random_stmt->execute();
                          $random_videos = $random_stmt->fetchAll(PDO::FETCH_ASSOC);
                          
                          // 合并结果
                          $page_related_videos = array_merge($page_related_videos, $random_videos);
                      }
                      
                      // 3. 如果仍然不足，获取所有分类的随机视频
                      if (count($page_related_videos) < $target_count) {
                          $remaining = $target_count - count($page_related_videos);
                          
                          // 已有视频的ID，用于排除
                          $existing_ids = array_column($page_related_videos, 'id');
                          $existing_ids[] = $videoId; // 加上当前视频
                          $ids_to_exclude = implode(',', $existing_ids);
                          
                          // 如果有排除的ID，添加到查询条件
                          $exclude_condition = !empty($ids_to_exclude) ? "AND id NOT IN ($ids_to_exclude)" : "AND id != $videoId";
                          
                          // 完全随机获取视频
                          $fallback_sql = "SELECT * FROM videos 
                                          WHERE status = 1 
                                          $exclude_condition
                                          ORDER BY RAND() 
                                          LIMIT :limit";
                          
                          $fallback_stmt = $db->prepare($fallback_sql);
                          $fallback_stmt->bindValue(':limit', $remaining, PDO::PARAM_INT);
                          $fallback_stmt->execute();
                          $fallback_videos = $fallback_stmt->fetchAll(PDO::FETCH_ASSOC);
                          
                          // 合并结果
                          $page_related_videos = array_merge($page_related_videos, $fallback_videos);
                      }
                  } catch (Exception $e) {
                      // 出错时使用之前的数组
                      $page_related_videos = $relatedVideos ?? [];
                  }
                  
                  // 如果页面级操作也失败，确保至少有一个默认项
                  if (empty($page_related_videos)) {
                      $page_related_videos = [
                          [
                              'id' => 0,
                              'title' => '暂无推荐视频',
                              'thumbnail' => 'http://temp.im/120x68',
                              'duration' => '0:00',
                              'views' => 0
                          ]
                      ];
                  }
                  ?>

                  <?php foreach ($page_related_videos as $video): ?>
                  <a href="<?php echo $video['id'] > 0 ? '/video/' . $video['id'] . '.html' : 'javascript:void(0);'; ?>" class="rec-video-item">
                    <div class="rec-video-thumbnail">
                      <img src="<?php echo $video['thumbnail'] ?: 'http://temp.im/120x68'; ?>" alt="视频缩略图">
                      <span class="rec-duration"><?php echo $video['duration']; ?></span>
                    </div>
                    <div class="rec-video-info">
                      <h4><?php echo $video['title']; ?></h4>
                      <span class="rec-video-views"><?php echo isset($video['views']) ? number_format($video['views'], 0, '.', ',') : '0'; ?>次观看</span>
                    </div>
                  </a>
                  <?php endforeach; ?>
                </div>
              </div>
            </div>
          </div>
        </section>
      </div>
    </div>
    <!-- 页脚 -->
    <?php include ROOT_PATH . '/public/kf.php'; ?>
    <?php include ROOT_PATH . '/public/footer.php'; ?>
    <script src="/public/js/js.js"></script>
    <script src="/public/js/video-detail.js"></script>
  </body>
</html>
